(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    513087,      10064]
NotebookOptionsPosition[    505730,       9831]
NotebookOutlinePosition[    506263,       9852]
CellTagsIndexPosition[    506220,       9849]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introducing the Outbreak Threshold", "Title",
 Evaluatable->False,
 CellChangeTimes->{{3.4789081330530443`*^9, 3.478908148378318*^9}, {
  3.4789081940845013`*^9, 3.478908201563307*^9}, {3.48743644712309*^9, 
  3.487436456063019*^9}, {3.557722049870167*^9, 3.5577220583167562`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Matthew Hartfield & Samuel Alizon\n\n",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->24],
 StyleBox["Correspondence to ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14],
 StyleBox["matthew.hartfield@ird.fr",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14,
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->14]
}], "Subtitle",
 Evaluatable->False,
 CellChangeTimes->{{3.4789082049440117`*^9, 3.478908219493101*^9}, {
   3.487436423837699*^9, 3.4874364267275953`*^9}, {3.557722061276516*^9, 
   3.557722064379727*^9}, {3.561369200355567*^9, 3.5613692374798594`*^9}, 
   3.5705334384107*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Supplementary Material S.1: The outbreak threshold in a homogeneous population\
\>", "Section",
 CellChangeTimes->{{3.560244801427236*^9, 3.560244811320553*^9}, {
   3.560245016252426*^9, 3.56024505860182*^9}, 3.561366672476305*^9}],

Cell[TextData[{
 "The basic idea is that in a finite host population of size ",
 StyleBox["N",
  FontSlant->"Italic"],
 ", an out",
 StyleBox["break has occured w",
  FontColor->RGBColor[0., 0., 0.]],
 "hen enough infected individuals are present so that the probability of \
pathogen extinction due to stochastic loss is essentially zero. As a \
framework for investigating this, we will use a basic \
\[OpenCurlyQuote]susceptible-infected-removed\[CloseCurlyQuote] (SIR) or \
\[OpenCurlyQuote]susceptible-infected-susceptible\[CloseCurlyQuote] (SIS) \
type of infection [Anderson and May 1991]. The process of interest is the \
rate of change of infected individuals over time, which in both these models \
is equal to: "
}], "Text",
 CellChangeTimes->{{3.561366662383978*^9, 3.561366702382846*^9}, {
  3.5613697376524487`*^9, 3.561369745954976*^9}, {3.5613772664212217`*^9, 
  3.561377267343587*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["dI", "dt"], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Beta]", " ", 
      FractionBox["S", "N"]}], "-", "\[Delta]"}], ")"}], "I"}]}]], "Input",
 CellChangeTimes->{{3.561366725263681*^9, 3.561366742117442*^9}}],

Cell[TextData[{
 "Where \[Beta] is the contact rate, 1/\[Delta] the mea",
 StyleBox["n duration of an infe",
  FontColor->RGBColor[0., 0., 0.]],
 "ction, and ",
 StyleBox["S",
  FontSlant->"Italic"],
 " the total number of susceptible individuals at time ",
 StyleBox["t",
  FontSlant->"Italic"],
 ". If the whole population is susceptible, then ",
 StyleBox["S",
  FontSlant->"Italic"],
 " = ",
 StyleBox["N",
  FontSlant->"Italic"],
 ", and so the initial growth rate is equal to \[Beta]/\[Delta] = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ". This is the reproductive ratio of the infection, the number of secondary \
infections caused by a single infected h",
 StyleBox["ost in a population that is entirely susceptible [Anderson an",
  FontColor->RGBColor[0., 0., 0.]],
 "d May 1991]. \n\nIn a stochastic model, the probability of extinction is \
equal to \[Delta]/\[Beta] = 1/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " [Grimmett and Stirzaker 2001, Hubbarde ",
 StyleBox["et al.",
  FontSlant->"Italic"],
 " 2007]. Furthermore, if we assume that the population size is large enough \
so ",
 StyleBox["that",
  FontColor->RGBColor[0., 0., 0.]],
 " S \[TildeEqual] N as the outbreak is emerging (that is, there are enough \
susceptible hosts present to carry and spread a potential epidemic), then \
each infected individual has a reproductive ratio approximately equal to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ". Therefore, if there are ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " infected individuals present at time ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", the overall probability of extinction of the entire pathogen population \
approximately equals ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "/", 
      SubscriptBox["R", "0"]}], ")"}], 
    SubscriptBox["I", "t"]], TraditionalForm]]],
 " [May ",
 StyleBox["et al.",
  FontSlant->"Italic"],
 " 2001, Allen 2008].\n\nWe want to find the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "t"], " ", "=", " ", 
    SubscriptBox["T", "0"]}], TraditionalForm]]],
 " so that the probability of extinction drops below a certain threshold, ",
 StyleBox["c",
  FontSlant->"Italic"],
 ". To find this we need to solve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "/", 
       SubscriptBox["R", "0"]}], ")"}], 
     SubscriptBox["T", "0"]], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["R", "0"], 
      RowBox[{"-", 
       SubscriptBox["T", "0"]}]], " ", "=", " ", "c"}]}], TraditionalForm]]],
 ", which is easily done:"
}], "Text",
 CellChangeTimes->{{3.561366753299479*^9, 3.5613668185728703`*^9}, {
   3.5613668893037252`*^9, 3.561367072761291*^9}, {3.561367325228169*^9, 
   3.5613673459077663`*^9}, {3.561377525356579*^9, 3.561377600144459*^9}, {
   3.561380939774624*^9, 3.5613809424040947`*^9}, {3.561380980529068*^9, 
   3.5613809836342983`*^9}, 3.561440253285943*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     SubscriptBox["R", "0"], 
     RowBox[{"-", 
      SubscriptBox["T", "0"]}]], "\[Equal]", "c"}], ",", 
   SubscriptBox["T", "0"]}], "]"}]], "Input",
 CellChangeTimes->{{3.560245088060513*^9, 3.5602451024473333`*^9}, {
  3.561367349442281*^9, 3.561367369249999*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ifun"}], "MessageName"], ":", 
  " ", "\<\"Inverse functions are being used by \[NoBreak]\\!\\(Solve\\)\
\[NoBreak], so some solutions may not be found; use Reduce for complete \
solution information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5613673697794027`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["T", "0"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Log", "[", "c", "]"}], 
      RowBox[{"Log", "[", 
       SubscriptBox["R", "0"], "]"}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.560245103151409*^9, {3.561367351425803*^9, 3.561367369781652*^9}}]
}, Open  ]],

Cell[TextData[{
 "This highlights the main result that ",
 StyleBox["on the order of ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]],
  FontWeight->"Bold"],
 StyleBox[") infected individuals are needed to maintain an infection in a \
homogeneous population. \n\n",
  FontWeight->"Bold"],
 "We are also interested in finding a general result for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 ", which does not depend on a cutoff value ",
 StyleBox["c",
  FontSlant->"Italic"],
 ". We can show this asymptotically. Ideally we want to find a solution to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["R", "0"], 
     RowBox[{"-", 
      SubscriptBox["T", "0"]}]], " ", "=", " ", "0"}], TraditionalForm]]],
 ", but a solution does not exist. We can find an approximate solution by \
writing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "0"], " "}], TraditionalForm]],
  CellChangeTimes->{{3.560245088060513*^9, 3.5602451024473333`*^9}, {
   3.561367349442281*^9, 3.5613673654497766`*^9}}],
 "= ",
 StyleBox["N",
  FontSlant->"Italic"],
 " \[Xi], and solving to find the proportion of individuals needed \[Xi], if \
\[Xi] << 1. Taking a Taylor series around \[Xi] = 0:"
}], "Text",
 CellChangeTimes->{{3.560245125541545*^9, 3.560245183038089*^9}, {
   3.561367376838011*^9, 3.561367380900302*^9}, 3.5613688825895987`*^9, {
   3.5613776504805717`*^9, 3.561377654037509*^9}, {3.561392617272832*^9, 
   3.561392634952227*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["R", "0"], 
     RowBox[{
      RowBox[{"-", "N"}], " ", "\[Xi]"}]], ",", 
    RowBox[{"{", 
     RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5563611863297586`*^9, 3.556361223385437*^9}, 
   3.556366251436844*^9, {3.5577255951306477`*^9, 3.557725596400478*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"N", " ", "\[Xi]", " ", 
   RowBox[{"Log", "[", 
    SubscriptBox["R", "0"], "]"}]}]}]], "Output",
 CellChangeTimes->{3.557725602531705*^9}]
}, Open  ]],

Cell[TextData[{
 "Solving this equal to zero gives ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " = N\[Xi] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 "), highlighting how ",
 StyleBox["at least this many infected individuals are needed to guarantee an \
outbreak. ",
  FontWeight->"Bold"],
 StyleBox["Note that this derivation implicitly assumes that N is finite; if \
N goes to infinity then it is clear that ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["R", "0"], 
    RowBox[{"-", 
     StyleBox[
      RowBox[{
       StyleBox["N",
        FontSlant->"Italic"], "\[Xi]"}]]}]], TraditionalForm]],
  FontColor->GrayLevel[0]],
 StyleBox[" goes to zero, so no solution to \[Xi] exists. This makes sense, \
since in such an infinite population an outbreak will not go extinct if ",
  FontColor->GrayLevel[0]],
 StyleBox["I",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox[" = 1 and ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontColor->GrayLevel[0]],
 StyleBox[" > 1, as in an infinite population the only sufficient condition \
for emergence is that ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontColor->GrayLevel[0]],
 StyleBox[" exceeds 1. Therefore, it would not be possible to solve for \[Xi] \
needed to push the extinction probability below a threshold, as the only \
solution would be zero [Anderson and May 1991]. ",
  FontColor->GrayLevel[0]],
 StyleBox["\n\n",
  FontWeight->"Bold"],
 "This general result highlights that if the number of infected individuals \
reaches the order of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 "), the extinction probability of the pathogenic population becomes low and \
approaches zero, especially if this limit is greatly exceeded. Threfore using \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 ") as the scaling for the outbreak threshold is appropriate.\n\n",
 StyleBox["This definition of the outbreak threshold has the great advantage \
of being general (it does not require a specific cutoff) but that this \
generality is traded-off against its specificity. The value of the outbreak \
threshold should always be seen as an order of magnitude. If one would want \
to apply the outbreak threshold as a strict threshold, one would be using an \
extinction probability equal to ",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox["c",
  FontSlant->"Italic",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[" = ",
  FontColor->RGBColor[0., 0., 0.]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[" \[TildeEqual] 0.37. This illustrates that on",
  FontColor->RGBColor[0., 0., 0.]],
 "ce this asymptotic level has been reached, the pathogen population is \
likely to persist, but still has a sizeable chance of extinction. As such, \
this limit should be considered a \[OpenCurlyQuote]lower bound\
\[CloseCurlyQuote] for the outbreak threshold in a homogeneous outbreak. If a \
more rigorous threshold is desired, then a multiple of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 ") should be adopted, or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Log", "(", "c", ")"}]}], "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 ") should be used to produce an exact threshold.",
 StyleBox["\n\n",
  FontWeight->"Bold"],
 "Note that if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " is approximately just greater than one, i.e. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "0"], "\[TildeEqual]"}], TraditionalForm]]],
 " 1 + \[Nu] for \[Nu] << 1, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "(", 
    SubscriptBox["R", "0"], ")"}], TraditionalForm]]],
 " is approximately equal to:"
}], "Text",
 CellChangeTimes->{{3.557725170943178*^9, 3.557725283545042*^9}, {
  3.557725421465641*^9, 3.557725447029113*^9}, {3.5613671403151083`*^9, 
  3.561367238827091*^9}, {3.561369794206205*^9, 3.5613697999003*^9}, {
  3.5613776849862843`*^9, 3.5613779017137814`*^9}, {3.561381037844119*^9, 
  3.561381056107465*^9}, {3.5662979450264177`*^9, 3.566297945942161*^9}, {
  3.566297998227334*^9, 3.566298010529501*^9}, {3.566298044163007*^9, 
  3.566298188693652*^9}, {3.566298240201241*^9, 3.5662983629417763`*^9}, {
  3.5667150859718657`*^9, 3.5667151389354897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", "\[Nu]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Nu]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5563617944016542`*^9, 3.556361806220495*^9}, 
   3.556366251442163*^9, {3.561369795826537*^9, 3.561369796615543*^9}}],

Cell[BoxData["\[Nu]"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.5563618073096657`*^9, 3.556366251443878*^9}]
}, Open  ]],

Cell[TextData[{
 "Then the number of infecteds",
 StyleBox[" needed for an outbreak to occur is appro",
  FontColor->RGBColor[0., 0., 0.]],
 "ximately equal to 1/\[Nu] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["R", "0"], "-", "1"}]}]}], TraditionalForm]]],
 ") = \[Delta]/(\[Beta]-\[Delta]). Thus one can make parallels with classic \
population genetics results demonstrating that a new allele of fitness 1 + ",
 StyleBox["s",
  FontSlant->"Italic"],
 " needs to produce on the order of 1/",
 StyleBox["s",
  FontSlant->"Italic"],
 " copies of itself before it is guaranteed to fix [Kaplan ",
 StyleBox["et al.",
  FontSlant->"Italic"],
 " 1989, Barton 2000, Desai and Fisher 2007]."
}], "Text",
 CellChangeTimes->{{3.560245210789268*^9, 3.5602452401312513`*^9}, {
  3.56136741054443*^9, 3.56136744550961*^9}, {3.561377930234654*^9, 
  3.561377934104846*^9}}],

Cell[CellGroupData[{

Cell["Accounting for imperfect samping", "Subsection",
 CellChangeTimes->{{3.561367298842712*^9, 3.561367304457322*^9}}],

Cell[TextData[{
 "If the sampling of an outbreak is imperfect, then only an average \
proportion ",
 StyleBox["p",
  FontSlant->"Italic"],
 " of all infected individuals are detected at a given time. This factor can \
be incorporated into the model. \n\nIf there are ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " actual infected individuals at time ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", the probability that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "d"], TraditionalForm]]],
 " infected individuals are detected is sampled from a Binomial distribution \
with parameters ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["I", "t"]}], TraditionalForm]]],
 ", ",
 StyleBox["p",
  FontSlant->"Italic"],
 "). Thus the mean number sampled at a certain time is equal to ",
 StyleBox["p ",
  FontSlant->"Italic"],
 "\[TildeEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 ". So if the threshold ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " has been reached, then the actual number of infected individuals detected \
equals ",
 StyleBox["p",
  FontSlant->"Italic"],
 " \[TildeEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 ", which is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 ") at the lowest limit. "
}], "Text",
 CellChangeTimes->{
  3.56136731588944*^9, {3.561367452464656*^9, 3.561367544441889*^9}, {
   3.561377948667823*^9, 3.561377962873315*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time taken to reach threshold", "Subsection",
 CellChangeTimes->{{3.56136755397046*^9, 3.561367559466007*^9}}],

Cell["\<\
If the number of infected hosts is negligible compared to that of susceptible \
hosts (S \[TildeEqual] N) for the initial stages of an epidemic, then we can \
approximate the epidemic growth rate by:\
\>", "Text",
 CellChangeTimes->{{3.561367568954506*^9, 3.5613675920492496`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["dI", "dt"], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Beta]", " ", "-", "\[Delta]"}], ")"}], "I"}]}]], "Input",
 CellChangeTimes->{{3.561366725263681*^9, 3.561366742117442*^9}, {
  3.5613676040097847`*^9, 3.561367605082342*^9}}],

Cell[TextData[{
 "Therefore the number of infected individuals will grow approximately \
exponentially, with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}], "t"}]], 
   TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " is the initial number of infected individuals. By setting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 ", we find that the time that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " is reached by equals:"
}], "Text",
 CellChangeTimes->{{3.561367612415965*^9, 3.5613676740027122`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["T", "0"], " ", "\[Equal]", " ", 
    RowBox[{
     SubscriptBox["I", "0"], 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}], "t"}], "]"}]}]}], ",", 
   "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.561367686740775*^9, 3.561367723182411*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ifun"}], "MessageName"], ":", 
  " ", "\<\"Inverse functions are being used by \[NoBreak]\\!\\(Solve\\)\
\[NoBreak], so some solutions may not be found; use Reduce for complete \
solution information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.561367723836804*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"t", "\[Rule]", 
    FractionBox[
     RowBox[{"Log", "[", 
      FractionBox[
       SubscriptBox["T", "0"], 
       SubscriptBox["\[ImaginaryI]", "0"]], "]"}], 
     RowBox[{"\[Beta]", "-", "\[Delta]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.561367723840528*^9}]
}, Open  ]],

Cell[TextData[{
 "Here, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " is usually close to 1, and unless ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " is very close to one, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "(", 
    SubscriptBox["T", "0"]}], TraditionalForm]]],
 ") is of order 1 as well. Therefore it would take a duration of the order of \
1/(\[Beta]-\[Delta]) to reach the threshold limit. "
}], "Text",
 CellChangeTimes->{{3.561367737179742*^9, 3.561367776060443*^9}, {
  3.5614403324385567`*^9, 3.561440332539618*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delayed Sampling", "Subsection",
 CellChangeTimes->{{3.56136778453159*^9, 3.561367786882657*^9}}],

Cell[TextData[{
 "In some cases there can exist a time lag \[Tau] between an individual \
becoming infected and that infection becoming apparent. This delay could \
arise due to several reasons, such as a delay in the infection being \
reported, or if there is a latent period before the infection becomes \
apparent in a host. In this case, whilst still assuming that there is no \
limitation of susceptible hosts (S \[TildeEqual] N), the detected number of \
infected individuals at time ",
 StyleBox["t ",
  FontSlant->"Italic"],
 "is equal to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"t", "-", "\[Tau]"}], ")"}]}]], "=", 
    RowBox[{
     SubscriptBox["I", "0"], " ", 
     SuperscriptBox["e", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}], "t"}]], 
     SuperscriptBox["e", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}]}], "\[Tau]"}]]}]}], 
   TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}]}], "\[Tau]"}]], 
   TraditionalForm]]],
 ".\n\nIf the actual number of infected individuals ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "t"], TraditionalForm]]],
 " equals ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 ", the observed number of individuals equals  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "0"], 
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"\[Beta]", "-", "\[Delta]"}], ")"}]}], "\[Tau]"}]]}], 
   TraditionalForm]]],
 ", and so the observed threshold has to be altered accordingly. However, \
this is still of order ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 "), unless the time lag \[Tau] is large."
}], "Text",
 CellChangeTimes->{{3.561367879035898*^9, 3.561367912260806*^9}, {
  3.561367944322816*^9, 3.5613679455226593`*^9}, {3.561368063575304*^9, 
  3.5613682803984756`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Supplementary Material S.2: Effect of the limitation in host population size\
\>", "Section",
 CellChangeTimes->{{3.560244801427236*^9, 3.560244811320553*^9}, {
   3.560245016252426*^9, 3.56024505860182*^9}, {3.560351218815773*^9, 
   3.560351239446969*^9}, 3.5603520287192163`*^9, {3.56136766907158*^9, 
   3.561367669718741*^9}}],

Cell[TextData[{
 "The homogeneous results assume that during the emergence time of the \
pathogen, there are enough susceptibles present to transmit a pathogen to, so \
the overall reproductive rate is always approximately equal to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ". However, if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " is close to one, or if the population size is small, then the assumption \
that the reprodutive rate each generation will remain constant will no longer \
be valid. This section explores when this assumption will break down.\n\nIn \
an SIR infection, the rate of change of the susceptible population is:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["dS", "dt"], "=", 
    RowBox[{
     RowBox[{"-", "\[Beta]"}], " ", 
     FractionBox["S", "N"]}]}], TraditionalForm]]],
 "\n\nCombined with the term for dI/dt as above, we can create a term for the \
change in the number of infected individuals as a function of the susceptible \
population, by diving the two derivatives:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["dI", "dS"], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"N", " ", "\[Delta]"}], 
      RowBox[{"S", " ", "\[Beta]"}]], "-", "1"}]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["N", 
     RowBox[{"S", " ", 
      SubscriptBox["R", "0"]}]], "-", "1"}], TraditionalForm]]],
 "\n\nFrom this we can see that the rate of change equals zero at ",
 StyleBox["S",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"N", "/", 
    SubscriptBox["R", "0"]}], TraditionalForm]]],
 ", which is the point when the outbreak would reach its maximum peak and \
would start dying out. If this maximum value is less than the outbreak \
threshold, then it is clear that our previous assumptions are violated. By \
solving the above differential equation we find that:"
}], "Text",
 CellChangeTimes->{{3.557828444651897*^9, 3.557828451400989*^9}, {
  3.557828580047818*^9, 3.557828684386306*^9}, {3.5578287206288147`*^9, 
  3.5578287653934383`*^9}, {3.55782891526223*^9, 3.557828949106702*^9}, {
  3.557829247142268*^9, 3.5578293141531076`*^9}, {3.557829383775648*^9, 
  3.557829444915936*^9}, {3.557829484869287*^9, 3.5578294907866364`*^9}, {
  3.557829668255677*^9, 3.5578299394051743`*^9}, {3.557829978687254*^9, 
  3.5578299913265047`*^9}, {3.5578316720279903`*^9, 3.5578317348493233`*^9}, {
  3.558152864864077*^9, 3.558152874294004*^9}, {3.558152905065743*^9, 
  3.558152927227626*^9}, {3.560351676997467*^9, 3.560351787858384*^9}, {
  3.5613689102846737`*^9, 3.561368914641027*^9}, {3.56139288300981*^9, 
  3.561392884562071*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Inf", "'"}], "[", "S", "]"}], "==", 
      RowBox[{
       FractionBox[
        RowBox[{"N", " ", "\[Delta]"}], 
        RowBox[{"S", " ", "\[Beta]"}]], "-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"Inf", "[", "N", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"Inf", "[", "S", "]"}], ",", "S"}], "]"}]], "Input",
 CellChangeTimes->{{3.557830003646634*^9, 3.557830006814042*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Inf", "[", "S", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"N", " ", "\[Beta]"}], "-", 
      RowBox[{"S", " ", "\[Beta]"}], "-", 
      RowBox[{"N", " ", "\[Delta]", " ", 
       RowBox[{"Log", "[", "N", "]"}]}], "+", 
      RowBox[{"N", " ", "\[Delta]", " ", 
       RowBox[{"Log", "[", "S", "]"}]}]}], "\[Beta]"]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5578300087566853`*^9}]
}, Open  ]],

Cell["\<\
Therefore the maximum number of infecteds that arises over an SIR epidemic is \
equal to this function, evaluated at S = N \[Delta]/\[Beta]:\
\>", "Text",
 CellChangeTimes->{{3.5563684675503674`*^9, 3.5563685178719263`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"N", " ", "\[Beta]"}], "-", 
    RowBox[{"S", " ", "\[Beta]"}], "-", 
    RowBox[{"N", " ", "\[Delta]", " ", 
     RowBox[{"Log", "[", "N", "]"}]}], "+", 
    RowBox[{"N", " ", "\[Delta]", " ", 
     RowBox[{"Log", "[", "S", "]"}]}]}], "\[Beta]"], "/.", 
  RowBox[{"S", "\[Rule]", "  ", 
   FractionBox[
    RowBox[{"N", " ", "\[Delta]"}], "\[Beta]"]}]}]], "Input",
 CellChangeTimes->{{3.556368522985244*^9, 3.5563685348482428`*^9}, {
   3.5563685696837254`*^9, 3.556368571795475*^9}, 3.5563700077038317`*^9, {
   3.55783044124162*^9, 3.5578304493302927`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"N", " ", "\[Beta]"}], "-", 
   RowBox[{"N", " ", "\[Delta]"}], "-", 
   RowBox[{"N", " ", "\[Delta]", " ", 
    RowBox[{"Log", "[", "N", "]"}]}], "+", 
   RowBox[{"N", " ", "\[Delta]", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"N", " ", "\[Delta]"}], "\[Beta]"], "]"}]}]}], 
  "\[Beta]"]], "Output",
 CellChangeTimes->{
  3.557830034052772*^9, {3.557830446971252*^9, 3.557830450141284*^9}}]
}, Open  ]],

Cell["This simplifies to:", "Text",
 CellChangeTimes->{{3.557830042083234*^9, 3.5578300461861057`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MaxI", "[", 
   RowBox[{"ND_", ",", "R_"}], "]"}], ":=", 
  RowBox[{"ND", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Log", "[", "R", "]"}]}], ")"}], "R"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.557830049983095*^9, 3.557830066684928*^9}, {
  3.55783045316978*^9, 3.557830457190639*^9}}],

Cell[TextData[{
 "For ",
 StyleBox["R",
  FontSlant->"Italic"],
 " = \[Beta]/\[Delta]. By plotting the minimum threshold ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{"Log", "(", 
     SubscriptBox["R", "0"], ")"}]}], TraditionalForm]]],
 " against this maximum value of the infection, we can see when ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " becomes large enough so that this minimum threshold can be reached in \
theory. The following plot is for ",
 StyleBox["N",
  FontSlant->"Italic"],
 " = 10,000:"
}], "Text",
 CellChangeTimes->{{3.5578301039297047`*^9, 3.5578301097761793`*^9}, {
   3.557830406823675*^9, 3.557830427911195*^9}, {3.557830464502054*^9, 
   3.557830517263834*^9}, {3.557830903773312*^9, 3.557830963839031*^9}, {
   3.560351857600381*^9, 3.560351862711863*^9}, 3.561368949978518*^9, {
   3.56136995817101*^9, 3.561369966506709*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EmergeHom", "[", "R_", "]"}], ":=", 
  RowBox[{"1", "/", 
   RowBox[{"Log", "[", "R", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.557830127481806*^9, 3.5578301612005796`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"EmergeHom", "[", "R", "]"}], ",", 
     RowBox[{"MaxI", "[", 
      RowBox[{"10000", ",", "R"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.02", ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
      RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "\"\<Infected Individuals\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5578301441729403`*^9, 3.557830221304443*^9}, {
  3.557830374694716*^9, 3.5578303798436947`*^9}, {3.557830943076372*^9, 
  3.557830947698784*^9}, {3.560351877236581*^9, 3.560351899018692*^9}, {
  3.561368319832514*^9, 3.561368321693013*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.01], LineBox[CompressedData["
1:eJwV0G1UzGkYBvCJqZStlhJFivo3TaYMpnfcd42ORkdMrUon9DrIJFNR7VA2
UkSmFCqijfXS2Ky8tZFN2G2kFVqKmlY7ibKeJ52yLO1/P1znOr9v17lmxSQF
x4/jcDjL2fzffm8KcgakBPIVv2uaQYKmwX+AfjCB+MhdHkMeEuyos/k4k7Uo
zaLAVijBLXvVm4NZB2mj+vLsJFjhpAmrYy37S9dUoifBjzJ959wQAktlLkuL
7wTgpV5l6+xVBCKTo+YaBAXg7K4NUyPCCUT5qsxeJC7Fx3wZP2QdgQGpYf2d
en9UinxIezwBfd/qiTMil6DJPD19TzmB5hMxh+UCMW7JfVPqkEKgMY1zd5KR
HzaXV/eWZRCILckrt5zqi8NGqgvlOwlckXIVywWIRgnxd5W5BJLzVwe1/bwY
LfImF+kOEPBs8iGfIhchGXvZ3VFM4P2Y6HPt+IXY5JbfE1bO7smUycVd3pi1
xkF4pZKAv+r+BNVjLzTR9owdO0sgp+eD80izJxbO3LrbtIaAEUlLMtR54Ktr
gr3GVwn8muTt7DLmjjxx+3PdDQI1v137aOrqjmv2r+pd1kSgQdxUK053w7i5
/yR4awicyAn/acovIoxWpZ6pfUjAKvb5NE9bEQoDzeOuPSWQ1daV2qpcgK9H
v99c1k2A03ixN0Y3H4/GGLsa6giczLx60D16PlrxShK/DBAYac00Ne6ch6pz
o9FZQwRC24YWPo2Zh9Qm8JT2A4EMfddkw2Eh2g82yjRjBDYdPZNuli3EwPSv
uxcbUNCVVabb2QjRf212+yITChkeL7VxCXOR766znmFB4fDKun1FZ11xfIvt
lN3WFMyfHvIN+NcFa+p3HNw2i8Im2cpHpstcULqxtmGIRyHkrblyYbUAuyZ0
+gS5UigbTEjiWQrQe5yDl8iNwuq0LJFUOQcP1PkPVPlQCLgwTfueOOMlzT6b
Cj8K6pnqYWG0Mz4oPcOdLaEQo+jfk9LDx0cRV7xyVlCwfye3t1zPx3Nb+/5O
DqUgONnAPdjvhNuC3oW/iaTQ15zqwElzQovvposHYylIy3njSzlOeOy0p/JB
AoV7E/tbWlQ8tM5z2eCpoODMf9IlFvAw4Y5/u0s6BcUpP+6sJke82OA2qs6k
8Ozs3Xh5nCP2nLdcPzGHgkGVvP+0sSP+SazDhvMpmFhIWrPVDHYMj3ySFVEo
TAzHkjAGTzVsureL9fBrKze7UAa35PWoTrK2VM9ZV/0NgwYzNEwn62DJ5JDb
UgZF4uMrlh+iML9IfX0okMGCQnHVgmIK3esYxRpk0M9VtYxzmEKulTQggs+g
yQfuFBvW1kYL2gZ4DD5rzNB6sX5e8fnADkcGk1bFpqawVh+3q6q0Z/DYdveK
PtaWNzd6D9owOKJ5QVuOUIgOV5jnT2awsVh64zXrypTr7baTGNy/9t4eg6Ps
H3Ze9y+bMWg/VDMdWX/bXr9C+xWDK612+deyLnh15Ka7IYPTe0fNHrKedHn7
tAf6DPap5Z2DrHU/LvkhlsvgDgxNciylsM8jJKJQj8EA4/teYtZ60t07nTgM
WjwBbhTrtzWJHbe+OKD2+OXW7axvVXLjwz474Pn1/NJS1re3LbZ/98kB/wO0
qT0f
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJwV0Hs01HkYBnDJCMVWO6wISy5RpinjOvG+jfmlzaVQONRockmajYpO0r2U
Srlst4m0upAay7JWluac6eIgWtWqKJeIlmy+3yLSrtlffzznOZ+/nnMey40J
QTGaGhoa/my+tmjwdNq7QAIH7qX80jk6CQZBz4ATRGDDR36Spq4a2qrNJsxZ
j7cIyIK5akg8rtgaxNrYQaaXJVJD/vzG0OqvPn/+bl6mGiZiOQ7HggksnTU8
I9pQA8t7Ux9ZrSVQH8HLKS/XQKuOuO/CwwhEB6tCn49Owaf2sfbBkQRuv4iR
S9q0MFUgJK0x7P7lyPrcmmmov3gKx01GgGvv6aqs0cPEY4Ny6x0EkizGncQ8
A2zIvdV7MYVAVr7Owb6GmTiim1WSe4DARI1bb2f1bNSNj3mQeoyAuXLCr6Ka
i9z02Tl9pwg8Uc8I55cYIVH3dLadIRDm9Li4pMcY7zmf7A7NJVAXMMB9qmOK
+9db8ysLCCgc4hseu5mhfle3Ou8GgQAjlzfSUgvMNk8+YlBK4PF6kTRbxxLf
Vi08rvc7gdVWh5hciRXaebe+7KslIDS31FVXz8P1GWt7V94jsN1PUoI6Nhi9
6HO8RyOBkelK34G9tijNSiqqaCFw3/LfYZ0+O+T7fhtd9ZxA5seCPyXJ9jgw
dmXrxU4CfgNpT4p0F+CFjXq8aX0EJPXr7jzIWIhz7M7+OPmOgOFId4hIyMOs
4jHp/g8ErhS+2u7+fBFSM99rXePs359T/Fz/4OO8IVVso5pA84X07PTLi9F3
18xOL20Kgmc7aiN2L0FGcqjVU5/CjTezFillTmjv0mcyl0vBb7T4AYkU4NQm
C8MjJhSqtmUkxPs4Y2nN3sydlhRQ0n872ccFAzdXKD/YUeBo2ayxFbpih067
MIBHoSxmoSyK54YemtbuAmcKgyrzxPlCdzxVzby7KqRw88SBJTIPDyxvPGGW
L6IQGpMn01wjxGZ5kZbVDxTIibLvUyOX4pPwSve0VRR+9cp7PbTZE4uT+99v
D6Fw36LpcH6mF+4MGA4bXEeBZ73TzKgQkHvQ1HsoikIzmshWyBDzrrulNsdT
iGh6GWXMWYYm6Y5xbtsoDGlqhdw5uwzj7zOtjrso8P3TmRcCEZYpnccU+yj0
3DV23f9QhN03jTZNT6Mw2fFRZSv1xtfEJHTkJIWrRcSngiPGtpFPX2JzKLyX
HiHLC8R4Tbml7jDraS1Sfc1rYkxM7876mbXcUzfwTqEYtec22rSzXnKrzE+g
EKPA+9Iq/58oLG0XGlpXifF0tvdVpzMUMiy4g3rNYhTxslZqnKPw1jFYPjou
Rv1xLUMz1mXqlozKL2J8oUrpcmedk/ZPYfKkGBPWRiXtYF3n81/Ap6kM5u1x
ye9nbdYRuPWzAYOfGl/RpvMUTOYX/K1tw6DqTGDtAOuw8DimwY7BDEndUe0L
FGIUt+tPOjA470OpKbJ2WD0smsVncPWcw0wF64j20xxzIYOmvWPftLBujkg5
99qTwX6FrH2ItZFbj/91ZHAvhiTYyinE5dvzHZczuELvobs3a34KJ4KuYJD7
F2htYH3FL1xR6ctg16XfHu1hXauytd4dwODNTfZyOest+zbf9Qpk8H9qEUiP

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["\"Infected Individuals\"", TraditionalForm]},
  AxesOrigin->{1.02, 0},
  PlotRange->{{1.02, 1.1}, {0., 50.498345710078034`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.557830178311674*^9, 3.557830221697509*^9}, {
   3.5578303750128098`*^9, 3.5578303801168957`*^9}, {3.557830944014222*^9, 
   3.557830947907667*^9}, {3.5603518929535522`*^9, 3.560351900002984*^9}, 
   3.561368322565322*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["The red section denotes the values of ",
  FontColor->RGBColor[0., 0., 0.]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontWeight->"Plain",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[" for which the maximum number of infecteds is less than the \
outbreak threshold ",
  FontColor->RGBColor[0., 0., 0.]],
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{"Log", "[", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]],
  FontWeight->"Plain",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox["]. In theory, this means that the pathogen will go extinct before \
it reaches enough copies to guarantee not going extinct by stochastic drift \
alone, so the threshold cannot be reached due to a violation of the \
assumption that there are enough susceptibles at the start of an outbreak. \
The orange section denotes where the maximum number of infecteds exceeds the \
outbreak threshold, so the occurence of an outbreak can be detected using \
this threshold. For this particular case, ",
  FontColor->RGBColor[0., 0., 0.]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontWeight->"Plain",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[" needs to exceed 1.06 for the drift threshold to be reached (this \
of course depends on the value of ",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox["N",
  FontSlant->"Italic",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[", the host population size).",
  FontColor->RGBColor[0., 0., 0.]],
 "\n\nFor very small population sizes, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " needs to be rather large in ",
 StyleBox["order for an outbreak to be detected in",
  FontColor->RGBColor[0., 0., 0.]],
 " a homogeneous population. If we repeat the plot for ",
 StyleBox["N",
  FontSlant->"Italic"],
 " = 100, for example:"
}], "Text",
 CellChangeTimes->{{3.55637681594409*^9, 3.556376818873726*^9}, {
   3.556376881473529*^9, 3.5563769944250727`*^9}, {3.5563770985513287`*^9, 
   3.556377145276475*^9}, {3.5563771897476883`*^9, 3.5563772200696497`*^9}, {
   3.556382063919549*^9, 3.5563820678603497`*^9}, {3.5563821614040747`*^9, 
   3.5563821701919327`*^9}, {3.556382205332445*^9, 3.556382210872738*^9}, {
   3.55638333431765*^9, 3.556383403177195*^9}, {3.556383503408792*^9, 
   3.556383513313355*^9}, {3.557830975958832*^9, 3.557831209143832*^9}, {
   3.558152967912504*^9, 3.5581530402144423`*^9}, 3.5603519144179983`*^9, {
   3.560351963356885*^9, 3.560351978956827*^9}, 3.56136895765084*^9, {
   3.561378185958585*^9, 3.561378232397973*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"EmergeHom", "[", "R", "]"}], ",", 
     RowBox[{"MaxI", "[", 
      RowBox[{"100", ",", "R"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.02", ",", "1.5"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
      RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "\"\<Infected Individuals\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5578311835312*^9, 3.557831186690199*^9}, {
  3.560351926488853*^9, 3.560351940527548*^9}, {3.5613683273828087`*^9, 
  3.5613683293815737`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.01], LineBox[CompressedData["
1:eJwV1Hsw1XkUAHD8rq7HRbjXMxsuLrdUmlCRc8JKUorKI1OSRx6lokglSWht
UynWoIc3UR5Rl6UXUskrybIhllRa+t3L/SVhf/vHd8585sycOd8zZ46eb5ir
v5SEhIQX/f6PDdl9AZHrSZjh7V/iIr8MlRVC65hIQrzIOLkplY9+kZ7tZbSv
fLc+4ZnER8GQw7D7RhJYLYuDZ6P56PNAT6bIloR8bxt2kA8fy/f1uDn+SsJu
g4tqn5fxcXul7XiSEwkqjTfOBTWZ4BV3TS25XSRMnN01MCRpgotznkeygul6
3xQd/srioUquVHQFbdJT4JecwkN2ns3p3SEkmKQo929K4qFGwYPY26Ek6L1l
Fb0P56HunYKLa8JIkDR54BixhYcrKxMyvSNI4JRpy+34aYTbnjk8Lo0hYcze
NTHMzwiTh58v2nqNBL5ejJ94iyF661DkR9pBdod2WdoboqkHrz/2OgkVecf5
MdaG2N6aeL8qlQTVyxIBOqaGqFrj6LMknYQIz+igbEVDzLz8qmY8i4QTHbbi
mjcGWGLdFvpbAQnpJ9k1kvsMsCWt+01zDQncv395U5rARRl92drDtSRY+p2P
Lj3LRfu71tmcP0mQkWcfrIji4qOG3LADdSR0OM78eBXMxfJvR1kLj0j47nRu
j7ULF9OcFB0sGklI2XFAUlWTiz7zDjV5bfS8orb4BpXr45S/4Na5f0go1og9
euurHg4XFRcflxNC2wtB+ociXXT+AxPzVwnhYmHGUlixFG/dLvFnewlhv1W3
bTFfBx/qGJ6rjxUCFWkdlX1BGwXVx27k3xECVz8umCnSRPMZ/0svu4TwsGry
olKqBkaWB9byfgih1fu+TPERdcyJ2/CpkSsCs+K0dYSbGqa80HPLchIBP73H
u2U/B0NM+h5VRoig29RZxz6CjU/M184zbopgsJl9Qeq2KvZV50VfbRTBRGFq
pfsXFezfPkp5T4igc8F2vYK5CubvW1Ppy5kCT0FCU1e6Mn7SNME8qynI6xz3
vySnjJxJss3Afwpy1GRDtU4tRubalxmDyVNQd9/cre+nEg5nRgT2Vk9BS6ms
V6aEEq4taWIqDU4Bh8ExOqipiG4rDEdjpKfh+OE2e0UXBfR47dFgunIaTHtL
5FpiWag3kDGgtnsa5DXGu5Jb5DEgM67V6vQ0xMmVv77Mlcfr4Tb1t/KnodpZ
vRki5TDxscyXDa+noe8qJak+KIsHjArVtcXT9P/MFF/YyiJDcmfcah0xEKw5
Z1eBDOolFjy5YCeGE1L6QralDPKMWxfUD4lhs/iZamEFE4XWUqdHronhXdaq
SYYVEwtC5Wcm68WQHPNy4PCTRfhuU+1myzEx+J65alK9dRG9f5E9AgUK2j+q
z+4bk8ZiCdmAk5YUVAVf1zU7I43OA0VmEXsp6FeeNLb7RRpDAic67sRTECDS
Xz7ayMBweZmjuvcosMuZjesKZCByV23reEtBvk6YIJjNQMbAV9aZbgqSeqzO
z6kw8GV6cYvJOwpczG1+v6LMQFdF7ubzPRRY1+d6PFRkoN8Mx96ij4I899W9
TFkGJrXPrssapKD+5LGQqjkCO081Gx78Qtc33xhgNUZgmkX8CHuczq/U6u0e
JdCLxNyntB35q5OOjBA4ElCrq/0v7YqhjIIhAsU77mq3TdL9LE25wnlPoJbx
NeU10xS83zJcNt9B4MCwS8cH2lNS5wez2gnMvcG6fElMQfnuMCerNgKXqyaw
xigKeGUTnVEtBNrMRzEzflBA2Izki5sIlKoxf+4wS0Fix4Z7aY0ENocL40W0
q9aFkBYNBG7/HCK1dY4CVYVFxlFPCPp+GT+dob3z2S5tzccE9u4dPVswT4HX
yIbNtfUE3tTMsXFboGBVflnFnjoCfd/unVug/dEqa+dcLYH/Ae7xouY=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJwVz3k4lXkUB3B0LVkmcnFfUowkUkmUSTq/R5QabUhCN5ksWSe7YizZopIo
jXTJcrtiesoda5ZrhESiiDRdS0yG4r53ey3FvPPHec7zec73POc5up7BDl5S
EhISdLL+77xPzakzJ3ggkUTNzOzNhiqHgMlkBx7En/maZKuZA5daaPt1HEl/
yZGMO58DlIKLy05OZD74lnHMYg7QXPXCm5xJFxvk5hvfAdSb4pnlRuZrjll5
lN2FzIYjVru9SNcfrz9IYYDTlsW8PtISO7+uAToDaHnMeX9v0tUhI9W1DCiK
XGEX+pD5DwMZBsEFUG361Ejej5yP6u+VvlgIXBaV9jGIBxzpV72jcw9g2+0P
/MQo0ht1NA20S4HulGFvFE3ul9eXX3UuhUxVS2YfaQkryjfzm6XAy8o7rXOZ
dDg735/CBPaN05zGWDJ/7XfLQzwmWKQNXp9PJG0XNM4ZYIH15bebg66TflKk
tGewApzPddFPF/FgtL27P3OoEpxdgx+ISBc+E6Y2LZF2VJ3IKibnNbmdChvY
cNLW7cLLEh7oNOuNSXqzwclwJtTyIXlfw6vZTcSGE7j8Ve0KHqCgBuMWrArs
Ew6zx6p44BHlzjSKrgHrB52yfp3kf5t60vdkNcCja4FJ1XPkPeuDY3pzrbB0
a1LSGsMhvvXxWyWpLlBRCmiQRTi44DOhVnv6QLmoPVLRD4chhr9mPHsAMsbb
ZY5kk2Y70L9dGYauOwNvOupw8PBk6N84MwJCr9qChE849Nfp2rHixmGcVVYW
Ls+H+Xj6jVM/T4J9LkotNeGDWYhthfr2KSgoLPeiuvIhYL1arP+lGajR1k9o
jOdDTKBUet3TWaitCrlf+ogPE1x3nsgQB/MFr+udb/kw/bljwzOKACKf+NQb
LPLBOmrLTbxHCEWJVlPP9QRgbOrYjr8Ww60Xuo75hwWQ09D0Rq1xHvwNh5sq
wwRw9JkRw2Z8ETjmFssUhgB6kmKn/lT4DsNVJZeyngtAp9IvQGvdCnw8Pkm4
zwqgnZE711opgUrPmlV6qgkh7n6aH7NTEk1hhqjEUgic5Mmzq0elkNoc3rPR
Swh7WIvdzqoUJGvRmTeSIYTb3jt7+ndJo/F7YT7vq4SQqOa7XBgpgyzK22TX
jAgB/9Dxl1WNLHLcpj/5m7QImD5yj+0n5ZBLt0vr1u0ikJTJTcJN5JEuN4+r
7iyCrZ7Hnm7yU0De9xJfWcaI4MfznLU+hYooJ3RfY0GpCOTZqyBcqIRSm+Wm
rbpFkCk9gThma9Avmx5qaIlFkF9rcyHtkDKiSDolmmqLwdh91iBiVhnppjI5
yfvFwItQ16ZnqSCDza9WNALF0BIewnDZvxbx90rFTGSLoSTFyCxnei1iBigs
zDWK4dd5/KSgUBW9O1h/aPdn0m77gtVOUlHXncjBWiUCqm9n86SXqahMYrV3
9G4CtIV2Qxuq1ZA9l7UjjE4AZyRFvcdTHfn7zPY+SiLgb93G8peKGihUQe6i
zmMC8h6nYvw2DYT0TI729hPAHeBFnQ6lIQr3i2LsAAGsdI7yuQga6rxb1mX4
joBv+s1s32gacvhB79CVQQLWd1loRcXR0PkFNZtdwwSEqFQE52bQUNrrpZ/y
Rwg4vEp2y1AxDfVd7tD3nSYg/uup1+f6aejOrqQJ6gwB1yJM2vwGacgVR8Ut
pJFmTVvoMA1NeNfraH0lQOZF0z/JozQkPvGHVs8cAdEJdqxHX2hIc3O2ipmI
gANjr/TFFAxxx4/1jpK+u6Xi+YoshorvK2ZeFxOwaLkQuFoBQ8aqKYqfCQIo
gtcj61QwtG85SjZvkQDnOklko40hqTrz9gNLBKw1mdpxVAdDHaH8JAHpozLr
t7noYej4v/5SR74TMGHkaxtgiCFqyeaWBdJUVphHhDGG3tMn45jLBMyOcZLj
t2OIgRXtc1whoAW3q0o3xZBnP/37CmkbXG4uxxxD/wEt2Obn
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["\"Infected Individuals\"", TraditionalForm]},
  AxesOrigin->{1.02, 0},
  PlotRange->{{1.02, 1.5}, {0., 13.52208794294346}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.557831184237111*^9, 3.5578311869466333`*^9}, {
   3.560351928076487*^9, 3.560351941331678*^9}, 3.561368330006872*^9}]
}, Open  ]],

Cell[TextData[{
 "In this case, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " needs to exceed around 1.34 for the threshold to be reached."
}], "Text",
 CellChangeTimes->{{3.557831191569108*^9, 3.5578313522508707`*^9}, {
  3.557831464115014*^9, 3.557831472170854*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Supplementary Material S.3: Finding a numerical approximation for the \
threshold in a heterogeneous population\
\>", "Section",
 CellChangeTimes->{{3.560244801427236*^9, 3.560244811320553*^9}, {
   3.560245016252426*^9, 3.56024505860182*^9}, {3.560245355832532*^9, 
   3.560245377318655*^9}, 3.560351211283036*^9}],

Cell[CellGroupData[{

Cell["Deriving the formulae", "Subsection",
 CellChangeTimes->{{3.560245823760351*^9, 3.5602458274146833`*^9}}],

Cell[TextData[{
 "In a heterogeneous population, the probability of extinction is the \
solution ",
 StyleBox["s",
  FontSlant->"Italic"],
 " to the following:"
}], "Text",
 CellChangeTimes->{{3.560245394445094*^9, 3.5602454098007917`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox[
       SubscriptBox["R", "0"], "k"], 
      RowBox[{"(", 
       RowBox[{"1", "-", "s"}], ")"}]}]}], ")"}], 
   RowBox[{"-", "k"}]], "=", "s"}]], "Input",
 CellChangeTimes->{{3.557758014340412*^9, 3.557758029804389*^9}}],

Cell[TextData[{
 "\nUnfortunately, this is unsolveable for general ",
 StyleBox["k",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.5577580215297623`*^9, 3.557758047609016*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         FractionBox["R", "k"], 
         RowBox[{"(", 
          RowBox[{"1", "-", "s"}], ")"}]}]}], ")"}], 
      RowBox[{"-", "k"}]], "-", "s"}], "\[Equal]", "0"}], ",", "s"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.557758057802804*^9, 3.557758064979438*^9}, {
  3.557758108097912*^9, 3.557758112673778*^9}, {3.557758148061246*^9, 
  3.557758151091576*^9}, {3.557758182317091*^9, 3.557758223539377*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "nsmet"}], "MessageName"], ":", 
  " ", "\<\"This system cannot be solved with the methods available to Solve. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::nsmet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.557758065738235*^9, 3.55775815184831*^9, {3.557758206457663*^9, 
   3.557758223874593*^9}}],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"R", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "s"}], ")"}]}], "k"]}], ")"}], 
      RowBox[{"-", "k"}]], "-", "s"}], "\[Equal]", "0"}], ",", "s"}], 
  "]"}]], "Output",
 CellChangeTimes->{
  3.557758065742487*^9, 3.55775815188937*^9, {3.557758206460125*^9, 
   3.557758223876754*^9}}]
}, Open  ]],

Cell[TextData[{
 "So instead we set up a function to numerically compute how many infected \
individuals are needed to equate the extinction probability to a threshold ",
 StyleBox["c.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.557758291375733*^9, 3.5577583412571*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FR3", "[", 
   RowBox[{"R_", ",", "k_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"Inf", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "/.", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"0", "\[Equal]", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  FractionBox["R", "k"], 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "s"}], ")"}]}]}], ")"}], 
               RowBox[{"-", "k"}]], "-", "s"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"s", ",", "0"}], "}"}]}], "]"}]}], ")"}], "Inf"], "-", 
       "c"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"Inf", ",", 
       RowBox[{"Log", "[", "R", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.5569466957724533`*^9}],

Cell[TextData[{
 "By plottin",
 StyleBox["g this function for a range of ",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox["k",
  FontSlant->"Italic",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox["-values (corr",
  FontColor->RGBColor[0., 0., 0.]],
 "esponding to those found by maximum-likelihood analysis for several \
epidemics in Lloyd-Smith ",
 StyleBox["et al.",
  FontSlant->"Italic"],
 " [2005]), we see the general behaviour that the threshold decreases with \
increased ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ", and increases with lower ",
 StyleBox["k ",
  FontSlant->"Italic"],
 "as the probability of extinction becomes higher, and thus more individuals \
are needed to guarantee an outbreak (see also Figure 1B in the main text)."
}], "Text",
 CellChangeTimes->{{3.5577583881994658`*^9, 3.5577584337263403`*^9}, {
  3.557758756263566*^9, 3.557758843489291*^9}, {3.560245439861186*^9, 
  3.560245451164702*^9}, {3.561368377109063*^9, 3.561368395600646*^9}, {
  3.5613782586077967`*^9, 3.561378273115199*^9}, {3.561392888594398*^9, 
  3.561392889985371*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1.0"}], "]"}]}], "]"}], ",", 
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1.0"}], "]"}]}], "]"}], ",", 
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1.0"}], "]"}]}], "]"}], ",", 
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1.0"}], "]"}]}], "]"}], ",", 
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", "1.0"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.01", ",", "5"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.005", "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "Threshold"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5574668283796167`*^9, 3.557466885131597*^9}, {
  3.557468266000785*^9, 3.557468323154626*^9}, {3.557468408304875*^9, 
  3.5574684153829613`*^9}, {3.5574724539622383`*^9, 3.557472466751315*^9}, {
  3.5574726964298267`*^9, 3.557472711457556*^9}, {3.557476235019891*^9, 
  3.5574763457135973`*^9}, {3.557476377704617*^9, 3.557476398457218*^9}, {
  3.5574764972703333`*^9, 3.557476578515699*^9}, {3.5601598959269657`*^9, 
  3.5601599351640463`*^9}, {3.56016006229655*^9, 3.560160068919221*^9}, {
  3.560160256739706*^9, 3.560160328152313*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.005], LineBox[CompressedData["
1:eJwVk3s0lAsbxWeMcRnj+jo6HHQ7UUkK5xRdnidKVCbXUr4iOREllK4k3dCN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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
    LineBox[CompressedData["
1:eJwVlHk4lAsbh5mxDMb6iiRLOVIKhVbleSyVFmMnEnIUqWiRtinJUlEnyRKV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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.005], 
    LineBox[CompressedData["
1:eJwVjnk0lY0axZ2DY57OK6VBReiGVBSpPI9GEZUhIpSGg4pyhVtS3FDJmCEq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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[0.005], 
    LineBox[CompressedData["
1:eJwVlHk01Ykbxrn2iyxfMSpbjTFjyUSlibyvqDSKsZVsyTCkogWpITFRthh0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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], Thickness[0.005], 
    LineBox[CompressedData["
1:eJwVk3k81Pkfx93HuH11uCsbftZQYbvk/Wnr107J7LpFodI6ailJtrXuo1CO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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["Threshold", TraditionalForm]},
  AxesOrigin->{1.01, -0.47588498520822736`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.01, 5}, {-0.47588498520822736`, 3.712431322466112}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.560245465459571*^9}]
}, Open  ]],

Cell[TextData[{
 "To proceed with finding an approximation, we first note that the ratio of \
the heterogeneous threshold with the homogeneous threshold is independent of \
the cutoff value ",
 StyleBox["c",
  FontSlant->"Italic"],
 ". To see this, let the extinction probability for an infected individual in \
a heterogeneous outbreak be equal to ",
 StyleBox["p. ",
  FontSlant->"Italic"],
 "Now if we solve to find ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " that reduces the overall extinction probability below a cutoff",
 StyleBox[" c:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.560245483828437*^9, 3.560245608161578*^9}, {
  3.560245655266056*^9, 3.560245688258643*^9}, {3.561370009977683*^9, 
  3.561370010596991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["p", 
     SubscriptBox["T", "0"]], "\[Equal]", "c"}], ",", 
   SubscriptBox["T", "0"]}], "]"}]], "Input",
 CellChangeTimes->{{3.561370002027429*^9, 3.561370006025775*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ifun"}], "MessageName"], ":", 
  " ", "\<\"Inverse functions are being used by \[NoBreak]\\!\\(Solve\\)\
\[NoBreak], so some solutions may not be found; use Reduce for complete \
solution information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.56024569027852*^9, 3.561370014185322*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["T", "0"], "\[Rule]", 
    FractionBox[
     RowBox[{"Log", "[", "c", "]"}], 
     RowBox[{"Log", "[", "p", "]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.560245690279611*^9, 3.561370014188273*^9}]
}, Open  ]],

Cell[TextData[{
 "Therefore the ratio of the homogeneous threshold to the general threshold \
is independent of ",
 StyleBox["c",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.559491792547913*^9, 3.559491826742902*^9}, {
  3.56024570403539*^9, 3.560245713537447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   FractionBox[
    RowBox[{"Log", "[", "c", "]"}], 
    RowBox[{"Log", "[", "p", "]"}]], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Log", "[", "c", "]"}], 
     RowBox[{"Log", "[", "R0", "]"}]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.559491830019518*^9, 3.5594918730394087`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"Log", "[", "R0", "]"}], 
   RowBox[{"Log", "[", "p", "]"}]]}]], "Output",
 CellChangeTimes->{3.560245715624261*^9}]
}, Open  ]],

Cell[TextData[{
 "Greater insight can be gained if we plot these thresholds, relative to \
those obtained for the same cutoff ",
 StyleBox["c",
  FontSlant->"Italic"],
 " in a homogeneous population. In this case, we see that the main scaling \
appears to be for ",
 StyleBox["k",
  FontSlant->"Italic"],
 " and only seems strongly dependent on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " when it gets closer to one."
}], "Text",
 CellChangeTimes->{{3.557759128405731*^9, 3.557759139214836*^9}, {
  3.5577592045939417`*^9, 3.5577592995779543`*^9}, {3.557759331936357*^9, 
  3.557759347455353*^9}, {3.5602458674392653`*^9, 3.560245903606615*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HomThresh", "[", 
   RowBox[{"R_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"Log", "[", "c", "]"}], 
    RowBox[{"Log", "[", "R", "]"}]]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"FR3", "[", 
       RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
      RowBox[{"HomThresh", "[", 
       RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"FR3", "[", 
       RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
      RowBox[{"HomThresh", "[", 
       RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"FR3", "[", 
       RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
      RowBox[{"HomThresh", "[", 
       RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"FR3", "[", 
       RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
      RowBox[{"HomThresh", "[", 
       RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"FR3", "[", 
       RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
      RowBox[{"HomThresh", "[", 
       RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.0001", ",", "5"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.01", "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "Threshold"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.55748593577218*^9, 3.557485964915331*^9}, {
  3.557486282458538*^9, 3.55748629794547*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.01], LineBox[CompressedData["
1:eJwV0X8w1HkYB/BFDst397P7laM6bUiIsP2i8H1Xqi2zXeoqTSFrVnVo+4VS
cSulWqGGfsoIF9GoVGcJqSvMkLaW0o+RJE7qWrUhivveH8+85zXzzDPvmWeK
TLFKbsjhcKTs/J8bl8X0b+HoGHli41srDgW7L9MDFMY65vBxmbWHAYXe7M6C
GK6O4fS1NUsMKcTqfg1KstQxo13d+j3jKJw47XLnvJOOWf5ms1uLKYW6d69T
m1fqmKux5RmxAgruScudZl3UMbzDttbRdhQMb08OHVvQz0yyp7keiyjU1oYW
5uV8ZvjSDlH4IQqP9l/YPL3rCzN1vM2koWoK9W83RQbaf2WMxCXvvPopPGuv
WJZ8YIDx/cOPV+7Ag3cGyc2uHWQ2zKx0lQfyUNb6XXPX9hvjEOV2MDOBB8u6
bYuTY4eZd9CmcIt4aIhq93QtH2HSpiSGbGniIbPw7VCH8AfT8rC1Paufh+tn
uufuWzfKJG0tkoQJ+Sifpagsyxpj/lEfD+rx4OP3sjrVvjgODmcUOgav5CPv
z99iM6wNYK1/Wh0QxUe3zK15er0B/BMlAdOO8pHztaE+a6chvKu+8VwK+EgM
Dz+wU2gE5XCb5eIqPqLOS3Jb7xgh3FQ/Y1UrH0mlroklYeMgzl4zvraPjwLV
hkYTgTGWbEvLUBkQzPOTVoirjWGk6UtLtSD41ugbrgn+CT3mLk0KK4L79nvj
9eYmgPncEw9EBOq1N6SqUhM8USaOWLoQiEKv3dNJTdE3EvRLr5gg03Oo4NWw
KWr3vox29SHwfO23aH62Gfy8NnKO+RO8WKtZIQrggrhZ1QVKCQbzHb5rB7h4
VbHlQPEaAt+mOPnwKXMEuu9Z7RVMkF4z3qfQ3wJHlzVEuMoJuKllzXXdFshO
ibggi2L7zhAa3WL/zMl7MbJoF4H+fFWBs5gHn4jSkynxBNZdckOBloeC4gly
kZJAMrD+YYKSj+/10eKfjxBodjgWuwsJOj8UfYpKI5izWulnIiNwr6HD92cS
5J1VmuWpCUodt3K7zxHkS5XiWDMBZlY/da/OJSiOcDxJhQnQaNvz5P0lgsj3
VxZalAvwJFni8/QKQe1LcaC/iRDbp958Pr+MYKI45BQTIoTZaOkOfTmB+cAR
791XhdD+7XzCrZrglkOWGxkTwoMf4Op5j0CuXhKkWEPDXropPrme4HLFYIfJ
JRo7vL5Yy5oIHPuD7yoKaURazD4XxzrP6f7FZ0U03qSrbI6zPnc6Q1ZYwu53
xgnVrFNjnLuWXKdhE7L2I/WQYLvnhp5DVTRkZYqlFaznXq75aKSlscDJK533
iOBmh0NzZAuNqe5FWnvWHtaqUm0rDU3JHCtv1k4p6xT5bTROzbuWFc56glyn
W9hOY6uVbYKa9ajITq/spVHzeNrXMA1BfNCRlt73NI655E+MYz2Y/u/NwA80
wu4uQCpr3WhlzJRP7P223oN/se58tXqwVk8jd+ijnvuYIMSy8pnTAA3jVJWF
iPXLAJE6Y5AG5/YKu9msWyo/7Nk0TMPXZqkklPXKz6vWN4zQoF7vD9rNusm5
wtvjB42c6OcRR1lLwiZPODNKw4IE78ph/eDMoeGxMRqhAtOEG6z/A1mSD3Q=

     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJwV0Hs0VHkAB3DGvb/xLOZaZ9QpUs0SilmppLlfLbaHKb3QqTxXdaqlh0ch
jtfqREVK04YNY0VlM9V6rEoUNpFdJp04ciLUVkZNpuSxd//4nu/5/Pn9zgsO
3xzK09LSknL5v3eujRzdq6Vir08rZhlpUbD6aLs+nFax4jhe43XOr3NfyiP1
VazG44zjBm0KUaqNfkmmKtZmrnDraR6FrAuL7l2yVrHyI3SLAU2h8dWLjDZv
FRth4VT0VY/CkqR11k4FKrZl+KPBDYYC70+LgGm3UVa3NKbhiIhCXV1ASWH+
B7Y1Z3JOhBeFJ3F5e2wHPrL62Y+e0j9RaOoP3L9p/id2Z6Votuwkha7e6rUp
x8dYSX9Dhv8VCisyjS/n1mnYiiLpiFs9BYVyov3+3C/stb2nrsX1UDBtDPNI
iRpnT5l3D8rUFJoP9DraVX5l6/xu2jfp0ThX0v+5TzDJOq+URERZ0KiQDS6L
9Z1i3yfnvckT06h0Cq9RnJ9mU52FgdHuNPYpGtNjo7VglhZ26qUPjcLirVGZ
Qm28S1me7baHxmCwfZttkzbWqTQ8h6M08j81N50/zINB6TY7oxM0EkJCjh8W
6KCpbPjZ8hwaBy6tuay8p4Og3KVzxuQ0ksrtEq4GUVgo7fC0VdCQp+9o4ZvQ
MDvIpry9R8NFIq0W36HRI73sM/SYxpeWVSHtuwj6dFOcsp/ReDD/WIzagI+G
hoDA5gEaVT43penlfGR4nY37a4SGZcCNepVUF00Tz6Ndxrn9jp/lPeO6qLX/
NseBJnB8Ifl+Za4eukm8h3AmwXOf9g2W6/Vx1fecKMGcQFO0YKJjTB8Sb6vO
kPkEqx5Hh47nGOC5a9qi7XYEZ+5+41riboheQflQ81IC/QxFW+OgIVovTP7o
JyH4sligczvVCMWaUuMUTwL1pVq5jXgGluRZei/cSCAcCOWZdMyAmdIhecKH
YM3Y9tb4xJno6+lxcw8gaD8kKlsiMIb7YCfbupvAeUuihB9sjIf1rV46YQSF
FxP1CquMETuHCi6OJCiSJoqj9Ezw+fR9xcU4grLdorNGQSbwPPmd/FMywf43
11YbVprAT3zIWyedoK5bvMmdLwCbNWx6OItgttg/h/UXwHDbyFp3GYHB2IkV
Eb8LoO3mMRWfT3B7wXl742kBJJY2XjFygtAqT7/wbQyGgoKslGUEpdWaPv5v
DAqyXUeLbhCIRnfdDy9hUOzkm3eHc6H1g4KuKwxc/ln8QxfnXy5kBpdcZVAf
YXZOv4IgI9JmwLOCARX2t+AQ54OOO4ZSaxk4F3jKVykIlpXefafTwWDH8uvm
ypsEt/oWtO3vZND/Shj/nrODML28Q8ngqdqrj3+LwDrNN7zoGYMZ+TPzXTjP
ClWpVvcySPpXd/pXzlOWVurE1wxscs19990miPE70fn6DYMgr6WyZM6aM+9v
bXrLIGB0blcuZ9VUTeS8EQY1sbs2POH8smeLpk7NQLUyy8rpDwJ/05ou6zHu
D1fRZinn7vWWVZkaBrXq9ITdnDtr3h4NHGfw8/CjDhln7w+btzd/ZWDaKR+v
4PzYpnqFwyQDudLbooXzmiCLWbIpBl3uT9wGOD+UpY5PTzNwPGYZPMn5P5HL
Fb8=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJwV0Xs0lHkYB/DfS5ow2jE/OrYkt5yhrEytS+H3rKxVQmiL4xbSZTlpq5lW
ioimmjoum9jShezoKo1aY1LRKZRY22TVkmajpJvXdVwy7777x3O+5/PPc57v
eazikkMSdBBCAez8n5GrRINbEU1Sk2yG93dqifXwIv9kPZp0oG+7fbq0pL/4
dZnIgCaV6RfTDV9qiZgOCss0oUnEqh/eF3ZrSV6hw73TAppgj63x1/7VkoY3
r461rqWJQtpn1NynJU6ZqwXLSmii87XkwNNhLdG5vSCG+W6QSCzUHvMMGVJX
F1NeenaI9Fu434lczpA/953Zsqh3mByp3hE6HseQxp6NicE2oySs1qzko4Qh
Hd01q7L2j5H7feZnXK4xxD2Xd764TkPOt6n65C0Mkbd/aau3mCCVC4Lcrn5m
iEnD9u+zxJPE6ijKzJqJoCmp23lx9RTJHgoffoURnCjvGVfzp0npavuHeVYI
bhS9dU3doCUa85myCkcE1cuSlfIChoT3XH805YbgJ3mDNHUPgqmBvy5d9EFQ
+vs6ca4ZBUy5tws3CMHbOMfWRY0UWGfNKGkJR3B2tKmxYKcOpFXlze6NR5Ae
H79/J18XYmKODr5LQpB02u98+z1d6E4yObFGjCCzYnH6ldgZQO4luinSEJRJ
I5o5xnowrkmh0yQIlnsF1Ajv6IHqD195Uw6CiWbP+LaomXDwON3vWYjggU3K
3hFDDoQ57XXhnkOgWF8VIK3ggH/BLvkcGQLLmMr7dMAsCKIjJx5eZfs7j5d1
Tc6C+y+0h5urEDi/8lq5olgfIl3sG2yVCP5Z3xZo6W8ACVJXcVsdAs0F2y+q
MQNwqBJn2zci8HyyJ2HypCF8MsW1/U8Q5Nw19Sj34YJoMst74ikCg2Py1oa3
XODwh7akPGfv/YaveyvbCExla6ZqXiIYOV1bZi+cDaN5gbW+PQjMehN0jFWz
wXV6t0nIOwR+Y+EtaRlfgXlUVbTsE4K2n+0uO/F5MMC7GXVgCIFLaIYXJ44H
fx/Pil2oYf/xW4Z+qYIH6gFBEu8LggsBGUKxvjEEcl+8kSIKLm+2yzeKNQY0
gPNX61GQ+P6qN7faGJxDzjl06FNQ1ykM9uHwYX692alpIwrmCaNPkmg+VI5+
lmziU2A4dth993U+oHq96W1zKLhlW+DIY/jgfXvzI9+5FCQofMOSf8SgPknl
xFpQcKlGo+bIMHj5e9paW1NgNxhVn1yOwf+DSilkXSp4UNJxEUOu9UTQStan
CnPjyq9g+EBo0SbWx0T2vb432H35hZUy1jucI/qyazHsWz+tdrChwPXS3U+6
KgzbJQonoS0FN9W2rYnPMLRQ+UXerJeYSStU7RhiVlIolLVAsiH5wnMMNdqS
x7tYz02gae9uDFeyhwJvsdZaWo9k9GM4tJAycVtIwd6ww8/632MoORS82Y+1
JufzzeCPGI4sXVEdxprWKkVWAxiWru1cl8L6dVeopm4Ew/yKdelK1tEmyg7B
GAZ3iajhMetOf0tFrgbDjW3O3E7Wz5Qff9k4ieGsIPXXKdZrh0LCm6YwdO3S
bze0o+CJfY37kmkMc2RLTc1Z+8UumFukxZA/NhG6mPXDouxJhsFwvDgyz4P1
f93gIJ0=
     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJwVzXs81Xccx/ETcVzjnJ82akUlOwgdXUzJ5zOXRiaX3JpbmG56dKrlEIvH
sTxWD4qEbEludcJSThrHmksPox5JNqzWRYaRVqcj3y/FOey3P96P1+P513tF
rCgwXoPD4fiy+78R3okTezlKSN341+V72wmsnLT1EWkpwXOverumH4Hx4qHK
RD0lGNi8eunCWqz0C8swUYL4496h66zPnrdpuSBQQtXBBGW+P4GOf15kd/sr
QUeg+DY8kIBDxjbB+jIlpOUdqnkSTEDjF/Po+c8nQGV4paUigkBra7S0vOQd
aN8YqEvZT+Dhtxf32I5MAroZDh4WE+gc3pUQsIqCoX9X3NcSAo8G5N4njk+B
unGkJC2bgHOucWlx6zTYCYUxGwsJyPpVPW3LP8BokODM8lICJh0HPU+IZ+CF
+77iL6oI3D0wIFzTMAtGfjfPRNURyJcOvx/kq+FsdKlDnZxAXdGoU2roHGyq
9B9k2gg0rBc1yQrmwagzgqfuJLBf1pGVmsTBhwHB6tUPCZRfDhLnmi5Az2MW
oaf6CYzG2nXbdi7AuZ+tG22eESihdzsLjmigR/FA2e4hAulxcceP8DXR83SU
TDVG4MAFr9L+Fk18kBxf0vOGQEbtmvSamIWY92VIiOEkgcqs8Ptcnhbam5F9
me8JbHL1lTv+qoWRZm9XyNQEPtzfEtcTqY264gynCA0K7auOpRB9Lrat3PcR
cik0htz0zarl4u2xzsU1+hQsom/cUfrqoFufcP+AEYV84fvKZzM6uKw7p8Db
hILwhav75mJdXBeU1+RtSuFJSM92Cx89DE6KdUv/hMJ0haWqd0oPdTc3z0ss
KGzpSoqfKdRH5xDNbastKeQ0L3aRehigZpL5yOynFPSyZd0dowboJ1lel2xL
4YM9X/NWpiHe5Il43fYUyIXbldaOi7B5eKAhyJGC6Ui8Bq93EVbnB0yf2kDB
a2rngzSJEfYHHD2k+IxCz2Grage+MT7/Rt2l5UJh4w6JKzfWGO273RapXCmU
/yDRLW80RpWfTGruRqHCV+Io1uWhSCGVqjwoVO+2yjOM4aHcTrZey4tCwquf
3AwaeKhdzwlVbKPQ+tQxwIPLxwN2Gy4W+lJY6hhVCFF8LH0nrN/rT0F/6qTz
0et8HHIxeaAKpHDLssDOeJ6Pgg73LUnBFOIbt4aJghmsEiz82yyMQpV8epB7
hcEMvxnOd19RsJqIbBNJGXyq0Ko+zbpc0F726CqDt8JtA4tY/3g+N1Zaw+C4
Tfula6yzE61HttYxuC5ZuPYx60PC8LHM2wxOpJpZ2YVTcKpqfqPZy+DSef6e
P1nXD1p2J/QxeGRB8eQg67WmWbW9/Qwus3FP/5e14PtQUcVjBo8nvT7HiaCw
JF6pdBtgMKW1VmbDes5iJZGMM6gzbNSRxjol7GTf+CsGf/fJ8jjFejpHUR/w
msGXs1Z3zrFWzjUlrnjL4GZ5S9NV1kPPdky3Egbjd6aU/cE6yqTpkWCKwXvX
Zk2fs37qY9GYO83gmtCSnDHWfU2vk3fNMOjp4JWiYu3/LnDn3VkGDcv8FNqR
FLqs5c5r1QxyFMkxPNZeMeZLiuYYzHdq713K+reizJn5efb/ktDTivV/Dl1U
Tg==
     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], Thickness[0.01], 
    LineBox[CompressedData["
1:eJxFkwtMk1cUx/uQlj5tq2MENt5rfCJtVHysvR++BjK2MJxuQ0ToCgMJbK6U
bQxJUQgJc5ppjQYlrnQSHdNRR3hMWTFamE7WiGwLGtBSYVtkLWtpoUA7XW7P
bfKl+eX3P/d895w2Nr/sLTWDRqOpnj3Pv/emlU99QHMi+0xlIBBwoDU1O5et
/dqJCmnPP07E+DE6N5AyhSjMj68jZqZzCrUGAv/nzebcFkPTv2gac3/TIXZh
iguJcf7Xz88VrrS7EANzelJ1Uc9hN3LjfN/Y/gOZ8dPIj/nNvKPDxdZpRMf5
30e60o5UeRATc33yE40o2gu88bjo/FmzFy3C7DHVbbhSNoN8+DzT0Ly1N2oW
eOzuOl7z7Vk4f6mldPsRrQ/NY1965sLmP8Lm0G/B+5SMyFZ1zKEpzIncPD1L
PQ/1J1vGZh5JFhANc1yMOjyxfQHer+30eHLlHj/4jrVl3SZ9AOpV0mrNilga
FeRik6WhsoJGLeB+rFYBndVPo4L1hm92aY+H06ngvMbzVw+s7KNDvmm6v09/
kAG+WqWqOihhAmsDQ8KEIib0K2lMPT/0E2GvsfuYWbQIuObyqupv8wgbG7Lv
sMUhVHCfm5QZXfLrIeAjard/qROwgGfvKFTWHBYVnO9IxYNS2w8sKoD5Zvyn
n7l5bPBKRZgd5bCpXsydu69mNFxmU8F9PB2WhSr9bOoJ5pjc7284M0IpB+b3
Uu9fLTCGUi7MJ2Uzxoe+UCq4//z6SHdDOgdYNqrcuvksB+bX6vGeWN7CgXlJ
hW32F00cag7zS4r4OncfybMa2T9/5+LAfYZ3W9+ISecCe5sT5gc9XMhHbBhI
mtjBg/MVv1Sofad4sN97qdGN6huEC25ZrNZJwsd6Xni1ZRsf5vv6K++HdOj5
4LlfmAYs43zob9Hczq4RCsg+c2x/KtYLID+bKGG21wrgfdyN14zL5ULw4XY1
QzwohPqkydGJ11YsBp/qeffuId1i6OcuGRQ57hG2fiS9tEYigvrDtixN5CbC
67N0Sna+CPIlWrpx11HChjM6jqGT5A0f06P4j0WUF/vmDJ1cyxHDfG86y6OK
lhK2nyjm7o0Ww+9LOpxlS1knhvteKpB+JcgTQ78Df7du4XcQHzbmSFs2Kob+
5gfyzG1sCfCetqo45suE/6nrd/XKJTCfSPm+U2gf8TxP/UbNFeLbE/SrRQHC
6s4d75S9vQTyF7u8j9gXloD/UJY9UXuN+OSLPZPMQeIj1E7nlhHi/TFxbt1f
xDv93eWxDuJtD7O8Zjfx97uffrLfR/yt07XP/iqE/wM3IeWR
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["Threshold", TraditionalForm]},
  AxesOrigin->{1, 0},
  ImageSize->{570.6666666666669, Automatic},
  PlotRange->{{1, 5}, {0, 4.204786271326468}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5574859665983686`*^9, {3.557486283667544*^9, 3.557486298837761*^9}}]
}, Open  ]],

Cell[TextData[{
 "As a first approach, we observed that for a fixed ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ", it appears that the heterogeneous/homogeneous ratio scales according to a \
function of order 1/",
 StyleBox["k",
  FontSlant->"Italic"],
 ". As an example, here are the ratios if we set ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "0"], " ", "=", " ", "5."}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.560246249653048*^9, 3.560246263640848*^9}, {
  3.560246302108823*^9, 3.560246371186178*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "5"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.47648691715173`", ",", "4.204786276098524`", ",", "2.8393504806553045`", 
   ",", "2.143670213289029`", ",", "1.3352415761082526`", ",", "1.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5602463750757713`*^9}]
}, Open  ]],

Cell[TextData[{
 "The graph below shows a plot of these ratios, along with a fit of the curve \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.401", "+", 
    FractionBox["0.608", "k"]}], TraditionalForm]]],
 ", which provides a good match to the data. The coefficients were found \
using nonlinear regression analysis in R [R Development Core Team, 2008]."
}], "Text",
 CellChangeTimes->{{3.5602464016425*^9, 3.56024644085903*^9}, {
  3.561369017983657*^9, 3.561369018925708*^9}, {3.5613690495321217`*^9, 
  3.561369067996488*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  GraphicsBox[
   {Thickness[0.001984126984126984], 
    {FaceForm[{RGBColor[1., 1., 1.], Opacity[0.]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., -35784.}, {
      36288., -35784.}, {36288., 504.}, {0., 504.}}}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 84.5}, {461.1, 
      89.89999999999998}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 89.89999999999998}, {461.1, 
      84.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{306.3667, 105.5446}, {
      311.76669999999996`, 110.94459999999998`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{306.3667, 110.94459999999998`}, {
      311.76669999999996`, 105.5446}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{178.3667, 156.36559999999997`}, {
      183.7667, 161.7656}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{178.3667, 161.7656}, {183.7667, 
      156.36559999999997`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{135.7, 200.02519999999998`}, {141.1, 
      205.42519999999996`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{135.7, 205.42519999999996`}, {141.1, 
      200.02519999999998`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{97.3, 285.7739}, {102.7, 291.1739}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{97.3, 291.1739}, {102.7, 285.7739}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 428.5}, {77.1, 433.9}}},
      CurveClosed->{0}]}, 
    {Thickness[0.004464285714285714], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 433.9}, {77.1, 428.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{117.0667, 73.44}, {458.4, 73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{117.0667, 73.44}, {117.0667, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{202.4, 73.44}, {202.4, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{287.73329999999993`, 73.44}, {
      287.73329999999993`, 66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{373.06669999999997`, 73.44}, {
      373.06669999999997`, 66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{458.4, 73.44}, {458.4, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLZx4+LK2b7TDjENfNWIeezrA+C+qRNa5p3o5GD5b
p/okONphRYEt1/WzXg75H1pPhiRGOzxYDBSQ9XZY8ysm92hetIPAdaBADpTf
BNW/0huifm60Q0I/0IIr3hDztkP1//d2mOEj2uN1M9pBYp37wyoRH4dFyjv/
tDPGwPlgeXkE323KN7Z4yxiHE0Dn9nP4QOzzj3HQaH0duOODN8T9aTEQ8296
O/zbVP1pQ0WMQwPQOQ+3Qd3THgNxb5e3wwPdCQt+TI1xWDATCGK9HWQt0l0y
F8Y4WBgDgbq3gzo/99ZlK6HmPfeCqN8INW+Zl4PN3qBpittiHA7IAR0QgODD
whPGB7s3ydPhy+3rjcXrofxfHg6pko8ixBdB1a/2cGied3bV+SlQ82I8HIxA
4dUAdY+8B8T9QP9xAOOO4Ys7xP/eMQ4XzgDBCXeI/7Wg6je7w8MTxj+4Yomf
w5loOB8cnouiHTqAwSd30x0SP83RDgYxwAhT8YCERzw0fho8UNOHKCK9wPwL
AE8FBq4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvUh555/2SdEOMw591Yh57OkA41sYA4G+p8MrFhNB
s7nRDi+qRNa5b/dwqDyuaTVpU7TDgplAUO3hwNEln/zueLRDxA651tf2Hg4H
Vyzxc3gU7bDB/WGViJIHxDzGGDj/ge6EBT8UEHy3Kd/Y4q1jHDiAbmFw8HC4
GvZGf3dAjMOKAluu60DzUyUfRYinQflA+9f8isk9WhDjEADUvg7oPhgf5n4Y
P6EfKDDDC65f4PriAlsBb7j5YPd7e8PtN4gBamiDygPdVwG0bvESb4fmeWdX
nWdA8MH+eRgN55+u99hfeyLaQWId0ENd3g7/NlV/2rA1GmJ/mDckPOZBw0/Y
Gx6+YPdP93JAD38ArmW1PA==
       "], {{116.4802, 47.52000000000004}, {116.4802,
        48.72187500000001}, {117.682075, 48.72187500000001}, {117.682075, 
       47.52000000000004}, {116.4802, 47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGCwBmIQfSbW+wS7UbxDRhoQuHg4wPgnvmrE9B9yd1h7I77M
/1gsBv/B4gJbrsfuDhpvefcZnIyF6GfycJATy/L9fC7WocKW6/piBQ8Hzgyl
nIobsQ4b3B9WiQR5OPQFl6hMfx7rcOEMEDR5QMz7A+Vv8nCoWqrjLCMY52AA
tO3rIw8HoyMb9fL04iD2S3k6XDN5b+EaEuewYCYQRHo6uBf95H/ZF+ewAuic
67s9HbavZ37esy3OIQBo3TpOL4j7Tsc5dLwO3CHn7OUwU0ti6pX7UPNqvBwC
Pec2qL2Kg9qP4IPNe4rgOwC9UyDt7SBif+zO1gdxEP95eEPMOwuVz/WGhN/u
OAcBINd2krfDA+7JK5sWQdUv8Ya4vwXBb6m5sDkyBcE/1LY8/JQX1L0TvSHh
ZR4HCb8sb4doBcePySpxkPB3hqqXinNoEFnn/pAHwQeHz3Evh1ePzKQOXI51
4ADGNcM1L3h8gMPH1tvh/4S631avoPHVA3U/J9S8Q1D/qcc5vAAqd/8JVR8Y
5yCxDuQgHwi/FcFP/f4kceFOBB8cn4/jHCyMgeC7t4PN7ND5qxnjIfbtgZqn
EA/xXxM0vPTjIeFpieBrtAID5JEXKn+bF8S92lD13V4Oixn3sAopxUPcn+AF
sV8y3uGAHFCDmRfEPi6oemD6AKevr9D4uuUJcf8DqHtXe0Lk90HTS5YnJDyA
6Q1snoQnxL70OIcEYHLVuOIBSX++cQ4RO4AKlnpA4tsJGh+9Hg5fd97q+msG
Dc9SD4h9utDwjvGApFe1OIz8COMDALbrnkQ=
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLXUgWsExMMNhxqGvGjGPPR1g/BdVIuvcU70cVjUF
es4NyXBYUWDLdf2sl8MJdtvZodEZDg8WAwVkvR2e92i85U3KcBC4DhTIgfJz
oPpXekPUV2Y4JPQDLbjiDTGvDar/v7fD3a0tNQHTMxwk1rk/rBLxcUhaeM0k
fzWCD5bfheBvify6M+p4hsMJoHP7OXzA9vVeynDQaH0duOODN9j9B+9Czb/p
7SDwcvt65ucZDg1A5zzcBnXPO6h7u7wdGtUOtS3/muGwYCYQxHo7LFi99kb8
7wwHC2MgUPd2UJ3+f0Ldf6h5z70g6pkzIeYt83LQz1vMuIc10+GAHNABAQg+
LDxhfLB7kzwduv+mfk9hgvJ/eTg4y7x+tO03NPxXezhcvveAWxjoHrB5MR7g
8JJ9DXWPvAfY/VeB/uMAxh3DF3eI/y9kOFw4AwQn3CH+3w9Vv9kdHp4w/sfk
M7GnJyD4oPC8VZ3h0AEMPrmb7pD4AcafQQwwwlQ8HOaDwiMKGv4NHqjpQxSR
XmD+BQByKwgR
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQnbTwmsn74gyHGYe+asQ89nSA8S2MgUDf04FNSMTe
rTLD4UWVyDr37R4Ofp/7gr80ZzgsmAkE1R4OU69wZizqy3CI2CHX+trew+Fj
8pnY07MzHDa4P6wSUfIAm5e/GsFvVDvUpr4bwd8S+XVn1IkMBw6gWxgcPBz+
WBWc47ic4bCiwJbrOtB8Z5nXj7bdhfKB9j/v0XjL+zjDIQCofR3QfTA+zP0w
fkI/UGCGF1y/wPXFBbYC3nDzwe739obbbxAD1NAGlQe6rwJo3eIl3g6X7z3g
Fl6N4IP9MxvBL/eXE3sF9L/EOqCHurwdBF5uX9/cCrU/zBsSHrDwE/aGhy/Y
/dO9HNDDHwDW57jv
       "], {{201.8136, 47.52000000000004}, {201.8136, 
       48.72187500000001}, {203.015475, 48.72187500000001}, {203.015475, 
       47.52000000000004}, {201.8136, 47.52000000000004}}, {{207.912, 
       47.52000000000004}, {207.912, 49.56000000000006}, {204.192, 
       49.56000000000006}, {204.192, 50.52750000000003}, {208.10512500000002`,
        56.10937500000006}, {208.96575, 56.10937500000006}, {208.96575, 
       50.52750000000003}, {210.133875, 50.52750000000003}, {210.133875, 
       49.56000000000006}, {208.96575, 49.56000000000006}, {208.96575, 
       47.52000000000004}, {207.912, 47.52000000000004}}, {{207.912, 
       50.52750000000003}, {207.912, 54.41062500000004}, {205.227, 
       50.52750000000003}, {207.912, 50.52750000000003}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQrRnTf+hrbaHDjENfNWIeezrA+C+qRNa5p3o5FNhy
XV9cX+iwAsQ46+XAAALNhQ4PFgMFZL0d+kH62godBK4DBXKg/G6o/pXeEPWT
Ch0SQBJXvCHmzYDq/+/tAOQV/F1Q6CCxzv1hlYiPw9kzZ87wrEbwQfK1mxB8
oOn9TDsLHU6AGBw+YPvm7Ct00Gh9HbjjgzfY/aZHoObf9HZYArLwRKFDA9A5
D7dB3NNwBureLm8HkHc1LhQ6LJgJBLHeDkBT5FgvFzpYGAOBurcD2NqrUPOe
e0HUX4eat8zLAaTM+EahwwE5oAMCEHxYeML4YPcmeToATVvXfg3K/+XhAAoO
g8tQ9as9HEDeuHceal6MBzi8Hp+CukfeA+x+B6D/OECML+4Q/+8tdLgADLcz
J9wh/t8KVb/ZHR6eMD7I2bvmIvggZzhNLnToAHn8pjskfoDxZwDyqIoHODxa
m6Dh3+CBmj5EEekF5l8AVVsDfQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQffbMmTM+/YUOMw591Yh57OkA41sYA4G+p4Nc6+vA
HxMLHV5Uiaxz3+7hAFLmP73QYcFMIKj2cEgDgmVzCh0idgBV2ns4AFU9tFpc
6LDB/WGViJIH2Dye1Qh+TP+hry82IfhA4/qbdhY6cADdwuDg4QAy9ua+QocV
BbZc14HmA8nFBkegfKD9QO0ad44VOgQAta8Dug/Gh7kfxk8AMWZ4wfULXF9c
YCvgDTcf7H5vb7j9BiCHtUHlge6rAGlc4u0A9P6Oe6sQfLB/FiP4IGNPAf0v
AfR3VZe3wxKgO8VnQO0P84aExyRo+Al7w8MX7P7pXg7o4Q8Aif6/nQ==
       "], {{
       287.14689999999996`, 47.52000000000004}, {287.14689999999996`, 
       48.72187500000001}, {288.348775, 48.72187500000001}, {288.348775, 
       47.52000000000004}, {287.14689999999996`, 
       47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGCwAGIQraxR1/OztMiBgwEEvB0srh3NNUlF8EHyO5OLHC6c
AQIDb4euvief5icWOTxYXGDLFertkM35c8HzuCIHjdbXgTtyvB2mpHYkx0YV
OVTYcl1fPMnb4cMXr8hjIUUOC2YCwVJvh/rtDk1Kfgj+HTfmitMeCP48G50r
Ui5FDgEPq0TWzfR2OD5j9zQBhyKHFUDrrjd6O1zMj2c/Z1XkYBDTf+hrkrdD
6YM5gkvNihwidsi1vjb1dtj8qnjrVGOoe355gc3vNoCat98L7B42fah92Qi+
xDr3h1X/PCF8oP4NQK6IgZeD09rMex/NixwaRIAKQrwcnskuf3HCFsrP8YKE
hzOU3+LlIBl4S3qPJ5Q/wQscHrIBCD7IfLdoVP6xFKj78iHq5+YUObwAct11
vcDhX1kCVf/KExze6RVFDh1A78lNRfDB8aWD4IP9/8wDHF59ZUUOGWlAsMwD
HL63iqDxl+0BVq+eD7Vf38Nh70FxNeGsIocEYPBqMHlA3JMMDZ9H7hD1sdDw
P+QOjp8LoUUOFsZAsNndYYXwBZcZvgg+WL89gq/7X/GvmQnUvDvu4PhL1Ya6
B2r/ZKUihx8aQAsaPRwSjUINtOSg/uPyhPPB8scRfHD8z4bED4dykYPAdaCB
ZtD0pwMNj2mQ9OZtWuRw4ivQgFfeDr9Ovzt52AHqHhEfB58WXn99fwQfHP+R
CD7r4klWB5Og7vkDSe9zM6HuP+3twF9ltrquAJp+ZkHlgfFXAAr/MEh+Qs5v
AFiCeSw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvfeguNpkwyKHB4sLbLm0PR1gfIl17g+r/ng43HFj
rjhtVOSwAih9/byHg2TgLWkb0yKHjteBO+SWejiERW/cv8a8yOHEV42Y/ioP
h82vireKWhc5bABqF4nycND9r/i3zL7IIQDIXefs4TAltSP5rnORwwsg110X
Yl6NB1S9kgfY/mBfBL9+u0NTUgiCb3HtaG5JFNR+Sw+HZ7LLX3TEFzlYGANB
OsT8uSlFDg5c1xcXTPVwyOb8uUA9vchBAMi1vYLgL5gJBMqecP4PoPMP5Xs6
lD6YI7g0Bcpf7enQ1ffk0/x4qPrrng7zbHSuzIqC8pm9wPZ7hED5kl4OiUah
Bqt8EHyQfnlXBF9Zo65npx1CPzh8LBHmg/xnYoKwHxYfYPcXIfiw+AIAhljD
5Q==
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQ7Xrjwxevy2UOMw591Yh57OkA47+oElnnnurl0LMz
m/PnlTKHFQW2XNfPejnI1CQahd4oc3iwGCgg6+2w2i48euPtMgeB60CBHCj/
AVT/Sm+I+udlDgn9QAuueEPMewvV/9/bQS2YdXHQtzIHiXXuD6tEfBxeeuj9
T2Qoh/NB8pfYEXzBpXsPhvOVO5wAOrefwwds30fhcgeN1teBOz54g93fJVkO
Mf+mt8OBN/NsdOTKHRqAznm4DeKeq4rlEPd2eTtUcKto1KmWOyyYCQSx3g7s
5yQDozTKHSyMgUDd2+HUYae1mVpQ8557QdTrQM1b5uXgv35KaoduucMBOaAD
AhB8WHjC+GD3Jnk6/P1W+uCONpT/y8Mhss3iWqsGVP1qD4eF6ZtfGatCzYvx
AIeXpQLUPfIeYPdPBfqPAxh3DF/cIf4XKne4cAYITrhD/M8FVb/ZHR6eML6B
1kphgc9lcD4oPKe/KHPoAAaf3E13SPwA488gBhhhKh7g8Lh1HRo/DR6o6UMU
kV5g/gUA1YoEQw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/dJD7//CJ2UOMw591Yh57OkA41sYA4G+p4MVo2+L
7/MyhxdVIuvct3s43Cvs6lvypsxhwUwgqPZwaHp0fMbvj2UOETvkWl/bezgY
aK0UnvCjzGGD+8MqESUPsHmJDOVwfgW3ioYdB4IvuHTvwet85Q4cQLcwOHg4
bBX9fVpPpNxhRYEt13Wg+ZFtFtdaJaF8oP2r7cKjDWXKHQKA2tcB3Qfjw9wP
4yf0AwVmeMH1C1xfXGAr4A03H+x+b2+4/QYxQA1tUHmg+yqA1i1e4u2wMH3z
K2MGBB/sH6D/YPzP8pfy5T+VOUisA3qoy9vhwJt5NjlvyyD2h3lDwgMWfsLe
8PAFu3+6lwN6+AMA6ciyIw==
       "], {{372.48019999999997`, 
       47.52000000000004}, {372.48019999999997`, 48.72187500000001}, {
       373.682075, 48.72187500000001}, {373.682075, 47.52000000000004}, {
       372.48019999999997`, 47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGAwBGIQrSj/Jedab7mDRuvrwB1iXg5F14U+HWwrd7AwBgJt
Lwf7Jff39TWWO0isc39Y5eHl0N4addmmrtzhxFeNmP48L4fzaVefv6oqd7hw
BgimQPQ7VkLlDyH4Kwpsua5/R/AT+g991fDwdjA9a+13sabcIeBhlci6bm+H
XTt62T40lzsUpAHBIW8H7W/T7wp3lzt0AJ0n9xOifuIUqHtEfBxu2lZGZCxA
8EHu9VuD4L99fcDy8VYo/4e3w2MR2ZOqe6H8A94Q/Ueg/A5vh5Ag9QWcJ8od
DsgBA8QFwecAhhXDFy84vwLoncUHvBx+HEpZlXAMKj8FEl58h8sdNoCsz4OE
1579UPOA4Qeyb8UuRPiC/b8ZEf5xmqcF3PdAzWfwcljG5aa69RBU/V1PB57C
Nd3Sx8sdMkDhs8YTrL79dLnDD1BwV3tC7Dtb7rBgJhA4IvgRO4AO+OsB54PN
X+DhIOYR8GfGSWh8BHmA3RN4EBoeQh4Q/+4sdzAAGv/1kjs4PJXXQd2z2d2B
aRaH9LwFqHy5yQj+bONFW8w7oPF32R2SXuqh5gHNB5m3uBzKB9pfu25bUn0x
1H2LEHxw+DJ5wvlg8z0h/j9eCk1/LZ4OoPQcBkuPWzwh9tVB+U8g/KzWcgcH
oPEFrF4O6OkfAKgaXpQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXXRd6FNjV7lDhS3X9cV/vBxg/ANyra8DT3g5mJ61
9pvYU+7wIXCHXOtcL4ddO3rZNkwodxC4vrjAtsbLQfvb9LuXp5Q7GMT0H/oa
BZE3mAXV7+XlkMGQ33hkAYIPll+O4G94+HJq0ZpyhwtngACo37O6Wb9nQ7nD
Dw2ggdVeDo9FZE8u3VLuoAFUvmMORP2mbeUOD4DWcx1F8MHyXxB8sH/UvMHu
mwzUf+Ir0MAAbwdF+S85YUDzJda5P6wq8nZgmsUhLbcGKj8Fwr+3rNxhwUwg
WApRP20Bgl+7bluS/SwEf2LMP+dfMP8D9cdpnhY4DgyfgIdVIuuKvR3EPAL+
zACGX0YaEAR5w8MX7F4tBB8W/gA9kMEK
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQzTSLQ/peS7nDiyqRde6Mng4w/oPFBbZctz0catdt
S/rfWu6wwf1hlcg2D4ei60KfHDvKHTLSgGCSh0NIkPqCzq5yB43W14E78jwc
btpWRrzoheoP9gCbFzep3GHGoa8aMfYeDmIeAX9uTCt3WAGUvq4NUb9iNtR8
JQ8Hz+pm/TMLEHzTs9Z+F1cg+Lt29LIVrC93qABqX2wG1b+l3OGHRkz/oXgP
hx+HUlY92Am1v9PDob016nLNnnIHB6Dygr0IvgFQ+dc/CD7Y/7aeEPuB+k8A
ndtf5OlwPu3q8yyg+RfOAMEcTwf7Jff38a2Hmn/c00FR/ktOGNB9CUDjNO54
QsJnAYLPU7imO3oGgg/2z0SofUD9b18fsFzcU+7wIXCHXOtcT4dlXG6qpe3l
DhFA7utiRHyAw8sewYfFFwDMCsx9
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 
       1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{454.47295, 47.52000000000004}, {
       453.41920000000005`, 47.52000000000004}, {453.41920000000005`, 
       54.240000000000066`}, {453.16545, 53.99875000000003}, {452.832325, 
       53.756875000000036`}, {452.41982500000006`, 53.51437500000003}, {
       452.00732500000004`, 53.27187500000002}, {451.63732500000003`, 
       53.09000000000003}, {451.30982500000005`, 52.96875000000006}, {
       451.30982500000005`, 53.98875000000004}, {451.899825, 
       54.266250000000014`}, {452.41545, 54.601875000000064`}, {
       452.85670000000005`, 54.99562500000002}, {453.29795, 
       55.39062500000006}, {453.61045, 55.773750000000064`}, {
       453.79420000000005`, 56.14500000000004}, {454.47295, 
       56.14500000000004}, {454.47295, 47.52000000000004}}, {{457.8136, 
       47.52000000000004}, {457.8136, 48.72187500000001}, {
       459.01547500000004`, 48.72187500000001}, {459.01547500000004`, 
       47.52000000000004}, {457.8136, 47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQ7bbt898rJ2ocZhz6qhHz2NMBxn9RJbLOPdXLoXd6
nlDzqRqHFQW2XNfPejnIRqVY3z9b4/BgMVBA1tthjQxQ4GKNg8B1oEAOlH8N
qn+lN0T9nRqHhH6gBVe8IeY9hur/7+2gbsix5s7rGgeJde4Pq0R8HF6pGXK8
+Yrgg+Rj/iL4Qs0HTj1krnU4AXRuP4cP2L5qzloHjdbXgTs+eIPdL8JfCzH/
prfDwVMLXbcJ1zo0AJ3zcBvEPfHitRD3dnk7VL4EWihd67BgJhDEejtwAA18
IlvrYGEMBOreDqeB2j/LQ8177gVRrwQ1b5mXQwDIQ8q1DgfkgA4IQPBh4Qnj
g92b5Onw70rFyzRFKP+XhwMoePjloOpXezgsAlq3VwpqXowHOLwOi0LdI+8B
dr880H8cwLhj+OIO8T9HrcOFM0Bwwh3ifwao+s3u8PCE8YHBKTPrBYIPCk/F
ezUOHcDgk7vpDokfYPwZxAAjTMUDHB4pZ6Hh3+CBmj5EEekF5l8AbfsChQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/UrNkEPnVo3DjENfNWIeezrA+BbGQKDv6WB937/3
+p0ahxdVIuvct3s4ALnT9R7VOCyYCQTVHg7NB04tbH1e4xCxQ671tb2HgyHH
GhmpdzUOG9wfVokoeYDNe/MVwa98qWZ44i+CLwQ0IJGl1oED6BYGBw+HbZ//
XtnBWeuwosCW6zrQ/KgU6/v8/FA+0P41MlEpuwVrHQKA2tcB3Qfjw9wP4yf0
AwVmeMH1C1xfXGAr4A03H+x+b2+4/QYxQA1tUHmg+yqA1i1e4u2wyHXb571f
EXywf94i+F/+XqlYCfS/xDqgh7q8HQ6eWuj6DRg+YPvDvCHhcRcafsLe8PAF
u3+6lwN6+AMAl/K1Gw==
       "]}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 87.19999999999999}, {59.04, 
      401.2979}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 87.19999999999999}, {
      51.839999999999996`, 87.19999999999999}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 150.01960000000003`}, {
      51.839999999999996`, 150.01960000000003`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 212.83919999999995`}, {
      51.839999999999996`, 212.83919999999995`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 275.65869999999995`}, {
      51.839999999999996`, 275.65869999999995`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 338.4783}, {51.839999999999996`, 
      338.4783}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 401.2979}, {51.839999999999996`, 
      401.2979}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{41.760000000000005`, 
      88.27685000000002}, {41.760000000000005`, 87.22310000000004}, {
      35.040000000000006`, 87.22310000000004}, {35.28125000000001, 
      86.96935000000002}, {35.52312500000001, 86.63622500000002}, {
      35.76562500000001, 86.22372500000006}, {36.00812500000001, 
      85.81122500000004}, {36.190000000000005`, 85.44122500000003}, {36.31125,
       85.11372500000004}, {35.291250000000005`, 85.11372500000004}, {
      35.01375, 85.70372500000002}, {34.67812500000001, 86.21935000000002}, {
      34.284375000000004`, 86.66060000000004}, {33.889375, 
      87.10185000000001}, {33.50625000000001, 87.41435000000001}, {
      33.135000000000005`, 87.59810000000004}, {33.135000000000005`, 
      88.27685000000002}, {41.760000000000005`, 88.27685000000002}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
      0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJrIGYCYjuu64sL4l0cLmyO/GopnuzwqEpknftDTL7T
x+QzsYlJDufOAMEBBB+sf6GLQ91vq4JzSUkOJsZA0Ozi8Iv/5fb1qUkO3zRi
+g8Fujh8sHB1L8pKcrixuMCWS9HFYZNe3mLGIij/ozPEvJokhxqQdQecHVaE
nzI60pYEsb/T2YHleY9G7tQkB26gdbZezg5h81evjViR5ADyC8MLJwe+fQYz
Vx1NcojtP/RVY5aTw7E7W1tqbiY5yLe+DtyR4ARx32OoeepODhZSB6IV3sHs
d3SYsrIp0PMz1Lx9CH56GhB0IPhg/0U7OpSoTP8/4R1U3swRYt7TJIdZM4FA
0BEcfjtvQ9X/d3C40/U3tfw8gg92/wEEX89Z5nXSBqh7hRwdfE6w285eDA0/
S0dIeM1KcjgLCv8ERweJqVc4MyYkOWgBpb9Og6rvhobPHQR/CdB71886OiSU
+cuJZUDDJ80RHh9g+8UdHbJ8P/cFF0PNe+AAcX9TksPhr0AHrHKA+G9SksOE
QyABB7D6y8vQ+AcQ/HkNaofYgP4vAlq/eI0DJD7fQ+177uDQdeneA+7/UP8p
Qu3nS4aEZ5YjOLy+iyY7tAGDQ+4gGv8tgg9WL+EEca9wMsT9Tk4Oe1iFROz5
kx3eAJW35jpB7OeCqgemD7B9zMmQ+DrpBE5fb38kORSC3PvDCez+tnfQ9GIJ
TX93kyDmdTuDw2MBML15PAQqOO8Mtm//xiSHYKD067/O4PT3Zwk0PsRcIPE9
Hxqeei4OzxIXXtsyExrebi6Q8JoKzU/xkPzkNxHBh+VHAJSJpBs=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}}}, CompressedData["
1:eJxdlHtI01EUx6dSkRZBmUrEyogQNREaEYF6fo/wERrORAKVlqR5K10lPcRi
SZr4SCukaYsI3wppabGFhK7sOVaJNMsaKImJixYxy/qn270nbviDwT7ce7/n
nO8594YfKNYfDNBoNH70l0l//vhfM6jAVNDVLn+ZAONuBTSXz/1+kEcgp97u
i5hXoKwtWrEUEBhvMcYFblUh/nrmzagiAsfiAl0taSokHV9YVXiKQJCLbjCq
oE++YWo34f7zfH22RnDkl5UPY5sWrXcSqJxLt2oP4/p9AlOlwbcTE1Rw5Ox+
tmyYQDwNZ1yD+1/i/o8KVJa97t/3hoBNWzGXbhG8gaI1V3CGlW6IQnYgByDb
CcxHZNfbJ2TI3ih9y7MSSJqkCTyVWT59PYI9U9vXgUVw4KFNR342oh8OGVr9
BpesvkTgkY8KvpXB2hswU3sB/dkvQ3NkWOPeKgK6bfQz8P1XqlGPstFZNZpb
K5j1o05w/o9PhnAL6usxXhfWr8N4AwR6E+mBEFwfItBA25k9I7H4YyPY307B
Bfn0OymY+ZsqsXi3hlE/WmL57LShXpDE8nX3ESij7Zr8BTxeu2CmZxYcnPDk
wz06Dx4qX0HPj+u+7hih8+J00I/qs3k8jfmnSdzvYmQT5lOI++0Sm7ctBehH
N88ndxf6tUeCedv76rPJ6PdyifX7nR7rcwFoQ0jqCQPOYxtAQ0bJ5lAj3oda
AHtlR1ZKueC//q4wL+IOApF0fHxm4PoDWO9d1B/GfB2o70T/vcDqG3Lh+fUS
6B7fiSly4zwmY33T6PcZ7k/5Z1zvEczux4RgpreUz2/sNPYvBufDjf5nyiy/
7y6c3xKZ318n+leDbMf71Cyz+3hxlEArtctlk/l9dKN/szLz68UM9itM4f32
Yj56hb8fPtRvEszqWxC8ltpXmqJy/zyoX6fy+ZjAel+p/H16jvl7VebvtX7B
rD7zIjZh/8ZQ7+i/+lR+v3Lw/TGovP+pGD9U5fOo4vn/3s8/uRtVpw==
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 
       2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{41.760000000000005`, 
       276.16179999999997`}, {39.720000000000006`, 276.16179999999997`}, {
       39.720000000000006`, 272.4418}, {38.752500000000005`, 272.4418}, {
       33.170625, 276.354925}, {33.170625, 277.21555}, {38.752500000000005`, 
       277.21555}, {38.752500000000005`, 278.383675}, {39.720000000000006`, 
       278.383675}, {39.720000000000006`, 277.21555}, {41.760000000000005`, 
       277.21555}, {41.760000000000005`, 276.16179999999997`}}, {{
       38.752500000000005`, 276.16179999999997`}, {34.869375000000005`, 
       276.16179999999997`}, {38.752500000000005`, 273.4768}, {
       38.752500000000005`, 276.16179999999997`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJTIGYCYjuu64sL9jo7bGupubD5Z4kDmL/R2eHF9vXM
6dylDoe/asT0f3N2WHjN5P0OHihfy8UhbzHjnqP8pRD1vi4O/nJiWb0ipQ47
5VpfBxa4OBjM1JIIlSx1+AZUfqjRxUHm9SMzKXkEX0jE/tgdVQR/2v8Jdb91
Sx1MjIEgE6L+lkmpw3r3h1UiFi5g+yusSh20gMq/srk4qB1qWy7uANV/FOLe
506lDqLrgBpKEPwJh4AOVkeTf+UE9q8xUP/SAluu63udwO4/awW1f6ITxP+m
pQ41IiANTg5WBec6gvQQfFf3op/9qgg+h+3sUHmFUodzZ4Cgxclh9dob8WbS
pQ6FQOMXz3ACh8dVMaj9a5wg/hEqdYgFekfjmJND1Nedt7iA4ekB9O66pxB+
FzC8214H7pC7CnHv5j8lDgrA4N0xz8GhR+Mt7z/OUjj/CmeGUo5fqcMSkH/k
HTH4IPV14qUO8iD1Hk7g8JcRgLpPygkc3lESpQ6zZgIBs5NDU6DnXAZFBB/k
X34tNL4ZND5UnBxOGR3ZqOcAdX+6E8R+j1IHbmDysF0FkV8XAA3v/xD950Og
4ZHhDOeDw+MMgg9OT0ouDgeiFRwNA6H2ZbmAw+OzJzR9HHFx+Jv6/YmiI9Q/
H6DpzRTBh6U3ZH6MJJR/xQUc3+r8UP4cSHq0Zoe6LwWanv+XQOyTcgGnh0u/
oPkFKf8AALULcOc=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxFk11Ik2EUx2eJ+ZWgSS2iRa+RslxBWS5i9n/evbDCEiroSkGEbgahpeX7
hBiDDLpaYDcGRmFjJaQgXSywIAO96IO8SWEFGUXQCL1wySpX5/nQ54Exfnue
nfM//3PO7o7Osxc2eDyeIH3E98OuUOncCMP5isDEpyaONY5O9gx693PMj9AP
3ep+uJ7j7Rs6LQzi+oaf42bmTMrXyHBvMTn9upaj4RCdSobp5sZbrIajbI4C
5IGadK5/dKfhieHFZNE2wyL8eCVHW3wqW1fKMGulc/lyjgLS6LEYfvdHJ5eL
OfqqxyILYCgUgjZynEv5BjIXGR6JhP9cpecxw7f3Vpr/dVW8r0zG78y5Kl/Q
lnp+rLi4TdetCcO/6lrjU92a/7jwE2ZbbFwZ9BZ+8HDFR2x4ScCTIs0+W/lR
rrnKxikq/36V4RmSV7DdsIjv36PrbVA8GuB4RXLiV23pX+ywfp+ypf9tIY5d
A1RgRVj63cw4EqJfvYZl/c8NN1E3u1bD0q/Lxzneif4FHenvi2M6f48j35cF
OU4sXKsee+Bgif6+cpArf146Sk+99v+zfr+X45IYlyVH9uepzzCVE+3baljU
HyvW8WYctFODdqy6Sg/lF/07uexiPEICLJW/N+Oq+obCuCMM/67vP9rrLPu/
yfDdITo0DwJ/ZvQ8bGbK36yLL1Re5JmatwN53f84EBADWcLX+TotwBavYdl/
S+9HEqD2tif2aT/nofwhv+T8lDDYVGDHUe3/abUPsZDZr7V9+w/yIpEU
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O3xYfsy7/FeFw4RDXzViliP4jEA1DFec
Hfh0N81d/7vCQb71deCOf84OPuadjgr/KhweVYmsc9d0ceh0THg6gaHS4ZtG
TP8hTxeHpxeUbv9krnSI7QcamODikAAUiOaodDgMNL6/zMXhuLd550EeqPpG
F7B5CYIIPsh+czEEf9Pc98vdZCsh9me5OGTtKZkcoVzpUGjLdX2xjYuDBEsY
X65GpUN6GhDwQcxv1K10mDUTCM47O8x7v/wYt0GlA/f1xQW2DQj+eveHVSIm
aPwfTg4rgNZ36kLVn3FyAFon0aIB5S9wcrgI9F6dMpTf5QS2X1cWwZ8CFOgT
RfBB+ln4EPrDQAHKjjAfHD5MCPtB/pP4WwFxvyEiPtDjCwA2Usdz
       "]}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.04, 
      73.44}, {473.76, 73.44}, {473.76, 444.96}, {59.04, 444.96}, {59.04, 
      73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001984126984126984], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}}}, {{{264.23999999999995`, 18.770625000000052`}, {
      264.23999999999995`, 27.360000000000014`}, {265.295625, 
      27.360000000000014`}, {265.295625, 22.44187500000004}, {267.79125, 
      24.960000000000036`}, {269.15625, 24.960000000000036`}, {
      266.77687499999996`, 22.663125000000036`}, {269.39624999999995`, 
      18.736875000000055`}, {268.09499999999997`, 18.736875000000055`}, {
      266.038125, 21.935625000000016`}, {265.295625, 21.225000000000023`}, {
      265.295625, 18.770625000000052`}, {264.23999999999995`, 
      18.770625000000052`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}}}, {{{12.96, 145.41589999999997`}, {4.32, 145.41589999999997`}, {
      4.32, 146.47902499999998`}, {7.920000000000001, 146.47902499999998`}, {
      7.920000000000001, 150.9359}, {4.32, 150.9359}, {4.32, 
      151.99902499999996`}, {12.96, 151.99902499999996`}, {12.96, 150.9359}, {
      8.88, 150.9359}, {8.88, 146.47902499999998`}, {12.96, 
      146.47902499999998`}, {12.96, 145.41589999999997`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOUvPiNE8fSnYQXef+sEpHzcHv4sSY
f0+SHWL6gQpK1B328c0xXnQ/2eEwUHl/kYZDE8vR/o1Xkx08HlaJrFPXdJi2
iadQ53iyQyxI/R1NiPyOZIf0NCAw0wLzDZch+CD1a/oRfLYPYh4BxckONxYX
2HIt1wTzL8QkO+yUa30d2KEBMd8n2UEL5KAMdYc/EsXXJ1lD9V9TdTDwWcbl
ZpzsUGjLdX3xBWU4H6x/hyKczwACEgoOqxJCgpYD9YP9f1/WYUHnhoeZQPMV
QMr7pB1ywmrXmcVCzU+TgoRHEYLv8uvt6wO9CD7YP8uh4dEu7fDJ8Xza1T3J
DtzXgR46JesQscL0rPXZZIdvwOA7xKoAUX832WEJ0LvXZys6bDH/cejJU6h7
livD+fIg9xxD8MH2fUPjm6lg8EHx6R0Kdc90VTgfFL0iy9Qg8R2V7DBrJhAk
qkP4qckObUDr5GQ1IPyCZIdqEZAODbD/6+oQfLB9fQg+KH0ozYba76YBiZ+l
yQ52wOgouKsOCc910PQFTE/3Jre33toGte+sGlh+216o/5HSIwDHTCWe
       "], {{
       9.240000000000002, 154.71605}, {9.240000000000002, 158.09855}, {
       8.721250000000001, 158.0523}, {8.331875, 157.92104999999998`}, {
       8.071875, 157.70479999999998`}, {7.668125, 157.3723}, {
       7.4662500000000005`, 156.94167499999998`}, {7.4662500000000005`, 
       156.41292499999997`}, {7.4662500000000005`, 155.93417499999998`}, {
       7.6275, 155.531675}, {7.950000000000001, 155.205425}, {
       8.271250000000002, 154.87917499999998`}, {8.701250000000002, 
       154.71605}, {9.240000000000002, 154.71605}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4p1yra8DNTQcTrHbzg6NTXEI2gEU+KnpMO0K
Z4ZSUorDoyqRde6SWg5q0/9PqItIcdCM6T/0VUPLYcHqtTfu+yP4HEIi9m4e
CD7IvKvWKQ7VQO0PubQcok4ZHTE0SnGQB1q345ymw7bIrzujtKH2TdR0EHq5
fX2zSooD9/XFBbZOmmD1G+VTHDweAh1wX8Oh52/q9ycyKQ5tQO1ytRoQ90ml
OGiB7Fuh7iBzIFrhoESKg4kxECSrwflg/0XIYfDzKqqW6jBC/fdQCoMPUw82
f4cInB8Ccq+hENi/x6wQ6tH5sPCE2YfOh6kHm9+gBucvKbDlui6tDueD/V+v
Dg7veGB4igJNr1qj7nDl3gPuyTYpDoVA5YtvQNXbQvX/hoaHfYrDeqByETEN
SPg6Qe030IDEl2uKgx0XKMA1IP73RPBdZF4/MvND8F/0aLzlDUpxSE8DAjMN
hwMGM7UkwqHmIaUfAK1p6nc=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOj15O3cTDnOogus79YZWOmoOY7Mmn
9qqpDjH9QAUl6g5tUZf3PJZPdTgMVN5fpOHgFfBH4rNoqoPHwyqRdeqaDnH/
nH/lsqc6xILU39GEyP9IcUhPAwIzLTC/+BmCD1L/9jyCf87a7+LEzSkONxYX
2HIt1wTzBeemOOyUa30d2KEBMb8nxUEL5KAMdYcjKasSrlRD9V9Tdfgx/e7k
9uIUh0JbruuLLyjD+WD9OxThfAYQkFBwKFrTffsFUD/Y//dlHTKuPs9aDTRf
AaS8T9rBZNEW84q5UPPTpCDhsRnB53FTLWU6h+CD/fM8BRIe7dIOu3rZPoj9
TXHgvg700ClZB4UvOWG1vKkO34DBd4hVAaJeNtVhCdC712crOtQ06/uoqaVC
3LNcGc6XB7nnGIIPtu8bGt9MBYMPis+eqVD3TFeF80HRK7JMDRLfs1McZs0E
gkR1CH9ZikMb0Do5WQ0If2OKQ7UISIcG2P/79yH4YPvOI/ig9JF8GxoebhqQ
+Hma4mAHjI6Cu+qQ8HyXAklfwPS07P4+PpnvUPvOqoHlf/yFxgdSegQAd/Yr
7A==
       "], {{9.240000000000002, 164.72405000000003`}, {9.240000000000002,
        168.10655000000003`}, {8.721250000000001, 168.06030000000004`}, {
       8.331875, 167.92905000000002`}, {8.071875, 167.71280000000002`}, {
       7.668125, 167.38030000000003`}, {7.4662500000000005`, 166.949675}, {
       7.4662500000000005`, 166.420925}, {7.4662500000000005`, 
       165.94217500000002`}, {7.6275, 165.53967500000005`}, {
       7.950000000000001, 165.21342500000003`}, {8.271250000000002, 
       164.887175}, {8.701250000000002, 164.72405000000003`}, {
       9.240000000000002, 164.72405000000003`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/SZwh1zra02HY23Lw08FpDo8qhJZ5/5QCoP/hHvy
yqb8VIfDXzVi+jfJwfmzZgLBSxmHuqU6zjLlqQ4gMxkOSDtkfH+SqFiX6vAN
qPyQqbTDMsY9rJNaUh3A9q2GmMfUneqQngYCUg6TgktUxCch+BtuxJedn4ng
82Qo5fxYkuqwpMCW6/pliPu8NqQ6KLS+DtyxTtrhlsl7i6O7oe5bJO9gdmSj
Xt4GqH42ebB5/itSHXbKgTTIOYjZH7tjugDBB7t3BoIP0v9uQqoDI8g/DPIO
SmJZvsVdqQ4TDoEskHfQecu7bwPQP/Ig5XwKEPV10PAqVIC4vwqq/r2Cwxwt
iakhFVD+ekWI/hKo+kYlh5JzHZfuFaU6tIFsT1WG82Hxg86HxQ8AO2THwA==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHb33BJSpHUx1E17k/rEpRhPPtuK4v
LoiVd9jRUnPB+HyqQ9vrwB1yqrIOdgXnOoIepzoUArUvDpCGyH9JdUhPAwEp
h6qqpTqHOdLg/JZAz7kMigh+zNedt7hs0hy+a8T0H2qVduCynR0qH5TmIAay
/4iswwSNt7x2yWkOs2YCAaOCg4iI/bGYkjSH9UBpkT5Fh2ucGUpvatIcPIDc
de3KcH7QDrnW14qqcP7ZM0CQogbxT2Waw06gdGCAuoPRTC2JqYVpDibGQGCt
4VCwmHEPaxbUvo8aEPfGpzm8AXq3tVgTLN8akAYJj6+aEPc7Qf1jpgVxrxGC
D/aPIoIPsn8Ja5rDhENfNWKWazocilZwLHyf6vAI6Hz3Toj9rfdSHQ4Dpfuz
1B3kXj8ym3U21QEUHCLnVOHxgR5fAAaluv4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHRw+4J2s+T3VYUmDLdd1bFc4HylaJ
1Kk5fOsLLlnyJtVh1kwg8FR3kHv9yGzW91SHtteBO+RENSB8pjSHapB5VRoO
h6IVHAsFEHwu29mh8ooI/hmjIxvXGaY5nD0DBCJQ9fZpDoVA6xd7qDu82b6e
Od0rDeKeajUIPxTKd1YF859HQdUvUIbz09OAQEwJzn8DdF7rawUHhrTvTxKB
+hlAQEHBQeNQ2/JwoPlaMf2Hvq6QcwiSE8vyBdpvBzSu4K6sg4d70c9+QwQf
5n4YH+Y/T2DwrFsuB/c/OLzkFODhA7I98IUCPPyCQAKSSvDwRQ9/ANF4q9Y=

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCwAGIQ/SZwh1zrZy0HBd4HuhMWpjlwX19cYOuk7WCyW52/
+2CaQ2z/oa8aT7QdjtTKWjw/BJWP0nHYsazy+MpjaQ6i69wfVi3RcRAzs9l7
6Uyaw0651teBHLoOHpn5H1ivQtVb6TrYTTpd7/EAwf+2ISB71jsEf935q2Fv
/qY5MIAAUH+Qg3DiYc50B7D7Fus4PGLi7JIXSnfweFglss5eB2x+q1Q6xH1b
tB2W/DB8pqeQ7qAZAxRg0AabL6UM1T9ZC+I+lXSHttdAgbWaYPXrVNMdvmkA
NfhqwPmzZgJBoibYf5riUP2vNR244mf4iLIi+LMU+0oL36fB+UVH/22qvpIG
NU8T7N75+6H+E9JweHNzza87G9Ic1gODS+SaGsR9i9IcTIyBIFrVoWbOIuWd
s9Ig9i9URuUXKsH5j4Ded49UhOifl+ZQaMt1fXGEAsT8JWkOCsDg37FODmL/
6jSHYJDzFGXB4ZuzNc2hBqj9IZcMOHydgfF55CvQwZ+kHM6FHFyhcj7NIT0N
BKQg8vcQfLB57xH8jHdRTvvY0h2WFAAdMFnaQetJ87yzkukQ+9/JQvga6RD3
PpTC4IPjzz3dQR6k3kwDzp8AjM4YdS04/wYw+LjatSHud4HGV6gOODws7aDx
qQpNbxbpDlqg+D+hC5HXg9rnqAeJfwVo/O7Uc2grdptSJgw176ueQ4z49osM
zAg+LH5hfHB6uAFN3wv0wOEdczTNwQ4Y/AVfdcH5hXs7ND69IfbvXJHmcBgU
vl468PyFnt8A8tmI3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/ahKZJ17pbJDxrsop3170hxE17k/rJJRhfPT04DA
T83hzc01v+4cTHO4sbjAlotf3eHbhoBsqTNpDh4PgQacV3e4oZ0qmXQtzYEB
BAw0wPrtHiP4S34YPlv3CcGPEd9+kYEp3WGnXOvrwAvqDgwdX25f50t30Izp
P/RVQN1hgtcrFhPJdActED9ADWzfLOV0iPtUVB20njTPO6uR7vAmcIdca7cy
nN/2GijAqgTnywON33FPwWGWYl9poTLUPgkFh5o5i5R3SqQ7LAV65/piOQeT
3er83ED77YC8gruyYPfqMSL450IOrlABuh/GB5nvC/QfOPwWykH8dw0afiIK
DnaTTtd7wMLnuoLDuvNXw94chKr/qQgPX/TwBwAGcqv6
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOE3Ke/17JnOEgus79YZWOmsOR+VL6
d1UzHGL6gQpK1B1M7qqwNSpkOBwGKu8v0nD4cck3aYJYhoPHwyqRdeqaDjyN
U525OTIcYkHq72hC5H+mO6SnAYGZFpgv8BzBB6nvvoDg1+wDWrgl3eHG4gJb
ruWaYP76uekOO+VaXwd2aEDM70130AI5KEPdoQjo3MIaqP5rqg7LgM5VKUl3
KLTlur74gjKcD9a/QxHOZwABCQUHBSC3Dagf7P/7sg5iEZZbPIDmK4CU90k7
PAJ6V3Qe1Pw0KUh4bEbwd50o2zf/HIIP9s+LdEh4tEs7ZAgADfyb7sB9Heih
U7IO54DKpfgyHL4Bg+8QqwJEvVyGwxKgd6/PVnTQYmucelgtA+Ke5cpwvjzI
PccQfLB939D4ZioYfFB8ak6Dume6KpwPil6RZWqQ+J6d7jBrJhAkqkP4y9Id
2oDWyclqQPgb0x2qRUA6NMD+j92P4IPtO4/gg9IH4x1oeLhpQOLnWbqDHTA6
Cu6qQ8LzfTokfQHTU0iSQMTO71D7zqqB5af+g8YHUnoEAKlkHsM=
       "], {{
       9.240000000000002, 188.74325000000016`}, {9.240000000000002, 
       192.12575000000015`}, {8.721250000000001, 192.07950000000017`}, {
       8.331875, 191.94825000000014`}, {8.071875, 191.73200000000014`}, {
       7.668125, 191.39950000000016`}, {7.4662500000000005`, 
       190.96887500000014`}, {7.4662500000000005`, 190.44012500000014`}, {
       7.4662500000000005`, 189.96137500000015`}, {7.6275, 
       189.55887500000017`}, {7.950000000000001, 189.23262500000016`}, {
       8.271250000000002, 188.90637500000014`}, {8.701250000000002, 
       188.74325000000016`}, {9.240000000000002, 188.74325000000016`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ1IGYC4jeBO+RaX2s6lHD+XJAemOHwqEpknftDKQz+
pL4nn+QLMhyKbLmuLw6Qg/PFgLJVW6QdnrgxV3DXZTikp4GAlMMG4QsuEZMQ
/B9fvCLZ1iL4IP3zd2Q4zJoJBCulHJjOvDvpfDjDAeQmBgNpB6+1mfc+noGq
3ybtkGEUarDqGky/DET+boYDyC8MDrIO72SXvzjxKMNhNsg8SYj75j/PcAD7
T1regWfxJCvG1xkONSDvKCk4xEVv3P/mTYbDhENfNWLaFRwcrh3NNXmX4QAy
jsFCEez+G0D+2TNAYKIE58PCC51/5KC42mWge4NAXE8lOH9JATDAshXh/G8a
Mf2Hjio47HpVvHXq6QwHj4fAAA5XcFhmo3NF6mSGg4kxEFyWh7j/GFS/sjzE
fYeg8bFQDmL/7gwHhdbXQBfIgcO3bWuGgx0wegruyoLNF12H4IPllyL4Hdsd
mh5Nz3AoBMVnATQ+ezIcbiwGWjhd3kGsymy1XRPU/DgFhzmpHcmxFRkO64HR
LVKmCA6/nGJo/Akqw/mw8EDnw9ITAKAAGTA=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOc9pboy6vy3QQXef+sEpHzeHCrh29
bBczHWL6gQpK1B0cfhxKWXU60+EwUHl/kYYDy7vXB3YezHTweFglsk5d00Fi
jvEik82ZDrEg9Xc0IfJLMh3S04DATAvMt5yE4IPUb6lG8Dtu2lZGxGc63Fhc
YMu1XBPMv+GR6bBTrvV1YIcGxHyLTActkIMy1B3qmGZxzFaH6r+m6rDJ9Ky1
n3ymQ6Et1/XFF5ThfLD+HYpwPgMISCg46HhVN68H6gf7/76sg1LxdaEioPkK
IOV90g7v7Jfct/OEmp8mBQmPeAT/2GMR2ZOVCD7YP5Oh4dEu7VCi/W363RWZ
DtzXgR46Jetwa2LMP+edmQ7fgMF3iFUBov5kpsMSoHevz1Z0MFOU//LmItQ9
y5XhfHmQe44h+GD7vqHxzVQw+KD4DHaEume6KpwPil6RZWqQ+HbLdJg1EwgS
1SH8wEyHNqB1crIaEH5MpkO1CEiHBtj/bVkIPti+KgQflD602qH2u2lA4mdi
poMdMDoK7qpDwnMWNH0B01NC7bptjxZB7TurBpbftxLqf6T0CACv+Sa+
       "], {{
       9.240000000000002, 202.09205000000026`}, {9.240000000000002, 
       205.47455000000025`}, {8.721250000000001, 205.42830000000026`}, {
       8.331875, 205.29705000000024`}, {8.071875, 205.08080000000024`}, {
       7.668125, 204.74830000000026`}, {7.4662500000000005`, 
       204.31767500000024`}, {7.4662500000000005`, 203.78892500000023`}, {
       7.4662500000000005`, 203.31017500000024`}, {7.6275, 
       202.90767500000027`}, {7.950000000000001, 202.58142500000025`}, {
       8.271250000000002, 202.25517500000024`}, {8.701250000000002, 
       202.09205000000026`}, {9.240000000000002, 202.09205000000026`}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHKZfuPeD+mOkgus79YVWKIpxvx3V9
cUGsvEPYCXZb6d+ZDm2vA3fIqco63Nkc+dWSP8uhEKh9cYA0RF4hyyE9DQSk
HCT2GcxcZYLgK029wvnCB8H/ZeHq/ik9y+G7Rkz/oVZphxUNaofY6rIcxED2
H5F10MupqFLtz3KYNRMIGBUcNoWfMnJZkOWwHigt0qfoUOL7ue/yiiwHDyB3
XbsynB+0Q671taIqnH/2DBCkqEH8szTLYSdQOjBA3eHCna0tNXOzHEyMgcBa
w4HveY/G26lQ+z5qQNzbleXwBujd1mJNsHxuTRYkPL5qQtyfC/WPmRbEvXEI
Ptg/vgg+yP5uwyyHCYe+asQs13RImL96bYR0lsMjoPPdOyH253JlORwGSvdn
qTvs0ctb3Pgz0wEUHCLnVOHxgR5fAEN3xk0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHBpXp/wWEsxyWFNhyXfdWhfOBslUi
dWoOUy7de9AtkeUwayYQeKo77NHLW9yonOXQ9jpwh5yoBoSvl+VQDTKvSsMh
Yf7qtRE2CP6KBrVDbL4IflaZv9y02CyHs2eAQASqPjvLoRBo/WIPdYeu31YF
fmVQ91SrQfiNUL6zKph/rg2qfoEynJ+eBgRiSnD+G6DzWl8rOMxb2RToCdTP
AAIKCg7HWIVE7IHma8X0H/q6Qs7hQ+LCayZA++2AxhXclXV41vU3tTwWwYe5
H8aH+c8TGDzrlsvB/Q8OLzkFePiAbA98oQAPvyCQgKQSPHzRwx8ABjGqXw==

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4jeBO+RaX2s6qGy/yHAvINth1kwgUNSA85cU
2HJdr9Z0CHvFYiLolO2gGdN/6KuGlkPSwRVLzuki+E42e4PERBD8LZXHNXdx
ZDukpwEBm5aD1APdCQr/shweVYmscz+o6VCW/6HV80uWA9h+oPkrFinvrHmV
5SC6zv1hlYqmw52rYW/0H2c5xIKM26PhIMDZJZ98L8vBxBgIgjXA5i24meUw
ASgdc17dYd7peg/7a1kOhUDnLjaA8q9kOXzTADroqJqDRarkoxuXoObLqDmw
GT1bpwrknz0DBCaqcD7YfQ+lMPgfmued1foC1Z+iAuczgECDKpx/YzEwwOzV
HHyEEw9fBvLB4bkQat+3LActUPgA3Qfm/4DJqzv8inKyy/gDDY/P6g7P1vyK
ecuUDXGfiwYkfDizHeyA3ivI1QDHx0RBBB9svzSC3yVrkX5EBRp/zhrg8D4J
jC9w+HxQB8ePlRnU/DnqYP2r7LIdqkHe1VKHhK8LlD9LzUGvr7RQ2gPK51KD
yHtnOwSBko+lKiR+fLMh4aGhAufDwg+dD0ov0/KzHWDpD50PS38AB0chvA==

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxNVFtIVGEQ3kwsVDCpNtpdd/fsru5ZjQzMQkudUCpfArOgyOxGJvwnCh8y
TLo8lEZS7UuQSyGpSRfMyKJ7ZJZGtnQTFbK0fUgwu1imlEL/mRn29MN5+Pj/
OfPNN9+Msn3P2p3TTSbTNPltlV+E/Hrr92ZFL02CDbERKVW1Ar4U3LYfDSXC
GXNfcPy+gE8Vc5pX3UmCh2Wl/pGHArKje+r3bvbi+xntAkz6eeWF7aHGQF6X
gLUyfHiFCnnFd/Nr3gk4IMMHK1RY2FJWGj9gYI/8/duvBt7nH6l8NCXgjgwv
WM33MzVYnCZPyEvxszTQX8856IXMKnPfmnkanG4bU4tmeImfRQOs51BSGL/s
kifSwEEdNyRSvnn8fksiDAXHC3fEM05NhMvtzpbRWI3q+eHB+9A0DVbL9M1N
HqgbqcxJ/y6gQT7vyfXAG6ck2Mv6jLhhtDHQXtchYK5OuMENk/L5hwes7yY3
RK0LNVpbBThkubd/u6A1IBNeFVTfPhfeB5oE8f2lYP3+C3xfoqC+sXWs93Nn
GCOfZQYuy9IJOahfMt6p5ztoh8NSjslG5nMigfAlAYX6/x7bUK/d1xgrNtL7
liB9mqzoj/J7zD/bivGVbQKSi061jQ1ZsN7iF8zPb4E16ZKQ9MOuEv1YqL/9
Bsb8nw08K6XKvHGc/9/M7yO53zlW4if9gPdBK9Vn08ivfhtYpJ3PeLifVQmk
dzL3v9IOnfmxEVdSNRhXJeGnDuKfphH/Fifpnc54wkl85mpwTKazr3div4dm
axAj1c267IAaWe7dOI30+mFHvYLSv7Vn5cmwk/+kf9Af/QmYP2VChDHO37CB
sf/vBeizalpkp3l8LSh/t53uX7De+x3o55ynAnSo2oh/vOwH5j9uYJpXA6Oe
cQr5/4kgf69SSM9nPP9HFNKrk/F1herr4vc9Cs5L2Rv207BCfu7m/PNdxO8j
+2GbC+fD+Y3jO1zYL3MUz7vVTfqYNZqfIpqfYgfrf47mJ6BqlO+vG/vTl8rz
We6h/8n+4Tz89KB/CjN5f5zk+V6ukd9WJoUx9vOPgTG+3kv9zWB+uSr5OY33
w6BK+Rfwviny0f5zc/wNH+kr9w3uu+hk/F9mDOdfkkzzNCXCGP361cD6vrn5
jvfjgI/8+FjAZr3fi33Ur1bub7VK7y8K8OmGqPbSvjrP8/vfvv8HNtmRcA==

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4p1yra8DNTQcZnm9YjGRz3UI2gEU+KnpkCa+
/SKDSq7DoyqRde6SWg7fbq75FSOV66AZ03/oq4aWQ8G7KKd9ggj+jZCDK1S4
EHyQeVv+5jhUA7U/5NJy0OJ9oCvwJcdBHmjdjnOaDm1zFilbvs2B2DdR0+GR
dqpk0rMcB+7riwtsnTTB6ic8zHHweAh0wH0NhxgH4cTD93Ic2oDa5Wo1IO67
k+OgBbJvhbrDGybOrvm3chxMjIEgWQ3OB/svQg6Db7dbnZ/7cA7Efw+lMPgw
9WDzd4jA+SEg9xoKgf275A9CPTofFp4w+9D5MPVg8xvU4PwlBbZc16XV4Xyw
/+vVweFtBwxPUaDpVWvUHZYo9pUW/stxKAQqX3wDqv4/VP9vaHgw5jqsByoX
EdOAhC8L1H4DDUh8sec62HGBAlwD4n9uBF8kfoaPqACCv+P81bA3wrkO6WlA
YKbhMKHYbco3Cah5SOkHAKkH/ts=
      "]], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmUHlSzfz32GuQ6i69wfVqUowvl2XNcX
F8TKOzyLL/OfZ53r0PY6cIecqqxDjvcJ9r3+uQ6FQO2LA6Qh8gm5DulpICDl
sCJ0/mrdUgR/k46zTHYvgt91YXNk6Ypch+8aMf2HWqUdLCSmXuncl+sgBrL/
iKzDPubnPSvO5zrMmgkEjAoOTu8tXI8/yHVYD5QW6VN0YHmauDDsZa6DB5C7
rl0Zzg/aIdf6WlEVzj97BghS1CD+eZrrsBMoHRig7pBQojL9/91cBxNjILDW
cJhX99uq4BrUvo8aEPeeznV4A/Rua7EmWP7DHmh4fNWEuH8d1D9mWhD3zkPw
wf7pRfBB9vMV5TpMOPRVI2a5psMHM6kDt6NzHR4Bne/eCbH/g1euw2GgdH+W
uoPPsTtbWaxyHUDBIXJOFR4f6PEFAN9RxH8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmUHgT2sQlOCcx2WFNhyXfdWhfOBslUi
dWoOKlm+n/kicx1mzQQCT3UHn2N3trKk5Dq0vQ7cISeqAeHn5zpUg8yr0nD4
YCZ14HYNgm8hMfVKZy+C/4t3n4HkvFyHs2eAQASqfnWuQyHQ+sUe6g5Sk1c2
XdwGdU+1GoR/EMp3VgXzA49D1S9QhvPT04BATAnOfwN0XutrBQc9x4/JZ4D6
GUBAQcEhbG6D2iGg+Vox/Ye+rpBzaPjJ/3I70H47oHEFd2UdypRyKn7NRfBh
7ofxYf7zBAbPuuVycP+Dw0tOAR4+INsDXyjAwy8IJCCpBA9f9PAHAOlNqkE=

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}}}, {{{12.96, 244.1567000000004}, {4.32, 244.1567000000004}, {4.32, 
      245.2198250000004}, {7.920000000000001, 245.2198250000004}, {
      7.920000000000001, 249.6767000000004}, {4.32, 249.6767000000004}, {4.32,
       250.73982500000042`}, {12.96, 250.73982500000042`}, {12.96, 
      249.6767000000004}, {8.88, 249.6767000000004}, {8.88, 
      245.2198250000004}, {12.96, 245.2198250000004}, {12.96, 
      244.1567000000004}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHleVzFim35zuIrnN/WJWiCOfbcV1f
XBAr75Cde/Sf0cR8h7bXgTvkVGUdPkSIbw9cmu9QCNS+OEAaIr8t3yE9DQSk
HPSS30UdOoXgW1hNOv3/EYLPf4+Jk+tfvsN3jZj+Q63SDveEPjnycxU4iIHs
PyLrsJBDet48oQKHWTOBgFHBIeWf8y9d6QKH9UBpkT5FB9fKiBWl8gUOHkDu
unZlOD9oh1zra0VVOP/sGSBIUXO4Yu13caJsgcNOoHRggLrD5wOWyqckCxxM
jIHAWsNByE21lEkMat9HDQcZ2ZNP6wUKHN4AvdtarAmWd+IsgITHV00HjvxG
FlamAoh/zLQcnATNbGy/5MP5e1WfNMs9RvBB4bn4eL7DhENfNWKWazqUumTm
F2zMd3gEdL57p4aDco/Xq5YF+Q6HgdL9WeoOFy9rp87sz3cABYfIOVV4fKDH
FwB7arp2
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHKSdDDmqszHdYUmDLdd1bFc4HylaJ
1Kk5rCyfs2jxunyHWTOBwFPd4eJl7dSZO/Md2l4H7pAT1YDwj+Q7VIPMq9Jw
KHXJzC+4hODvVX3SLPcYwW+Q5n2w9nO+w9kzQCCi4WC1aIv5DoYCh0Kg9Ys9
1B38A/5IGLMVQNxTrQbmb+aG8p1VwfxiPqj6BcpwfnoaEIgpwflvgM5rfa3g
EKW+oHMDUD8DCCgoOORdfZ6lDTRfK6b/0NcVcg5Nzfo+y4D22wGNK7gr6/BL
f7d6P9B9MD7M/TA+zH+ewOBZt1wO7n9weMkpwMMHZHvgCwV4+AWBBCSV4OGL
Hv4AgqmtmQ==
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1,
        0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxlU01IVGEUfRQRWBCBVozz/kYQcyGFLmLAOpSjFUFpURES2eQP0c9Ng2Iy
+iELopwkMGagGBnLKCg3gq0Ms0UyFIUwtGhRq0AXEdgiCrr3e997D6cHM9+c
9+aee86957nHz7Z1LjMMYxt/5FxonbQG5jfizjz/aCB8S5W/aPka+Q9H+Tu1
g3BT7iesAK+Ts9zESua62kxoqOerKorvXHdrt64/V4kp7jK0lzA0vVjTPhXB
db49coDQ3SVXBBcby4rJIyHOZTKZz8dCPFcoFFb3EGa4PD0dQVNZMf/jNOGS
yEtV4qf46CXsFzubo57+C4RVxTw1xk2cEZoUYZS40X0Lw6Kjn9Av9bNe/Yob
Jf0GQxxnW33ZEIt+d5TwS+RUaH/P9TzORxXf23Gt56OJtazj7wThaJobL9jK
X2aSkJWzww2wv49S/Ix1PxjT+pfHAqz81boBVnruOphle2vGtN46R+3HeEJ4
Ket6ZGMT/22R9T9WfLbnN6+fD1pKfyJHeMXdWzdYSv/lh4StPHf6Yqr9x7Mh
Vs+HQyz9Xqc1f5+l5l99m9DLMJ+z1f7GBwgqPl2Ox3dN6z3oenqv6PyMxALs
z6MUq/lyHiqEcMYN8BvJyycnwCq/poMk2396SvvbaXt8J/3+lprnoe6lfozk
Uv+/20Os8nVYz6/OUvw1nO97krMPFv6wjO37tH+yVX469oT7UfnZRWgTO+8c
TDDPXAvhPe+lcMLb7/pm7a8phmqWvSVBqJU99lQF2J9HKfbf53+O7qVf
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHpe+XH/M+V+Agus79YVWKIpxvx3V9
cUGsvENb1p6S4MsFDm2vA3fIqco6eCQ8vZB0t8ChEKh9cYA0WP7y0wKH9DQQ
kHLIeHpBSfoDgv/mgtJtyz8I/g2l2z/3cRY6fNeI6T/UKu2w/pi3+UmRQgcx
kP1HZB2K9pRMjpAtdJg1EwgYFRxMNs19/1y10GE9UFqkT9FBTHfTXH2tQgcP
IHdduzKcH7RDrvW1oiqcf/YMEKSoQfyjUeiwEygdGKDucKRkskSLSqGDiTEQ
WGs4PPpZl7VHAWrfRw2Ie6ULHd4AvdtarAmW/yNcCAmPr5oQ9/MUQvxjpgV2
7w0WBB/kH0+Yf4F8kP3d7wocJhz6qhGzXNOBO4xPt+hxgcMjoPPdOyH2/7lV
4HAYKN2fpe6wc+775W2XChxAwSFyThUeH+jxBQDRAc3y
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHWRIsYX73CxyWFNhyXfdWhfOBslUi
dWoOS98vP8b9qMBh1kwg8FR32Dn3/fK25wUOba8Dd8iJaoD5bG8LHKpB5lVp
OHCH8el++ozgrz/mbe75B8Gf4JjwdAJLocPZM0AgAlFfxF3oUAi0frGHuoMC
SxjfW4FCiHuq1cD8XDEo31kVzNeVhKpfoAznp6cBgZgSnP8G6LzW1woOWrd/
1mUB9TOAgIKCg10n0AFA87Vi+g99XSHnEGwOFADabwc0ruCurMM5b/PORhYE
H+Z+GB/mP09g8KxbLgf3Pzi85BTg4QOyPfCFAjz8gkACkkrw8EUPfwBs5qJC

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCwAGIQ/SZwh1zrZy2HHXp5ixttCh24ry8usHXSdjjMKiRS
71PoENt/6KvGE20Hruc9Grq+UPkoHYe231YFfP6FDqLr3B9WLdFxMHGWea0U
VOiwU671dSCHrsPZO1tbbMKg6q10HTw+Jp+5G43gL2lQO8SWjOAzCLzcvj6r
0IEBBID6g06w284uKHQAu2+xjsOslU2BJ0sKHTweVomss9cBm/+nAuq+LdoO
1SrT/1+oLnTQjAEKMGiDzXerheqfrAVxX12hQ9troMBaTbD6CUD+Nw2gBl8N
OH/WTCBI1AT7z68cqv+1psO68FNGLnkI/jcLV/eiZAT/Udff1O+hMPM0we7t
9Ib6T0jDQX7qFU4Nl0KH9cDgErmmBnbfMWB4mxgDQbSqQ3qZv5yYJdT+hcqo
/EIlOP8R0PvukYoQ/VaFDoW2XNcXRyhAzLcrdFAABv+OdXIQ+x0LHYJBzlOU
BYdvvluhQw1Q+0MuGXD43gbG75GvQAd/knKYcOneA+/gQof0NBCQgshHIfhg
85IR/Jj5q9dK5Bc6LCkAOmCytIOd1IHoBRVQ+9/JgvkKDVD3PpTC4IPir6a/
0EEepN5MA86fAIzOGHUtOP8GMPi42rXB7n/fCw3fUB1weFzrgsanKiS97Wkv
dNACxf8JXYh8E9Q+Rz1I/NdAw3OnnsObxIXXSkqh5n3Vc7ixOfKrZS6CD4tf
GB+UHs6FQ9P3Aj1weGf4FTrYAYO/4KsuOL/Yu0Pj0xtiv5hDocNhUPh66cDz
F3p+AwA6Q3/A
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/ahKZJ17pbJDzPzVayW8Ch1E17k/rJJRhfPT04DA
T81BfuoVzhU+hQ43FhfYcvGrOyxpUDt0LLDQweMh0IDz6g6i+wxmvgordGAA
AQMNsP6IWAS/WmX6f4FUBP/G5sivO3MKHXbKtb4OvKDuoJVTUaVaXOigGdN/
6KuAukOh7+e+4IpCBy0QP0ANbF9bLdR9KqoOdlIHohUaCh3eBO6Qa+1WhvPb
XgMFWJXgfHmg8TvuKTh8s3B1L6qF2ieh4JBe5i8nBjR/KdA71xfLORxmFRLZ
X1ToYAfkFdyVBbs3IAfBn3Dp3oPTKQg+yPwEoP/A4bdQDuK/cKj7RBQcPD4m
n7kLC5/rCg4MAi+3r/eBqv+pCA9f9PAHAAj5oZk=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOBfcKu/reFjqIrnN/WKWj5sBVwa2y
4l+hQ0w/UEGJusOhaRP4f/0udDgMVN5fpOGwRHDpXsbvhQ4eD6tE1qlrOqx7
4aG3/32hQyxI/R1NsHzji0KH9DQgMNMC8x3vI/gg9f8vI/hp7OckLx4tdLix
uMCWa7kmmD9xV6HDTrnW14EdGmD19psKHbRADspQd3goXZP4aSVU/zVVh6qt
or9PLy10KLTlur74gjKcD9a/QxHOZwABCQWHHfvfzPsD1A/2/31ZB+Mrs57F
As1XACnvk3aYZcXoe2QX1Pw0KUh4HEXwW3t2ZnNeRvDB/rkPDY92aYcYA62V
k18VOnBfB3rolKxDf3LsnWOfCh2+AYPvEKsCRP2vQoclQO9en63oYLvaLlz6
P9Q9y5XhfHmQe44h+GD7vqHxzVQw+KD4PLcN6p7pqnA+KHpFlqlB4ntnocOs
mUCQqA7m8+0vdGgDWicnqwGRP1LoUC0C0qEB9n/GaQQfZN/sywg+KH3sugm1
300DEj/3Ch3sgNFRcFcdHJ4uj6HpC5iegiLbLKY9h9p3Vg0sz/Ia6n+k9AgA
fSYuAw==
       "], {{9.240000000000002, 283.4760500000004}, {
       9.240000000000002, 286.8585500000004}, {8.721250000000001, 
       286.8123000000004}, {8.331875, 286.68105000000037`}, {8.071875, 
       286.4648000000004}, {7.668125, 286.1323000000004}, {
       7.4662500000000005`, 285.70167500000036`}, {7.4662500000000005`, 
       285.1729250000004}, {7.4662500000000005`, 284.69417500000037`}, {
       7.6275, 284.2916750000004}, {7.950000000000001, 283.9654250000004}, {
       8.271250000000002, 283.63917500000036`}, {8.701250000000002, 
       283.4760500000004}, {9.240000000000002, 283.4760500000004}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ1IGYC4jeBO+RaX2s6PFjzKyZXpMjhUZXIOveHUhj8
gvwPrSeVixyKbLmuLw6Qg/PFgLJVW6QdZp6u99ivVeSQngYCUg7/DZ+te2qC
4C9epLzTxgnBB+nn9ChymDUTCFZKOWj0lRZG+xY5gNzEYCDtcObfpmqjIKj6
bdIOMQdXLOELh+mXActviipyAPmFwUHWQW77RQa52CKH2SDzJCHu64wvcgD7
T1reYV3lcU2rxCKHGpB3lBQcrl0Ne6OfVOQw4dBXjZh2BQd34cTDl4F8kHEM
Fopg96smFzmcPQMEJkpwPiy80PlcnF3yykD3BoG4nkpw/pICYIBlK8L53zRi
+g8dVXBokbVIbwkscvB4CAzgcAWHKrcp39wCihxMjIHgsjwkfPyh+pXlIe7z
gcbHQjmw/Us9ixwUWl8DXSAHDt8atyIHO2D0FNyVBZt/xAnBB8vbIfivm+ed
XWVe5FAIis8CaHwaFjncWAy0cLq8g1Gq5KMbOlDz4xQcvkY52b1QL3JYD4xu
kTJFcPjlq0LjT1AZzoeFBzoflp4Aq3gI8w==
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOX14fsFQ+XOQgus79YZWOmkNfa9Rl
mytFDjH9QAUl6g5uS+7v67tY5HAYqLy/SMNBQ/5LzrQzRQ4eD6tE1qlrOhh9
m343+GiRQyxI/R1NsLzYviKH9DQgMNMC869tQfBB6ievRPBficieTJ1d5HBj
cYEt13JNMF91QpHDTrnW14EdGmD1l9uLHLRADspQd0jVPC3QXg/Vf03V4d+h
lFUJ1UUOhbZc1xdfUIbzwfp3KML5DCAgoeBgc9babyJQP9j/92Udtj98OfUT
0HwFkPI+aQc5j4A/EROg5qdJQcJjNoLPOYtDet4KBB/sn63Q8GiXdnhgWxmh
caDIgfs60EOnZB2EC9d0R58ocvgGDL5DrAoQ9ReKHJYAvXt9tqLDwR29bBuu
QN2zXBnOlwe55xiCD7bvGxrfTAWDD4rP5B6oe6arwvmg6BVZpgaJ7/4ih1kz
gSBRHcxfPKXIoQ1onZysBkR+VpFDtQhIhwbY/38WIPgg+wxWIvig9OG3Hmq/
mwYkfoDxbQeMjoK76uDwvLEDmr6A6ela2tXnWnuh9p1VA8vPOAD1P1J6BAB5
mzUp
       "], {{9.240000000000002, 296.82485000000037`}, {9.240000000000002,
        300.20735000000036`}, {8.721250000000001, 300.1611000000004}, {
       8.331875, 300.02985000000035`}, {8.071875, 299.8136000000004}, {
       7.668125, 299.48110000000037`}, {7.4662500000000005`, 
       299.05047500000035`}, {7.4662500000000005`, 298.5217250000004}, {
       7.4662500000000005`, 298.04297500000035`}, {7.6275, 
       297.6404750000004}, {7.950000000000001, 297.31422500000036`}, {
       8.271250000000002, 296.98797500000035`}, {8.701250000000002, 
       296.82485000000037`}, {9.240000000000002, 296.82485000000037`}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWH/Ilva+yfFDmIrnN/WJWiCOfbcV1f
XBAr7xDAw6Tt/rLIoe114A45VVkHISbt9rDPRQ6FQO2LA6TB8sd/Fzmkp4GA
lINRu9hNPrZiOH9bUcZEXSEEf9ERhQ2b5IsdvmvE9B9qlXaozJj4do9WsYMY
yP4jsg42cbs8fYyLHWbNBAJGBYd/wY+X3rYudlgPlBbpU3R4cO57sLJDsYMH
kLuuXRnOD9oh1/paURXOP3sGCFLUIP6xK3bYCZQODFB36BO7ea7cqtjBxBgI
rDUc1swGOsgMat9HDYh7DYsd3gC921qsCZb/oFkMCY+vmhD3K0H9Y6YFdu8Z
KQQf5B8bIQQfZH89S7HDhENfNWKWazpc/R78OPVnkcMjoPPdOyH2f/hQ5HAY
KN2fpe7QbG8aV/WiyAEUHCLnVOHxgR5fAGiUw50=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHlF2ePE5fixyWFNhyXfdWhfOBslUi
dWoO+RPf1vz/XuQwayYQeKo7NNubxlX9LXJoex24Q05UA8z/xVTsUA0yr0rD
4er34MdPORH8yoyJb22EEPyox0tnt0gVO5w9AwQiEPWpisUOhUDrF3uoO7xa
OvvIA7ViiHuq1cD8BB0o31kVzFfQh6pfoAznp6cBgZgSnP8G6LzW1woOX2qA
DgTqZwABBQUHDu12sZtA87Vi+g99XSHnIHvz3PdgoP12QOMK7so6zHhbY18q
heDD3A/jw/znCQyedcvl4P4Hh5ecAjx8QLYHvlCAh18QSEBSCR6+6OEPAKpU
sHo=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4jeBO+RaX2s6bGN+3qMxpdhh1kwgUNSA85cU
2HJdr9Z0CJjboHaop9hBM6b/0FcNLYcrHZfuLWhC8F2P3dl6pBTB//ckcaFY
QbFDehoQsGk5GEpMvXIyq9jhUZXIOveDmg7348v876UWO4DtB5pf8ZP/5feE
YgfRde4Pq1Q0HYQmr2wKjC12iAUZt0fDYY2Os8zrqGIHE2MgCNYAm9cZUeww
ASgdc17d4QvvPoObYcUOhUDnLjaA8kOLHb5pAB10VM3hwK2uv6qhUPNl1BzU
HD8mnwkpdjh7BghMVOF8sPseSmHwZbJ8P59LhepPUYHzGUCgQRXOv7EYGGD2
ag6nNurlKadBw3Mh1D4gXwsUPkD3gfnpMHl1h0Wh81e/zYSGx2d1h+l1v60M
cqHuc9EAh085MDztgN4ryNUAx0dTCYIPst+vEsF/aSZ1QLoOGn/OGuDwntcE
DZ8P6uD4udYGNX+OOlg/X3exQzXIu1rq4PDl7IPyZ6k5WL+3cD3eD+VzqUHC
f2KxQxAo+ViqguMnexI0PDRU4HxY+KHzQemlZTHUv8D0h86HpT8AfIIoqA==

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxNVHlI1EEU3rSyjJDICN11d3+76x4SJWZ32ivFDoiwqAi1MtIMoaTZSuyO
DjvIhJCKCkLJSpIiKs1M3TLxTMUjtEzbqFATbT0ysZrfm5e/BuaPj5k373vf
+95IO/auj3NXqVTj+N7Otxvf7zKTQjwXmGHd7D/SaB6D7sg87WmnP+x53Mnm
VTD4lOKduzLfDCdjgzYGVjII9WzOTIqx4P3CagYqedVaoMEnsqW1jsF6Ht61
3Arhm6Me/WlkcIiHd6RYYfHxZ+BoVfDTK3GpRqeC23r711zrZJDPwyNX0Xkv
g+C5fDktIt7FQL7tfdQCxYmTh7cPMbjsGLBGe1gEv2EGWM8x8xiuruJrvIJr
ZJzlL/IN0f1t/pDhlTI/sZ/wHH9IPn/pc9APqqfPhOc53QxW8fS52SZw3Vo6
q4Hzz+LXm8NMcHFhU+n3ZtLnuxE0I5U9594ymCETzjLC7S9+2XcrSN8oI5jr
924rK2Wg4+XmDRpgdH/7jWkOqu+AAc/PFhHffgnrdyuk83gJ9S0qIH7l+jGM
fJYoeF+ITEgn+vWCgV7Od1QLO99HuOe9JD4X/AQuZrBBfq9Eg3olvSIsaVDv
9jekT7Ya/bG/nPiHqjH+ZxWDgOg0x8A3X6w34Z8f0n2hYsWD3W3cD7vi5eWL
/c1sUTDm/6jgnMKSmfFf6f1ccd/YQ/1epkZ+vS46r1GL+obJr+kaCLw3vXb8
b+J71k/orbILPQ9rwWPtqalp7nYYsnLCpTrMnzzBLvg/1KPeJycS/qkXfAYZ
nOHptBv12O8HAwymcHVD7uvgW9nVggwX6dWnRb303L/Xr/G1SIt8H3aTPz74
Yf63XxUs8z/SoWCZrwfXR55VVaAW9X7SQPkbtcIfdaR3sg79vKWGgQytGsHf
UUX5zylYzKuCUU8vSfi/mvy9UhJ61pCeJyTk61VL+JEk6qun+80SzsuPBvJT
l4R+Tm+i/D4Gwa+V/BBrwPlY7aT4MgP263UPzbvaKPQZpPmJFvOTMEL13xTz
48H7iflGjNifO7yf+N5BE74XzvuH8+AyoX+ck+xifi7RfHvahd8izGMY+/lL
wRifaRH95fHIL8yKft7K/YL1dFgxv9nNLv6baBvO37FRmsfHNqHvEP13ngH4
3qY+8vv8ADFPnQpGv35SsPzfeDfR/9huE37k/YuR+x1sE/0qpf6mWsV9/n/Y
ZEOkWsR/9Zzm4b///i+BfrZo
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4p1yra8DNTQcCnw/9wVXlzgE7QAK/NR0uL45
8uvO2hKHR1Ui69wltRzkpl7hfFFR4qAZ03/oq4aWQ8z81WtnlCD4/ZfuPThd
gOCDzJucVeJQDdT+kEvLYYde3uKDqSUO8kDrdpzTdEgr85cLS4LaN1HTQWSf
wcxXcSUO3NcXF9g6aYLVN8aUOHg8BDrgvoZD0Al2W+noEoc2oHa5Wg2I+yJL
HLRA9q1Qd5i1simQE8g3MQaCZDU4H+y/CDkM/iFWIRF7X6j/Hkph8GHqwebv
EIHzQ0DuNRQC+5c7C6EenQ8LT5h96HyYerD5DWpw/pICW67r0upwPtj/9erg
8I4A8kWBpletUXf4ZuHq/gnILwQqX3wDor47G6r/NyQ8OnNKHNYDlYuIaUDC
Nxdqv4EGWL13fomDHRcowDUg/i9E8NeFnzI6UozgMwi83L6+tMQhPQ0IzDQc
3iQuvGZSATUPKf0AAKt6BDc=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYC4jeBO+RaX2s66LA1TnXuKnHweFglss5dEIOv
pH9XxW12icOsmUCwUhbOP3cGCGqkHUKSBCJ+LipxSE8DASkHs7sqbAfXIPhH
50vpz92B4C+T0r/7ZH+Jw5ICW67rh6XA+i2PlTgotL4O3FEn7XChbN/8WadL
HHYCXRdoIePg1Z3z/PeFEgetmP5DXy1kHZ6osDVevVLiUATUvrhBzmGOc3eO
+nWo+hPyYPMqb5Y4BIG8d1HBYcPHS76LbkHdz6kE58P8j87ffQLogJMlDtzX
FxfY/lKE87lA/FcKcL7oOveHVSoKEPccL3EIBmkPlAf73/EI1L5IOYeOqc7d
aw6UONiBDLgrC/HfbgSfFxjc3FsR/ElA72puKHF4BAp+QzmHH5d8kyashvr/
hpyDw5YTZXbLYf6XB5v/ZhHUPkMFh1u+SQI35kPD44AC2D2M80ocbgCdz+Wv
6FC3Dxghc6DuF1GCx2chyDwBZTgfFh7ofFj6AABo4ANV
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/SZwh1zra02Hdz0ab3m/ljg8qhJZ5/5QCoNf6y8n
lsVS6nD4q0ZM/yY5OH/WTCB4KePgJfP6kRlHqQPITIYD0g4Oru5FO7lLHb4B
lR8ylXaIO2V05CNfqQPYvtUQ87SESh3S00BAyiHkc1/wFlEE/8nWlpoJkgj+
pL+p31XkSx2WFNhyXb8Mcd9ZlVIHhdbXgTvWSTv8SD4T260Fdd8ieYdlq9fe
uK8C1c8mDzbvgkKpw045kAY5B7GX29cflkHwwe6VQPBB+uWB7mEE+YdB3mHO
Fc6MR4KlDhMOgSyQd1A4EK3AyF/qIA9SzqcAUc9TCgmvQgWwfQJcUPXvFRxu
3nvAfZkDyl+vCNHPDlXfqORwxGCmlgRbqUMbyPZUZTgfFj/ofFj8AAAE8by6

       "], CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOfkU/+V9WlDqIrnN/WKWj5vCCe/JK
pq5Sh5h+oIISdYcFWhJTQ9pLHQ4DlfcXaTg0LtVxjmkqdfB4WCWyTl3Toafm
wmbJ6lKHWJD6O5pg+TvFpQ7paUBgpgXmz8lC8EHqI+MRfJfZofO1A0sdbiwu
sOVargnmv3Ytddgp1/o6sEMDrH6mbamDFshBGeoO+9YzP/cxheq/puoQ4Tm3
Qc2w1KHQluv64gvKcD5Y/w5FOJ8BBCQUHKYFl6iEA/WD/X9f1kEgQylnB9B8
BZDyPmmH8nMdl+TcoOanSUHCIxDBT1Jw/Jgch+CD/ZMNDY92aQerIxv13pWW
OnBfB3rolKxDzvcniYp1pQ7fgMF3iFUBor6t1GEJ0LvXZys6SNkfu1PaBXXP
cmU4Xx7knmMIPti+b2h8MxUMPig+NZ2g7pmuCueDoldkmRokvl1KHWbNBIJE
dTA/06vUoQ1onZysBkTev9ShWgSkQwPs/0NhCL400L6vcQg+KH2IpELtd9OA
xA8wvu2A0VFwVx0cnvPyoOkLmJ703/Lu+1AEte+sGlg+rgzqf6T0CABoIh4j

       "], {{9.240000000000002, 340.18565000000035`}, {9.240000000000002, 
       343.5681500000004}, {8.721250000000001, 343.5219000000004}, {8.331875, 
       343.3906500000004}, {8.071875, 343.1744000000004}, {7.668125, 
       342.84190000000035`}, {7.4662500000000005`, 342.4112750000004}, {
       7.4662500000000005`, 341.8825250000004}, {7.4662500000000005`, 
       341.40377500000034`}, {7.6275, 341.0012750000004}, {7.950000000000001, 
       340.67502500000035`}, {8.271250000000002, 340.3487750000004}, {
       8.701250000000002, 340.18565000000035`}, {9.240000000000002, 
       340.18565000000035`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
       0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1,
        0}}}, {CompressedData["
1:eJxNVGlIVFEUHltBESOUyNE382bGWSRK0GxDO2WL9KNIjYoUy8oIiqy4JhVt
kFlBLlBhq6UlWo6aJpaQpYkLNphLo2XiUqJlkplmG3TfuQdfFx6Pj3vPPd/5
zneuHHcgYvcUjUaznX/Kvz07IcR1kRlMuQPh8zMZDG0sl872+UHYvNZr8fkM
eo962tc+McOWt9rjOx4wCHV1ZifEWPD8cAEDjbKaLJCfsdTF/RGDCB7+eYUV
vJtWtQeUMTjGw3uOWmHWz6w9oxUqvui+oTCqWsWle7sONjQweMLDN4bTfhOD
oEC++iwivoWBctrzhAUuf/imy3AySKsas0bPtAh+HQywnpPmSfyqka9pKnYo
OMdP5HPS+Vg/2JeyM+ZGK+EFfrB+apLbrmaqZ8SE+52NDMJ5enuuCermmCOn
v2SQw487w0wQV1w5JJWTPl+MMHL4sVdFIQMvhXCOERJjZzo68knfbUb4s25r
8sQ9Bjpebvm4AZqH66tX3qX6Eg24X36b+H6Xsf7Am7QfL6O+X68Tv3r9JEY+
y1R8KEQhpBP9usFAr+Q7IcGSTQH+g7eIz0VfgbMYRCr3vfBBve5kE5Z9UO/Z
uaRPrhb9cT+P+IdqMd7G/eAfnVo1NuCN9WYWE790b8iquJLmwf2wJ15Z3tjf
1qcqxvyVKj4V/CD0ai3dbxfnoxzU7+Va5Ce30r5DK+rrIL+m+8AMw9/xhV3E
95yv0Lub9DwuQWfN/qDnfQx+WDnhGh3mz/tI/Iv0qHdJP+EJveDzhkEyTydt
0mO/u9oYuHF1Q/J18AzO9Na2kF4jEuoVwf17LZOvJRLy7Wkkf7z3xfyaOhUr
/O0vVKzwXcz1cVHmK0BCvftLKX+bJPxRTPySdOjnC3YGCrT6CP6jDyn/eRWL
eVUx6ukhC/8XkL/XykJPO+l5Wka+UES4WBb1PaLzThnnxfSY/PRZRj9XlVH+
uQbBr4L8sMOA83GsmuJrDdivMQfNu9Yo9HHS/ESL+cl8R/XfFPOzuJvy/TZi
f5x9dN8RE97H+mkeRk3oH89Bmp9LNN+fyG9rzJMY+/lLxRifbRH9HSB+YVb0
c+pHqqfHivk399J7E23D+St6T/ElNqGvk947V3+879xryh/sL+apQcXo1yoV
K+/N6jJ6H7ttwo+8fzFKv4Nsol/3qL8pVnGevx82xRApFvFeXad5+O+9/wfh
7bYj
       "], CompressedData["
1:eJxTTMoPSmViYGBQAWIQ/SZwh1zra02HfQ5Nj47/L3XweFglss5dEIO/JfNe
4SmBModZM4FgpSycf+4MENRIOzyfI7i0VqLMIT0NBKQcToirBbsqIfgRt6Rr
FPUQfMtQA61M0zKHJQW2XNcPS4H177Uuc1BofR24o07aIWnj/jdyjmUOO4Gu
C7SQcbh7NNekwa3MQSum/9BXC1mHsnj2c5FeZQ5FQO2LG+Qc9Op6dq72gao/
IQ82769fmUMQyHsXFRycda7MUguAup9TCc6H+R+d78dcwa1iX+bAfX1xge0v
RTifC8R/pQDni65zf1ilogBxj22ZQzBIe6A82P9HLaH2Rco5SF1wuWFgVuZg
BzLgrizEf4YI/oLd0yb0ayH4KstfeKxTLXN4BAp+QzmHbl7/9SKKUP/fkHO4
9O7k4UMyMP/Lg80vkIDaZ6jgkNORHBsjCg2PAwpg97QKlzncADqfy1/RQeDn
gvTNglD3iyjB47MQZJ6AMpwPCw90Pix9AAAZDfd5
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHrnlnV51PKXMQXef+sCpFEc6347q+
uCBW3iFH8lHE9cwyh7bXgTvkVGUd9Pi5tz4rLnMoBGpfHCANlg+vKXNITwMB
KQffKd/Y5rch+JfqPfbvnYTg77vIcM9pQZnDd42Y/kOt0g5TSgulfVeXOYiB
7D8i6xCePav8zuYyh1kzgYBRwUEq8fDl7D1lDuuB0iJ9ig6/b19v3HygzMED
yF3XrgznB+2Qa32tqArnnz0DBClqEP/sK3PYCZQODFB3WKm88w/77jIHE2Mg
sNZwOLFiiZ/Ddqh9HzUg7t1Y5vAG6N3WYk2wfMMqaHh81YS4fzHUP2ZaYPfG
zEbwQf45OwnBB9nP31rmMOHQV42Y5ZoOH1hMBL9Vljk8AjrfvRNif0NhmcNh
oHR/lrrDPB/RHi5geIOCQ+ScKjw+0OMLAALIzr0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHhuOaVpdKyxyWFNhyXfdWhfOBslUi
dWoOXfPOruqvKHOYNRMIPNUd5vmI9nDVlTm0vQ7cISeqAeZ3NZc5VIPMq9Jw
+MBiIljWheBPKS2UPjsJwS/70HpSZHaZw9kzQCACUf9tYZlDIdD6xR7qDqyb
qz8VLIe6p1oNzP+wBsp3VgXzN6yHql+gDOenpwGBmBKc/wbovNbXCg4CXfLJ
74D6GUBAQcFBxSLdJRNovlZM/6GvK+QcLJ6tU30CtN8OaFzBXVmHzb9iclln
I/gw98P4MP95AoNn3XI5uP/B4SWnAA8fkO2BLxTg4RcEEpBUgocvevgDAAit
rcU=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.96, 
      365.33510000000035`}, {4.32, 365.33510000000035`}, {4.32, 
      366.39822500000037`}, {12.96, 366.39822500000037`}, {12.96, 
      365.33510000000035`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1,
        0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/SZwh1zra02HDR8v+SbZlzu0vQYKxGrA+YW2XNcX
z9B0yBCIsDSxLHdITwMCMy2HXSfK9skbIPjLpPTvqqgg+GD9MlD9HzQdTO+q
sDmKQs1PhfAP8pU7aMb0H/p6QwMiz1HuYAdUXiCq4RBnueWEGXO5w+GvGjH9
Uupg8xb9L3O4sbjAlktezYFp1cdLvH/KIPb9U3HQZmuc6vyrDGLfDmU4Pwjk
vUolOF8LZF+EIti8R7/LHL4BjT8UqgDxD9B8sPuWyjkcmS+lH8tU7rALqD1Q
QtYhJAkYAOxQ97PKgMNjCy/Mf1IONfuAGkSg/k+Tcmif6tydI43GV0bwxYDa
PTTLIf7ZLgX2f6NeuQPIuYER0g6PgVxRY6j9P6TB5q83L3eYPRMITso4TMx5
/jvTutwhFugdjTOyDgrA4HezK3fweFglss5dEINvvwXoQb9yB1h8o/Nh8Q0A
wHrb3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLd/6OnDHNmUHBf27Km7c5Q43FhfYcvmrwvmFtlzX
FzeoOWz4eMn3EW+5w5vAHXKt3uoO58r2zZcSLnf4phHTf0hUw+Hd75UfgyTK
HapF1rk/rNJw8OrOeV4th+A/VmFrnKqK4NtvOVG2T6fcgfs60EIpiPxVo3IH
TaBxXyMg5t8yh7pnuprDLqDy+zblDgwgUKAKdk+SfbnDEqD09cfKcD7YP3pK
cD7INpF3CmD3XQLqDwI6/7WigkOGQITlFnOo/avkwPbNAtpvB/RuwV1ZsHtC
dRD8ZVL6d5+oIPg3fZMEZsiWOwSDzFsoB/ZPnThUXlQBIi8Ete+mgkOc5ZYT
24Dh5wF0zjp+JXj4ooc/AMlqqcs=
       "]}]}, 
    {RGBColor[1., 0., 0.], Thickness[0.002976190476190476], Opacity[1.], 
     CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJwllHlUjWkcx5M0ihYh2YtERopJqtHpG0q2mUql9S7v3ZfuvS23LkMkqQhF
O2lhKltDVFrcYqJsMSYUo0wHpxQpMSkd87znPuc87z/veX7L5/f9/iwouQ9v
vJaW1jhyueRqk5ubQx8fGId6da4c3okZnl7fzKZvQ3zD3cJb/TuQ/kWXmZ26
DV07p5VtGFPhu9P9rBmTfaFg/tAyc54Ku7v3jWQm+qIu6riZjlcMRjOdQk3H
+yGjVU+4IC0aKveP9Rmxfhh0e8h/0qnEl0/FC6aP+IGEd690ViKyKDQhXemP
m5+XhBwtiELHmwXqqQP+oMN7G0chOL3d/Lh0O3CmU22YHIm2tanxJt3bYV90
dfWwXiT8BjzepnECIP+YcMf3WAT+zh/znNIZAPu9VdhnEQGlZdb31KBAUIVP
7fsrw5FTm5lq9DQQzdHq/Fk+4ZDH6dw66h2E5mzyY1CBdDMdf8MHQRgaa1X1
ZCkg6gg/eMQzGPoVxTua3BQ4ogyfbdAYDJcTfvnnO+Xg/dz562HXEJhfihCm
rZMj+XHHq0m1IahZbDSpokwGRvaW6SkOocikOZrLsN92S7F+eShMApyuNmeH
Ifhz9fODNgw05M+yfWkahj0p1RK9swwU63ssUuZK4euzuCDZkomR970NTgul
2NFjtWJiARM6Pyaatl+SoHT73ZWNBixYKbVzJ66TwHnhpt/iN7PQ531tXkK7
GPc/3PlzbTJLU3eUGJV/aXVoN7FgRg/IRIyNeXutbuqw4UEP+qoIq2hua9k4
dm+PZ32gCE2bVye77WUjZT7nQ5C2COXLZafHqdkg37oJZUK404WNsrGGYMgK
EcL2paVunBOFkQLBlXcGQtwoPfMLYijUfEscenFDgIuHXgi1KihgFaNmo0oA
1+3Bl+sHKfBndgXMWCGAtTPJbMfB8Iq3ZYv6+KibYDLNVcZBx/HEhKCzfJR0
ey7/fp6Dc/u8N+YJ+SAUo9U9HGQvJR1Z80GPO3YxF6XL1s3p7eOhktrT7sLj
wtxtgHP/Mg9EdZ/Giri4MPB4K6XiwX6Kw5rrr7jwkeTGnAQP5kNS/93zeDCl
+ejzcKW+79SaEBJn/65HV55wkVe0sPpbDg/rLxJlkDg0jrpnPETTiRVczPJ+
PnvXdD7UtB9A8swJ4v68jY9uVyJgYy7o8kZT+Sj/tyejvIuDpfeMm2pa+Jr6
KzioI/LcOVkAMW2ogxwQ1Vk7bxKgiOCMZHLg6L4h4muiAITK7X9WcWC5JDal
+pYAx84SIAYckO5aVeOFGDHqqfrjDYUiIntHNyHm0IOppzS+iRXCjsjQI4fC
/IRe72t1QvDpE0Wh3IuAGBGi6PzFNqYXhZM/kQeOIlAr/eyW2lCw/W4x9kUp
QsqS9wZqfQr02KquiGCoTQTZwwb9LHpABDXBtqyZjSzSjoOtGEmm7S3/lbBh
HXL05mepGKW0vpPYoNuoOCdG2aLX8adEbI3uu8VouzASEraZjbT3u1xXWUk0
/dqwQegnDnEkOPl2bkm3MRtGdIGFEujGZaw7NMTScOqUALSu2lhI2fROx36u
VOOL6yzMNxVv/RQkxUE31ptHRSzofSVCzZYiwkX/2ekkFk40Eic/leIIseFX
GQuJJcRg08LQTAvTj4WZkc9MBr3DNPvPhQWyLWzKj4ZB1pL0uMOShSwL4rQH
YVDb5Sw1I76kMdlNkiFp6MWzuF4mpj5a3/bRU4YAYutL15n4nU54QAauMVkI
qUykxY46KxplGBraFHiAy4QlKdtWWw5a9hZOTBjZlOf1u8rhSPvUkIlC2ii7
5WgwJCBeM3CY2EteK0eUkJCrZWAebZivciTRe+k4A2TbrYiZrUBBf8ntzRIG
Ws49fOLvrIAXRQpYzwBxTZdDoAKtctLgXAYm03NVKdBYc+2w7nAo4iLJpshU
wKyKLJLHofgfxEnRzg==
      "],
      CurveClosed->{0}]}, 
    {RGBColor[1., 0., 0.], Thickness[0.002976190476190476], Opacity[1.], 
     CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJwlVHlYTWkYv3SnQlmylT166lqikK2YX40lRMvUOedulC5CdPc1KSLMZZhk
LAlZEqlQJM2dIrTYRWb0kGWmndsyGpOY7zz3PM/3x3fOd773fX+b86qYkNVW
HA6nB1mryepJVoJi4YFPB6VwvPaY8+qJGAH8HbOe50shsXngFJwtRnHFyQVX
q6Qwx37vtWK3GLty3zSktEvhP/mbc/caMThjuz+pHGRQDrevdZ8vRpnN3KNh
njJw64y8Fmcx5uqYc15BMvg8v71xOkcMm5WHAgbHyNC/4VqO1WsRNj+6wv9n
jwzaZEcuZRJh4dX27qosGQrO6u6OTxOh0K1fn/xKGYoO7uunjxMh0T4w50Cj
DMZIcc3ClSJ8jltfpOwlBxPidmIXRLglOR8eypNjTOQHgd9YEWaxdRfJ4bN2
/roYrgg9i75zGLRGjhenpHN71wlRScZrT5Qja9Eb/aAKITAw4tbTU2R/Z+nM
XReF6P35xNorN+VwbPN9uGa/EGy55DdymMtv+V1UCbEo6IujgqOw9C8QwlQy
1PXH0QqEbs6+uup7IZIy6Iqp8xSI75ojfeAiBDld7SBWoNne5HG4txC3v142
tBkU6NheHlpiFsBb+mDnkyMKKKsd2nyrBeBSfd0vX1eA52mbNcIkAEFlzi8v
FMjyuu+9/IwAfhfXvZJ1KuDP4mYUoGDU9qbgIUoEsEApBdjKvf2zp5cSdrKs
n16KBOhU1aYOCFXixbJV/ZkFAhQLx/i2ypUwNxXPHjdZgBnk2sf7lcgaIZB4
DxXgG2kvN1eJ8Eu/N6dxBFC6/Ppt30Nyv2HblIBGPub2rj4l/aCEVn9m0g9V
fFwhx4PsVUgMXnws3sRHbMTUMI9JKkRxYhK4mXy0PiGFl6qgJbK4n8xHYcEe
a/M6FbgTk4b8EceH54TMgY92qhBEfnddz8fnfkQoGSpIrjQq8sP42JRABrqj
wqE5PZYl+vIxi+X1LxWqXtX2SXbng7y1D+SqUcoC48SHxnR82JRxahTM/Pem
xJoPnH5t6uunBtM85YZbO4P8wV2VH8LV8LfS9nGpZRDH8rRFDZ8L82jhfQYd
0dTm7DQ1BjGz88oKGZhCDjrv/U1tqXuOwdTSS5M31ahBVG1ccpBBVyaZsEuN
+hnDioWJDGSsL4ZpENX5PuKknIE32+BsDVz2qmTDIxjkyKP2t9Aa5B37mHEn
kLHgotbgXmjJudPzGIvOUjSwZXXgzqAgx6rOmKdBKaubEQzcnUd3RD/VgEx3
PtyOQac1MVibBqnp465/6aIRzRIzQGu5v4mG14rCxXYeWvjklalNL2mcf/iM
al6uRfw1bH1bSUPJArJRi0RWt0U0GlyJ8IxapIYdv3Axi8ZlVkgXtLBLztwa
fIwGL854fUOFFsa979tG76XRGnlPvLRBC4nTW2boFhprn9Wtn2irQ+q09LyZ
UhoeN4ih3XSIJ/bYEkHjP2KvxgU6MEIisBAamxy2FVdIdKhhBTOfBkvb+W06
hBJYvGfQyCZy352uwyOn4D+H82ioA0cNWV+is9QfRoOV8ZJaHSyD0shnc+Qb
+c7m1lcKEx1TqnqN0iOa1WMrhY7uKm2Djx41LtYJKe8oRMWYt5cL9RY+n1Mg
6p2QqdcjsSm4YFQ5hQw2Fw7rYcvmWBEF1lZRBXoLzjkU/h6ZUe9frQe31+7R
kekUcgldvE96sPFZmELBVdXziO1gA3gtJAB2Ufgo8JtXP82A0HdnjpbGUpAQ
+MpCDMgN2nBEI6XgfpkQJzPggLV5iL+EAktr0j4DmrnTB8xgKET3IgGVY0AZ
acs3gAJJsexFDwxQsn2BAknDELcWA+pZHqdTGPMkZqWNXayFh/EU2BiumxAL
/3Vk8JEUVoyv7H93cawlbxwo8Ej8no0i+/fb0u5bUyCuvLkjKRZELXcPdYVh
DfucjQVxDy/OHIb/Aa0k0N0=
      "],
      CurveClosed->{0}]}},
   AspectRatio->Automatic,
   ImageSize->{504., 504.},
   PlotRange->{{0., 504.}, {0., 504.}}], "}"}]], "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],

Cell[TextData[{
 "However, it is also clear that there is some dependence on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " on this threshold ratio as well. To try and find the form of this \
dependence, we repeated the above regression with 1/",
 StyleBox["k ",
  FontSlant->"Italic"],
 "but for different",
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " values. Then, we plotted the coefficients of the regression as a function \
of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ", and determined what function appear to fit the data best. The below \
graphs show a plot of the coefficients, as well as a curve of the form (a + \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "/", 
    SubscriptBox["R", "0"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "/", 
    SubscriptBox["R", "0"]}], TraditionalForm]]],
 "), which appears to provide a good fit to data."
}], "Text",
 CellChangeTimes->{{3.560246464099605*^9, 3.560246493649708*^9}, {
  3.5602466343072643`*^9, 3.560246643016123*^9}, {3.560246687010334*^9, 
  3.560246718948597*^9}, {3.560246759796296*^9, 3.560246801488097*^9}, {
  3.560246972067054*^9, 3.560246978805522*^9}, {3.560248136692931*^9, 
  3.5602481825210667`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  GraphicsBox[
   {Thickness[0.001984126984126984], 
    {FaceForm[{RGBColor[1., 1., 1.], Opacity[0.]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., -35784.}, {
      36288., -35784.}, {36288., 504.}, {0., 504.}}}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 428.5}, {77.1, 433.9}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 433.9}, {77.1, 428.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{160.3154, 243.44390000000004`}, {
      165.7154, 248.8439}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{160.3154, 248.8439}, {165.7154, 
      243.44390000000004`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{234.1615, 178.731}, {239.5615, 
      184.13099999999997`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{234.1615, 184.13099999999997`}, {
      239.5615, 178.731}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{308.0077, 137.10290000000003`}, {
      313.4077, 142.50290000000007`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{308.0077, 142.50290000000007`}, {
      313.4077, 137.10290000000003`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{381.85380000000004`, 
      107.58470000000005`}, {387.2538, 112.98470000000003`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{381.85380000000004`, 
      112.98470000000003`}, {387.2538, 107.58470000000005`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 84.5}, {461.1, 
      89.89999999999998}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 89.89999999999998}, {461.1, 
      84.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{74.4, 73.44}, {428.8615, 73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{74.4, 73.44}, {74.4, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{133.4769, 73.44}, {133.4769, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{192.5538, 73.44}, {192.5538, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{251.6308, 73.44}, {251.6308, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{310.7077, 73.44}, {310.7077, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{369.7846, 73.44}, {369.7846, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{428.8615, 73.44}, {428.8615, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
      0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlU2FIU1EUXkbRRlDiCEt8FCG9P2JoiKuNDk569703wncflDEhG0zKEPdH
yhVUsiCylCKi/QlpBVJsREQbVJT7Y+FIw5hQSdukGEoQ4UMKcd3euesRHrg/
Pu655/vOd87dFeijwfU2m20dOwfYqWBnS7bkyhzS4WQ3izYCZfzGEDtH0hL8
aHcWqz5pa3AuFvI45iU4HUw3GHMavq8gcGJYeJWc1+CsxzEb20nAl8vOub9r
8FjKh52UwPtJ8bZ/RYPpDItBgvUqKeInBF7W5p/m6ijsZWxGgUC/u3u00UuR
f4cM2+Oxh/ZTFEajLI7JcHUhfikeozDG5Mw+l+H3nlSHNkmhndEl7Arq+0Lh
yqKWErwKfL6X2Rhd4vXOK3BrXPu5sFrmt7BZ76uFgbUTqlHhSDJ8OGxQ7I+o
WK/A73tV9G+KwlYGPTdV2B2RaqQkz7+vov6ohSeWInXCgIU3lPxvh49zvTdU
9MtH0b8eFe7eMQKii6L/Xp7fQOGiMyHlN1vY9GdCgXr/4lCkqMEmNmtbVvk3
D9Mfjwqt9qbe0iqf1zWuv5bXS/P+3BSKLF36xfODFKoTfwX5EEctPNYXnQm+
s7A5z2UKLU0sllW4UOWoDG3Tke8Fr7dPx/4GuV9tOvrpsrB4mRlSUP7HzxTU
e5DnDynwbSB0Jtuso/4uBfnrdXgtsAfNCvIJPJ/th7lfDh3n9VFG/QbX+0jG
+xm+Lz0y+sH2zaxXLSPfOQpdbF3FDwT3L0ChI8USHhCc91E+j+sEWhpHVsZV
7mc/Qb5W7ncnwX3dT9f8xzL+A4GLpIE=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 
       2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{133.98, 47.52000000000004}, {133.98, 
       49.56000000000006}, {130.26, 49.56000000000006}, {130.26, 
       50.52750000000003}, {134.173125, 56.10937500000006}, {135.03375, 
       56.10937500000006}, {135.03375, 50.52750000000003}, {
       136.20187499999997`, 50.52750000000003}, {136.20187499999997`, 
       49.56000000000006}, {135.03375, 49.56000000000006}, {135.03375, 
       47.52000000000004}, {133.98, 47.52000000000004}}, {{133.98, 
       50.52750000000003}, {133.98, 54.41062500000004}, {131.295, 
       50.52750000000003}, {133.98, 50.52750000000003}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCwAGIQrVHXs/N1aoYDBwMIeDsE3JKuSXRB8NWB8tmOGQ4X
zgCBgbfDF6/INgvbDIcHiwtsuUK9HbY7ND06bp7hoNH6OnBHjrcD588F6Zv1
MhwqbLmuL57k7XBQXC24VTnDYcFMIFjq7fBgjuBSWzEEf8buaRP6uRF82eUv
PPSYMhwCHlaJrJvp7ZAfz35O8le6wwqgddcbvR1aeP3XT3mf7mAQ03/oa5K3
w+l3Jw87PU93iNgh1/ra1NvBjbmCW+VhOsQ9v7zA5vPfToeYt98L7B7WG+kQ
+7IRfIl17g+r/nlC+A/SHTYAuSIGXg6pHcmxd16mOzSIABWEeDmszbxX2PUV
ys/xgoQHYwaE3+LlIHzB5UYBL5Q/wQscHsZSCD44PAzQ+M5Q/+ZD1QdnOLwA
ct11vRzA8ZMEVf/KExLeWRkOHUDvyU1F8MHxpYPgg/3/zAMcXiLpGQ4ZaUCw
zAMcvuviofGX7QFW7x4BtV/fwyF64/43cn4ZDgnA4NVg8oC4Bxj/4PB55A5R
b5IBCf9D7uD4mama4WBhDASb3R2MQg20NEURfLD+n+lwvo3OlVlpj6Dhfccd
HH+HLqRD3AOzf3+6ww8NoAWNHg6LJlkx+m5Lh/iPyxPOB8sfR/DB8T8bEj9c
B9IdBK4DDTSDpr/L0PQwDZrenqQ7nPgKNOCVt8O1o7kmDb+h7hHxcag0W20X
LpEB54PjXxfBf1W8VbTaHhrefyDp3dgXGp6nvR3+K/799jUqA5J+ZkHlkzMc
CkDhH+btgJ7fAOtEegY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQHb1x/xu5u+kODxYX2HJpezrA+BLr3B9W/fFwmLF7
2oT+++kOK4DS1897OAhfcLlR8CTdoeN14A65pR4OfU8+yQe9THc48VUjpr/K
w8GNuYJb5UO6wwagdpEoDwcbnSuznv1IdwgActc5ezhw/lyQvpkxw+EFkOuu
CzHvA1cGRL2SB9j+eSII/oM5gkv3KiH4Abekax7qZUDst/RwWJt5r5DLMsPB
whgI0iHmGztnODhwXV9cMNXDYbtD0yN3jwwHASDX9gqCv2AmECh7wvk/gM4/
lO/pcPrdycNOzlD+ak+HL16RbRaWUPXXPR1kl7/w0NOH8pm9wPZ3KUH5kl4O
iyZZMfoKI/hg/SwIvnpdz87s7+lw/eDweZMONx/kv8RH6XD7YfEBdn8Rgg+L
LwCchcup
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGAwBGIQ7bQ2816hb76DRuvrwB1iXg7PZJe/8LDPd7AwBgJt
L4f67Q5Nj0zyHSTWuT+s8vBy4K8yW22nl+9w4qtGTH+el8M8G50rs9TzHS6c
AYIpUP0qUPlDCP6KAluu698R/IT+Q181PLwdsjl/LkjXzncIeFglsq7b26H0
wRzBpZb5DgVpQHDI2yE8euP+N+75Dh1A58n9hKh/HgV1j4iPw+ZXxVunFiH4
IPcmdSH4d9yYK7rnQvk/vB2Oz9g9TWANlH/AG6J/F5Tf4e2wQviCy42D+Q4H
5IAB4oLgcwDDiuGLF5xfAfTO4gNeDh++eEW27YPKA/3fAAqv7fkOG0DW50HD
ayPUPGD4gewTXY4IX7D/ZyLCf+9BcbXgVVDzGbwcfFp4/fW3Q9Xf9XSQDLwl
/Wd/vkMGKHzWeILVXz6R7/ADFNzVnhD7zuY7LJgJBI4IfsQOoAP+esD5YPMX
eDjo/Vf8++0IND6CPCDu2QINDyEPiH8X5zsYAI3/eskdHJ7cfVD3bHZ3YF08
yYqxGI0fgeBbXDuaa+IEjb/L7pD0Ygg1D2g+2DxFKB9o/6/T704eloC6bxGC
Dw5fJk84H2y+J8T/wbLQ9Nfi6QBOz2pQ/hZPiH36UP4TKN8m38EBaHwBq5cD
evoHADIYVqs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/Ux2+YsTbvkOFbZc1xf/8XKA8Q/Itb4OPOHlkM35
c8Fzr3yHD4E75FrnejmUPpgjqBqc7yBwfXGBbY2XQ3j0xv050fkOBjH9h75G
QeXToPq9vBwu5sez+xUj+GD5BgQ/0SjUYFVXvsOFM0AA1D8ltSP57qR8hx8a
QAOrvRyOz9g9TWB2voMGUPmOORD1WvPzHR4Arec6iuCD5b8g+GD/qHmD3fdm
Vr7Dia9AAwO8HZzWZt4rBJovsc79YVWRtwPr4klWjF1Q+SkQfmN9vsOCmUCw
FKL+YxGC/+v0u5POaQi+skZdz06Y/4H69x4UVwsGhk/AwyqRdcXeDnr/Ff9+
A4ZfRhoQBHnDwxfsXi0EHxb+AHReuFU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQzbp4klWjdb7DiyqRde6Mng4w/oPFBbZctz0cfp1+
d/Kwbb7DBveHVSLbPByeyS5/4eGU75CRBgSTPBxWCF9wueGW76DR+jpwR56H
w+ZXxVun+kL1B3tAzAvLd5hx6KtGjL2Hg95/xb9l8fkOK4DS17Uh6kUzoeYr
eThMSe1Iji1G8LM5fy5Ib0bwSx/MEVw6Id+hAqh9sRlU/+x8hx8aMf2H4j0c
PnzximxbCrW/08OBv8ps9b5V+Q4OQOUFexF8A6Dyr38QfLD/bT0h9gP1nwA6
t7/I02Gejc6VWbPyHS6cAYI5ng4N2x2aHvVDzT/u6eC0NvNeYVO+QwLQOI07
npDwKULwJQNvSdckIfhg/4RC7QPqv+PGXMHtne/wIXCHXOtcTwefFl7/9Q75
DhFA7utiRHyAw8sewYfFFwB3p8iw
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
       308.44764999999995`, 47.52000000000004}, {307.3939, 
       47.52000000000004}, {307.3939, 54.240000000000066`}, {
       307.14014999999995`, 53.99875000000003}, {306.80702499999995`, 
       53.756875000000036`}, {306.394525, 53.51437500000003}, {
       305.98202499999996`, 53.27187500000002}, {305.61202499999996`, 
       53.09000000000003}, {305.284525, 52.96875000000006}, {305.284525, 
       53.98875000000004}, {305.87452499999995`, 54.266250000000014`}, {
       306.39014999999995`, 54.601875000000064`}, {306.8314, 
       54.99562500000002}, {307.27264999999994`, 55.39062500000006}, {
       307.58514999999994`, 55.773750000000064`}, {307.7689, 
       56.14500000000004}, {308.44764999999995`, 56.14500000000004}, {
       308.44764999999995`, 47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQnRx7x425uNhhxqGvGjGPPR1g/BdVIuvcU70cVtmF
R28sKXZYUWDLdf2sl4MVo28Lb0Wxw4PFQAFZb4eTh53WZlYXOwhcBwrkQPkN
UP0rvSHq24sdEvqBFlzxhpjXC9X/39vB5caHL1zTih0k1rk/rBLxcWA/Jxko
tQDBB8l3LUfw9bVWCgusK3Y4AXRuP4cP2L6Vm4sdNFpfB+744A12v/NOqPk3
vR3uFXb1Pdlb7NAAdM7DbRD39B6EurfL22HaBP4qs6PFDgtmAkGst4NqMOti
oRPFDhbGQKDu7fDCQ++/4imoec+9IOrPQM1b5uWQa9Kw3eFsscMBOaADAhB8
WHjC+GD3Jnk6SNckGk09DeX/8nAo51bRsDsBVb/aw2H/m3k2b45AzYvxAIfX
x/1Q98h7gN3vC/QfBzDuGL64Q/y/qdjhwhkgOOEO8f8qqPrN7vDwhPH91k9J
PTEJwQeFZ0BHsUMHMPjkbrpD4gcYfwYxwAhT8QCHx6RyaPg3eKCmD1FEeoH5
FwDrGf7q
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQzX5OMjCqpdhhxqGvGjGPPR1gfAtjIND3dIhos7jG
2l7s8KJKZJ37dg+HP99KH8T0FDssmAkE1R4OC9I3v9o8sdghYodc62t7Dwe/
9VNSPWYUO2xwf1glouQBNk9qAYI/bQJ/1bflCL6+1krhCeuKHTiAbmFw8HC4
POuZ7PPNxQ4rCmy5rgPNL+dW0bDbCeUD7T952Gnty93FDgFA7euA7oPxYe6H
8RP6gQIzvOD6Ba4vLrAV8IabD3a/tzfcfoMYoIY2qDzQfRVA6xYv8XbY/2ae
zZv5CD7YPzMQfMGlew9eB/pfYh3QQ13eDvcKu/pUeqH2h3lDwgMWfsLe8PAF
u3+6lwN6+AMAiQCyVQ==
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}}}, {{{367.52455000000003`, 47.52000000000004}, {
       366.47080000000005`, 47.52000000000004}, {366.47080000000005`, 
       54.240000000000066`}, {366.21705000000003`, 53.99875000000003}, {
       365.88392500000003`, 53.756875000000036`}, {365.47142500000007`, 
       53.51437500000003}, {365.05892500000004`, 53.27187500000002}, {
       364.68892500000004`, 53.09000000000003}, {364.36142500000005`, 
       52.96875000000006}, {364.36142500000005`, 53.98875000000004}, {
       364.95142500000003`, 54.266250000000014`}, {365.46705000000003`, 
       54.601875000000064`}, {365.90830000000005`, 54.99562500000002}, {
       366.34955, 55.39062500000006}, {366.66205, 55.773750000000064`}, {
       366.84580000000005`, 56.14500000000004}, {367.52455000000003`, 
       56.14500000000004}, {367.52455000000003`, 
       47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGCwBmIQHSm+/aJDbblDRhoQuHg4wPgnvmrE9B9ydxAys9kb
pITJf7C4wJbrsbuDwW51fm5lqH4mD4e8o/82VauUO1TYcl1frODh8PLmml93
1ModNrg/rBIJ8nA4FXJwxRKtcocLZ4CgyQNs3iV9KH+Th4NrZv4HVtNyBwOg
bV8feTh83hCQHWUDtV/K00GG94HuBddyhwUzgSDS06FiziLlypByhxVA51zf
7elwRTtVMimu3CEAaN06Ti+w+7qTyx06XgfukHP2cuj1esWyJQNqXo2Xg/Wk
0/Ue2TD7EXyweU8RfAegdwqkvR1Wn78a9iYD6j8Pb7B5JilQ+VxvcPg1xJc7
CAC5tpO8He4zcXbFR0LVL/GGuD8QweeIn+Fz1RPBn67YV1roDHXvRG9IeNlB
wy/L2+Fv+5fb1y2h4e8MVW9e7tAgss79IQ+CDw6f414OC38YPlunWu7AAYxr
hmte8PgAh4+tt4Pak+Z5vtpQ+3sg7mcwhpp3COK/LVblDi+Ayt1/QtTzAsNf
Yh3IQT4QfhCCf6BW1kI9HsEHxWdrZrmDhTEQfPd22Las8rhmIdS+PRDzzlZA
/dcECa/5NdDwtETwNVqBAfLIC5W/zQsS3tVQ9d1eDv4OwonOlVD3J3hB0lN5
ucMBOaAGMy+If4uh6oHpA5S+pPKg8XXLE+z+5xlQ9672hKS/BGh6yfIEh0dJ
CNQ8CU+wfc1e5Q4JwOSqccUDnP6UXModInYAFSz1AMd3gCM0Pno9HFLeRTnV
2UHDs9QDEl42UPfGeIDTq7cVZn6E8QHiuZNG
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 
       1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
       426.60145, 47.52000000000004}, {425.5477, 47.52000000000004}, {
       425.5477, 54.240000000000066`}, {425.29395, 53.99875000000003}, {
       424.960825, 53.756875000000036`}, {424.54832500000003`, 
       53.51437500000003}, {424.135825, 53.27187500000002}, {423.765825, 
       53.09000000000003}, {423.438325, 52.96875000000006}, {423.438325, 
       53.98875000000004}, {424.028325, 54.266250000000014`}, {424.54395, 
       54.601875000000064`}, {424.9852, 54.99562500000002}, {425.42645, 
       55.39062500000006}, {425.73895, 55.773750000000064`}, {425.9227, 
       56.14500000000004}, {426.60145, 56.14500000000004}, {426.60145, 
       47.52000000000004}}, {{432.7021, 47.52000000000004}, {432.7021, 
       49.56000000000006}, {428.9821, 49.56000000000006}, {428.9821, 
       50.52750000000003}, {432.895225, 56.10937500000006}, {433.75585, 
       56.10937500000006}, {433.75585, 50.52750000000003}, {434.923975, 
       50.52750000000003}, {434.923975, 49.56000000000006}, {433.75585, 
       49.56000000000006}, {433.75585, 47.52000000000004}, {432.7021, 
       47.52000000000004}}, {{432.7021, 50.52750000000003}, {432.7021, 
       54.41062500000004}, {430.01709999999997`, 50.52750000000003}, {
       432.7021, 50.52750000000003}}}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 91.74130000000002}, {59.04, 
      394.4915}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 91.74130000000002}, {
      51.839999999999996`, 91.74130000000002}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 167.42880000000002`}, {
      51.839999999999996`, 167.42880000000002`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 243.1164}, {51.839999999999996`, 
      243.1164}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 318.804}, {51.839999999999996`, 
      318.804}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 394.4915}, {51.839999999999996`, 
      394.4915}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 
       0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVAScHiQjLLSeUQhwOf9WI6bdD8BmBahiu
OTqY3FVha9QMcTh3BgjaHB1Knv9e+dEsxGHWTCAwd3TY8PGSb5ILVP8vBwg/
IsTB42GVyLrzDhD1RVD9Sxwg5vWGOEw4BNLg4DDHuTvn+ToEf4WU/l2V62jy
X0IcHgGNc5/t4OAB5P7mC3Voex24Q24z1D7VUIj5pxwg7rcOddCK6T/09Y2D
A8sqoAK/UIh7JaHujwl14L6+uMDWzdHhCdA5U7NDHQptua4vrnF0UABaz1YO
NW+Po4MOUNq5HmreH6j69lCHN0DrW4OdHBy2nCjb1x3qAAtPGB/sXkdnVP5K
Z4cfQOcKtELV/3B2yBAAOrgcap67i0PHVKCHs6DuaXGBhFdYqMPSAqDAeheI
+4H+uwF0PtdtF4j/FaHqP7hA/P8/BM6HhSeMf2Q+UGBhiIN8KzAAT7lAwrM8
xKEG6LyHdVD7IqHhr+wCCQ9TaPz2OcPTB3r6AQCU1A3l
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHFVL6d1UyQhwKbbmuLy5xhvMPf9WI
6X/j7PDm98qPl4pCHLivLy6w1XBxqNk3X0q/I8QheIdc6+tkFweexqnO3XND
HL4BlR9qdHE4ApS+ux3BB5t3HcF/osLWOPVbiMPSAqCFQP0e3TnPfwuEOjAC
3cQANP+Gb5JAhBqUD7Q/QyDCcot1qENs/6GvGkD3bfh4yTfJLdQB5n4Y3+Nh
lcg6bgR/1kwgmOwI1w92f4Qj3PwaEaABMo5w+02MgeC/A0Qe6D4YvwPovZxr
CD7YP0D/TQA6J0bS0eFCGTBA5oVA7Pd1dGBZBXRANzT8JjhCwqM4BOJ+HkR4
o4c/APscp1U=
       "], {{41.760000000000005`, 87.81790000000007}, {
       40.558125000000004`, 87.81790000000007}, {40.558125000000004`, 
       89.0197750000001}, {41.760000000000005`, 89.0197750000001}, {
       41.760000000000005`, 87.81790000000007}}, CompressedData["
1:eJxdlG1Ik1EUx+cLglr4wZkFpUlgmhlEKwrUzvPsIZeU6dLnSrjKwCz84OxF
0BYVMZHMl6LIRPqQy9YiHX5xklLNQqqVBNakETWRpJQc5MSCpNtzDtzwgTF+
3HP/95z/OfemHasxV0bqdLpS/vv3H8F/uiEjlEBixYhTBY1dRmgv+B5tmFXB
0uYNZywYoen0nhsLP1WY6LbmxmUrsOJIx76kCAa1uXH+7kIF1q/8kt2eyCDe
zwOsChgeb0yIT2cYf4nWcwRPRcZeSWXL1usYNM4Ue1Kqaf0ag8kGfW/+bgUy
pi7fedPDII8fZ02k+CGK/2SErrTWs7WjDAZT7DPFXYJTOXoOCz7o4QFZxMPE
UcQPGCxklLd5AzKYTtaE7DcZmII8gVEZ87EJPvHjkJxnEexY3Pq1t4j88Mkw
kVW5ZhIYjIS54AcZdE3zAX82+XNUhufn1+2s2s7AsI1/FRS/i/Q4W18s9Z/L
Faz1AwSXJw+801lI30z766h+A53XwqAvn29YResOBu28neXTEp7vZthfp+Cq
4/yrE6z5u1/C85ykv1nCfG6RXryE+TYysPF2BX8DnmcVrOmpgj099aOZfB5m
ubyd74frry+Y+Ly89fGP62vzqKf8CyX0O4r4IuWzqGK8V8J54/Op+eGifPpU
9OuABLauuxsGB1T0O1bCfr9SsT4/gK/kmdMxTfN9D8A99l6djWZ4H64C6Hfk
DJszBWv+lizjUww28fEJdwDqt1K9/aR/n+rzkf5T8j8EWN847V8rwaK7qLoz
SPO4l+qbI7/ryZ8wrT8UrN2PgGBNL4bmd476t4XmI0j+l8qY3zjN7xkZz/PS
vDUTu+g+dcp4H18ycHC7/IMy3sdJus/fZPRrnvq12oj9jinDfMxGfD8SylD/
tmCtvl+Ck7h9DQUK5veH9FsUrO8j1Tum4Ps0QPmHFPS3WbC2X13G6dS/cdJb
Uqk+Befrs4rvT4WC9Tyh+UhWsF+P6L387/38Cz1APjs=
       "], CompressedData["
1:eJxFk1FIU1EYx2c9lJqCtuqhmuhDLCmQGjZC7X/uLm0IrZYE59CEMkcYSJNF
iQwfSsUg2thDTOkh20zDmvYgTiJsSkQwowfRFRFTRkRKRKjgw6qze467By6X
3z3fPd//+3/fqWy5edGzw2AwWPmTe0e99UVLEYLdkdDpghjDNrsvv5pZu8GQ
ivAPPrnvYZhP8uUkiNYdWxh0M/StuuKmUwRmc/eDaReD5SRfZQTJ8OtHwTMM
xUv8gL9A3eK7dstRnTvTj8uGS3VeOzzyw7FF0RyY3TAXEayvN7K+7xQFXKOh
iiDs6b/WvEjhN8bsyyB4mzhwpClB0RQ39a62E1zoKTk/PkGFnucEjpdt3zqi
8rwMEeeHqchnVYSeEEWQb7uHdd40uwOzPslPKao5bjgV9Ezh7sqk5FoFxq7a
sYZ5ySZF+JGRXK4gfXZnZ3FWZ82P/SzP2vk2JvRZJLcxzHE5gdsyvl/GxxXh
/yhDRS8vsNQm/J5iGM71647OWv1vdG7g3fRmbcKvCYaPuf5ZVeHvkMx/SxXx
IQbHcpcxNqTCW7j15Ho3E/4kVKGnlQn/0zK+kaEjNy6/VdGf4zofcn056N+j
s/b/gvT7vYqaf5XZzWdU6OH5tf7doxi3cwFVMv8VKuobsMGQ/PVhzin3vyp5
1vq/S+fBAb74PGj9aZHzUEKEv/cpVnh59mk5b2NSTwBoPXGppvqzzi/2flJT
5SzPWv/r5f0YAYIPM38qrko/UxD1+ZmYn0KC+E/f5L6w9P+cvA+j+v3avm//
AZVgk5Q=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4OxRw/lyQPifCYcKhrxoxyxF8RqAahivO
Dm9kl7/wWBjhIN/6OnDHP2eHB27MFdyrIxweVYmsc9d0cbiSH89+bkuEwzeN
mP5Dni4OHmsz7xUeinCI7QcamODiYPBf8e+3yxEOh4HG95e5OJyZsXvahKdQ
9Y0uEPN+IPhg+7kj4fyKB3MEl6pHQuzPcnGIid64/419pEOhLdf1xTYuDiJV
ZqvtQiId0tOAgA9qfkakw6yZQHDe2UFDo65nZ1GkA/f1xQW2DQj+eveHVSIm
aPwfTg4BLbz+6zOg6s84OSyx0bkyKwTKX+Dk8OWLV2SbA5Tf5QSxXx3BZzjz
7uRhDgQfrP9VBFw/x+JJVowXI+Dmg8NndwTcfrD/lkVA3G+IiA/0+AIAW6XK
Uw==
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHpMOXtVPbkx0Of9WI6bdD8BmBahiu
OTp8aD0ZcrAr2eHcGSBoc3QQ4N66rHJissOsmUBg7uigN2HBD8MZUP2/HCD8
RckOHg+rRNadd4CoXw/Vv8QBYt6eZIcJh0AaHBxUdv5pLzmL4K9a4ucw+SGa
/Idkh0dA49xnOzj8isk9Wvc32aHtdeAOuc0Q+zZypEDMP+UAdv9T4RQHrZj+
Q1/fODhEvNHfrS6bAnGvJNT9KikO3NcXF9i6OTqc0LSadFo7xaHQluv64hpH
h2frVJ80G0LN2+PokDOrfM4iU6h5f6DqLVMc3gCtbw12cigrlOZ9YJ3iAAtP
GB/sXkdnVP5KZ4dLDPeYOi2g6n84O3TJJ7+7ZQg1z93FQepRhLg5zD0tLuDw
clRMcVhaABRY7wJ2/0+g/24Anc912wXifzao+g8uEP9/TYbzYeEJ41uku2S+
P5bsIN8KDMBTLuDw/Lcx2aEG6LyHdRD7Di6Chr+yCyQ8JkDjt88Znj7Q0w8A
e8EVEA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHVUv8HIRXJTsU2nJdX1ziDOcf/qoR
0//G2cFHtMcra32yA/f1xQW2Gi4OU76xxUvsSnYI3iHX+jrZxeHO9cbiY0eS
Hb4BlR9qdHGwSHfJfH8RwQeZN/khgn9C02qS98dkh6UFQAuB+n/F5B6t+5fs
wAh0EwPQfCe7Fzd1OFMgfKD9XfLJ724JpzjE9h/6qgF0n96EBT8MJVMcYO6H
8T0eVoms40bwZ80EgsmOcP1g90c4ws2vEQEaIOMIt9/EGAj+O0DkPyL4Uo8i
xM0fIvhg/wD9NwHonBhJR4d9QdMU+Y4mQ+z3dXSIeKO/e/luaPhNcISEBzD8
wO7nQYQ3evgDAEeQqwY=
       "], {{41.760000000000005`, 163.50549999999998`}, {
       40.558125000000004`, 163.50549999999998`}, {40.558125000000004`, 
       164.707375}, {41.760000000000005`, 164.707375}, {41.760000000000005`, 
       163.50549999999998`}}, CompressedData["
1:eJxdVAtIVEEUXTOM1QjLVcNKW7AQsy1riSy1+94+Ujcy1l9ZVqu+UfqIK4mk
VGigRFpKRJiIBRaJUpEUKYmREllt9jM3MiOlMlPKpN1SChtnLk048Hgc5s6Z
e889d/QZuQlklkajSabf9N+Nfpo2ExTfhuMZj1RguNEEdZFhPQGjKuyu7HCG
uEwQYHmz6Pc3FV7X26I8VyrwdrP74XKXCnlRno76eAU+LbnyuWtKBS8HDbAp
MPbDnOqhJTy+hO/H6gTuqr5zrko/Yz+cQNmIpSXwAO5HExgs0l2L2aTAfu3E
xew4AtH0OpsPxidhfL8JgkOOVbSmEmgNLB2x1AocRGHLHoETW2jACsRJiN0R
mwm4QtIqO/pkmHz89WEnEIgdoAk8kFk+3kaBT57+MH4hWOAGn2fKjkDC9bDL
IF/d9y7Pj0CnkxL2ypCy68bd0bmE62OVYX3v/Zyb3gSMa+lK5/HfFyAfxfOK
1jW16wRm/fATeHb9mQ0lwcifgPeFY/1GvC+SwPUYesAP92MJVNF2pg1J7H5j
POH9bRA4O4uuAoGZvlsldp+bGfnDJJZPjYR8XhLLNzqCwBHaroFJ4PcZBGZ8
eoGbvxy65UvrG6X0pfR8wfva+cuoX7rtdFF+5kcN5h8vcb1/qhwXYz7jKo/v
kJjfyqg/mR6NPJ/2JyrXa5sEZ8mJzP7nKtdbK7F+R/SpvD4HQNs9/+Uvh9Hf
lwEMU/o/Bb9wHioArGuSVzd6kn94Wt+DS2fgVQRCqX2c1cD5o7DeZuSPw/rs
yJ+C+o8Bqy/IiucXS/Aid++c7iz0YxzWl4N6F3J9Bm243yQwm48+gRmfB/dv
VQ72z4D+yEL9k2WWX6IV/Zsv8/ndjn4rR7wF56lGZvM4tJPAJSqXo1Xm85iN
8zwsM71Cbdi/hSbe70LMJ8HE34+jyH9eYFbfhMC+VL4is8L1y0f+Uwr3RybW
+1Th75MF8x9TmL6ujQKz+vQzsBb714N8ThXrU/h8fVT5+5Ou8P6/Qn/4K9yP
dvTHf+/nX9N6SgY=
       "], CompressedData["
1:eJxTTMoPSmViYGAwBGIQ3fY6cIdcr5PDvDjN0wKXUh0KbbmuL65wcnA4n3b1
+eFUhwmHvmrERDs53MpgyG/cmerwqEpknbupk0OW9rfpdzelOtxYXGDLxe/k
8Ovt6wOWa6DyDx0h+lekOjAC7WBYg+B7PAQqiEbwY/uBFkg4OhzbtaOXbUOq
gx3Q+oKHDg4XJsb8c96X6qDQCnTgKgeHTTyFa7rPQN3T7wBW33YfweebY7zI
5DuCD3IvI38ahL/awcHsx6EULSUo/7GDg5JXdfN6Ayhf2hGi3z7N4Q0wOFrj
HR1YjvYblrulOSwBeu/6egTfxBgIHqPJA/3vs4zLTdU5zeEb0PZDptDwsoGa
Fw0NL9M0ePiC7NuineYAC3+w/+Wg5i92cpAovi70SQ+q/piTwwrTs9bnrNMg
4fPdyaGEaRbHbJc0h/XuwADVcAarL/JNc+AGStsmOUPsC0xzCAZa/3opgg82
n9kFzgfHR6CLQ8eGhy+nekLDY6ILxD2WaQ41oOi84ALxrwbUPR9cwOG5SgjB
TwgJUl/wPRWVfyfVQR4Uf0D9k9pboy4fS4WYN8EFkl62QfkBUPOWpkLcx+ji
EFa7blvS3FSHpaDwXegM54PNj0LwwelPHuL/Twuh/PfQ9Lwayt8PTZ9bUh3S
04BgHpR/MNUBPf0DADocWi8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQbWIMBMsdHRzOp11NP53q8CZwh1zrbQR/p1zr60A2
J4dju3b0tp1PdZg1EwjUnRwuTIz5d/h6qkONyDr3hx5ODpt4CtdwP4Dqj4TK
v0LwdRTlv7z5jibPkuZwY3GBLZenk8OexyKynvxpDuvdH1aJaDg5vBPzCKgR
T3Noew3UwO7koORV3bxePs3h7BkguOcIVn9SGSq/HsEH+6cWwX9UBXRgsCPY
fd1A/RMOfdWIMXR0mBeneVpAHCrP7+iQEBKkvoAvzYH7OtBB/xzAfAUWBB+k
fgLQ/TB+WO26bY9eQf3P5+hQd9O2MgLo/9h+oAUGjg4SxdeFPgHDx44LqCHQ
0aFjw8OXU4HhB3ZvJSJ80cMfAFNOsdM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQffirRkz/ImeHhJAgdYUDqQ7nzgDBCQT/G1D60Ftn
h7DadduSDqU62HFdX1wg6OLgcD7t6vNjqQ5trwN3yJm6OLAc7TcsPw3VH+Di
wDfHeJHJpVQH0XXuD6tSXCDm3U51YATayVDh4tCx4eFL0SdQ8xsh6re8RfDf
iXkE/PmO4B/btaOXjSPNwcQYCHJdHC5MjPnnLJrmsB5ovIgLVL98GsR+KRcH
n2VcbqpaaQ7paUDwzNkhS/vb9Fj9NIcaEaCDliH4YP+nIfiPqoAKDJ0h9mum
OdxYXGDLxe7s8Ovt6wOWMPPvODncymDIbxRJc/AAWr/uuJPDvDjN0wLsCD44
fL6lwvklTLM4pJ+nQuwD6gf751aqw0651teBbM4OZj8Opaw6n+oQvAMooO/s
sML0rLXfUWh4pSDiAz2+AGSUxSQ=
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHPbe6/qb+zXE4/FUjpt8OwWcEqmG4
5ujgNbdB7RBDrsO5M0DQ5uiQpZRTUcWe6zBrJhCYOzp0LA8/ZcSXC9H/ywHC
l8h18HhYJbLuvANEvSpU/xIHiHlGuQ4TDoE0ODjUXdgcWeqM4LPsYRWaEo4m
n5br8AhonPtsB4eQEpXp9cW5Dm2vA3fIbYbYt6kOav4pB7D7n3bmOmjF9B/6
+sbBYRPz8x6NyVD3SkLdPyvXgfv64gJbN0cHJcePyWcW5joU2nJdX1zj6OBw
7M7WluVQ8/Y4OhzbqJe3eDXUvD9Q9etzHd4ArW8NdnK40HHp3oONuQ6w8ITx
we51dEblr3R20JGYeqVzHVT9D2eHJ2ZSB24vh5rn7uJQ8pP/pTnMPS0u4PBy
mp7rsLQAKLDeBez+X0D/3QA6n+u2C8T/NVD1H1wg/s9G8GHhCeNPqvtt9cEm
10G+FRiAp1zA4flfPdehBui8h3UQ+w5JQMNf2QUSHmzQ+O1zhqcP9PQDAMVG
HLw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHlj2sQiIKuQ6FtlzXF5c4w/mHv2rE
9L9xdlim4yyTrZrrwH19cYGthovDO959BpIGuQ7BO+RaXye7OJi9t3A9bpXr
8A2o/FCji8Okut9WH9wRfJB5U8IRfCXHj8k+6bkOSwuAFgL1h5SoTK8vyXVg
BLqJAWj+nND5q3XroXyg/U/MpA7c7sx1iO0/9FUD6L6O5eGnjPpzHWDuh/E9
HlaJrONG8GfNBILJjnD9YPdHOMLNrxEBGiDjCLffxBgI/jtA5NMR/JKf/C/N
wxF8sH+A/psAdE6MpKODRJbvZz5rqP2+jg6bmJ/3rDCEht8ER0h4qELdz4MI
b/TwBwAPW58I
       "], {{41.760000000000005`, 239.19310000000002`}, {
       40.558125000000004`, 239.19310000000002`}, {40.558125000000004`, 
       240.39497500000004`}, {41.760000000000005`, 240.39497500000004`}, {
       41.760000000000005`, 239.19310000000002`}}, {{41.760000000000005`, 
       245.29149999999998`}, {39.720000000000006`, 245.29149999999998`}, {
       39.720000000000006`, 241.57150000000001`}, {38.752500000000005`, 
       241.57150000000001`}, {33.170625, 245.484625}, {33.170625, 
       246.34525000000002`}, {38.752500000000005`, 246.34525000000002`}, {
       38.752500000000005`, 247.513375}, {39.720000000000006`, 247.513375}, {
       39.720000000000006`, 246.34525000000002`}, {41.760000000000005`, 
       246.34525000000002`}, {41.760000000000005`, 245.29149999999998`}}, {{
       38.752500000000005`, 245.29149999999998`}, {34.869375000000005`, 
       245.29149999999998`}, {38.752500000000005`, 242.60649999999998`}, {
       38.752500000000005`, 245.29149999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeH9VNSO5KF8x0Of9WI6bdD8BmBahiu
OTrYh0dv3C+W73DuDBC0OTrE3nFjrpDNd5g1EwjMHR1qEo1CDVSg+n85QPh6
+Q4eD6tE1p13gKi3hupf4gAxzyPfYcIhkAYHh6KuvidFkQj+99IHcybmosnX
5Ds8AhrnPtvBwVPvv2JtZ75D2+vAHXKbIfZtmAI1/5QD2P2P5+c7aMX0H/r6
xsFh6d6D4moroe6VhLp/Q74D9/XFBbZujg5iv0+/O7k936HQluv64hpHB5OG
7Q5Ne6Hm7XF02JXN+XPBQah5f6Dqj+Y7vAFa3xrs5HDEaW3mveP5DrDwhPHB
7nV0RuWvdHZQuJQf334Eqv6Hs8OND1+8bu6Fmufu4pCx+VWxKcw9LS7g8LJf
m++wtAAosN4F7P4fQP/dADqf67YLxP+ToOo/uED834jgw8ITxm+zuHb0bVC+
g3wrMABPuYDD869tvkMN0HkP6yD27deDhr+yCyQ8ZKDx2+cMTx/o6QcAlgwW
rg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeH76UP5gia5TsU2nJdX1ziDOcf/qoR
0//G2WH2M9nlGdb5DtzXFxfYarg4PD4+Y7eYW75D8A651tfJLg5aK4UvHAnI
d/gGVH6o0cWhzeLa0bexCD7IvIm5CL7Y79PvPGvzHZYWAC0E6vfU+69Y25Xv
wAh0EwPQ/In8VWbaU6F8oP03Pnzxujk/3yG2/9BXDaD7ahKNQg2W5jvA3A/j
ezysElnHjeDPmgkEkx3h+sHuj3CEm18jAjRAxhFuv4kxEPx3gMjXIvgZm18V
m+Yi+GD/AP03AeicGElHBx4VjTqeQKj9vo4OS/ceFF/mDg2/CY6Q8LCGup8H
Ed7o4Q8ADf6s/w==
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
       0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeH2Nyj/zZZFjsc/qoR02+H4DMC1TBc
c3RY6ucgnGhd7HDuDBC0OTqYCJrZ7LUrdpg1EwjMHR2OXNZOlXSC6v/lAOG7
Fzt4PKwSWXfeAaLeF6p/iQPEvJBihwmHQBocHOxe3FyzKwbBZ7zHxHkqDVXe
Kq/Y4RHQOPfZDg5aVpNO7y8pdmh7HbhDbjPEvsgqqPmnHMDu/1Rf7KAV03/o
6xsHhxuNxW5TWqDulYS437aj2IH7+uICWzdHhwkLfhg+6y52KLTlur64xtFB
Ifld1KE+qHl7HB0eRYhvvzgBat4fqPpJxQ5vgNa3Bjs5ZLhk5n+YXOwAC08Y
H+xeR2dU/kpnB7Eer1cuk6Dqfzg7FEnzPnjbBzXP3cVh15/2L7Nh7mlxAYfX
wrZih6UFQIH1LmD3/wX67wbQ+Vy3XSD+r4Sq/+AC8X8Bgg8LTxjfY3+tbEVk
sYN8KzAAT7mAw/O/X7FDDdB5D+sg9iW6Q8Nf2QUcHk520Pjtc4anD/T0AwA1
mRC1
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHxntMnFzexQ6FtlzXF5c4w/mHv2rE
9L9xdgiepti31bfYgfv64gJbDReH72zxM3iCix2Cd8i1vk52cZhVPmdRckSx
wzeg8kONLg4e+2tlf8Qh+CDzTqUh+BMW/DBcllfssLQAaCFQv5bVpNP2pcUO
jEA3MQDNP7fq/NVpVVA+0P4iad4Hb+uLHWL7D33VALrvyGXt1JlNxQ4w98P4
Hg+rRNZxI/izZgLBZEe4frD7Ixzh5teIAA2QcYTbb2IMBP8dIPJ5CP6uP+1f
Zqch+GD/AP03AeicGElHB56tyyrbI6D2+zo63GgsdrsSDA2/CY6Q8PCFup8H
Ed7o4Q8A81KoRA==
       "], {{41.760000000000005`, 314.8806}, {
       40.558125000000004`, 314.8806}, {40.558125000000004`, 
       316.08247500000004`}, {41.760000000000005`, 316.08247500000004`}, {
       41.760000000000005`, 314.8806}}, {{41.760000000000005`, 
       320.97900000000004`}, {39.720000000000006`, 320.97900000000004`}, {
       39.720000000000006`, 317.259}, {38.752500000000005`, 317.259}, {
       33.170625, 321.17212500000005`}, {33.170625, 322.03275}, {
       38.752500000000005`, 322.03275}, {38.752500000000005`, 323.200875}, {
       39.720000000000006`, 323.200875}, {39.720000000000006`, 322.03275}, {
       41.760000000000005`, 322.03275}, {41.760000000000005`, 
       320.97900000000004`}}, {{38.752500000000005`, 320.97900000000004`}, {
       34.869375000000005`, 320.97900000000004`}, {38.752500000000005`, 
       318.294}, {38.752500000000005`, 320.97900000000004`}}, CompressedData["

1:eJxTTMoPSmViYGCwBmIQbcd1fXFBvIuD3+e+4C1zSxweVYmsc3+IyWcTErE/
5lTicO4MEBxA8MH6F7o4qEz/P6HOucTBxBgIml0ckhZeM3nvUuLwTSOm/1Cg
i8PdrS01Ae4lDjcWF9hyKbo47DOYqSXhDeV/dAab5xZQ4lADsu6As4Olq3tR
ZSjU/k5nh+c9Gm/PxpQ4cAOts/VydhB4uX29c1qJAyPQDwwvnBxyKqqWvikp
cYjtP/RVY5aTwwl229lX60oc5FtfB+5IcAK7718z1Dx1J4cGtUNt6p0w+x0d
9PIWM+7phpq3D8FPTwOCDgQf7L9oR4cFq9feiO+Eyps5gs1b3lLiMGsmEAg6
gsPvSz1U/X8Hh0v3HnBfrkTwwe4vQvD/WBWc88iCulfI0aH7b+r3J8nQ8LN0
hIRXfInDWVD4Jzg6fEo+E+sdVeKgBZT+Og2qPhwaPncQ/CVA710/6+gw9Qpn
hpIbNHzSHOHxAbZf3NFB6kC0wkFvqHkPHMDuLwkucTj8FeiAVQ6Q8IoucZhw
CCTgAFbfmIrGL0Lwt0R+3TkL6P8ioPWL1ziA4/NnJ9S+5w4Oq5oCPedOhPpP
EWK/40xoeGY5gsNLGJj+2oDBIXcQjf8WwQerl3CChPdsqPudnBycZV4/2gY0
7w1QeWuuEyQ9TYeqB6YPsH8nQ+PrpBM4ffX2lTgUgtz7wwns/qhOaHqxhKa/
Bqh53c7g8HgOTG8eD4EKzjuD7fsGjL9goPTrv87g9Dc1BRofYi7g+D6cCA1P
PReHiFNGRz7GQd3r5gIJrxhofoqH5Kd9UQg+LD8CAKs4oic=
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVAScHrp8L0jd/KXc4/FUjpt8OwWcEqmG4
5ugQeEu6JvFbucO5M0DQ5ujwYI7g0r0/yx1mzQQCc0eHgnj2c5J/ofp/OUD4
TBUOHg+rRNadd4Co56iA6F/iADGPv8JhwiGQBgeH18VbRXeLI/hrM+8VnlJE
lbfWrHB4BDTOfbaDw7WjuSYH9Csc2l4H7pDbDLEv0hRq/ikHsPs/W1U4aMX0
H/r6xsGhhdd//RT7Coh7JSHut3WucOC+vrjA1s3RwUbnyqxnbhUOhbZc1xfX
ODqceXfy8CFPqHl7HB36nnySv+QNNe+Po4MtSL1vhcMboPWtwU4OIhdcbnzw
q3CAhSeMD3avozMqf6WzwyFxtWBXX6j6H84OcstfeLzzhJrn7uKQ1pEcOwfm
nhYXcHgtdKxwWFoAFFjvAnb/X6D/bgCdz3XbBeJ/E6j6Dy4Q/2sj+LDwhPG/
ekW2VYhUOMi3AgPwlAs4PBm4KhxqgM57WAexL5EJGv7KLuDwcPoJjd8+Z3j6
QE8/AGSwFm4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHtZn3CrnYKhwKbbmuLy5xhvMPf9WI
6X/j7PBf8e+3rRwVDtzXFxfYarg4LJ5kxcjLV+EQvEOu9XWyi4M7cwV3inCF
wzeg8kONLg5fvSLbfkgi+CDzTiki+LY6V2Yt06xwWFoAtBCo/9rRXBMHgwoH
RqCbGIDmV5mttptuCuUD7Zdb/sLjnVWFQ2z/oa8aQPcVxLOfm2lb4QBzP4zv
8bBKZB03gj9rJhBMdoTrB7s/whFufo0I0AAZR7j9JsZA8N8BIq+J4Kd1JMfO
UUTwwf4B+m8C0Dkxko4OOxyaHrULQ+33dXRo4fVff4UPGn4THCHhwQF1Pw8i
vNHDHwBCsKUt
       "], {{41.760000000000005`, 390.5682}, {
       40.558125000000004`, 390.5682}, {40.558125000000004`, 391.770075}, {
       41.760000000000005`, 391.770075}, {41.760000000000005`, 390.5682}}, {{
       41.760000000000005`, 396.6666}, {39.720000000000006`, 396.6666}, {
       39.720000000000006`, 392.9466}, {38.752500000000005`, 392.9466}, {
       33.170625, 396.859725}, {33.170625, 397.72035}, {38.752500000000005`, 
       397.72035}, {38.752500000000005`, 398.888475}, {39.720000000000006`, 
       398.888475}, {39.720000000000006`, 397.72035}, {41.760000000000005`, 
       397.72035}, {41.760000000000005`, 396.6666}}, {{38.752500000000005`, 
       396.6666}, {34.869375000000005`, 396.6666}, {38.752500000000005`, 
       393.9816}, {38.752500000000005`, 396.6666}}, {{41.760000000000005`, 
       403.341}, {39.720000000000006`, 403.341}, {39.720000000000006`, 
       399.62100000000004`}, {38.752500000000005`, 399.62100000000004`}, {
       33.170625, 403.534125}, {33.170625, 404.39475000000004`}, {
       38.752500000000005`, 404.39475000000004`}, {38.752500000000005`, 
       405.562875}, {39.720000000000006`, 405.562875}, {39.720000000000006`, 
       404.39475000000004`}, {41.760000000000005`, 404.39475000000004`}, {
       41.760000000000005`, 403.341}}, {{38.752500000000005`, 403.341}, {
       34.869375000000005`, 403.341}, {38.752500000000005`, 400.656}, {
       38.752500000000005`, 403.341}}}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.04, 
      73.44}, {473.76, 73.44}, {473.76, 444.96}, {59.04, 444.96}, {59.04, 
      73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001984126984126984], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1,
        0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQ3aTvs4zLusChIA0IDhk5wPgfqkTWuUdaOxywVPba
XY7gf84Jq33XjODf38c3x7i3wMGB6/riAldrsP6uyQUODJox/YdkrR2EPjme
fzazwGGD+8MqkW9WYPN+zwPKg8AGK4detg9iJxYBzQvcIdfqbeUQeXnP4ynL
ChwmHPqqEfPcEqy+ekWBQ4Mt0IIKBB8s/98CzncwBoJkC4eUVQkhQUuh8vfN
HVZ3385gmA+0vwBoQLE52L2bZ0DN4zB32JZUf/NvX4GDwjqgA4+YORiU6yre
b4TqX24Gdv+ytgKHC0Buf5MZ2H9eXQUOCUDnvo6F8E/1QP1vaQa2X2hSgcOD
xUALX5s6+P+RKBafXuBgAAyOrx2mDq6qpUy3ZkPdK2wKCd/NBQ4HgMYF7jCC
2D8HwT8lcHzXji5o/HSZOLycuomnsBVqPy/U/EaofJGpw1/nX29X10L9u93U
Yfrdye2uVQUOC2YCwV9TsHkW5VD1emZg+daSAgcBoPNtvSDuv1QIja80qH/y
oforIepdc4DhcQYIWszA7rfOgtrXbeagtqBzw8M0aPj1m0HsS0Lj+2Ly0dMf
jA8AN6MlOg==
       "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQfUrg+C4L3wKHCYe+asR0mzu4qpYySZUg+P5/JIrD
axD8Jn2fZaeagPzXgTvkZpo73N/HN6e4vcChwZbr+uIt5g5qCzo3KPYUOCis
c39YdcHc4XNOWO26/gKHC2eA4A/U/EkFDgtmAoGlhcP0u5PbW6cUOBSkAUGZ
hcMBS2Wv3VOh+ncg+BsKgBb8R/AT+oEOyrAE25c4GcjfIdf6eq8lxL4+qPsY
rRxWd9/OYOiCus/FCuyf6U1Q+9KsIO6vQPBh4YHOh/kfAEu3iIo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQLaV/V4VtX4FDwg651tc/zRxgfAbNmP5Df80dEgUi
LLfsL3BoEFnn/vCchcPHS75JAocLHD5UAQVyLR0apjp35xwrcAh4CBTgtoLw
T0P1t1pB1F8Cqg8EWnDbCmLeDah+Q2uH3ys/XuJ9CLS//9BXjRhrh33zpfRl
XyP4IPneTwj+M6CA0M8ChwNA5wa6WIPtW/MP6D5bruuLRazB7ndjKYSY/9TK
AeSc5xyFDgZA53xdAHHPBJ5CiHvdrRyArouwFCh0KEgDgneWDndU2BpFhQsd
FswEgkZLh/kgA0Wh5jFaQtSLQ81rsHAAKp/qLFHosKEA6IDL5nA+LDxhfLB7
f5g6gIJjhhiUr2HqoAcMbkdhqPpOE4cyYAC854ea99oYHF5fuKDuKTQGuz8A
6D8HYyCQNob4/2+Bw4UzQHDECOL/rwUQ9TON4OEJ47MCnXP6LoIPCs+gywUO
DsDgK3hqBIkfYPxNeA2MsFpjcHhMPQQNfxMT1PQRa+qAnn4AUPoBBw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvW++lH7s+QKHhB1yra9/mjnA+AtmAsFEUwf+CMst
HJcKHBg0Y/oPLTRx2HyibF/89QKHgjQg0DJxCLfccmLbnQKHB4sLbLk2Gzuw
Nk519n5c4DDh0FeNmHJjsHmyrxF83ySBiJ+fEPxnv1d+nPSzwMHBGAiA+rty
nv9++a/AoUFknftDoPl6d1XYHFkKIfxFJg4NU52737AVOlwAau+fZArnw9wP
438IBAokW8D1BzysElkXbAk3H+z+U5Zw+ye8BmpwtILIA92nALSuqsbKoQzo
gfevEHywfx4j+MDgmH8L6P+EfqCHPKwcgNbnqN8ogNh/3xISHrDwi7SEhy/Y
/UkWDujhDwCHZ7pB
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, {{{12.96, 200.48282500000005`}, {
       4.32, 197.22220000000004`}, {4.32, 198.42782500000004`}, {10.5975, 
       200.61595000000005`}, {11.100000000000001`, 200.79095}, {
       11.571250000000001`, 200.93782500000003`}, {12.01125, 201.056575}, {
       11.540000000000001`, 201.18657500000006`}, {11.069375, 201.337825}, {
       10.599375000000002`, 201.51032500000002`}, {4.32, 
       203.78470000000004`}, {4.32, 204.92095000000006`}, {12.96, 
       201.62657500000006`}, {12.96, 200.48282500000005`}}, CompressedData["
1:eJxNVAtIVEEUXdPK/mEGtqtvv637xErMTAztWmxKGbFBRrmmZpozRllZhIVJ
oUhERh/MPoZsH6WyskQzrdhokTBSicwtRcsMU/CHWIrYvJlxXxcej8O97865
55552r2HtqfOUCgUseSR3teLSVhMULLj9oNHkRgUUniK0B2qfBMfjGF/Gol8
EXzw1pELRgwfGqUQIXQgzBytwhCymsSSAAj0ufppzmJeHxoAWHfgxLi7jAcX
vApaNoZceOHl8jPNXQheCHl9lk4Rcpqe7TrWjCCh0D5qChEBHN+qPByI8Skw
gTPx+LaSWgRLK6K7sh/6Q1ngRt++5wgo/1KjC9PvPWRM67OWM37VCN6OmqyF
wwbG/yWCwxFzW22ZBjbfa449DeB4uvKg/h2vr9UzPo0I7mSSggw9XMqZCB9s
4fyD9JD1d1FvtZPz9dQz/X7w+j4dy/ciCLASgk06qk/2CIKLhK61WkfPsykw
9FtqhLyzOto/k+gr0ffepKP7WbEKwxcbaTilpf2/rsMQKdGvkrGa0KnJl/Ep
b9LhiIwpv2saF6bnTaghaUvD7PowzOaJUUNclqHo9PT+4wS2T5Gf1+4HTQUt
HUl+Mi64v/N95XwZU/0mEYwR+exrBDbfEN9/j0Drg38jNk+RGmJv5Rrt37l+
6RqKN7TzfcRoWf82vm83LdOnluupYfPE1/N+rQLTy873Z/eDOue5yZ8NCB5L
elb4QqX7r/NlHxHckPq1qWg+lfTPJ/IJZhX1m9CDQOpme6KE8e7k0s/DnH+a
kvq52A27MP3eS8bUb3oM6RK8p2T+CuJ5o4r6fTQcs/Puqhh/M8dmX6r/VCyv
n8X07rRw7PADXdRQSmMcZvPXCHR/Ebsxm69DzfS1Yjb/Zg29b5YEzPw2oGH9
Eqb3pXVhqm+5wYXpfbppdOF5pDzC6Q8edTO9ruzBzN8pJuaPRP5/6DfR+5eR
zPNHRer/tfswiBLfPyLzT7qMqX5m7s9clu+MwnBS8u+wiflnPef33//qH4tM
FEo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBWIQffirRkz/ImWHJ2ZSB25bZzmA+Z+UHfgmr2y6qJ/l
kJ4GBGYqDgneJ9j3ymY5rHN/WCWSp+JwK77Mfx5rloMd1/XFBb0qDllKORW/
vmc6aMX0H/q6QQWsP/BdpkOhLVDBDRWHYxv18ha/yHTYKdf6OpBB1SGsRGX6
/0eZEPusVCHy9zIdJhwCCrSrOkhk+X7uu53p8CZwh1zrZVWw+VU3oPo11Bwm
1f22+nAt0+EbUPuhVgS/7TVQg6g6nC8KcnCPuoPZewtX91uZDksKgA56re5Q
d2Fz5NcHmQ4mxkDgrQGx/3mmQ7UISIMGWL70I4K/QsdZJvsfgl/yk/+lOXcW
xH5fDYcPvPsMZoplQdz7WR3ifoUsiP9nqDs4HLuztUUry+HsGSCQUXf49SRx
4TXDLAcGEGhQg8ibQcObTc2BZQ+rkIgV1LxgVXj8gMMnXQU1vpDiDwBQf8/T

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.96, 
      212.56810000000013`}, {4.32, 212.56810000000013`}, {4.32, 
      213.6312250000001}, {12.96, 213.6312250000001}, {12.96, 
      212.56810000000013`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4jeBO+RaX2s6BCUJRFimZTvMmgkEihpw/pIC
W67r1ZoOLVOdu3PCsx00Y/oPfdXQcpiQ8/y3pjOCX/D898pCTQT/kQpbo6hc
tkN6GhCwaTl4dOc8rxbOdnhUJbLO/aCmwxIp/btLOLMdwPYDzb/mmyRw43+W
g+g694dVKpoOXI1AC39kOcSCjNuj4WC35UTZvs9ZDibGQBCsATbv97sshwlA
6Zjz6g5nyvbNn/U6y6EQ6NzFBlD+yyyHbxpABx1Vc0gDesfkBdR8GTUHk7tA
Bz7Pcjh7BghMVOF8sPseSmHw5fTvqrQB3QvWn6IC5zOAQIMqnH9jMTDA7NUc
qvbNl9LngobnQqh93NkOWqDwAboPzOeFyas7aLA1Tj0sCA2Pz+oOIhGWWzwk
siHuc9GAhA8wPO2A3ivI1QDHxxs1BB9svwGCvwMYXPJW0Phz1gCHtwowvsDh
80EdHD9TvaHmz1EH62cLyXaoBnlXSx0SvpFQ/iw1hxhLYATEQvlcahD5hGyH
IFDysVSFxE8SNDw0VOB8WPih80Hp5WML1L/A9IfOh6U/AM5+HHw=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOMdEb979xyXEQXef+sEpHzWFC35NP
8uk5DjH9QAUl6g4MZ96dPJyY43AYqLy/SMPhyEFxtcvhOQ4eD6tE1qlrOtzI
j2f388xxiAWpv6MJkbfKcUhPAwIzLTA/WAPBB6k/J4jge6zNvFf4NdvhxuIC
W67lmmD+x3vZDjvlWl8HdmhAzD+X7aAFclCGuoPdtaO5W/ZmQ/RfU3Uo4vy5
IH1rtkOhLdf1xReU4Xyw/h2KcD4DCEgoOLyRXf7iBFA/2P/3ZR0euTFXdAPN
VwAp75N2WCd8wSXiPtT8NClIeHxF8Nu2OzQ94s+B88H+0YSGR7u0g8l/xb/f
7HIcuK8DPXRK1mFWakdyrH+Owzdg8B1iVYCoj89xWAL07vXZig7fvnhFsmXk
QNyzXBnOlwe55xiCD7bvGxrfTAWDD4rPnOvZEPdMV4XzQdErskwNEt93sh1m
zQSCRHUI/3m2QxvQOjlZDQj/U7ZDtQhIhwbY//MZcuB8sH2CCD4ofTjLQu13
04DEj3qOgx0wOgruqkPC0wCavoDpSSHwlvQfixyIfWfVwPI37KH+R0qPAHBs
Kvk=
       "], {{9.240000000000002, 222.78265000000016`}, {9.240000000000002,
        226.16515000000015`}, {8.721250000000001, 226.11890000000017`}, {
       8.331875, 225.98765000000014`}, {8.071875, 225.77140000000014`}, {
       7.668125, 225.43890000000016`}, {7.4662500000000005`, 
       225.00827500000014`}, {7.4662500000000005`, 224.47952500000014`}, {
       7.4662500000000005`, 224.00077500000015`}, {7.6275, 
       223.59827500000017`}, {7.950000000000001, 223.27202500000016`}, {
       8.271250000000002, 222.94577500000014`}, {8.701250000000002, 
       222.78265000000016`}, {9.240000000000002, 222.78265000000016`}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHaU8+yV/6mOMgus79YVWKIpxvx3V9
cUGsvEPELemah79zHNpeB+6QU5V1uHc014RBINehEKh9cYA0RF4h1yE9DQSk
HKQuuNwoMEXwVZa/8Fjni+D/8Yps25GR6/BdI6b/UKu0w6pJVoxn63IdxED2
H5F1MKjr2fm6P9dh1kwgYFRw2JJ5r5BrYa7DeqC0SJ+iQ1k8+7mZK3MdPIDc
de3KcH7QDrnW14qqcP7ZM0CQogbxz9Jch51A6cAAdYdL704edpqX62BiDATW
Gg4CPxekb54Gte+jBsS93bkOb4DebS3WBMsb1+ZCwuOrJsT9eVD/mGlB3BuH
4IP944vgg+wPMsp1mHDoq0bMck2HpI3738jJ5Do8AjrfvRNivzF3rsNhoHR/
lrrDPoemR+6/chxAwSFyThUeH+jxBQDNLcqq
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHJrPVdteFcx2WFNhyXfdWhfOBslUi
dWoO0558kg+SzHWYNRMIPNUd9jk0PXJXyXVoex24Q05UA8LXz3WoBplXpeGQ
tHH/GzlbBH/VJCvGs74Ifk5HcmxMXK7D2TNAIAJVn5PrUAi0frGHukMPr/96
kXKoe6rVIPwmKN9ZFcyf0g5Vv0AZzk9PAwIxJTj/DdB5ra8VHBbsnjaBH6if
AQQUFBxOiKsFswLN14rpP/R1hZzDp+Ktor+zcx3sgMYV3JV1eDFHcKltHIIP
cz+MD/OfJzB41i2Xg/sfHF5yCvDwAdke+EIBHn5BIAFJJXj4ooc/AIuIpzA=

       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6qJ18aq9yO9fBjuv64gJbOQz+
FYHju3bsz3VITwOCY1IYfJh6MF9NAlV/rRicHwKyzlHUIW9VQkjQnVyHJQW2
XNeLRRz+5ITVrruX67DO/WGVSJywA4fLr7evH+Y6nDsDBDVCDlbluorzn+c6
gNzMcEHQYRrbB7ET73MdTIyBQFnQ4ZSlstfv71D1ZwQcPk3dxFPInAfnC0nP
i9MUQvD9VEuZZknnORQBrV/8QcChopHlKL9angPIeYEWgg49+j7LugzzHCYc
+qoRc18ELN+vk+fgAXTeuu1Q96rmQdy/WARivjyCv637dgaDJIJvsKBzw0O+
PAetmP5DX1+IOLzYxzdnM3sexP3Fog73nmdplwHdCw6vv6IOq7aY/3D6n+vw
CGidO6M4xPy/uQ4KQOftqJOA82Hhj84Hu1c5Dx5/6HyYelj8o/Nh8QUAsPjn
qQ==
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6rHLd9rl2Q56DHdf1xQW2chj8
iN7peUJT8xzS04DgmBQGH6YezFeTQNVfKwbnh4CscxR1+KRmyLFmY57DkgJb
ruvFIg4NL4ECW/Ic1rk/rBKJE3boOXBqoev2PIdzZ4CgRshh3+e/V37syXMA
uZnhgqCDVPOBU4pH8xxMjIFAWdDBb9vnvyFnoerPCDiUCQEV3EDwpwGd2/wc
wb+0EOigD3kORUDrF38QcPjz90pF5u88B5DzAi0EHQTWyEQ9Yct3mHDoq0bM
fRGw/EvGfAcPoPPWbYe69zfU/YtFIOZ/QfCtOIAGvEPwt8hEpVg/yXPQiuk/
9PWFiEOO9X1/3rtQ9xeLOiSlWN8/fwMaXn9FHfSAwTPnSp7DI6B17oziEPMv
5TkoAJ23o04CzoeFPzof7N4fiPhD58PUw+IfnQ+LLwCzXPyU
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.640000000000001, 
      248.71210000000022`}, {4.440000000000001, 248.71210000000022`}, {
      4.440000000000001, 249.7752250000002}, {5.640000000000001, 
      249.7752250000002}, {5.640000000000001, 248.71210000000022`}}, {{12.96, 
      248.71210000000022`}, {6.720000000000001, 248.71210000000022`}, {
      6.720000000000001, 249.7752250000002}, {12.96, 249.7752250000002}, {
      12.96, 248.71210000000022`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/SZwh1zra02HrgOnFrpm5Ds8qhJZ5/5QCoO/0nXb
579t+Q6Hv2rE9G+Sg/NnzQSClzIOTvf9e6f35TuAzGQ4IO2gZ8ixZs7UfIdv
QOWHTKUdsq3v+/POyXcA27caYl7tonyH9DQQkHII752eN2klgl8m1HzAayOC
f2mh67biPfkOSwpsua5fhrjv6PF8B4XW14E71kk7zM8Tana4DHXfInmH33+v
VLw8DtXPJg8279T+fIedciANcg53Kl6qbdyO4IPdux7BB+nPXJHvwAjyD4O8
wzOg994tzHeYcAhkgbzDBzVDDh2gf+RByvkUIOqnQcOrUAHi/klQ9e8VHBJT
rO+f74fy1ytC9PdA1TcqOVhwrJGJ6sp3aAPZnqoM58PiB50Pix8ADUfKtg==

       "], CompressedData["
1:eJxNVGlIVFEUHs2spsUQy3LGN/NmfTNWZlk5ydgJqaQIaaMwyxLbQHy3BZOK
FiRbxMpf0YaIUhQhSiEZERZECyURhiJtamSbxDAt0jDVvecefF0Yhu/de+75
7vm+c9RifeWWWJPJtIn/xH93Awua53lgz0DkaqhHh68rbilH+93QEnqxvDiq
Q9++pKYlbR7oWV48cd1fHXLMXQ1sgxduh6OdWbEMTGI998KCt/k1a+MZrOTh
XxZq0GwtKNlvZrCfh/fu0+DyotZwcKKB7QUl2XXJBl7aGo4m2Ri08fAVebTv
YpA5m69+r4zXGIjTSQe94M8Yff1VGoMz939ohaO8MOjhH6YzwPcc8gzjZ0/5
ijNwh8CNbplvGp0vckPsy4pPHzTC6W7oz6852+Sh94RcuO9RGeTx9E1XXLCx
JPtt/hQGjfx4V64LhqKdFTvGMVmfQSdUtT+pHxnHYJIg3OiEKesCN/P+UH3X
O8GR/tpV9V0HG3/urZ8OeF5+ty5lUJfvK3fgfvxHXfL9rsKy6tKBSB/tb1Wh
KHDzUfk7XfJ7bB/GyCfbwLuCgpAN9d3J4+0i30EFLuVWl277QHyqUyX+rMMq
cd89K+rd/Y2waoU1XP62n7qszxUL+qMvQvxzLNBRv6h1dwwDf+Hp+z8+psC4
69aC9yOpfrUpMGc0/8D9sG2rWCmory3BwCJ+dpKBJ1e2P+m1MHl/kzxf5yC9
F1hQz1KN9jss0o8zmPRrrRUulCVWHp5Feh5LhdqzZYm5c0j/AwrsSqxsN2cx
+KVxwg9smD8cIP7NdvRbdD7hIbvk42dQxdMpa+yot4/jsby6wWs2WF3DE3A+
WK+Qgv68yP17/hxfAQX5TlPJH69TMf9Sq4EF/6FJBhZ8KycwiBH9NVOBbm6/
jDGU/6WC+yPiiV+FDf3cyftRQM0q+QdjKP8JA8t+NTDWM0GV/o8hfy9RZT1H
UD2PqMj3ZBzhFlW+L57Od6nYL2WcH/rpiwrbeXuMH0v5pzokvwTyw2YH9seD
ZIp/6EC9wEn9bnHK+qRR/xQ6pZ/S6f2XnLI+mZQv4kR91Cy6b68L72ufT/0Z
dqF/ioI0P05Rf+eQ3xZ7hjHq+dvAGN/glfoGiV+uhn7uCdB7ejXMXz+X5k2h
D+dfJIPib/hkfdNo3pn9eN8LN+Wf60d9Q4qB0a/JBhbz5rSZ5uM7n/SjicEG
oXemT/Y3nyeo73EN7jwqv2sb0MEnDHHci7juDfXvf/P+HzsFkiI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQvVOu9XWghobDrs9/r1RUFTgE7QAK/NR0UIhKsb5f
U+DwqEpknbuklkOG9X1/3ooCB82Y/kNfNbQclrlu+7y3GMG/UfFS7WM+gg8y
b0dmgUM1UPtDLi0HpqsVL5+lFDjIA63bcU7TYYNMVEp1ItS+iZoOcUDr+OMK
HLivLy6wddIEq18WXeDg8RDogPsaDrPzhJodogoc2oDa5Wo1IO6LKHDQAtm3
Qt3hsX/vdD0g38QYCJLV4Hyw/yLkMPg8a4AO8IH676EUBh+mHmz+DhE4PwTk
XkMhsH8NMxHq0fmw8ITZh86HqQeb36AG5y8psOW6Lq0O54P9X68ODu9aIF8U
aHrVGnUH+/v+veJZBQ6FQOWLb0DUb8yC6v8NCY912QUO64HKRcQ0IOGbC7Xf
QAOsvjCvwMGOCxTgGhD/FyD4P4DOfVmE4HttA3qgpMAhPQ0IzDQcTDmAGsqh
5iGlHwA06wcy
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGAwA2IQfWNxgS1XvKoDO2eX/OL/BQ4x/Ye+aixRdfhr+Gzd
U/5Ch1kzgUBQ3UFm+0UGOb5CBwYQMNBw8H/FYjKRs9BhAlB5zH8Nh2mn6z3s
mQod5FtfB+44p+lwb82vmLe/ChzS04DATMvhytWwN+8/IvgVblO+uT1Hk79Z
ADF/habDAXV+btPzBQ4mxkDQreFgZbM3SOx4gcM3DaALc9UdtgZkz/q+r8Ch
DWid3FVVh09RTnYvdhU4PKoSWed+UBnO1wJ5KEMJzl8C9O51a0Ww/5buKXAI
2iHX+tpSwUHoge4EhQMFEPfnyYH5Cw4XOLwJBCmQcTj1b1P1pxMFDtzXgQH2
ShringsFDl4PgRY+l3JYXXlc0+o61D9pUg4LFynv/HMPwQeFX9xzBB/s/o9Q
/4hKQ8IfGF5i69wfVpXIgO1PYCx0CAZZf1EWEv4chQ6Hv4I0yIPDK5+nEBI+
yopg94QB4wfsv2JFh54vt687/itwWA80TmSeAti+7X+g7v8lD46v/z8LIOYr
yjsYpEo+kvhW4DAbFN+ecmD15p8KHOy4gBruyoLjq+0tKp/tBYIPcs/6+wUO
hUDrFy+Qc3jRPO/sqxvQ8BOG2n+5wEEBFL7XFByaZC3SW85B45dbCaL+NDS+
NijD+eDwiVWF88H2TVUDp6/cc9D0EqEOjp+iy9D4lNQA21cOtL9aBBSgGmD7
WO4j+GD/Pkflz3gLSw9Q9Z+h5u9Qd1DrKy2M/l7gAFItYgZJf9t/w9KjGjj+
q4DhjZ6fAKf4fz0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaTAluv6ZmWHhYuUd/6RKHQQXef+sCpFEc6347q+
uCBW3qFJ1iKdRa7Qoe114A45VVkHF+HEw8IahQ6FQO2LA6TB8i0GhQ7paSAg
5ZAyw0f0jBWC/6J53tlXbgj+lathb/JDCh2+a8T0H2qVdlhdeVyzKr7QQQxk
/xFZh7z8D62cGYUOs2YCAaOCg0Gq5KMZBYUO64HSIn2KDkIPdCc8KCl08ABy
17Urw/lBO+RaXyuqwvlnzwBBihrEP0WFDjuB0oEB6g4H1Pm5TfMLHUyMgcBa
w+Heml8xudlQ+z5qQNybWujwBujd1mJNsPzaOGh4fNWEuD8c6h8zLbB7O/0R
fJB/frkh+CD7bSwLHSYc+qoRs1zTgZ2zS15Zr9DhEdD57p0Q+9eqFjocBkr3
Z6k7bA3InmUuW+gACg6Rc6rw+ECPLwB68MG9
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXSOyzv3hJmWHaafrPf5rFjosKbDluu6tCucDZatE
6tQcFi5S3rlHp9Bh1kwg8FR32BqQPcvcqNCh7XXgDjlRDTB/u3mhQzXIvCoN
B3bOLvnFdgj+6srjmr/cEPyeL7evO/oXOpw9AwQiEPXKYYUOhUDrF3uoO8hs
v8gwLxrqnmo1MF8uEcp3VgXz7yVD1S9QhvPT04BATAnOfwN0XutrBQe1vtJC
aaB+BhBQUHCwstkbNA1ovlZM/6GvK+Qc/F+xmAgC7bcDGldwV9bh1L9N1Ub+
CD7M/TA+zH+ewOBZt1wO7n9weMkpwMMHZHvgCwV4+AWBBCSV4OGLHv4AHkKn
sA==
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOq7jcVEvPFjqIrnN/WKWj5uCy5P6+
vnuFDjH9QAUl6g5/DqWsenC70OEwUHl/kYbDPdvKiBfXCh08HlaJrFPXdHgh
Inty6flCh1iQ+juaYPmME4UO6WlAYKYF5mvsR/BB6p9uRvAXGC/asn1pocON
xQW2XMs1wfzyWYUOO+VaXwd2aIDVq04qdNACOShD3UHaI+DPjU6o/muqDlse
vpy6qbXQodCW6/riC8pwPlj/DkU4nwEEJBQcPr0+YPkYqB/s//uyDrkM+Y0u
QPMVQMr7pB2upF19vmoW1Pw0KUh4LEXw9+/oZfuwCcEH+2c/NDzapR2mxfxz
rjpV6MB9HeihU7IOJ/sNy9deKnT4Bgy+Q6wKEPW3Ch2WAL17fbaiQ/l1oU+M
96HuWa4M58uD3HMMwQfb9w2Nb6aCwQfF59ZpUPdMV4XzQdErskwNEt8zCx1m
zQSCRHUw/+u8Qoc2oHVyshoQ+SWFDtUiIB0aYP/7rUbwQfY1bkbwQeljwU6o
/W4akPjZV+hgB4yOgrvq4PDUOgxNX8D01NMadbnmONS+s2pg+VenoP5HSo8A
dYM0hA==
       "], {{9.240000000000002, 281.46985000000024`}, {
       9.240000000000002, 284.85235000000023`}, {8.721250000000001, 
       284.80610000000024`}, {8.331875, 284.6748500000002}, {8.071875, 
       284.4586000000003}, {7.668125, 284.12610000000024`}, {
       7.4662500000000005`, 283.6954750000002}, {7.4662500000000005`, 
       283.16672500000027`}, {7.4662500000000005`, 282.6879750000002}, {
       7.6275, 282.28547500000025`}, {7.950000000000001, 
       281.95922500000023`}, {8.271250000000002, 281.6329750000002}, {
       8.701250000000002, 281.46985000000024`}, {9.240000000000002, 
       281.46985000000024`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6rJp9RKHgR6GDHdf1xQW2chj8
RnvTuF2vCh3S04DgmBQGH6YezFeTQNVfKwbnh4CscxR18ONh0mb/WeiwpMCW
63qxiMO0tzX2pr8KHda5P6wSiRN2kLp57vvl34UO584AQY2Qw5aijIlr/xU6
gNzMcEHQIWmXJ88hpiIHE2MgUBZ0+BP8eOlttiKI+jMCDgJM2u3TeBD8BUcU
NnwSRvD3efIwrZYocigCWr/4g4DD5e/Bj5/KFjmAnBdoIehw99z34MXKRQ4T
Dn3ViLkvApZXVSxy8AA6b912iHu3AtWD3b9YBGx+kRSC/wnonThxBF+/Xeym
n1CRg1ZM/6GvL0QcusVuntvOB3V/sagDm3a72Eyge8Hh9VfUIWfi25p6riKH
R0Dr3BnFIeZzFjkoAJ23o04CzoeFPzof5N6lMkXw+EPnw9TD4h+dD4svAGm8
79I=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6nNm1o/eYbpGDHdf1xQW2chj8
RXGapwUUihzS04DgmBQGH6YezFeTQNVfKwbnh4CscxR1yNf+Nj1Wr8hhSYEt
1/ViEYftPIVruvWLHNa5P6wSiRN2sPlxKEXLsMjh3BkgqBFyuDYx5h+zSZED
yM0MFwQdWm7aVkpYFDmYGAOBsqCDXPF1ISMbqPozAg5GivJf3jgi+Acfi8h6
eiL4DzIY8hn9ihyKgNYv/iDg8EXMI8AmuMgB5LxAC0GHf29fH/gZUeQw4dBX
jZj7ImD5mrAiBw+g89Zth7iXOxjq/sUiYPNP+iP4wnOMF23xQfADlnG5LXUv
ctCK6T/09YWIwxrTs9Z8LlD3F4s6aHhVN793hIbXX1GHvg0PX161L3J4BLTO
nVEcYr5dkYMC0Hk76iTgfFj4o/NB7v0TiIg/dD5MPSz+0fmw+AIA9rjq5Q==

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.640000000000001, 
      294.0577000000003}, {4.440000000000001, 294.0577000000003}, {
      4.440000000000001, 295.12082500000025`}, {5.640000000000001, 
      295.12082500000025`}, {5.640000000000001, 294.0577000000003}}, {{12.96, 
      294.0577000000003}, {6.720000000000001, 294.0577000000003}, {
      6.720000000000001, 295.12082500000025`}, {12.96, 295.12082500000025`}, {
      12.96, 294.0577000000003}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGAwA2IQfWNxgS1XvKrDGtOz1n2nihxi+g991Vii6rAoTvP0
hVtFDrNmAoGgusPBxyKynDeLHBhAwEDD4YuYR0DNlSKHCUDlMf81HGx+HErR
OlvkIN/6OnDHOU2Hlpu2lTeOFjmkpwGBmZZDFdMsjtt7EHy54utCRpvQ5JdA
zV+h6ZAaEqSuMKvIwcQYCLo1HB5kMOQzTipy+KYBdGGuukNU7bptjzqLHNqA
1sldVXWY0d4adbm1yOFRlcg694PKcL4WyEMZSnD+EqB3r1srgv03ob3IIWiH
XOtrSwWH7TyFa7i7oe7PkwPzu/uKHN4EghTIOORrf5t+d3KRA/d1YIC9koa4
Z3aRg9dDoIXPpRwClnG5qS6C+idNysHtfNrV5ysRfFD4eW5C8MHu3wP1j6g0
JPyB4SW2zv1hVYkM2H7vM0UOwSDrL8pCwv9ykcPhryAN8uDwir4ODR9lRbB7
HG9C/Ves6GCkKP9F52SRw3qgcSLzFMD2LToOdf8veXB8vToCNV9R3uHaxJh/
zAeLHGaD4ttTDqxeaW+Rgx0XUMNdWXB8Fe1A5X/ahOCD3DN7VZFDIdD6xQvk
HPo2PHx5dTE0/ISh9s8rclAAhe81BQcNr+rm/JlQ93MrQdRPg8bXBmU4Hxw+
sapwPti+qWrg9BUxE5peItTB8RM7Dxqfkhpg+5KA9leLgAJUA2zf+5UIPti/
m1D5zTtg6QGqfi/U/B3qDmd27eh1O1TkAFItYqbuEA3yzzFYelQDx38qMLzR
8xMA3JZ3hA==
       "], {{5.640000000000001, 302.72410000000025`}, {
       4.440000000000001, 302.72410000000025`}, {4.440000000000001, 
       303.78722500000026`}, {5.640000000000001, 303.78722500000026`}, {
       5.640000000000001, 302.72410000000025`}}, {{12.96, 
       302.72410000000025`}, {6.720000000000001, 302.72410000000025`}, {
       6.720000000000001, 303.78722500000026`}, {12.96, 
       303.78722500000026`}, {12.96, 302.72410000000025`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPeHQV42Y56oOORPf1thHFDuIrnN/WKWj5sCm3S4W
mVnsENMPVFCi7rDPk4dpdVqxw2Gg8v4iDYcFRxQ2bEosdvB4WCWyTl3TYdXs
IwoFUcUOsSD1dzTB8kbBxQ7paUBgpgXmf/JE8EHqN9gh+Em7PHmaDIodbiwu
sOVargnmO6kWO+yUa30d2KEBVv9BpthBC+SgDHWHu+e+By8Wgeq/pupQlgH0
gECxQ6Et1/XFF5ThfLD+HYpwPgMISCg4bCnKmLgWqB/s//uyDvrtYjf5ZIsd
FEDK+6QdpgGDo1QVan6aFCQ8DBD8RnvTuF22CD7YP17Q8GiXdoh4vHS2S2ix
A/d1oIdOyTp0i908Vx5b7PANGHyHWBUg6lOLHZYAvXt9tqKDZdwuzzOZUPcs
V4bz5UHuOYbgg+37hsY3U8Hgg+KzXhHqnumqcD4oekWWqUHiW6XYYdZMIEhU
B/P3axY7tAGtk5PVgMjrFztUi4B0aID9L2mG4IPs87FD8EHpI9sFar+bBiR+
gPFtB4yOgrvq4PD86gtNX8D05MfDpO0eBLXvrBpYfmso1P9I6REA5mYZpQ==

       "], {{9.240000000000002, 306.1442500000002}, {9.240000000000002, 
       309.5267500000002}, {8.721250000000001, 309.48050000000023`}, {
       8.331875, 309.3492500000002}, {8.071875, 309.13300000000027`}, {
       7.668125, 308.8005000000002}, {7.4662500000000005`, 
       308.3698750000002}, {7.4662500000000005`, 307.84112500000026`}, {
       7.4662500000000005`, 307.3623750000002}, {7.6275, 
       306.95987500000024`}, {7.950000000000001, 306.6336250000002}, {
       8.271250000000002, 306.3073750000002}, {8.701250000000002, 
       306.1442500000002}, {9.240000000000002, 306.1442500000002}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ1IGYC4jeBO+RaX2s63Ikv85erL3Z4VCWyzv2hFAY/
Rymnoqqv2KHIluv64gA5OF8MKFu1Rdphat1vq4KpxQ7paSAg5fD7SeLCafMR
/Pmh81e/XYPgg/Tv2lTsMGsmEKyUclBx/JjMs6PYAeQmBgNphxMb9fIe74Gq
3ybtEFGiMn3/QZh+GbB88tFiB5BfGBxkHaSyfD+fO17sMBtkniTEfVanih3A
/pOWd1il4yzz+nSxQw3IO0oKDpc6Lt17cKbYYcKhrxox7QoOzsfubG05W+wA
Mo7BQhHs/mtA/tkzQGCiBOfDwgudz7aHVegK0L1BIK6nEpy/pAAYYNmKcP43
jZj+Q0cVHBoubI40BfI9HgIDOFzBoewn/8vvu4odTIyB4LI8JHx2QvUry0Pc
tx0aHwvlwPaHbSl2UGh9DXSBHDh8dTcWO9gBo6fgrizY/NK1CD5YfiWC/9xM
6kD0omKHQlB8FkDjc06xw43FQAunyzvoSUy90jkdan6cgsNH3n0GMycVO6wH
RrdImSI4/BQmQONPUBnOh4UHOh+WngCT1RbE
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4p1yra8DNTQcWH1beP0FShyCdgAFfmo65Gx+
VbxVqMThUZXIOndJLYfNU1I7HvOWOGjG9B/6qqHl8GGejc4UTgRf5VJ+/HFW
BB9kXv//YodqoPaHXFoOPnr/Fff+KnaQB1q345ymw6/SB3MCvxdD7Juo6bBy
70HxZ5+LHbivLy6wddIEq6/9WOzg8RDogPsaDs+Oz9gt9qHYoQ2oXa5WA+K+
d8UOWiD7Vqg76K0UvsAC5JsYA0GyGpwP9l+EHAY/nHXxJKtHxRD/PZTC4MPU
g83fIQLnh4DcaygE9i/7f4R6dD4sPGH2ofNh6sHmN6jB+UsKbLmuS6vD+WD/
16uDwzsEyBcFml61Rt2hy+La0bdAfiFQ+eIbEPXtDCUQ/b8h4dHCWOKwHqhc
REwDEr5MUPsNNMDq3VlKHOy4QAGuAfE/G4LvFB69cT8Hgj+Fv8psNVeJQ3oa
EJhpODQkGoUa8ELNQ0o/AF0h+K8=
      "]]}, 
    {RGBColor[1., 0., 0.], Thickness[0.002976190476190476], Opacity[1.], 
     CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}}}, {{{74.4, 430.94834}, {163.0154, 250.13799999999998`}, {236.8615, 
      177.0426}, {310.7077, 136.00640000000004`}, {384.5538, 
      109.94839999999999`}, {458.4, 91.97790000000003}}},
      CurveClosed->{0}]}},
   AspectRatio->Automatic,
   ImageSize->{504., 504.},
   PlotRange->{{0., 504.}, {0., 504.}}], "}"}]], "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],

Cell[BoxData[
 RowBox[{"{", 
  GraphicsBox[
   {Thickness[0.001984126984126984], 
    {FaceForm[{RGBColor[1., 1., 1.], Opacity[0.]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., -35784.}, {
      36288., -35784.}, {36288., 504.}, {0., 504.}}}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 84.5}, {77.1, 89.89999999999998}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{71.7, 89.89999999999998}, {77.1, 84.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{160.3154, 263.41859999999997`}, {
      165.7154, 268.81859999999995`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{160.3154, 268.81859999999995`}, {
      165.7154, 263.41859999999997`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{234.1615, 329.7086}, {239.5615, 
      335.10859999999997`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{234.1615, 335.10859999999997`}, {
      239.5615, 329.7086}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{308.0077, 372.5075}, {313.4077, 
      377.9075}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{308.0077, 377.9075}, {313.4077, 
      372.5075}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{381.85380000000004`, 404.0435}, {
      387.2538, 409.4435}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{381.85380000000004`, 409.4435}, {
      387.2538, 404.0435}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 428.5}, {461.1, 433.9}}},
      CurveClosed->{0}]}, 
    {Thickness[0.002976190476190476], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{455.7, 433.9}, {461.1, 428.5}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{74.4, 73.44}, {428.8615, 73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{74.4, 73.44}, {74.4, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{133.4769, 73.44}, {133.4769, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{192.5538, 73.44}, {192.5538, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{251.6308, 73.44}, {251.6308, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{310.7077, 73.44}, {310.7077, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{369.7846, 73.44}, {369.7846, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{428.8615, 73.44}, {428.8615, 
      66.24000000000001}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
      0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlU2FIU1EUXkbRRlDiCEt8FCG9P2JoiKuNDk569703wncflDEhG0zKEPdH
yhVUsiCylCKi/QlpBVJsREQbVJT7Y+FIw5hQSdukGEoQ4UMKcd3euesRHrg/
Pu655/vOd87dFeijwfU2m20dOwfYqWBnS7bkyhzS4WQ3izYCZfzGEDtH0hL8
aHcWqz5pa3AuFvI45iU4HUw3GHMavq8gcGJYeJWc1+CsxzEb20nAl8vOub9r
8FjKh52UwPtJ8bZ/RYPpDItBgvUqKeInBF7W5p/m6ijsZWxGgUC/u3u00UuR
f4cM2+Oxh/ZTFEajLI7JcHUhfikeozDG5Mw+l+H3nlSHNkmhndEl7Arq+0Lh
yqKWErwKfL6X2Rhd4vXOK3BrXPu5sFrmt7BZ76uFgbUTqlHhSDJ8OGxQ7I+o
WK/A73tV9G+KwlYGPTdV2B2RaqQkz7+vov6ohSeWInXCgIU3lPxvh49zvTdU
9MtH0b8eFe7eMQKii6L/Xp7fQOGiMyHlN1vY9GdCgXr/4lCkqMEmNmtbVvk3
D9Mfjwqt9qbe0iqf1zWuv5bXS/P+3BSKLF36xfODFKoTfwX5EEctPNYXnQm+
s7A5z2UKLU0sllW4UOWoDG3Tke8Fr7dPx/4GuV9tOvrpsrB4mRlSUP7HzxTU
e5DnDynwbSB0Jtuso/4uBfnrdXgtsAfNCvIJPJ/th7lfDh3n9VFG/QbX+0jG
+xm+Lz0y+sH2zaxXLSPfOQpdbF3FDwT3L0ChI8USHhCc91E+j+sEWhpHVsZV
7mc/Qb5W7ncnwX3dT9f8xzL+A4GLpIE=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 
       2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{133.98, 47.52000000000004}, {133.98, 
       49.56000000000006}, {130.26, 49.56000000000006}, {130.26, 
       50.52750000000003}, {134.173125, 56.10937500000006}, {135.03375, 
       56.10937500000006}, {135.03375, 50.52750000000003}, {
       136.20187499999997`, 50.52750000000003}, {136.20187499999997`, 
       49.56000000000006}, {135.03375, 49.56000000000006}, {135.03375, 
       47.52000000000004}, {133.98, 47.52000000000004}}, {{133.98, 
       50.52750000000003}, {133.98, 54.41062500000004}, {131.295, 
       50.52750000000003}, {133.98, 50.52750000000003}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCwAGIQrVHXs/N1aoYDBwMIeDsE3JKuSXRB8NWB8tmOGQ4X
zgCBgbfDF6/INgvbDIcHiwtsuUK9HbY7ND06bp7hoNH6OnBHjrcD588F6Zv1
MhwqbLmuL57k7XBQXC24VTnDYcFMIFjq7fBgjuBSWzEEf8buaRP6uRF82eUv
PPSYMhwCHlaJrJvp7ZAfz35O8le6wwqgddcbvR1aeP3XT3mf7mAQ03/oa5K3
w+l3Jw87PU93iNgh1/ra1NvBjbmCW+VhOsQ9v7zA5vPfToeYt98L7B7WG+kQ
+7IRfIl17g+r/nlC+A/SHTYAuSIGXg6pHcmxd16mOzSIABWEeDmszbxX2PUV
ys/xgoQHYwaE3+LlIHzB5UYBL5Q/wQscHsZSCD44PAzQ+M5Q/+ZD1QdnOLwA
ct11vRzA8ZMEVf/KExLeWRkOHUDvyU1F8MHxpYPgg/3/zAMcXiLpGQ4ZaUCw
zAMcvuviofGX7QFW7x4BtV/fwyF64/43cn4ZDgnA4NVg8oC4Bxj/4PB55A5R
b5IBCf9D7uD4mama4WBhDASb3R2MQg20NEURfLD+n+lwvo3OlVlpj6Dhfccd
HH+HLqRD3AOzf3+6ww8NoAWNHg6LJlkx+m5Lh/iPyxPOB8sfR/DB8T8bEj9c
B9IdBK4DDTSDpr/L0PQwDZrenqQ7nPgKNOCVt8O1o7kmDb+h7hHxcag0W20X
LpEB54PjXxfBf1W8VbTaHhrefyDp3dgXGp6nvR3+K/799jUqA5J+ZkHlkzMc
CkDhH+btgJ7fAOtEegY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQHb1x/xu5u+kODxYX2HJpezrA+BLr3B9W/fFwmLF7
2oT+++kOK4DS1897OAhfcLlR8CTdoeN14A65pR4OfU8+yQe9THc48VUjpr/K
w8GNuYJb5UO6wwagdpEoDwcbnSuznv1IdwgActc5ezhw/lyQvpkxw+EFkOuu
CzHvA1cGRL2SB9j+eSII/oM5gkv3KiH4Abekax7qZUDst/RwWJt5r5DLMsPB
whgI0iHmGztnODhwXV9cMNXDYbtD0yN3jwwHASDX9gqCv2AmECh7wvk/gM4/
lO/pcPrdycNOzlD+ak+HL16RbRaWUPXXPR1kl7/w0NOH8pm9wPZ3KUH5kl4O
iyZZMfoKI/hg/SwIvnpdz87s7+lw/eDweZMONx/kv8RH6XD7YfEBdn8Rgg+L
LwCchcup
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGAwBGIQ7bQ2816hb76DRuvrwB1iXg7PZJe/8LDPd7AwBgJt
L4f67Q5Nj0zyHSTWuT+s8vBy4K8yW22nl+9w4qtGTH+el8M8G50rs9TzHS6c
AYIpUP0qUPlDCP6KAluu698R/IT+Q181PLwdsjl/LkjXzncIeFglsq7b26H0
wRzBpZb5DgVpQHDI2yE8euP+N+75Dh1A58n9hKh/HgV1j4iPw+ZXxVunFiH4
IPcmdSH4d9yYK7rnQvk/vB2Oz9g9TWANlH/AG6J/F5Tf4e2wQviCy42D+Q4H
5IAB4oLgcwDDiuGLF5xfAfTO4gNeDh++eEW27YPKA/3fAAqv7fkOG0DW50HD
ayPUPGD4gewTXY4IX7D/ZyLCf+9BcbXgVVDzGbwcfFp4/fW3Q9Xf9XSQDLwl
/Wd/vkMGKHzWeILVXz6R7/ADFNzVnhD7zuY7LJgJBI4IfsQOoAP+esD5YPMX
eDjo/Vf8++0IND6CPCDu2QINDyEPiH8X5zsYAI3/eskdHJ7cfVD3bHZ3YF08
yYqxGI0fgeBbXDuaa+IEjb/L7pD0Ygg1D2g+2DxFKB9o/6/T704eloC6bxGC
Dw5fJk84H2y+J8T/wbLQ9Nfi6QBOz2pQ/hZPiH36UP4TKN8m38EBaHwBq5cD
evoHADIYVqs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/Ux2+YsTbvkOFbZc1xf/8XKA8Q/Itb4OPOHlkM35
c8Fzr3yHD4E75FrnejmUPpgjqBqc7yBwfXGBbY2XQ3j0xv050fkOBjH9h75G
QeXToPq9vBwu5sez+xUj+GD5BgQ/0SjUYFVXvsOFM0AA1D8ltSP57qR8hx8a
QAOrvRyOz9g9TWB2voMGUPmOORD1WvPzHR4Arec6iuCD5b8g+GD/qHmD3fdm
Vr7Dia9AAwO8HZzWZt4rBJovsc79YVWRtwPr4klWjF1Q+SkQfmN9vsOCmUCw
FKL+YxGC/+v0u5POaQi+skZdz06Y/4H69x4UVwsGhk/AwyqRdcXeDnr/Ff9+
A4ZfRhoQBHnDwxfsXi0EHxb+AHReuFU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQzbp4klWjdb7DiyqRde6Mng4w/oPFBbZctz0cfp1+
d/Kwbb7DBveHVSLbPByeyS5/4eGU75CRBgSTPBxWCF9wueGW76DR+jpwR56H
w+ZXxVun+kL1B3tAzAvLd5hx6KtGjL2Hg95/xb9l8fkOK4DS17Uh6kUzoeYr
eThMSe1Iji1G8LM5fy5Ib0bwSx/MEVw6Id+hAqh9sRlU/+x8hx8aMf2H4j0c
PnzximxbCrW/08OBv8ps9b5V+Q4OQOUFexF8A6Dyr38QfLD/bT0h9gP1nwA6
t7/I02Gejc6VWbPyHS6cAYI5ng4N2x2aHvVDzT/u6eC0NvNeYVO+QwLQOI07
npDwKULwJQNvSdckIfhg/4RC7QPqv+PGXMHtne/wIXCHXOtcTwefFl7/9Q75
DhFA7utiRHyAw8sewYfFFwB3p8iw
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
       308.44764999999995`, 47.52000000000004}, {307.3939, 
       47.52000000000004}, {307.3939, 54.240000000000066`}, {
       307.14014999999995`, 53.99875000000003}, {306.80702499999995`, 
       53.756875000000036`}, {306.394525, 53.51437500000003}, {
       305.98202499999996`, 53.27187500000002}, {305.61202499999996`, 
       53.09000000000003}, {305.284525, 52.96875000000006}, {305.284525, 
       53.98875000000004}, {305.87452499999995`, 54.266250000000014`}, {
       306.39014999999995`, 54.601875000000064`}, {306.8314, 
       54.99562500000002}, {307.27264999999994`, 55.39062500000006}, {
       307.58514999999994`, 55.773750000000064`}, {307.7689, 
       56.14500000000004}, {308.44764999999995`, 56.14500000000004}, {
       308.44764999999995`, 47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQnRx7x425uNhhxqGvGjGPPR1g/BdVIuvcU70cVtmF
R28sKXZYUWDLdf2sl4MVo28Lb0Wxw4PFQAFZb4eTh53WZlYXOwhcBwrkQPkN
UP0rvSHq24sdEvqBFlzxhpjXC9X/39vB5caHL1zTih0k1rk/rBLxcWA/Jxko
tQDBB8l3LUfw9bVWCgusK3Y4AXRuP4cP2L6Vm4sdNFpfB+744A12v/NOqPk3
vR3uFXb1Pdlb7NAAdM7DbRD39B6EurfL22HaBP4qs6PFDgtmAkGst4NqMOti
oRPFDhbGQKDu7fDCQ++/4imoec+9IOrPQM1b5uWQa9Kw3eFsscMBOaADAhB8
WHjC+GD3Jnk6SNckGk09DeX/8nAo51bRsDsBVb/aw2H/m3k2b45AzYvxAIfX
x/1Q98h7gN3vC/QfBzDuGL64Q/y/qdjhwhkgOOEO8f8qqPrN7vDwhPH91k9J
PTEJwQeFZ0BHsUMHMPjkbrpD4gcYfwYxwAhT8QCHx6RyaPg3eKCmD1FEeoH5
FwDrGf7q
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQzX5OMjCqpdhhxqGvGjGPPR1gfAtjIND3dIhos7jG
2l7s8KJKZJ37dg+HP99KH8T0FDssmAkE1R4OC9I3v9o8sdghYodc62t7Dwe/
9VNSPWYUO2xwf1glouQBNk9qAYI/bQJ/1bflCL6+1krhCeuKHTiAbmFw8HC4
POuZ7PPNxQ4rCmy5rgPNL+dW0bDbCeUD7T952Gnty93FDgFA7euA7oPxYe6H
8RP6gQIzvOD6Ba4vLrAV8IabD3a/tzfcfoMYoIY2qDzQfRVA6xYv8XbY/2ae
zZv5CD7YPzMQfMGlew9eB/pfYh3QQ13eDvcKu/pUeqH2h3lDwgMWfsLe8PAF
u3+6lwN6+AMAiQCyVQ==
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1,
        0}}}, {{{367.52455000000003`, 47.52000000000004}, {
       366.47080000000005`, 47.52000000000004}, {366.47080000000005`, 
       54.240000000000066`}, {366.21705000000003`, 53.99875000000003}, {
       365.88392500000003`, 53.756875000000036`}, {365.47142500000007`, 
       53.51437500000003}, {365.05892500000004`, 53.27187500000002}, {
       364.68892500000004`, 53.09000000000003}, {364.36142500000005`, 
       52.96875000000006}, {364.36142500000005`, 53.98875000000004}, {
       364.95142500000003`, 54.266250000000014`}, {365.46705000000003`, 
       54.601875000000064`}, {365.90830000000005`, 54.99562500000002}, {
       366.34955, 55.39062500000006}, {366.66205, 55.773750000000064`}, {
       366.84580000000005`, 56.14500000000004}, {367.52455000000003`, 
       56.14500000000004}, {367.52455000000003`, 
       47.52000000000004}}, CompressedData["
1:eJxTTMoPSmViYGCwBmIQHSm+/aJDbblDRhoQuHg4wPgnvmrE9B9ydxAys9kb
pITJf7C4wJbrsbuDwW51fm5lqH4mD4e8o/82VauUO1TYcl1frODh8PLmml93
1ModNrg/rBIJ8nA4FXJwxRKtcocLZ4CgyQNs3iV9KH+Th4NrZv4HVtNyBwOg
bV8feTh83hCQHWUDtV/K00GG94HuBddyhwUzgSDS06FiziLlypByhxVA51zf
7elwRTtVMimu3CEAaN06Ti+w+7qTyx06XgfukHP2cuj1esWyJQNqXo2Xg/Wk
0/Ue2TD7EXyweU8RfAegdwqkvR1Wn78a9iYD6j8Pb7B5JilQ+VxvcPg1xJc7
CAC5tpO8He4zcXbFR0LVL/GGuD8QweeIn+Fz1RPBn67YV1roDHXvRG9IeNlB
wy/L2+Fv+5fb1y2h4e8MVW9e7tAgss79IQ+CDw6f414OC38YPlunWu7AAYxr
hmte8PgAh4+tt4Pak+Z5vtpQ+3sg7mcwhpp3COK/LVblDi+Ayt1/QtTzAsNf
Yh3IQT4QfhCCf6BW1kI9HsEHxWdrZrmDhTEQfPd22Las8rhmIdS+PRDzzlZA
/dcECa/5NdDwtETwNVqBAfLIC5W/zQsS3tVQ9d1eDv4OwonOlVD3J3hB0lN5
ucMBOaAGMy+If4uh6oHpA5S+pPKg8XXLE+z+5xlQ9672hKS/BGh6yfIEh0dJ
CNQ8CU+wfc1e5Q4JwOSqccUDnP6UXModInYAFSz1AMd3gCM0Pno9HFLeRTnV
2UHDs9QDEl42UPfGeIDTq7cVZn6E8QHiuZNG
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 
       1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
       426.60145, 47.52000000000004}, {425.5477, 47.52000000000004}, {
       425.5477, 54.240000000000066`}, {425.29395, 53.99875000000003}, {
       424.960825, 53.756875000000036`}, {424.54832500000003`, 
       53.51437500000003}, {424.135825, 53.27187500000002}, {423.765825, 
       53.09000000000003}, {423.438325, 52.96875000000006}, {423.438325, 
       53.98875000000004}, {424.028325, 54.266250000000014`}, {424.54395, 
       54.601875000000064`}, {424.9852, 54.99562500000002}, {425.42645, 
       55.39062500000006}, {425.73895, 55.773750000000064`}, {425.9227, 
       56.14500000000004}, {426.60145, 56.14500000000004}, {426.60145, 
       47.52000000000004}}, {{432.7021, 47.52000000000004}, {432.7021, 
       49.56000000000006}, {428.9821, 49.56000000000006}, {428.9821, 
       50.52750000000003}, {432.895225, 56.10937500000006}, {433.75585, 
       56.10937500000006}, {433.75585, 50.52750000000003}, {434.923975, 
       50.52750000000003}, {434.923975, 49.56000000000006}, {433.75585, 
       49.56000000000006}, {433.75585, 47.52000000000004}, {432.7021, 
       47.52000000000004}}, {{432.7021, 50.52750000000003}, {432.7021, 
       54.41062500000004}, {430.01709999999997`, 50.52750000000003}, {
       432.7021, 50.52750000000003}}}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 111.3347}, {59.04, 
      433.13077999999996`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 111.3347}, {51.839999999999996`, 
      111.3347}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 175.69390000000004`}, {
      51.839999999999996`, 175.69390000000004`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 240.05310000000003`}, {
      51.839999999999996`, 240.05310000000003`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 304.41229999999996`}, {
      51.839999999999996`, 304.41229999999996`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 368.7716}, {51.839999999999996`, 
      368.7716}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}}}, {{{59.04, 433.13077999999996`}, {
      51.839999999999996`, 433.13077999999996`}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001488095238095238], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHkMdLZx/hiHQ4/FUjpt8OwWcEqmG4
5uhQkDHxbQ1/pMO5M0DQ5uiwoQgoIBPpMGsmEJg7OrypsTeN04Lq/+UA4dtF
Ong8rBJZd94Boj4Cqn+JA8S84kiHCYdAGhwcbpz7Hvx4CoL/BGi9wl40+VuR
Do+AxrnPdnBoEbt57vuXSIe214E75DZD7eOOgph/ygHifsUoB62Y/kNf3zg4
OJjG7fI0iYK4VxLqfqcoB+7riwts3RwdFEACgVEOhbZc1xfXODrE7PLkYYqF
mrfH0QHkXPtUqHl/oOpzoxzeAK1vDXZyAFm/qzDKARaeMD7YvY7OqPyVzg4m
QOfwZEPV/3B2WAL07oZYqHnuLg5HQBYEQN3T4gIJL5soh6UFQIH1LhD3A/13
A+h8rtsuEP+zQ9V/cIH4/2kknA8LTxifQbtd7GZ7pIN8KzAAT7lAwjM20qEG
6LyHdVD77KHhr+wCCQ9paPz2OcPTB3r6AQD3kxEs
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHJ0tnH1Hwi3QotOW6vrjEGc4//FUj
pv+Ns4NGu9jNcxGRDtzXFxfYarg47PDkYdLOi3QI3iHX+jrZxcEDyG1vjnT4
BlR+qNHFgUEbqGEugg82by+Cr7ChKGPinUiHpQVAC4H6W4DGf/8W6cAIdBMD
0HwRIDeYJwrCB9q/BKh9g2KUQ2z/oa8aQPe9qbE3jdOJcoC5H8b3eFglso4b
wZ81EwgmO8L1g90f4Qg3v0YEaICMI9x+E2Mg+O8Akb+D4B8BOXgPgg/2D9B/
E4DOiZF0dAB5X6wlEmK/r6ODg2ncLs9CaPhNcISER2QkxP08iPBGD38A9C6o
hg==
       "], {{41.760000000000005`, 107.41139999999996`}, {
       40.558125000000004`, 107.41139999999996`}, {40.558125000000004`, 
       108.61327499999999`}, {41.760000000000005`, 108.61327499999999`}, {
       41.760000000000005`, 107.41139999999996`}}, CompressedData["
1:eJxTTMoPSmViYGAwBWIQbcd1fXHBXmcHjge6ExZ0RDuA+RudHW6s+RWTez7a
4fBXjZj+b84OO9T5ubdegfK1XBzeRDnZvXgAVe/r4lDgNuUb25doh51yra8D
C1wcvhg+W6fKHuPwDaj8UKOLw5LK45pWcgh+jaxFuoslgj/hdL3H/sgYBxNj
IMiEqi+NcVjv/rBKxMIFYn93jIMWUPlXNheHM1fD3ugvguo/CnXv2hgH0XVA
DSUI/oRDQAero8m/coL4F6h/aYEt1/W9ThD390Ltn+gEUV8e41AjAtLg5KDQ
V1ooHY3ge7xiMRG0QPADDq5Y4qcU43DuDBC0ODk8aJ53dhVfjEMh0PjFM5wg
4fE3GmL/GieIf15HO8QCvaNxzMlhxiLlnX/uRjt4AL277imUfznaoe114A65
q1D3Tol2UAAG7455Dg4p+R9aT55E8Fu+3L7eeDvGYQnIP/KOGHyw+v/RDvIg
9R5OkPB/FA1xn5QTJLyZYxxmzQQCZicHG+HEw5dVEXywf73Q+FXQ+FBxcoiZ
4SPaAwxPsPvTnSD2H45x4AYmD9tVUPkn0PD+D9X/FRofGc5wPjg8ziD44PSk
5OJgYrM3aNozqH1ZLpDwOAlNH0dcHDRSJR9FLIOG9wdo+ilD8GHpDYXPDuVf
cYHE9z1oeMyBpsd90PhKgabn+dEQ+6RcIOmhF5r+kfIPAMm3eZw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkcHF73/in8nxznA+DOeyS5/ERDncGMx
UKAYKu8V53D2DBD4OTo8OD5j9zSnOIe214E75MwdHVI2vyreah7nYGIMBIKO
DhwqGnU9qnEO3NeBBvxzcKhINAo14Efwt2Rz/lzwJRbO11gpfMHlfqxDbP+h
rxpcjg4GDdsdms7EOjAC3cig5Ohw5cMXr8g9sQ41IuvcHzo4OvzxaeH1Xx7r
ELxDrvV1rqNDD3+V2eppsRD3rHR0aLG4djS3C2reE0eI+XVQ+yycIO6piHWY
AJSOWYrgf9OI6T9UDOV3xDpoAblf/ZwcDjitzbw3G8o3c3IIYF08yWozlC/n
BAmPU1C+kJODzKX8ePbHCD44PP4g+GDzNeMg7jOB8v3jHA4DndNfBlWfFwdR
v8MJEv69cQ7yrUAP8jlDwntunMNSUHyVI/hg/+9F8O2AsVnw1xkSXtPiHM6B
4s/CBRK+7VD7S1wg6iviHDweVomsW+jisGZKakdyShwkfA66QNwDjH9w+D+A
qjeIcygEJZcPLpD4EUbwI+64MVd8ioXzwfp3QcP7uItDTlffk089sRD3AO0H
x19mrMN6d6ADlKD2u8VC/DfT2cEmPHrjfhOo/B0nOB8c/+wI/qyZQABMD+D4
8YCmB15HSPjmxzo8AnrPfSc0vU2EuqffwWHB3oPiavsR/BfzbHSu/EDwwfGv
DM0fyx0czkgG3pJ2h4bnDQeI/5LiIOmH09HhS+mDOYJ10PD3heaHPkT+guU3
AOrtiQ8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O6yZktqR3BTrMOHQV42Y5Qg+I1ANwxVn
B42Vwhdc2mMd5FtfB+745+wgcyk/nn1irMOjKpF17pouDgK/T787OSvW4ZtG
TP8hTxeHFotrR3NXxDrE9gMNTHBxyOnqe/JpZ6zDYaDx/WUuDhwqGnU9p6Hq
G10g5t1D8MH2f0Twt2Rz/lzAGwexP8vFYcYz2eUvVOMcCm25ri+2cXEIYF08
ycoqziE9DQj4oOb7xTnMmgkE550dUja/Kt4aEefAfX1xgW0Dgr/e/WGViAka
/4eTQw9/ldlqP6j6M04OD47P2D3NCspf4ORg0LDdoUkNyu9ygtjPi+DbhEdv
3P8uFs4H678QC9fvovdf8e+2WLj54PBZGAu3H+y/nliI+w0R8YEeXwA628yJ

       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHCx2X7j3oT3E4/FUjpt8OwWcEqmG4
5ugQ532C3XZyisO5M0DQ5uhQd2Fz5NeZKQ6zZgKBuaPDnND5q9cugOr/5QDh
r0px8HhYJbLuvANE/Xao/iUOEPOOpjhMOATS4OAwqe631YerCL5Elu9nvldo
8j9SHB4BjXOf7eCQoZRT8Ys11aHtdeAOuc0Q+3QFUyHmn3IAuz9BJtVBK6b/
0Nc3Dg7HNurlLVZNhbhXEup+nVQH7uuLC2zdHB3M3lu4upukOhTacl1fXOPo
EFKiMv2/JdS8PY4Ot+LL/OXsoOb9gap3SnV4A7S+NdjJ4YmZ1IFol1QHWHjC
+GD3Ojqj8lc6Ax10ZyuLI1T9D2eHH08SF4ZZQc1zd3HoWB5+apMx1D0tLuDw
2quZ6rC0ACiw3gXs/lKg/24Anc912wXif36o+g8uEP//S4HzYeEJ4y/TcZbJ
Pp/iIN8KDMBTLuDwrNqV4lADdN7DOoh9tquh4a/sAgmPGdD47XOGpw/09AMA
qC4Xbw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHiSzfz32bUhwKbbmuLy5xhvMPf9WI
6X/j7LDrVtffp9tTHLivLy6w1XBxYNrDKjTlUIpD8A651tfJLg5ecxvUnM6m
OHwDKj/U6OKwTMdZJvsWgg8yj+8Vgm/23sL1+M8Uh6UFQAuB+jOUcip+saU6
MALdxAA0fwPz854VglA+0P4fTxIXhsmkOsT2H/qqAXTfnND5q9cqpjrA3A/j
ezysElnHjeDPmgkEkx3h+sHuj3CEm18jAjRAxhFuv4kxEPx3gMgD3QfjdywP
P7XpJYIP9g/QfxOAzomRdHTQkZh6pRPof7D9vo4Oxzbq5SkfgYbfBEdIeOxI
gbifBxHe6OEPAG9ZrGk=
       "], {{41.760000000000005`, 171.7706}, {
       40.558125000000004`, 171.7706}, {40.558125000000004`, 
       172.97247500000003`}, {41.760000000000005`, 172.97247500000003`}, {
       41.760000000000005`, 171.7706}}, CompressedData["
1:eJxTTMoPSmViYGAwBWIQbcd1fXHBXmcHrXaxm+fOpzqA+RudHSa9rbE3/Zzq
cPirRkz/N2cHJm2ggq9QvpaLw5wjChs+/Yaq93VxiNvlydPEmuawU671dWCB
i4PChqIMQf40h29A5YcaXRx+BD9eOlsKwX+ydPYRBQ0E/x3QujiLNAcTYyDI
hKiXdktzWO/+sErEwgVsf2RgmoMWUPlXNhcHHqDAtBio/qNQ9yalOYiuA2oo
QfAnHAI6WB1N/pUTxL9A/UsLbLmu73UCu58pCGr/RCeIevc0hxoRkAYnBzOQ
AksE3wvkAHUE/9x3oINl0hzOnQGCFicHoOnfLwulORQCjV88wwkSHlxQ+9c4
QfzDmOYQC/SOxjEnh6KMiW9rfqU6eAC9u+4plA8M77bXgTvkrkLdezXVQQEY
vDvmOTjcAFqY/AHBBym3r0xzWALyj7wjBh+snjvNQR6k3sMJHP4L/qRC3Cfl
BAlv3jSHWTOBgNnJ4QjIwXIIPti/Bmh8D2h8qDg5hACj9wgwPMHuT3eC2J+b
5sANTB62q6DytdDw/g/Rz94GDY8MZzgfHB5nEHxwelJycXAwjdt1sg5qX5YL
ODz8CqDp44iLAyj6VsdBw/sDNL25Ifiw9IbC54fyr7iA43vrL2h4zIGkx3uv
UiHuS4Gm59upEPukXCDp4RI0/SPlHwC01m4P
       "], CompressedData["
1:eJxTTMoPSmViYGAwBGIQ3fY6cIdcr5MDj4pGXc+tNIdCW67riyucHNZNSe1I
PpPmMOHQV42YaCcHD73/in8Ppjk8qhJZ527q5HDjwxevyN1pDjcWF9hy8Ts5
ZGx+Vbx1C1T+oSNE/8Y0B0agHQxrEHyPh0AF0Qh+bD/QAglHB5OG7Q5NO9Ic
7IDWFzx0cLALj964/1iag0Ir0IGrHBwULuXHs1+FuqffAaye6QWCX5NoFLrh
P4IPcm+teDqEv9rBYcneg+LLtKD8xw4OE/irzLQtoXxpR4h+93SHN8DgaI13
dCjq6nvyyS/dYQnQe9fXI/gmxkDwGE0e6P9d2Zw/F3inO3wD2n7IFBpeLlDz
oqHhZZcOD1+QfQYm6Q6w8Af7Xw1q/mInhzaLa0dzzaHqjzk5iP0+/c4TaB44
fL47OTw6PmO3mG+6w3p3YIBqOIPVvw1Nd+AGStsmOUPsi0p3CAZa/3opgg82
n9kFzgfHR6CLw7fSB3MEg6DhMdEF4h7HdIcaUHRecIH41wDqng8u4PBUk0bw
z0kG3pJmQOM/TXOQB8UfUD+Dbwuv//k0iHkTXCDpZR+UHwA1b10axH2MLg5H
nNZm3lua5rAUFL4LneF8sPlRCD44/clD/J+7Csp/D03Pm6H8/dD0uSfNIT0N
COZB+SfTHNDTPwDP91uM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQbWIMBMsdHdZNSe14fDnN4U3gDrnW2wj+TrnW14Fs
Tg4mDdsdmG6kOcyaCQTqTg524dEb7R+kOdSIrHN/6OHkoHApP779BVR/JFT+
M4I/65ns8gyGdFR53nSHG4sLbLk8nRy0VgpfOCKe7rDe/WGViIaTQ8wdN+Yf
8ukOba+BGtidHCbwV5lpa6Q7nD0DBPccwepddKDy6xF8sH9qEfxHVUAHBjuC
3ccO1D/h0FeNGENHBx4Vjboeeag8v6PDOcnAW9JA+7mvAx30zwHMn82D4IPU
8zAg+Eec1mbGfYb6n8/R4c08G50rQP/H9gMtMHB0aLO4djQXGD52XEANgY4O
30ofzBEEhh/YvZWI8EUPfwCGdalA
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQffirRkz/ImeHc5KBt2afSHM4dwYITiD434DSh946
OxxxWpt571Sagx3X9cUFgi4O66akdiSfT3Noex24Q87UxaGoq+/Jp8tQ/QEu
DjWJRqEbbqU5iK5zf1iV4gIx73GaAyPQToYKF4dvpQ/mTHwDNb8Rot7gG4If
c8eNuYIhHc43adju0CSQ7mBiDAS5Lg524dEb98umO6wHGi/iAtWvkQ6xX8rF
YVc2588FRukO6WlA8MzZ4caHL143zdMdakSADlqG4IP9n4bgP6oCKjB0htgP
1H9jcYEtF7uzQ8bmV8Vb1aHm33Fy8ND7r/hXJt3BA2j9uuNODjwqGnU9/Ag+
OHz+p8H5j47P2D3tfRrEPqB+sH8epTnslGt9Hcjm7LBk70FxtRtpDsE7gAL6
zg5iv0+/O3kWGl4piPhAjy8ADDXQvA==
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHT/KX8uNn5zgc/qoR02+H4DMC1TBc
c3RoeHR8xu55OQ7nzgBBm6PDgvTNr4qX5jjMmgkE5o4O+97Ms9FZA9X/ywHC
35bj4PGwSmTdeQeI+sNQ/UscIOZdyHGYcAikwcFhi+jv03kPEXwrRt+W3q9o
8iy5Do+AxrnPdnDo2pnNWSmY69D2OnCH3GaIfWtkciHmn3IAu/++eq6DVkz/
oa9vHBxeeOj9VzTMhbhXEup+i1wH7uuLC2zdHB0i2iyuHbXPdSi05bq+uMbR
oYxbRaPOFWreHkeHP99KH8zxhJr3B6reN9fhDdD61mAnB7ZzkoG3/HMdYOEJ
44Pd6+iMyl/p7JAUe8et2Qeq/oezg1RNotFVV6h57i4Oq+zCow1h7mlxAYeX
tWmuw9ICoMB6F7D7PwP9dwPofK7bLhD/S0HVf3CB+J8TwYeFJ4x/4rDT2pe3
chzkW4EBeMoFHJ4/j+Y41ACd97AOYt/ubdDwV3aBhMcSaPz2OcPTB3r6AQBd
WBk0
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHK0bfFt59OQ6FtlzXF5c4w/mHv2rE
9L9xdrhT2NWXcjjHgfv64gJbDRcHlWDWxULnchyCd8i1vk52ccgxadh+4EaO
wzeg8kONLg4nDjutffkUwQeZ1/sVwY9os7jmyprrsLQAaCFQf9fObM5KoVwH
RqCbGIDmX5r1TFZdFsoH2i9Vk2h0VT3XIbb/0FcNoPv2vZlno6Ob6wBzP4zv
8bBKZB03gj9rJhBMdoTrB7s/whFufo0I0AAZR7j9JsZA8N8BIs+K4K+yC482
BLofxgf7B+i/CUDnxEg6Ovitn5LKcTMHYr+vo8MLD73/C89Dw2+CIyQ8gOEH
dj8PIrzRwx8AA5Wk6Q==
       "], {{41.760000000000005`, 236.12979999999993`}, {
       40.558125000000004`, 236.12979999999993`}, {40.558125000000004`, 
       237.33167499999996`}, {41.760000000000005`, 237.33167499999996`}, {
       41.760000000000005`, 236.12979999999993`}}, CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkeHZ9vXM6d35znA+AIi9sfuZOY53FgM
FCiGyD9Py3M4ewYI/BwdtrTUXNiclOfQ9jpwh5y5o0NZ1VId59g8BxNjIBB0
dDhhdGSjXkieA/d1oAH/HBwaAj3nMngi+POumbzfYY3gR3zdeYvLMM8htv/Q
Vw0uR4c7D7gnr1TPc2AEupFBydFBb6aWxFT5PIcakXXuDx0cHZzci37yi+Y5
BO+Qa32d6+jQpfGWdx8P1D0rHR3YbGeHzmeDmvfEEWx+FwPUPgsnsHsa/uY6
TABKxyxF8L9pxPQfKobyWfMctIDcr35ODiqH2paH80P5Zk4OOYsZ97BKQ/ly
TpDwUIPyhZwcLnFmKL0xQvBB4bHOHsEHh0cY1H0mUD4wvA8DndNfBlVfAVW/
wwkSPx15DvKtQA/yOUPCe0Kew1JQfJUj+GD/70Xw7YCxWfDXGRxe/T15DudA
8WfhAg5fzVao/SUuYPWHa/McPB5Wiaxb6OIg9fqR2aziPEj4HHSBuCcNGv4P
oOoj8xwKQcnlgws4fkS9EfwPfcElS6wQfLB+Oah5x10cfqV+f/KQHeoeoP2g
+LP7luuw3h3oACWo/U9yIf6b6eyQdCbW+8RtqPwdJzgfHP/sCP6smUAATA+g
+Gl9mgsJD15HSPj+zHV4BPSe+05oeuOCuqffwWHK/wl1vxUQfIuCcx2XbBF8
cPwHQ/PHcgeHVWtvxH9Lgbr/hgPEf0V5kPTD6eiwL1rBsbABGv6+kPywrgOR
v2D5DQCJN5R8
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O0i9fmQ2iynPYcKhrxoxyxF8RqAahivO
DhFfd97iYs1zkG99Hbjjn7PDJc4MpTeceQ6PqkTWuWu6OPjIiWWd5ctz+KYR
03/I08WBzXZ26HzRPIfYfqCBCS4Ov1K/P0mUy3M4DDS+v8zF4YTRkY166lD1
jS5g83IMEHyQ/VJWCP68aybvLTyg9me5OAiI2B+LCclzKLTlur7YxsUhZzHj
nta4PIf0NCDgg5i/LiPPYdZMIDjv7FBWtVTncG6eA/f1xQW2DQj+eveHVSIm
aPwfTg5dGm9592VA1Z9xctjSUnNhcxyUv8DJ4c4D7skrQ6D8Liew/aweCH7S
mVjvExYIPli/JkL/s+3rmZ/LIMwHh48Qwn6Q/+6wQ91viIgP9PgCABB0xgs=

       "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHZzfX/IrZmOdw+KtGTL8dgs8IVMNw
zdGhZM4i5Z1b8hzOnQGCNkeHKYp9pYW78xxmzQQCc0eHTcsqj2segur/5QDh
n8lz8HhYJbLuvANE/U2o/iUOEPOe5TlMOATS4OCw4vzVsJzvCL7ubnX+bu58
VHmpfIdHQOPcZzs41Be7TSlTz3doex24Q24zxL6VRvkQ8085ODwFuv+Obb6D
Vkz/oa9vHBxuM3F2ybvnQ9wr6egwGeQev3wH7uuLC2zdHB18HIQTD4fmOxTa
cl1fXOPokHX036bqaKh5exwdPmwIyJ4VDzXvD1R9cr7DG6D1rcFODr/av9y+
nprvAAtPGB/sXkdnVP5KZ4cw8e0XG5Kg6n84O/CZ2ey9FA01z93FYd4Pw2d6
MPe0uDiUAsPL0jvfYWkBUGC9C9j9H4H+uwF0PtdtF4j/DaDqP7hA/C+P4MPC
E8bfUytr8fxDnoN8KzAAT7k41AHD89vtPIcaoPMe1rlA4ucMND6UXSDhsQsa
v33O8PSBnn4Aw1UhGg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHvd3q/NxX8hwKbbmuLy5xhvMPf9WI
6X/j7HBBO1Uy6WaeA/f1xQW2Gi4OErwPdAWe5DkE75BrfZ3s4pDwLspp37s8
h29A5YcaXRz21MpaPP+N4OsCzevmzofzfRyEE52l8x2WFgAtBOqvL3abUqaR
78AIdBMD0PzjIQdXqBhD+UD7+cxs9l6yzXeI7T/0VQPovk3LKo9rOuc7wNwP
43s8rBJZx43gz5oJBJMd4frB7o9whJtfIwI0QMYRbr+JMRD8d4DISyP4834Y
PtPjRvBB4dMN9N8EoHNiJB0dnDLzP7C+z4PY7+vocIeJs2v+U2j4TXCEhAcw
/MDu50GEN3r4AwDtTKL0
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
       0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHntsZDPnBRQ6Hv2rE9Nsh+IxANQzX
HB2u7HksIhta5HDuDBC0OTok1d+0rYwocpg1EwjMHR0+OZ5PuxoN1f/LAcJP
KHLweFglsu68A0R9OlT/EgeIeXlFDhMOgTQ4OOSG1a4rK0PwDXyWcbU1oMp/
ay9yeAQ0zn22g0PECtOz1X1FDm2vA3fIbYbYJzoFav4pB7D7188sctCK6T/0
9Y2DA9sHMY+AeVD3SkLc/3NhkQP39cUFtm6ODvv55hgvWlrkUGjLdX1xjaOD
38WJMXUroObtcXQQPL5rR+8qqHl/oOrXFDm8AVrfGuzkMG0TT+GatUUOsPCE
8cHudXRG5a90dnD59fY1wxqo+h/ODgs6NzxcuQJqnruLw4ss7W/hMPe0uIDD
K3ZBkcPSAqDAehew+3cC/XcD6Hyu2y4Q/0+Gqv/gAvF/F4IPC08Yv1xXUd6k
uMhBvhUYgKdcwOG5O6PIoQbovId1EPtkE6Hhr+wCDo9/4dD47XOGpw/09AMA
uv0V8w==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVAScHA59lXMdSihwKbbmuLy5xhvMPf9WI
6X/j7NDEcrS/ML3Igfv64gJbDRcHtVKmWSdyihyCd8i1vk52cTj51H6JfFGR
wzeg8kONLg7luoryWyoQfJB5bQ0I/n6+OcZJHUUOSwuAFgL1R6wwPfu7r8iB
EegmBqD5fySKrwdNgfKB9i/o3PBw5cwih9j+Q181gO775Hg+LXROkQPM/TC+
x8MqkXXcCP6smUAw2RGuH+z+CEe4+TUiQANkHOH2mxgDwX8HiHwHgv8iS/tb
eAOCD/YP0H8TgM6JkXR0sFL2qnYugtrv6+jA9kHMY0IuNPwmOELCIx3qfh5E
eKOHPwB24ql3
       "], {{41.760000000000005`, 300.48900000000003`}, {
       40.558125000000004`, 300.48900000000003`}, {40.558125000000004`, 
       301.690875}, {41.760000000000005`, 301.690875}, {41.760000000000005`, 
       300.48900000000003`}}, CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkeH9uXhp4q8ix1g/Nmh81evtSp2uLEY
KFDs6NAGlDeyLHY4ewYI/Bwd3vLuM5A0L3Zoex24Q87c0eFcx6V7CSbFDibG
QCDo6PDjSeLCa/rFDtzXgQb8c3AIKVGZbq+F4D82kzowWxnBtz92Z6uLXLFD
bP+hrxpcjg5Me1iFpkgWOzAC3cig5OigJTH1SqdosUONyDr3hw6ODqbvLVzd
BYodgnfItb7OdXS4EV/mL8cDdc9KRwexLN/PfJxQ8544gs1nYYPaZ+EEdk89
S7HDBKB0zFIE/5tGTP+hYiifo9hBC8j96ufksEzHWSabF8o3c3Lwmtug5iQM
5cs5QcJDEsoXcnKoubA50lQewQeFxzRVBB9k/n4DqPtMIHx7YHgfBjqnvwyi
XswJqn6HEzh+PnkWO8i3Aj3I5wwO7we+xQ5LQfFVjuCD/b8XwbcDxmbBX2dw
eLH7FDucA8WfhQs4fEM8oPaXuIDVL3ApdvB4WCWybqGLg4Ljx+Qee2j4HHSB
uMcSGv4PoOqNih0KQcnlgws4fjy1EXyeySubBJURfLB+Uah5x10cJtb9ttrA
CXUP0H5Q/N1jKHZY7w50gBLEfp4fRRD/zXR2OLJRL2/x5yKI/B0nOB8c/+wI
/qyZQABMD6D4aQLqB4cHryMkfJmKHR4Bvee+E5LejnBB3dPv4BDnfYLdVgzB
38D8vGeFCoIPjn99aP5Y7uCQoZRTYWUBdf8NB4j/7KHph9PRoegn/8vvrtDw
94XkBzEvRP6C5TcA/VKJ9Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4Oyg4fkzmYS92mHDoq0bMcgSfEaiG4Yqz
g/2xO1tdOIod5FtfB+745+xQc2Fz5FauYodHVSLr3DVdHHbd6vqrylvs8E0j
pv+Qp4uDWJbv5z6BYofYfqCBCS4OE+t+W30QKXY4DDS+v8zF4ceTxIVhklD1
jS5g877KIvgg+88oIfiPzaQO3NaE2p/l4jA7dP7qt/rFDoW2XNcX27g4eM1t
UGMyLXZITwMCPoj5YlbFDrNmAsF5Z4dzHZfuLbApduC+vrjAtgHBX+/+sErE
BI3/w8nhRnyZv5wVVP0ZJ4e3vPsMJE2h/AVODkx7WIVEDKD8Liew/Yc0Efwj
G/XylJUQfJD+mVII/W3Lw08ZiSDMB4cPH8J+kP/WckLdb4iID/T4AgDrscTd

       "], CompressedData["
1:eJxTTMoPSmViYGCwBmIQbcd1fXFBvItDTaJRaMH2YodHVSLr3B9i8k0atjs0
xRQ7nDsDBAcQfLD+hS4OwayLJ1nFFjuYGANBs4vDBP4qs9VxxQ7fNGL6DwW6
OPCoaNTxJBY73FhcYMul6OLwZp6NzpUUKP+jM9g8pqxihxqQdQecHTI2vyo2
zYfa3+nsIPb79LvOsmIHbqB1tl7ODnbh0Rv/1xc7MAL9wPDCyWHWM9nlK/qK
HWL7D33VmOXk8L30wZyJM4od5FtfB+5IcAK7b9dcqHnqTg7rp6R2PF4Es9/R
IfaOG3PFUqh5+xD89DQg6EDwwf6LdnQ4Jxl4S3oxVN7MEWxe8rxih1kzgUDQ
ERx+G2ZC1f93cGD0beHtn4zgg93fjeBrrRS+wNICda+Qo8OubM6fC2qh4Wfp
CAmvimKHs6DwT3B0ULiUH89eUuygBZT+Og2qvhAaPncQ/CVA710/6+hwxGlt
5r14aPikOcLjA2y/uKODh95/xdpUqHkPHMDuN8gtdjj8FeiAVQ6Q8ALaN+EQ
SMABrN62HsH3BPF7EPxHx2fsDgP6vwho/eI1DuD43LoYat9zB4cbH754Ra6G
+k8RYv/fTdDwzHIEh9f5bcUObcDgkDuIxn+L4IPVSzhBwnsr1P1OTg5FXX1P
ijYXO7wBKm/NdYKkp41Q9cD0AXJv7VpofJ10AqcvzxXFDoUg9/5wArtfbDE0
vVhC098sqHndzuDwWAxMbx4PgQrOO4Pt2wSMv2Cg9Ou/zuD0F1gHjQ8xF3B8
11dDw1PPxaHN4trRtRVQ97q5QMKrDJqf4iH5qaoEwYflRwBVUZxk
       "]}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
       0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
       0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVAScHueUvPPQiyxwOf9WI6bdD8BmBahiu
OTqkdSTH3okqczh3BgjaHB2+eEW2WcSVOcyaCQTmjg4tvP7rpyRC9f9ygPDT
yhw8HlaJrDvvAFGfC9W/xAFiXnGZw4RDIA0ODv8V/34zrUHwD4mrBbu2ocpv
7S1zeAQ0zn22g8Or4q2i1lPKHNpeB+6Q2wyx78pMqPmnHMDuz5tf5qAV03/o
6xsHhxm7p03gXwJ1ryTE/TuWlzlwX19cYOvm6BB4S7omcXWZQ6Et1/XFNY4O
D+YILrVdBzVvj6PD4klWjL4boOb9garfVObwBmh9a7CTg0Zdz87szWUOsPCE
8cHudXRG5a90drh2NNfkwEao+h/ODkahBlqZ66Dmubs4VJmtthOHuafFBRxe
MsvKHJYWAAXWu4DdXwH03w2g87luu0D8PwOq/oMLxP8TEHxYeML4nD8XpH+u
KHOQbwUG4CkXcHhW55U51ACd97AOYt+dNGj4K7uAw2NvLDR++5zh6QM9/QAA
U+0RgA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHQ+Jqwa1ZZQ6FtlzXF5c4w/mHv2rE
9L9xdhC54HLDILfMgfv64gJbDReHHQ5Nj9qLyhyCd8i1vk52cYjeuP/NvfIy
h29A5YcaXRw4fy5IL65D8EHmubYh+IG3pGsU+8oclhYALQTqf1W8VXT3lDIH
RqCbGIDm9z35JC80C8oH2m8UaqCVOb/MIbb/0FcNoPtaeP3Xiywqc4C5H8b3
eFglso4bwZ81EwgmO8L1g90f4Qg3v0YEaICMI9x+E2Mg+O8Ake9D8KvMVtuJ
tyH4YP8A/TcB6JwYSUeHM+9OHmaqgNrv6+gwY/e0Cf7F0PCb4AgJj1yo+3kQ
4Y0e/gAkx6bP
       "], {{41.760000000000005`, 364.8482}, {
       40.558125000000004`, 364.8482}, {40.558125000000004`, 366.050075}, {
       41.760000000000005`, 366.050075}, {41.760000000000005`, 
       364.8482}}, CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkcHyeLrQkaB5Q4wvq6i/Jcch3KHG4uB
AsWODhJA+U925Q5nzwCBn6ND/U3byhs25Q5trwN3yJk7OiSEBKkrWJU7mBgD
gaCjQ9eGhy+nmpY7cF8HGvDPweGZ/ZL7//QR/FKmWRzRmgj+xYkx/5hVyh1i
+w991eBydJjS3hoVLF/uwAh0I4OSo8OexyKyntLlDjUi69wfOjg6HN+1o5dN
rNwheIdc6+tcR4cs7W/T7wpC3bPS0WGF6Vnrc3xQ8544gs0/zA21z8IJ7B47
rnKHCUDpmKUI/jeNmP5DxVA+UL8WkPvVz8nB4sehFC1hKN/MyeFOBkM+oySU
L+cECQ85KF/IyYFvjvGiLyoIPig8QrURfJD5dWZQ95lA+P/syx0OA53TXwZR
f9Udqn6HEzh+NvmXO8i3Aj3I5wwO7wXB5Q5LQfFVjuCD/b8XwbcDxmbBX2dw
eB0Dxu85UPxZuIDDV9gPan+JC1h9gle5g8fDKpF1C10cNvEUrvF2hYbPQReI
e+yg4f8Aqt6i3KEQlFw+uIDjh9MQwZ8Xp3n6ggaCD9YvBTXvuIuDsld1cz4/
1D1A+0HxN5et3GG9O9ABShD7T/8tg/hvprNDWO26bUk/yyDyd5zgfHD8syP4
s2YCATA9gOLH8V8ZJDx4HSHhy17u8AjoPfedkPTWLAB1T7+Dwwcxj4A/0gi+
0/m0q+laCD44/k2h+WO5g8Ovt68P/LSFuv+GA8R/LtD0w+nowHK033C7NzT8
fSH54ao/In/B8hsAXD+ULw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O2ziKVxzmqfcYcKhrxoxyxF8RqAahivO
Dhcnxvxj5it3kG99Hbjjn7MD3xzjRSUC5Q6PqkTWuWu6OPgs43J7KlTu8E0j
pv+Qp4vDCtOz1n5i5Q6x/UADE1wclL2qm9dLlTscBhrfX+bi0LXh4UtReaj6
RheweVuUEXyQ/d0aCH4p0yyO2fpQ+7NcHHQV5b+sMS13KLTlur7YxsXhTgZD
/kGrcof0NCDgg5h/1b7cYdZMIDjv7JAQEqSe4FTuwH19cYFtA4K/3v1hlYgJ
Gv+Hk0OW9rfpd+2h6s84OdTftK28YQXlL3BymNLeGnXZFMrvcgLb36iP4IfV
rtv2SB3BB+mPUEDolyi+LvRJEmE+OHxEEPaD/JfDD3W/ISI+0OMLAJsJwAQ=

       "], {{41.760000000000005`, 377.621}, {39.720000000000006`, 377.621}, {
       39.720000000000006`, 373.90099999999995`}, {38.752500000000005`, 
       373.90099999999995`}, {33.170625, 377.814125}, {33.170625, 
       378.67474999999996`}, {38.752500000000005`, 378.67474999999996`}, {
       38.752500000000005`, 379.842875}, {39.720000000000006`, 379.842875}, {
       39.720000000000006`, 378.67474999999996`}, {41.760000000000005`, 
       378.67474999999996`}, {41.760000000000005`, 377.621}}, {{
       38.752500000000005`, 377.621}, {34.869375000000005`, 377.621}, {
       38.752500000000005`, 374.936}, {38.752500000000005`, 377.621}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
       0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBWIQLbrO/WHVASeHQ3cjd7+Nq3I4/FUjpt8OwWcEqmG4
5ujAuf/K+dkJVQ7nzgBBm6PDzMZTP74nVznMmgkE5o4OGi4HFEPSofp/OUD4
OVUOHg+rRNadd4CoL4LqX+IAMa+yymHCIZAGB4fFEXmZXxsR/DS/6UdZelDl
SydXOTwCGuc+28Ghb5Vax6+ZVQ5trwN3yG2G2DdlPtT8Uw5g9+surXLQiuk/
9PWNg4PNJ3bm8yuh7pWEuL98bZUD9/XFBbZujg5fBXrfKWyscii05bq+uMbR
oeVyk/jfzVDz9jg6uJ9cXcyzDWreH6j6HVUOb4DWtwY7OZzZ8ldbe2eVAyw8
YXywex2dUfkrnR2q/txbVr8dqv6Hs8O17oVzNLZAzXN3cZDLldl4bQPUPS0u
DlzA8Lq9usphaQFQYL0L2P3mQP/dADqf67YLxP/zoOo/uED8Pw3Bh4UnjL9W
X+jWproqB/lWYACecgGHp1VJlUMN0HkP61wg8ZMDDX9lF3B41CZD47fPGZ4+
0NMPAHYpIgc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbrO/WHVASeHNL/pR10KqhwKbbmuLy5xhvMPf9WI
6X/j7LCDbZvXh6IqB+7riwtsNVwcoss/h7hXVDkE75BrfZ3s4vD/uUH8vNoq
h29A5YcaXRzW6gvdMmpB8EHmsfQg+F8Fet89mFzlsLQAaCFQf98qtY6qWVUO
jEA3MQDNN5JOmXRxPpQPtP9a98I5GkurHGL7D33VALpPw+WA4pXlVQ4w98P4
Hg+rRNZxI/izZgLBZEe4frD7Ixzh5teIAA2QcYTbb2IMBP8dIPKTEXy5XJmN
17oRfLB/gP6bAHROjKSjQ4GqtdmhWqj9vo4ONp/YmfkroeE3wRESHsVQ9/Mg
whs9/AFrgqoH
       "], {{41.760000000000005`, 429.20744}, {
       40.558125000000004`, 429.20744}, {40.558125000000004`, 430.409315}, {
       41.760000000000005`, 430.409315}, {41.760000000000005`, 
       429.20744}}, CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkeHvSs9Wj+GVTvA+BfDJ6TpuFU73FgM
FCiGyG90qXY4ewYI/BwdlAXWv57uVO3Q9jpwh5y5owNL9+GZ9+2rHUyMgUDQ
0UHveVBMqHW1A/d1oAH/HBy6ykSD9pki+JKW3NVS+gh+6YmzBYc1qx1i+w99
1eBydLDY9+2MkGq1AyPQjQxKjg4JUm39HIrVDjUi69wfOjg6ZH/UZDgmXe0Q
vEOu9XWuowN/UjrXXHGoe1Y6Ovjk2K3rFYGa98QRbH6zINQ+Cyewe/7xVztM
AErHLEXwv2nE9B8qhvKFqx20gNyvfk4Od/RMrr+UgPLNnBzq5xc+PCAH5cs5
QcJDBcoXcnLYdGmJyBYtBB8UHqKGCD7IfDsbqPtMIPx9rtUOh4HO6S+DqJ/q
C1W/wwkc/oWh1Q7yrUAP8jmDwzs+stphKSi+yhF8sP/3Ivh2wNgs+OsMDq+2
8GqHc6D4s3ABh++lYKj9JS5g9fIB1Q4eD6tE1i10cQhzfiTH7Q0Nn4MuEPe4
QMP/AVS9XbVDISi5fHABx88JMwTfaeos2wl6CD5YvwLUvOMuDscb3nzVE4W6
B2g/KP5ieaod1rsDHaAEsb+bGeq/mc4OvzbLayr9r4LI33GC88Hxz47gz5oJ
BMD0AIofBhZoePA6QsKXt9rhEdB77jsh6c1ZDOqefgeHKb47D+1WRPCfsd5w
VzdA8MHxbwXNH8sdHOapxBrvdIa6/4YDxH9e0PTD6eiw4jfDkrJAaPj7QvLD
1FBE/oLlNwBIk4Tl
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O4Q5P5LrFqp2mHDoq0bMcgSfEaiG4Yqz
Q+mJswWHhasd5FtfB+745+yw6dISEROxaodHVSLr3DVdHD7cqd6xRKLa4ZtG
TP8hTxcHnxy7dbwy1Q6x/UADE1wcjje8+ZqnUO1wGGh8f5mLg97zoJirKlD1
jS5g80o0EXyQ/d56CL6kJXd1lCnU/iwXh4vhE9JyrKsdCm25ri+2cXGon1/4
sMGh2iE9DQj4IOZPda12mDUTCM47O7B0H54p71HtwH19cYFtA4K/3v1hlYgJ
Gv+HkwN/UjrXXFeo+jNODsoC619Pd4DyFzg5WOz7dmaSNZTf5QS238EUwf+1
WV5zkS6CD9IvrobQv3elR+tGeYT54PCRQtgP8p+OKNT9hoj4QI8vALQ8wtQ=

       "], CompressedData["
1:eJxTTMoPSmViYGCwAGIQvaTAluv6YkeHeoMPd3YfrHaA8afcM9/3bUO1w43F
QIFiiHz1+mqHs2eAwM/R4em0MOektdUOba8Dd8iZOzocF8z+uHJVtYOJMRAI
Ojp8yP21WX5ZtQP3daAB/xwcfP7uWdmxAMG/vX/TpSczEXxz/9ITvVOqHWL7
D33V4HJ0+OUyT+Vuf7UDI9CNDEqODsoLdZ9f6q52qBFZ5/7QwdFBt+Ji+IS2
aofgHXKtr3MdHS6+4EtKb4K6Z6WjA9/np6wR9VDznjiCzfetgdpn4QR2z4mq
aocJQOmYpQj+N42Y/kPFUH5dtYMWkPvVz8lh3tbbeluaoXwzJwcnNUnL7k4o
X84JEh79UL6Qk0NppE9O3VQEHxQe92cj+CDzOZZD3WcC4XcAw/sw0Dn9ZRD1
8Tug6nc4gcPf+kC1g3wr0IN8zuDw1jxS7bAUFF/lCD7Y/3sRfDtgbBb8dQaH
V8ChaodzoPizcAGH79x9UPtLXMDqX+6qdvB4WCWybqGLg+SpzrKrW6Hhc9AF
4p710PB/AFW/otqhEJRcPriA42fSQgSfRcZpatRMBB+svxtq3nEXh072Kb4/
66HuAdoPij/18mqH9e5AByi5OEgA7Q/Ng/pvprPDHqvjDW8yofJ3nOB8cPyz
I/izZgIBMD2A4ud0HjQ8eB0h4VtR7fAI6D33nZD0xtsIdU+/g0PYlQSpth4E
f0VP/fyPsxB8cPwvheaP5Q4OCatZupvXQd1/wwHiv63Q9MPp6JDVtOK3wx5o
+PtC8kP8AUT+guU3AJJhrzs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfe4MEFQ4O0ic6iwLra12mHDoq0bMcgSfEaiG4Yqz
g7l/6YneumoH+dbXgTv+OTuURvrk/GuodnhUJbLOXdPFYVOyskB+c7XDN42Y
/kOeLg58n5+y3mirdojtBxqY4OLQyT7F17K72uEw0Pj+MheHD7m/Ns/vh6pv
dAGbZzcFwZcE2i86E8G/vX/TJZUFUPuzXBym3DPfZ7as2qHQluv6YhsXByc1
SUvv1dUO6WlAwAcxP35DtcOsmUBw3tnhuGD2x5ebqh24ry8usG1A8Ne7P6wS
MUHj/3ByuPiCLyl9A1T9GSeHp9PCnJNWQ/kLnBx+ucxTiV0G5Xc5ge3nXoDg
77E63pAzA8EH6X80AaG/3uDDneouhPng8GlF2A/y37d6qPsNEfGBHl8Afw7O
jA==
       "]}]}, 
    {Thickness[0.001488095238095238], CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{59.04, 
      73.44}, {473.76, 73.44}, {473.76, 444.96}, {59.04, 444.96}, {59.04, 
      73.44}}},
      CurveClosed->{0}]}, 
    {Thickness[0.001984126984126984], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1,
        0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
       0}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQ3aTvs4zLusChIA0IDhk5wPgfqkTWuUdaOxywVPba
XY7gf84Jq33XjODf38c3x7i3wMGB6/riAldrsP6uyQUODJox/YdkrR2EPjme
fzazwGGD+8MqkW9WYPN+zwPKg8AGK4detg9iJxYBzQvcIdfqbeUQeXnP4ynL
ChwmHPqqEfPcEqy+ekWBQ4Mt0IIKBB8s/98CzncwBoJkC4eUVQkhQUuh8vfN
HVZ3385gmA+0vwBoQLE52L2bZ0DN4zB32JZUf/NvX4GDwjqgA4+YORiU6yre
b4TqX24Gdv+ytgKHC0Buf5MZ2H9eXQUOCUDnvo6F8E/1QP1vaQa2X2hSgcOD
xUALX5s6+P+RKBafXuBgAAyOrx2mDq6qpUy3ZkPdK2wKCd/NBQ4HgMYF7jCC
2D8HwT8lcHzXji5o/HSZOLycuomnsBVqPy/U/EaofJGpw1/nX29X10L9u93U
Yfrdye2uVQUOC2YCwV9TsHkW5VD1emZg+daSAgcBoPNtvSDuv1QIja80qH/y
oforIepdc4DhcQYIWszA7rfOgtrXbeagtqBzw8M0aPj1m0HsS0Lj+2Ly0dMf
jA8AN6MlOg==
       "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQfUrg+C4L3wKHCYe+asR0mzu4qpYySZUg+P5/JIrD
axD8Jn2fZaeagPzXgTvkZpo73N/HN6e4vcChwZbr+uIt5g5qCzo3KPYUOCis
c39YdcHc4XNOWO26/gKHC2eA4A/U/EkFDgtmAoGlhcP0u5PbW6cUOBSkAUGZ
hcMBS2Wv3VOh+ncg+BsKgBb8R/AT+oEOyrAE25c4GcjfIdf6eq8lxL4+qPsY
rRxWd9/OYOiCus/FCuyf6U1Q+9KsIO6vQPBh4YHOh/kfAEu3iIo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQLaV/V4VtX4FDwg651tc/zRxgfAbNmP5Df80dEgUi
LLfsL3BoEFnn/vCchcPHS75JAocLHD5UAQVyLR0apjp35xwrcAh4CBTgtoLw
T0P1t1pB1F8Cqg8EWnDbCmLeDah+Q2uH3ys/XuJ9CLS//9BXjRhrh33zpfRl
XyP4IPneTwj+M6CA0M8ChwNA5wa6WIPtW/MP6D5bruuLRazB7ndjKYSY/9TK
AeSc5xyFDgZA53xdAHHPBJ5CiHvdrRyArouwFCh0KEgDgneWDndU2BpFhQsd
FswEgkZLh/kgA0Wh5jFaQtSLQ81rsHAAKp/qLFHosKEA6IDL5nA+LDxhfLB7
f5g6gIJjhhiUr2HqoAcMbkdhqPpOE4cyYAC854ea99oYHF5fuKDuKTQGuz8A
6D8HYyCQNob4/2+Bw4UzQHDECOL/rwUQ9TON4OEJ47MCnXP6LoIPCs+gywUO
DsDgK3hqBIkfYPxNeA2MsFpjcHhMPQQNfxMT1PQRa+qAnn4AUPoBBw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvW++lH7s+QKHhB1yra9/mjnA+AtmAsFEUwf+CMst
HJcKHBg0Y/oPLTRx2HyibF/89QKHgjQg0DJxCLfccmLbnQKHB4sLbLk2Gzuw
Nk519n5c4DDh0FeNmHJjsHmyrxF83ySBiJ+fEPxnv1d+nPSzwMHBGAiA+rty
nv9++a/AoUFknftDoPl6d1XYHFkKIfxFJg4NU52737AVOlwAau+fZArnw9wP
438IBAokW8D1BzysElkXbAk3H+z+U5Zw+ye8BmpwtILIA92nALSuqsbKoQzo
gfevEHywfx4j+MDgmH8L6P+EfqCHPKwcgNbnqN8ogNh/3xISHrDwi7SEhy/Y
/UkWDujhDwCHZ7pB
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
       0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, {{{12.96, 190.800225}, {4.32, 
       187.5396}, {4.32, 188.745225}, {10.5975, 190.93335000000002`}, {
       11.100000000000001`, 191.10834999999997`}, {11.571250000000001`, 
       191.255225}, {12.01125, 191.37397499999997`}, {11.540000000000001`, 
       191.50397500000003`}, {11.069375, 191.65522499999997`}, {
       10.599375000000002`, 191.827725}, {4.32, 194.1021}, {4.32, 
       195.23835000000003`}, {12.96, 191.94397500000002`}, {12.96, 
       190.800225}}, CompressedData["
1:eJxVVAtIVEEUXdaU1Moiy9h1/6v7dg2jsohAuZaaVAhJhsRGYbjOk8TVoI9i
ZbqJIblkip8EcTXBUqQMEy1T+/spkjLFfpIaaRGiprZI82amfXXh8TjcO/dz
7pnRJKTGJkolEsl+/An/I4Vds1wEB1V99S/fLOehe5YzFy5yMN4Y8CXHicBo
xgFnjCAbjfdr+YnAjsPNHUbYkRTBp44hmMPhXe4mCLZXzW8eZvGcCU6Un76u
7RfxtO35wfBOEa/2vntj4SaCqQP3lLYBI1yI7siqrECQFuo16OCMsCvs69BG
O4JLkzggi4ORweyTT3IReA86rKHVBqiviYG15xFIBCsNdOEaK07wO8CFyfmU
ANpfNvNP6mn/NkTnTdbT+fIRZPo27vks1cMz486r+woR9PVia9bRfkoQYG+G
r0UH1+Y8jm6oZPEmHZxKk6/8VIMgZCs2Nx3lrwHBO9yu14SW+u8gIHz3agk/
1fdZ/dtaUq/nBQKVDTd8Tkvyl2J+RzNwgXAt2U/cApt/UUPyu3nwlK8mERP/
RRGT+qkiDsPh1mK1C7cqccF5FSR0DwSNSXlIsmCLUkH81Ka2Oifbb5yS7nMG
0fPvFfBa8kGaPyHiy6rjP4bfipjw9xTBL+H8NiWdrw3R/ONKEn+4mfmLVRCz
rmDvt1vMb1ETnFzH6kdqaH4H42dJTfnJZVhJ58nJQ1Ar7HdASfkqQJAu8PNQ
AQ9iSzSrilh/Df7QnDnd9KoMQUUZtiE58V9xML1EyoneopoQWAm/MnCaUx4v
tf/tT0b03NkjYnJ+RMREb99Z/7Uyqq9FBOsFAenlRO8Kd57qxSGn/fswvNuf
8G/w42n8Msq3pz/DjxSgb3XmzajZfluUZH+Jep7qa0RF+Q3k6X2LVpP7dtbA
Q7+g5yk1zcfxUE7m17iwSYiv0v+P7YEuTPjrM4BHyJrt7RzTyyGO6sPE0/fh
I0fuX1EQ81uMRP/Hgnl63yeNVD9bREz482HvTzr1e65g9cY4qh9PNt8/79Uf
cmsREA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBWIQvaTAluv6bGWHZ+tUnzCzZTqYGAPBa2UHAe6ty37+
zHBITwMCPRWHpMOXtZ8+z3Cw47q+uCBVxeHO9cbiY+eh/FYVh5xZ5XOUDmU4
PKoSWee+UgWsv3JHhoNWTP+hrxdUHE5oWk06vSnDoRBo3eIfKg4Rb/R3q6/N
cDj8VSOm30gVIr8iw0G+9XXgjjpVB6lHEeLbl2Y4cAONtz2lCjZ/0SKoe+TU
HKZ8Y4uXWJgBcW81gg+2n1MdzmcAgQZ1B4t0l8z8JRkOEw4BLbyv7tDgsb9W
dnWGwzr3h1UidhoQ+zdC/ZOrAZafuxvBX7XEz2HyCQS/rFCaN+FqhsNOOaCD
HTQcPrWeDDn4IMNhPci8Z+oQ97/KcACHb7e6g5Pdi5trvmQ4aILCQ0Dd4U9M
7tF/v6HmlapB5BkyHURBDvqj6sBmImhmw5IJCR8vVXj8eACNXxevAuejxx8A
tCnGbg==
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.96, 
      202.8855000000001}, {4.32, 202.8855000000001}, {4.32, 
      203.94862500000005`}, {12.96, 203.94862500000005`}, {12.96, 
      202.8855000000001}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4jeBO+RaX2s6hNySrkk0yHKYNRMIFDXg/CUF
tlzXqzUd2nj9109RzHLQjOk/9FVDy2HSk0/yQbwIflE8+7mZnzPh/CdzBJfa
vsh0SE8DAjYtBy/mCu4ldzMdHlWJrHM/qOmwbJIV49nLmQ5g+4Hm3ziaa8Jw
KtNBdJ37wyoVTQeenwvSNx/KdIgFGbdHw8FB58qsZ3szHUyMgSBYA2yeys5M
hwlA6Zjz6g7n3p08fGhrpkMh0LmLDaD8zZkO3zSADjqq5pDRkRwbswlqvoya
g1mogdbKjZkOZ88AgYkqnA9230MpDL7C8hce6y5D9aeowPkMINCgCuffWAwM
MHs1hxqz1XbhVzIh4bkQat/VTActUPgA3QfmX4fJqzto1fXsfH0bGh6f1R3E
LrjcKHgEdZ+LBiR8XmY62AG9V5CrAY4PkY8IPtj+Xwj+LoemR+4s0Phz1gCH
ty8wvsDh80EdHD97RbMg5s9RB+vXk8tyqAZ5V0sdEr4qUP4sNYe4jfvfzFOH
8rnUIPLaWQ5BoORjqQqJH50sSHhoqMD5sPBD54PSi6R/lgMs/aHzYekPAKOz
Htc=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPWsmEDxUdYi7vOexCH+2g3zr68AdamoOk9g+iHkY
ZjssKbDlup6t7sDk8uvta+1sh51yQAUZGg7HLJW9fitmO8T2H/qqIaPpcOt5
lnaZcLbDBCA35rwmRJ4l20EzBqRAC8yv/pQF54PUf7uN4HupljLN2p/lwH19
cYHtLE0wX2pllsPZM0BQowExf0YWxH1x6g4Ofhcn3mnPcrDjAmo4q+pQ0shy
tL8+y0ELZN4JZTjfxBgINivC+edA5okoOLybuonnI1D/m8Adcq23ZR2e7OOb
s3kG1LxeaYcN3bczGoD2p6eBgBQkPPYj+B36Psu4biH4YP98znLweFglsq5d
2sGsXFdRnjMb4p9Tsg5z7k5ub5XMdvimAXQgqwJEvSY0fGcrOvzICavVM4KG
33JlOB/s32MIPti+b2h8MxUMPig+pyyE+n+yKpwPlp+nBonv5VkODCAQoQ7h
b4LGh4AGhL8XGh65GmD/nziF4IPtu43gg9JH9vMsB3B6stSAxM/HLIcgYPC+
vqgOCc9f0PjNUndQOvnUXoU5GxK/R9TA8gxc2Q7o6REAsygoCQ==
       "], {{
       9.240000000000002, 213.10005000000012`}, {9.240000000000002, 
       216.48255000000012`}, {8.721250000000001, 216.43630000000013`}, {
       8.331875, 216.3050500000001}, {8.071875, 216.0888000000001}, {7.668125,
        215.75630000000012`}, {7.4662500000000005`, 215.3256750000001}, {
       7.4662500000000005`, 214.7969250000001}, {7.4662500000000005`, 
       214.3181750000001}, {7.6275, 213.91567500000014`}, {7.950000000000001, 
       213.58942500000012`}, {8.271250000000002, 213.2631750000001}, {
       8.701250000000002, 213.10005000000012`}, {9.240000000000002, 
       213.10005000000012`}}}], 
     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQAWIQ3fY6cIfcWmWHGTH/nH/tznbQiuk/9DVBEc6vFlnn
/jBK3iEqSH0B57FsB7B6VVmHB7aVERq3sh0KbbmuLw6Qhsi/znZITwMBKQcZ
j4A/M/4j+GryX3KuiefA+f8Opax6YJTjIAY0vqpF2mENl5vqV48chyKQeQdk
HYy+Tb8rHJXjcO4MEPyRd9j28OVUo+wch1kzgaBT0aHiutCng8U5DkE75Fpf
NyrD+UDdBbZSqnD+G6BzW6PVIP7Jz3H4pgH0oKu6w5W0q8+zMnIcJhz6qhGj
r+EgVLim+3ZCDsR/TzUg7g3NcbgBNI4rXRMsH+2e47ATaF3gC02I+y1yHDRB
4aWhBXGvJoIP9o84gg+yv+pPtsNhoHX9szQdUjRPC7g/y4a4pxZif/TVbIj5
CeoOB3b0shUcyXawA3noqCo8PtDjCwABGM2U
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3fY6cIfcWmWHlnXbkv7fzXZ4A+S2OqvC+UsKbLmu
F6s5zIj551z1ONthnfvDKhE7dYcDO3rZCt5lO+yUa30dyKEB4f/MdrDjur64
IFfDIUXztIA7ew6cv4bLTfWrOIKfx5Df2KKR48AAAhxQ9WY5DmD32Ko79LVG
XbZxzHGYNRMICtUgfJ8ciPusVcH8PYE5DjUiQBfNUobzg4DSrwWV4HwQN/CF
gsMi40VbzIH6we6XU3A41W9Yrgs03xPIXbdczuHL6wOWymZQ992VdXglInsy
VQPBR3E/kA/zX3oaECyTg/s/pv/QVw0ZBXj4gP3zVAEefmD9okrw8EUPfwBi
Ga0G
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6aDh+TPZZmuNgx3V9cYGtHAb/
Wselew86cxzS04DgmBQGH6YezFeTQNVfKwbnh4CscxR1KFDKqahaluOwpMCW
63qxiMO/J4kLr63IcVjn/rBKJE7YgWsPq5DImhyHc2eAoEbIwea9hevxjTkO
IDczXBB0mFH32+rDzhwHE2MgUBZ0OLNRL0/5EFT9GQGHL7z7DGaeRfBFJq9s
CryD4AfMbVA79DTHoQho/eIPAg5VP/lfmn/IcQA5L9BC0KFvefipTb9zHCYc
+qoRc18ELL/9W46DB9B567ZD3fse6v7FIhDzXyL4O5if92g8RvCNJKZe4byZ
46AV03/o6wsRh1dmUgduX4S6v1jU4UF8mf+8s9Dw+ivqsEbHWSb7ZI7DI6B1
7oziEPOP5zgoAJ23o04CzoeFPzof7N63iPhD58PUw+IfnQ+LLwAZWfci
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
       0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 
       3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxNVHtMjWEYP25DYxbFdOqc853rd1wbRqP0DHP5wzgtbO63cslbJ8uyUsOk
WKLYEUVNVq65/EGYIbdQakWRWBpJUY2EWuX93udZn3dr7Xfe530uv+f3+6T1
EUEhfTUazVr+p/yf6VaV4xxvheUDctKmhzAIKtAlNL21QPqwmKkXExlsCuUn
3wr3wwb/zT7A4OQJfhw2EX87hcE3B3/w0AYba+b2++NiUFLMzxQZ5i5bcS0w
i4HIz2TwPT+i7NEFFVvLI9Yk3lLxzoMpn7YXMZgymZ8ZdF/BQJ/Q5CiotOH7
aqofaQP/3Tehbx3V76T+PjPwzJ/3MSZKxbEe/IcOSy8W8RkWrFdH8y21QOPT
9DsjawhbLXDp7oNRuVVU76tZ3LuKGWiUk22GM/U+eQ23Gaw8XPhL9jfDq9GO
am0OA6W8R70J2k77jwtOY9Au84hTJujeUZuZmkT8BJtg0MJ9Q0vjGdzidDta
jXDjWEjShmjCTqO4X7SdwXyeLr9FEvPPYdTPOknwe28r1Xti6MWRAZxQPxWL
ecP0uK9tDHYpfMToYO+6SUuuOhmMUQZI8kEcxaCPMt99b8GXIYawwRv53sNA
oSc0Vyv0MXY/7WemVrz3PUT5GrzEvO4u0lOqFyye0CN1nSZ+Q71wv+dULOpf
V/Fwsxw/pJDy51N8KYMjnO6VgVrs7x3dv9TifPUM6jhd81K9wbvzRfOCFgZv
cpwBbok+yHcb8RGrg+ezLm9Z3UF6e6jH/rsp/ooB+daEI7/tBuynlvgLMoh9
Z3yg+Dw9pPhVPmbVxFerTvC1t4L48NOh/opJ7+99RP0PhSoW/ruhYrH/PJp3
og79mEn9Vujw3kX1o/VCzz8Ok969sP9HyaSfRBWL/CUqFvodIqH+uZ/P8nRV
syXk8wjFx0nI11EG+zndussSznec+CiXhF+sp6jfLxLqOZveexqxv/P0fpVR
+OMV979yHVBoFPt6Vkb3nibkp5b8swT9495I+nChfxb9JL+3mcR+kjvIn04z
5uuhfTeZhX4GDgjH/Ank74Hh6Ed/ay8W71tVbFcISrfhfvuHI5/TZNRzF/X3
Wsb6v8m/i+34/WsmPvLsyG8dxXfZRb7vrxnml8egn4pULPRaoGLle7M5i+ap
sKMek8nvsh33FU/8xckYH0n+iLfh92oz7eO/7/0/WAibvA==
       "], CompressedData["
1:eJxTTMoPSmViYGDQAmIQPWsmEDxUdTBYKXzBZVeeg3zr68AdamoOKXfcmCvu
5DksKbDlup6t7nBFMvCW9PU8h51yQAUZGg4z+KvMtM/mOcT2H/qqIaPpsGbv
QfFl+/IcJgC5Mec1IfIb8hw0Y0AKtMD81XMRfJB6tXYEX+b36Xcns/IcuK8v
LrCdpQnme4bkOZw9AwQ1GhDznaHui1N3EFLRqOMxznOw4wJqOKvq4BYevXG/
Vp6DFsi8E8pwvokxEGxWhPPPgcwTUXA4kM35UwGo/03gDrnW27IO26akdjx2
hprXK+3QlGgUugFof3oaCEhBwiMLwY9iXTzJqhXBB/tnfp6Dx8MqkXXt0g4c
vi28/lug/jkl65C3+VXx1iN5Dt80gA5kVYCovwoN39mKDqec1mbG3YWG33Jl
OB/s32MIPti+b2h8MxUMPig+j/hA/T9ZFc4Hy89Tg8R3UJ4DAwhEqEP4sdD4
ENCA8DOg4ZGrAfb/j1IEH2xfG4IPSh+zJ+U5gNOTpQYkfoDxHQQM3tcX1SHh
uRQaHlnqDl/m2eiErIPG7xE1sLzBVqh+pPQIABmgHy0=
       "], {{9.240000000000002, 
       242.4496500000002}, {9.240000000000002, 245.83215000000018`}, {
       8.721250000000001, 245.7859000000002}, {8.331875, 
       245.65465000000017`}, {8.071875, 245.43840000000017`}, {7.668125, 
       245.1059000000002}, {7.4662500000000005`, 244.67527500000017`}, {
       7.4662500000000005`, 244.14652500000017`}, {7.4662500000000005`, 
       243.66777500000018`}, {7.6275, 243.2652750000002}, {7.950000000000001, 
       242.93902500000019`}, {8.271250000000002, 242.61277500000017`}, {
       8.701250000000002, 242.4496500000002}, {9.240000000000002, 
       242.4496500000002}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGAwA2IQnZ4GBGGqDl8OWCqf6sx3OPxVI6Z/lqrDA6FPjv6r
8h0mHAIKsKs7yMqefLp/Wb5D2+vAHXKqGg4tzfo+y+bmOywpsOW6/lnDQdhN
tZSpP98haIdc6+uDmg6LOKTnxTXkO2jG9ANN0HLoi7q8JzkPwb9m7XdRMBJN
3i7fwcQYCGZrOqT+c/71ViPfweNhlci6eg2HaPUFnRsk8h3eAK1vTVZ3CAj4
I1HMke8QC9J+RtXhdMqqhBCGfIdZM4FgpzKcDzYvWQnOB5tnrgj233nmfIcb
i4EeMFdw4MxvZDnKBTU/Ww7CF4Sa91LGoXJN9+0MmXyHnUDvBb6QhrhHC6r/
uZSDzaIt5j8s8h3A4Zkm5aDxJSes1gPBB4WffSSCD3Z/HjQ8RaUh4V8PDf8i
GbD9rr35DgpA63ack4WE/6x8h/XuQA/sk4eE12KoexQUwe4xWJ7voAUKzwJF
h//T705mb4fGz2wFsH2fm6Hu/S4Pjq+munwHRmAaYFCQd3CrjFixtQyq30MO
oh7oPjuu64sL7sqC42tiKho/CsEHueexJzS9zJdz2L4tqT7SBhp+glD7DaHh
e1nB4dXLqZt61PMd5EH+Y1OCqFeCxtdqZTgfbH6oKqp8txokfQH1i64DBoiP
OiR+DKHhyasBCV9rqP5cDYh9Hgg+2L8RaHyg/86eAQIdqPoCqHtXqzsYnRY4
blWZ78ANVG6rBUl/nxth6UsNHP8V7dD4RcpPAHh7a9I=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ3fY6cIfcWmUHjS85YbV78h20YvoPfU1QhPOrRda5
P4ySd3j1cuqmnmP5DmD1qrIO+VefZ62+le9QaMt1fXGANET+db5DehoISDlc
y49n52MogPNjojfu1+FB8N3XZt7bKFngIAY0vqpF2kEu8Jb0HpUChyKQeQdk
HR64MVd46xY4nDsDBH/kHRbb6Fy5ZVrgMGsmEHQqOrRsd2hSsipwCNoh1/q6
URnOB+ousJVShfPfAJ3bGq3mIFJlttrOosDhmwbQg67qDkb/Ff+WmRQ4TDj0
VSNGX8MhsIXXf71BAcR/TzUg7tUucLgBNI4rXRMs/165wGEn0LrAF5oQ98sU
OGiCwktDC+ze0yIIPsg/NjwIPig8//7JdzgMtK5/lqbDlwOWyqee5UPcU6vh
sIhDet69q/kQ8xPUHQIC/kh8PpLvYAfy0FFVeHygxxcApt3EYw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3fY6cIfcWmUHYTfV0qZ7+Q5vgNxWZ1U4f0mBLdf1
YjUHjS85YX8f5zusc39YJWKn7hAQ8Efi87t8h51yra8DOTQg/J/5DnZc1xcX
5Go4VD2YI/iUuQDOlwu8JW3Dg+AznHl3slmkwIEBBDgg6lOlCxzA7rFVd+jr
e/LpvkKBw6yZQFCoBubHqxVA3GetCubLaxY41IgAXTRLGc4PAkq/FlSC80Hc
wBcKDjNTO5JjgfrB7pdTcFgnfMHlBtB8TyB33XI5h0MHxdWCpaHuuyvrYHPt
aG6JCIKP4n4gH+a/9DQgWCYH939M/6GvGjIK8PAB++epAjz8wPpFleDhix7+
AP0rq2Y=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ1IGYC4jeBO+RaX2s6nNG0mnTar8DhUZXIOveHUhj8
6Df6u9XjChyKbLmuLw6Qg/PFgLJVW6QdWjz218qmFjikp4GAlMOrdapPnPMR
/D755HezahB8kP70pgKHWTOBYKWUgzD31mU72wscQG5iMJB22F79acOEHqj6
bdIObnYvbuZMhOmXAcsLTC1wAPmFwUHWgdNE0KxmeoHDbJB5khD3PZ9Z4AD2
n7S8w4xvbPEzZhc41IC8o6TgcChommLfnAKHCYe+asS0KzgYTVjww3BugQPI
OAYLRbD7m4H8s2eAwEQJzoeFFzr/S+vJkEage4NAXE8lOH9JATDAshXh/G8a
Mf2Hjio4FMwqn/Oou8DB4yEwgMMVHFIPX9Ze2lXgYGIMBJflIeHTCdWvLA9x
Xzs0PhbKge1nbilwUGh9DXSBHDh8bzUUONgBo6fgrizYfKVaBB8sX4HgX2O4
x8RZVOBQCIrPAmh85hQ43FgMtHC6vIPcowhx83So+XEKDg+uNxa7JRU4rAdG
t0iZIjj8zsVD409QGc6HhQc6H5aeADUED4g=
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1,
        0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/SZwh1zra00H2eLrQp9+FDh4PKwSWeevAeebGANB
t6bD1Ykx/w5/KnDQjOk/9FVDy0Hdq7p5/UsEX2iO8aItdxF8sP6rUP2PNR0W
xWmevnAOan44hB9wosAhFqT8jAZE/mCBw6yZQMCp4XB6147eY3sKHBhAQEAd
bJ7RzgKHbxpAC0TVHPK1v02fu7XAYZ070MBvKg4z2lujLm8ucNAC2b9BGc4H
O6dECc4/ewYIQhTB5hUB9deIAE0IUoD4Z0eBQzAoOBbKORgpyn95s7vAISMN
CMRkHQ48FpE9eQDqH2YZcHg4Hy9wYAS574OUwyv7Jff3nS1wSAepT5Ny+CLm
EfDnChr/DoLfctO28sajAocbiwtsubZLgf0v8KLAAWR9YIS0Q8AyLrelbwoc
doH4P6TB5tt9LHCYDQqfkzIO/96+PvDzCyz8ZB36Njx8efU7NHzdBTH4a0zP
WvtxFDrA4hudD4tvAGK/8z4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfWNxgS3XemWHvg0PX149UuCwzv1hlYibKpyfngYE
ZWoOssXXhYqOFzgwgICDuoPNj0Mpq84UOGjF9B/6yqHhEFW7btujiwUOdlzX
Fxfkajhs4ylcw30DwQ9YxuWmeh/BX2N61trvGZTPC5FPfQPl+0LMz/pY4HD2
DBD0qDmoe1U3538rcAC7N10V7J5PPwocQNZr3FGG82fNBAJNJTi/RgToo1cK
YPclfYO6X0HB4erEmH/OH6HuXyEHtk8LZv9dWbB7nj5F8IXmGC8quYfgu51P
u6p+vcCh0BYosEAO7B8+oP/fBO6QaxVWgMgDw0eh9XXgjmsKDqd37eh1A4bf
4a8aMf1cSvDwRQ9/AB5/t2Y=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}}}, {CompressedData["
1:eJxTTMoPSmViYGAwA2IQnZ4GBGGqDo8mt7fOmlXocPirRkz/LFWHG3sei9xd
Vegw4RBQgF3d4Zvj+TTRlYUOba8Dd8ipajholTLN6lhS6LCkwJbr+mcNh8Kw
2nVmcwsdgnbItb4+qOmww/zHoSdTCx00Y/qBJmg5rEsICXreg+AHXZwYY9eE
Jl9S6GBiDASzNR1mbeIp1MkqdPB4WCWyrl7DQfT4rh28SYUOb4DWtyarO0y4
ncHwPrLQIRak/Yyqw9mn9kvuhxY6zJoJBDuV4XyweclKcD7YPHNFsP/mhhc6
3FgM9IC5gsObLO1v4tFQ87PlwPzpcVDzXso4LOnc8PBlcqHDTqD3Al9IQ9yT
DdX/XMqhjeVov2FRoQM4PNOkHGp0FeW/VCL4oPALbULwwe7vgYanqDQk/KdC
w79IBmx/+JxCBwWgdTvOyULCf3Ghw3p3oAf2yYPDK3051D0KimD3+ALjRwsU
ngWKDun1N20tZ0LjZ7YC2L7106Hu/S4Pjq9vUwodGIFpgEFB3oHrg5iHwESo
fg85sHr93kIHO67riwvuyoLjq64Dlf+vCcEHuWd5FTS9zJdzOMw3x/hRMTT8
BKH250HD97KCQ8wK07PVmYUO8iD/sSlB1KdB42u1MpwPNj9UFVW+Ww2cvlKA
+kXXAQPERx0cP5l50PDk1QDbl18M1Z+rAbbvdyWCD/ZvEyp/AtB/Z88AgQ5U
fS/UvavVHRgki68HTSp04AYqt9WCpL/102DpSw0c/4UzofGLlJ8AwIF5dQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ3fY6cIfcWmWHGl1F+S+bCx20YvoPfU1QhPOrRda5
P4ySd4hZYXr2945CB7B6VVkH+XlxmtyHCx0KbbmuLw6QBstXny50SE8DASkH
O2Wv6sNXEfzDfHOMHz1E8NclhASlvy90EAMaX9Ui7dDGcrS/8FehQxHIvAOy
Dh6/3r5mYC5yOHcGCP7IO3B9EPOYwF3kMGsmEHQqOrzJ0v52nb/IIWiHXOvr
RmU4H6i7wFZKFc5/A3Rua7QaxD+8RQ7fNIAedFV3mLWJp1CHq8hhwqGvGjH6
Gg47zH8cSmErgvjvqQbEvQxFDjeAxnGla4Lll/wsdNgJtC7whSbE/Z8KHTRB
4aWhBXZvwysEH+Sfjw8RfJD9JlcKHQ4DreufpenwaHJ7q9TJQoh7aiH2LzkA
NT9B3WHC7QwGfWB424E8dFQVHh/o8QUANJ7IxQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3fY6cIfcWmWHwrDadd+OFDq8AXJbnVXh/CUFtlzX
i9UcanQV5bccL3RY5/6wSsRO3WHC7QwG/bOFDjvlWl8HcmiA+esvFTrYcV1f
XJCr4fBocnvrrJsIfhvL0f6PDxH89PqbtpavCh0YQIADol7qY6ED2D226g7f
HM+nTf1W6DBrJhAUqoH5on+g7rNWBfOv/it0qBEBumiWMpwfBJR+LagE54O4
gS8UHBgki68L/YG6X07BQfT4rh29QPM9gdx1y+UctEqZZnF8hLrvrqzDks4N
DzVfIfgo7gfyYf5LTwOCZXJw/8f0H/qqIaMADx+wf54qwMMPrF9UCR6+6OEP
AK4auGA=
       "]}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPWsmEDxUdWid6tydk1HkIN/6OnCHmpqDnP5dlbbK
IoclBbZc17PVHa77JgncKCty2CkHVJCh4bDjRNm++4VFDrH9h75qyGg6HJov
pT83q8hhApAbc14TLB+fXOSgGQNSoAXmy0ch+CD1d/0Q/Kp986XWOxQ5cF9f
XGA7SxPMzzctcjh7BghqNMDqZXWh7otTd/h2yTfpgkqRgx0XUMNZVYf+nOe/
VyoUOWiBzDuhDOebGAPBZkU4/xzIPBEFhzNl++bfAup/E7hDrvW2rINHd85z
a12oeb3SDus+XvJdBLQ/PQ0EpCDh4YDgzwIG13NfBB/sH6D/PB5Wiaxrl3Yo
AFpXmAr1zylZhyVA6SW5RQ7fNIAOZFWAqC+Fhu9sRYegJIGIn5XQ8FuuDOeD
/XsMwQfb9w2Nb6aCwQfF5xpDqP8nq8L5YPl5apD4NilyYACBCHUw/40lND4E
NCDy9tDwyNUA+9/NDcEH2Vfph+CD0seMkCIHcHqy1IDET2SRQxAweF9fVAeH
p1IcNDyy1B3SBCIsS5Kg8XtEDSz/KBWqHyk9AgBBPyNZ
       "], {{9.240000000000002, 
       291.15525000000025`}, {9.240000000000002, 294.5377500000002}, {
       8.721250000000001, 294.4915000000002}, {8.331875, 
       294.36025000000024`}, {8.071875, 294.14400000000023`}, {7.668125, 
       293.81150000000025`}, {7.4662500000000005`, 293.38087500000023`}, {
       7.4662500000000005`, 292.8521250000002}, {7.4662500000000005`, 
       292.37337500000024`}, {7.6275, 291.9708750000002}, {7.950000000000001, 
       291.64462500000025`}, {8.271250000000002, 291.31837500000023`}, {
       8.701250000000002, 291.15525000000025`}, {9.240000000000002, 
       291.15525000000025`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6tKgdakufXORgx3V9cYGtHAY/
5pTRkY2tRQ7paUBwTAqDD1MP5qtJoOqvFYPzQ0DWOYo6aEz/P+EfkL+kwJbr
erGIQ0FF1VKdqUUO69wfVonECTt8TT4Te3pakcO5M0BQI+TQ9zf1+5KZRQ4g
NzNcEHSwcXUv2jm3yMHEGAiUBR2u3XvAfXkhVP0ZAYfXPRpve5cj+FX+cmKv
1iH4M69wZizaXORQBLR+8QcBh3VNgZ53dxQ5gJwXaCHosCPy685Z+4ocJhz6
qhFzXwQsL7unyMED6Lx12yHuXbMD6v7FImDzs7Yi+GfYbWeHbkLwuYRE7N3W
FjloxfQf+vpCxCFt4TWT9Suh7i8WdXiwtaVmwnJoeP0VdXCXef2obGmRwyOg
de6M4hDzlxQ5KACdt6NOAs6HhT86H+TeudsR8YfOh6mHxT86HxZfAACr7wI=

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
      3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
      0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4jeBO+RaX2s6LHPd9nnviSIHO67riwts5TD4
tS/VDDl2FzmkpwHBMSkMPkw9mK8mgaq/VgzODwFZ5yjq4LXt89+Qk0UOSwps
ua4XizhMmp4n1HyqyGGd+8MqkThhB7HmA6cUzxQ5nDsDBDVCDhtkolJ+nyty
ALmZ4YKgQ1yK9X3+y0UOJsZAoCzo8OPvlQrN61D1ZwQceNbIRD25g+DPARrv
8ATB3/X575UfL4ocioDWL/4g4HB+oes243dFDiDnBVoIOtyseKn28XORw4RD
XzVi7ouA5Ys/Fjl4AJ23bjvEvczvoO5fLAI2/8ArBP8dMHjWPEfwtYHcOY+K
HLRi+g99fSHi0H7g1ELW+1D3F4s6MF2tePnsDjS8/oo6ZFjf9z97q8jhEdA6
d0ZxiPk3ixwUgM7bUScB58PCH50Pcu/nN4j4Q+fD1MPiH50Piy8AbwABFA==

      "]], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.640000000000001, 
      303.74310000000025`}, {4.440000000000001, 303.74310000000025`}, {
      4.440000000000001, 304.80622500000027`}, {5.640000000000001, 
      304.80622500000027`}, {5.640000000000001, 303.74310000000025`}}, {{
      12.96, 303.74310000000025`}, {6.720000000000001, 303.74310000000025`}, {
      6.720000000000001, 304.80622500000027`}, {12.96, 304.80622500000027`}, {
      12.96, 303.74310000000025`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
       0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGAwA2IQnZ4GBGGqDu0HTi1sTS12OPxVI6Z/lqpD7Us1wxOl
xQ4TDgEF2NUd5uQJNTOUFDu0vQ7cIaeq4XB+oeu24vxihyUFtlzXP2s4iDUf
OKWYUewQtEOu9fVBTYe4FOv75xOKHTRj+oEmaDmE9E7PuxSO4P/4e6VC0xdN
3r7YwcQYCGZrOjjc9+8VNy128HhYJbKuXsNh1+e/V37oFDu8AVrfmqzuYMqx
RuaWSrFDLEj7GVWHIiGgAxSKHWbNBIKdynA+2LxkJTgfbJ65Ith/HUrFDjcW
Az1gruAwaXqeELMa1PxsOTC/WRNq3ksZB69tQAfoFTvsBHov8IU0xD2mUP3P
pRy0DYEOsi12AIdnmpSDYhQwAFwQfFD4Ofgi+GD3h0PDU1QaEv4J0PAvkgHb
75xe7KAAtG7HOVlI+OcVO6x3B3pgnzw4vIKKoO5RUAS7xwIYP1qg8CxQdOBZ
IxOlkgKNn9kKYPtmJUHd+10eHF8P44sdGIFpgEFB3mGDTFTK72iofg85sHqp
iGIHO67riwvuyoLjKzMYlf/SF8EHuWeSKzS9zJdzyLC+73/WDhp+glD7LaHh
e1nBgelqxcs0k2IHeZD/2JQg6g2h8bVaGc4Hmx+qiirfrQZOX/5A/aLrgAHi
ow6OnxBLaHjyaoDti7KD6s/VANv3zAXBB/vXB5VfDfTf2TNAoANVHwF172p1
h2Wu2z7bxhY7cAOV22pB0t+sRFj6UgPHf0wKNH6R8hMAvgVpvw==
       "], {{
       5.640000000000001, 312.4095000000002}, {4.440000000000001, 
       312.4095000000002}, {4.440000000000001, 313.4726250000002}, {
       5.640000000000001, 313.4726250000002}, {5.640000000000001, 
       312.4095000000002}}, {{12.96, 312.4095000000002}, {6.720000000000001, 
       312.4095000000002}, {6.720000000000001, 313.4726250000002}, {12.96, 
       313.4726250000002}, {12.96, 312.4095000000002}}}], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
       1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3,
        3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 
       3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQPWsmEDxUdXCXef3I7HOxg3zr68AdamoOD7a21ASw
lDgsKbDlup6t7jDzCmfGIsYSh51yQAUZGg5V/nJiq/4UO8T2H/qqIaPp0KJ2
qC39a7HDBCA35rwmWF7rXbGDZgxIgRaY/+oJgg9Sv/wmgm/j6l5UebrYgfv6
4gLbWZpgvuWBYoezZ4CgRgOs/vl2qPvi1B12RH7dOWt9sYMdF1DDWVWHwM99
wSWrix20QOadUIbzTYyBYLMinH8OZJ6IgkPf39TvS4D63wTukGu9LevAJSRi
z7YDal6vtENBRdXSHKD96WkgIAUJj9MIfswpoyMbbyD4YP88LXbweFglsq5d
2sEobzGjzQeof07JOqQtvGaS/6PY4ZsG0IGsChD1DNDwna3oIPJy+/rDwPAG
h99yZTgf7N9jCD7Yvm9ofDMVDD4oPsv2QP0/WRXOB8vPU4PE9/5iBwYQiFAH
87cdgcaHgAZE/hQ0PHI1wP4XuIjgg+xzvongg9JH0v1iB3B6stSAxA8wvoOA
wfv6ojo4PN+8gIZHlrqDxvT/E+zeQuP3iBpYfs0HqH6k9AgAee0wUg==
       "], {{
       9.240000000000002, 315.82965000000024`}, {9.240000000000002, 
       319.2121500000002}, {8.721250000000001, 319.1659000000002}, {8.331875, 
       319.0346500000002}, {8.071875, 318.8184000000002}, {7.668125, 
       318.48590000000024`}, {7.4662500000000005`, 318.0552750000002}, {
       7.4662500000000005`, 317.5265250000002}, {7.4662500000000005`, 
       317.04777500000023`}, {7.6275, 316.6452750000002}, {7.950000000000001, 
       316.31902500000024`}, {8.271250000000002, 315.9927750000002}, {
       8.701250000000002, 315.82965000000024`}, {9.240000000000002, 
       315.82965000000024`}}}], 
     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
      3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
      0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ1IGYC4jeBO+RaX2s6bH9VvFVUqsThUZXIOveHUhh8
t7WZ9wo1SxyKbLmuLw6Qg/PFgLJVW6QdCjh/Lkg3KHFITwMBKYdr+fHsfVYI
ftWDOYJP3RF8kP6NviUOs2YCwUoph3+n351kDi5xALmJwUDaYZGNzpVb4VD1
26QdjP4r/t0WA9MvA5aPSihxAPmFwUHW4csXr8hjSSUOs0HmSULcZ5ha4gD2
n7S8Q8t2h6ZHaSUONSDvKCk4rBW+4HIjvcRhwqGvGjHtCg5ygbekazJKHEDG
MVgogt1/Dsg/ewYITJTgfFh4ofMfuDFXnAa6NwjE9VSC85cUAAMsWxHO/6YR
03/oqIJDdPTG/TpAvsdDYACHKzgEtPD6vw8tcTAxBoLL8pDwCYHqV5aHuC8I
Gh8L5cD2+/mXOCi0vga6QA4cvqo+JQ52wOgpuCsLNj/HA8EHy7sg+IcOiqsF
25Y4FILiswAan+YlDjcWAy2cLu/AuXiSVaMR1Pw4BYczM3ZPm6Bb4rAeGN0i
ZYrg8JPQhsafoDKcDwsPdD4sPQEAQOED2Q==
      "]], 
     FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {
      0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {
      1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4p1yra8DNTQcHlxvLHZbXeIQtAMo8FPTwc3u
xc01a0scHlWJrHOX1HLok09+d2tFiYNmTP+hrxpaDqc1rSZ1L0Hw/8XkHt23
AMEHmdc2q8ShGqj9IZeWg/rOP+1bppY4yAOt23FO0+Eqwz0mz0lQ+yZqOrR4
7K+921fiwH19cYGtkyZYfUlPiYPHQ6AD7ms4HAiapsjXXeLQBtQuV6sBcV9n
iYMWyL4V6g4cJoJmfzpKHEyMgSBZDc4H+y9CDoNvNGHBD8NaqP8eSmHwYerB
5u8QgfNDQO41FAL7999MhHp0Piw8Yfah82HqweY3qMH5Swpsua5Lq8P5YP/X
q4PD2xsYnqJA06vWqDukHL6s/RTILwQqX3wDor5uNlT/b0h41MwpcVgPVC4i
pgEJ37lQ+w00wOrt5pc42HGBAlwD4v+FCL7sowjx7YsR/PxZ5XMWLS1xSE8D
AjMNh6g3+rvVV0DNQ0o/ANTUC/E=
      "]]}, 
    {RGBColor[1., 0., 0.], Thickness[0.002976190476190476], Opacity[1.], 
     CapForm["Round"], JoinForm["Round"], 
     JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
      0}}}, {{{74.4, 87.48070000000001}, {163.0154, 261.6952}, {236.8615, 
      337.0887}, {310.7077, 379.7871}, {384.5538, 407.00667}, {458.4, 
      425.81996000000004`}}},
      CurveClosed->{0}]}},
   AspectRatio->Automatic,
   ImageSize->{504., 504.},
   PlotRange->{{0., 504.}, {0., 504.}}], "}"}]], "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],

Cell["\<\
Combining both these regression curves, it appears that a function that \
provides a good fit to the heterogeneous/homogeneous ratio appear to takes \
the form:\
\>", "Text",
 CellChangeTimes->{{3.560248227224463*^9, 3.560248260417568*^9}, {
  3.560248301972999*^9, 3.560248338875944*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"a", "+", 
    FractionBox["b", "k"]}], ")"}], 
  RowBox[{"(", 
   RowBox[{"c", "+", 
    FractionBox["d", "r"], "+", 
    FractionBox["e", 
     SuperscriptBox["r", "2"]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.560248273600114*^9, 3.560248298135661*^9}}],

Cell[TextData[{
 "By generating numerical data for different ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " and k values, we can use Mathematica\[CloseCurlyQuote]s \
\[OpenCurlyQuote]FindFit\[CloseCurlyQuote] function to find the coefficients \
of this function. Here\[CloseCurlyQuote]s the data of the ratios for \
different ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " values:"
}], "Text",
 CellChangeTimes->{{3.560248340747712*^9, 3.560248438183487*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "2"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
  3.5599663414180593`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5.973352811175817`", ",", "3.9036945595479255`", ",", 
   "2.6612491284648128`", ",", "2.0296097605272316`", ",", 
   "1.2993723481688066`", ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{{3.559966303817224*^9, 3.559966342563806*^9}, 
   3.559966402509201*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "5"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
   3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
   3.5599663414180593`*^9}, 3.559966420996293*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.47648691715173`", ",", "4.204786276098524`", ",", "2.8393504806553045`", 
   ",", "2.143670213289029`", ",", "1.3352415761082526`", ",", "1.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.559966434657358*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "7.5"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
  3.5599663414180593`*^9}, {3.559966423140629*^9, 3.559966423491805*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.663273687706044`", ",", "4.3175834560493`", ",", "2.9068905956085174`", 
   ",", "2.187443763555809`", ",", "1.3494060805791508`", ",", "1.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.559966436154797*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "10"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
  3.5599663414180593`*^9}, {3.559966426500926*^9, 3.559966426548979*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.7846876099325595`", ",", "4.391142898305934`", ",", "2.95112261024421`", 
   ",", "2.2162241591588567`", ",", "1.3587991026229886`", ",", 
   "0.9999999999999962`"}], "}"}]], "Output",
 CellChangeTimes->{3.559966437651778*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "12.5"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
  3.5599663414180593`*^9}, {3.55996642962048*^9, 3.559966430187883*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.8731302615874235`", ",", "4.444830856628114`", ",", "2.983483757294212`",
    ",", "2.237325207460358`", ",", "1.365713184438794`", ",", "1.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.559966439431332*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.16", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.25", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.35", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.65", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "1", ",", "0.01"}], "]"}], "/", 
     RowBox[{"HomThresh", "[", 
      RowBox[{"R", ",", "0.01"}], "]"}]}]}], "}"}], "/.", 
  RowBox[{"R", "\[Rule]", "15"}]}]], "Input",
 CellChangeTimes->{{3.557548438298423*^9, 3.557548440272238*^9}, {
  3.5575486156481857`*^9, 3.557548618441471*^9}, {3.559966308849347*^9, 
  3.5599663414180593`*^9}, {3.5599664322048492`*^9, 3.5599664322591352`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.941949896011185`", ",", "4.486661517341739`", ",", "3.0087368274706066`",
    ",", "2.2538122307602633`", ",", "1.3711254489898002`", ",", 
   "0.9999999999999999`"}], "}"}]], "Output",
 CellChangeTimes->{3.559966432528412*^9}]
}, Open  ]],

Cell["\<\
We can combine this into a single data and subsequently fit the model to it:\
\>", "Text",
 CellChangeTimes->{{3.560248453113912*^9, 3.5602484769279623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "0.1", ",", "5.97335"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "0.16", ",", "3.90369"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "0.25", ",", "2.66125"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "0.35", ",", "2.02961"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "0.65", ",", "1.29937"}], "}"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t", 
    RowBox[{"{", 
     RowBox[{"5", ",", "0.1", ",", "6.47649"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "0.16", ",", "4.20479"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "0.25", ",", "2.83935"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "0.35", ",", "2.14367"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "0.65", ",", "1.33524"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "0.1", ",", "6.66327"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "0.16", ",", "4.31578"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "0.25", ",", "2.90689"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "0.35", ",", "2.18744"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "0.65", ",", "1.34941"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.5", ",", "1", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t", 
    RowBox[{"{", 
     RowBox[{"10", ",", "0.1", ",", "6.78469"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "0.16", ",", "4.39114"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "0.25", ",", "2.95112"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "0.35", ",", "2.21622"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "0.65", ",", "1.3588"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "1", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "0.1", ",", "6.87313"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "0.16", ",", "4.44483"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "0.25", ",", "2.98348"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "0.35", ",", "2.23733"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "0.65", ",", "1.36571"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12.5", ",", "1", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\t", 
    RowBox[{"{", 
     RowBox[{"15", ",", "0.1", ",", "6.94195"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", "0.16", ",", "4.48666"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", "0.25", ",", "3.00874"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", "0.35", ",", "2.25381"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", "0.65", ",", "1.37113"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"15", ",", "1", ",", "1"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5599834138963003`*^9, 3.55998345430993*^9}, {
  3.559983485852697*^9, 3.559983529931909*^9}, {3.559983594883544*^9, 
  3.559983943740443*^9}, {3.56024848737569*^9, 3.560248492502709*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "0.1`", ",", "5.97335`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0.16`", ",", "3.90369`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0.25`", ",", "2.66125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0.35`", ",", "2.02961`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0.65`", ",", "1.29937`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "0.1`", ",", "6.47649`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "0.16`", ",", "4.20479`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "0.25`", ",", "2.83935`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "0.35`", ",", "2.14367`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "0.65`", ",", "1.33524`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "0.1`", ",", "6.66327`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "0.16`", ",", "4.31578`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "0.25`", ",", "2.90689`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "0.35`", ",", "2.18744`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "0.65`", ",", "1.34941`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5`", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "0.1`", ",", "6.78469`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "0.16`", ",", "4.39114`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "0.25`", ",", "2.95112`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "0.35`", ",", "2.21622`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "0.65`", ",", "1.3588`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "0.1`", ",", "6.87313`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "0.16`", ",", "4.44483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "0.25`", ",", "2.98348`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "0.35`", ",", "2.23733`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "0.65`", ",", "1.36571`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.5`", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "0.1`", ",", "6.94195`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "0.16`", ",", "4.48666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "0.25`", ",", "3.00874`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "0.35`", ",", "2.25381`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "0.65`", ",", "1.37113`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.560248507111363*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"model", "=", 
  RowBox[{"a", "+", 
   FractionBox["b", "k"], "+", 
   FractionBox["c", "r"], "+", 
   FractionBox["d", 
    RowBox[{"k", " ", "r"}]], "+", 
   FractionBox["e", 
    SuperscriptBox["r", "2"]], "+", 
   FractionBox["f", 
    RowBox[{"k", " ", 
     SuperscriptBox["r", "2"]}]]}]}]], "Input",
 CellChangeTimes->{{3.559983946802794*^9, 3.559983966343371*^9}, {
  3.559984153715116*^9, 3.559984171145401*^9}, {3.559985966988163*^9, 
  3.559986011338763*^9}}],

Cell[BoxData[
 RowBox[{"a", "+", 
  FractionBox["b", "k"], "+", 
  FractionBox["e", 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox["f", 
   RowBox[{"k", " ", 
    SuperscriptBox["r", "2"]}]], "+", 
  FractionBox["c", "r"], "+", 
  FractionBox["d", 
   RowBox[{"k", " ", "r"}]]}]], "Output",
 CellChangeTimes->{3.5602485093929873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fit", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"data", ",", "model", ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "k"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "0.334401130451327`"}], ",", 
   RowBox[{"b", "\[Rule]", "0.6894350343724344`"}], ",", 
   RowBox[{"c", "\[Rule]", "0.40842666705669267`"}], ",", 
   RowBox[{"d", "\[Rule]", 
    RowBox[{"-", "0.5070535609249294`"}]}], ",", 
   RowBox[{"e", "\[Rule]", 
    RowBox[{"-", "0.3559327825396071`"}]}], ",", 
   RowBox[{"f", "\[Rule]", "0.4667007061724057`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.560248511001766*^9}]
}, Open  ]],

Cell[TextData[{
 "Therefore ",
 StyleBox["the predicted function to fit the heterogeneous to homogeneous \
ratio is:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.560248519431561*^9, 3.560248536462986*^9}, 
   3.561381191733385*^9, {3.561392851598199*^9, 3.5613928531623497`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"mfit", "[", 
    RowBox[{"r_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"0.334401", "+", 
    FractionBox["0.689435", "k"], "+", 
    FractionBox["0.408427", "r"], "-", 
    FractionBox["0.507054", 
     RowBox[{"k", " ", "r"}]], "-", 
    FractionBox["0.355933", 
     SuperscriptBox["r", "2"]], "+", 
    FractionBox["0.466701", 
     RowBox[{"k", " ", 
      SuperscriptBox["r", "2"]}]]}]}],
  FontWeight->"Bold"]], "Input",
 FontWeight->"Plain"],

Cell["\<\
By comparing this function multiplied by the exact homogeneous threshold, we \
see that it provides a good fit to the numerical threshold calculated for \
heterogeneous outbreak. Here\[CloseCurlyQuote]s plot for k = 0.1, 0.5 and 0.9 \
for a c = 1% threshold:\
\>", "Text",
 CellChangeTimes->{{3.5602485819574833`*^9, 3.5602486332263117`*^9}, 
   3.560248697033633*^9, {3.560248756595392*^9, 3.5602487742426157`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plot1a", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.1", ",", "0.01"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2a", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.5", ",", "0.01"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3a", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"FR3", "[", 
      RowBox[{"R", ",", "0.9", ",", "0.01"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Green", ",", "Dashed"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.560248694062663*^9, 3.5602487413255787`*^9}, {
  3.560248950251093*^9, 3.56024895348956*^9}, {3.560249038239087*^9, 
  3.560249058526307*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mfit", "[", 
        RowBox[{"x", ",", "0.1"}], "]"}], "*", 
       FractionBox[
        RowBox[{"Log", "[", "100.0", "]"}], 
        RowBox[{"Log", "[", "x", "]"}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "plot1a"}], "]"}]], "Input",
 CellChangeTimes->{{3.560248750647264*^9, 3.5602487513368196`*^9}, {
  3.560248792918624*^9, 3.560248795580971*^9}, {3.560248955680647*^9, 
  3.560248955808153*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV0ns41AkXB3BZxmBcckmEcctvzPiNCWMaRvstXZRSEY3KksyqRJFSqHVZ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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Hs41IkeBnArpsHEJpJLbGh+M/iN0RhMM9ZL+6xccq2WWl0cZIWVdDwH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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{2., 12.},
  PlotRange->{{2, 15}, {11.796880209700179`, 29.475958007189444`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.560248781100053*^9, 3.560248796150922*^9}, 
   3.560248956421417*^9, {3.5602490427017813`*^9, 3.5602490604363203`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mfit", "[", 
        RowBox[{"x", ",", "0.5"}], "]"}], "*", 
       FractionBox[
        RowBox[{"Log", "[", "100.0", "]"}], 
        RowBox[{"Log", "[", "x", "]"}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "plot2a"}], "]"}]], "Input",\

 CellChangeTimes->{{3.5602488413080063`*^9, 3.560248849011896*^9}, {
  3.560249083765585*^9, 3.560249083876562*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwVlHs0lIkbx51Z3nmN+2XGjPv9/rossiR9pa3NpcSvpaRaEQqbibVL21ob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      "]]}}, {{}, {}, 
    {RGBColor[0, 0, 1], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Hk41Isex/F51PxmjDHWMWMMIsb6sxS5Tjo+aaO0kQ7hOLmJHJSlpmhx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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{2., 2.8000000000000003`},
  PlotRange->{{2, 15}, {2.849198636541784, 7.540022081718572}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5602488453863363`*^9, 3.5602488492428913`*^9}, 
   3.5602490847308702`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mfit", "[", 
        RowBox[{"x", ",", "0.9"}], "]"}], "*", 
       FractionBox[
        RowBox[{"Log", "[", "100.0", "]"}], 
        RowBox[{"Log", "[", "x", "]"}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2", ",", "15"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Green", "}"}]}]}], "]"}], ",", "plot3a"}], "]"}]], "Input",\

 CellChangeTimes->{{3.560248854772386*^9, 3.5602488587516937`*^9}, {
  3.56024908842864*^9, 3.560249088548369*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVknk81AkDxsfEzDjmnhYp983P0eEo+j1sbwcdW22ttFJqEpG3ifVWQkkH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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwViXlYzIkDh6eZmpmmaZpmpot06/52KDztxvcT+1SUoqJBkVZbbKF7pZ8i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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{2., 1.8},
  PlotRange->{{2, 15}, {1.8550117950797402`, 5.1026958677773635`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.560248858968295*^9, 3.5602490889168997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sensitivity analysis", "Subsection",
 CellChangeTimes->{{3.560245833374838*^9, 3.560245842214085*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Sensitivity analysis\n\n",
 StyleBox["We next perform a sensitivity analysis of this function, in order \
to determine wh",
  FontWeight->"Plain"],
 StyleBox["en the outbreak threshold",
  FontWeight->"Plain",
  FontColor->RGBColor[0., 0., 0.]],
 StyleBox[" is mostly dominated by changes in ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[" and k respectively. Specifically, we invoke an elasticity \
analysis (Caswell 2001, section 9.2), to determine the sensitivity of this \
approximation based on proportional changes in ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["R", "0"], " ", "and", " ", 
     RowBox[{"k", "."}]}],
    FontWeight->"Plain"], TraditionalForm]]],
 " ",
 StyleBox["For our approximation function ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"f", "(", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "k"}]}],
    FontWeight->"Plain"], TraditionalForm]]],
 StyleBox["), the elasticitiy of ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["R", "0"],
    FontWeight->"Plain"], TraditionalForm]]],
 " ",
 StyleBox["at a given point ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["R", "0"], "*"], ",", 
     SuperscriptBox["k", "*"]}]}], TraditionalForm]],
  FontWeight->"Plain"],
 StyleBox[")",
  FontWeight->"Plain"],
 " ",
 StyleBox["is equal to:\n\n",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", "f"}], 
      RowBox[{"\[PartialD]", 
       SuperscriptBox[
        SubscriptBox["R", "0"], "*"]}]], "\[CenterDot]", 
     FractionBox[
      StyleBox[
       SuperscriptBox[
        SubscriptBox["R", "0"], "*"],
       FontWeight->"Plain"], 
      RowBox[{"f", "(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["R", "0"], "*"], ",", 
        SuperscriptBox["k", "*"]}], ")"}]]}],
    FontWeight->"Plain"], TraditionalForm]]],
 "\n\nSensitivity for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ".",
 StyleBox[" The following figure shows the sensitivity of ",
  FontWeight->"Plain"],
 StyleBox["f",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" to ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["R", "0"],
    FontWeight->"Plain"], TraditionalForm]]],
 StyleBox[":",
  FontWeight->"Plain"]
}], "Subsubsection",
 CellChangeTimes->{{3.557811933962431*^9, 3.557811946217119*^9}, {
   3.557823979007371*^9, 3.557824020444862*^9}, {3.557824135573393*^9, 
   3.5578242397902203`*^9}, {3.557824293728578*^9, 3.557824340307686*^9}, {
   3.557824423308638*^9, 3.5578244568255463`*^9}, {3.5578245215124474`*^9, 
   3.557824595082963*^9}, {3.557824636773726*^9, 3.5578247828243103`*^9}, {
   3.5578248153743*^9, 3.5578248778377733`*^9}, {3.557825094385899*^9, 
   3.557825101612772*^9}, {3.5578251959354067`*^9, 3.557825304673317*^9}, 
   3.5613783018944273`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FR4", "[", 
   RowBox[{"R_", ",", "k_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"Log", "[", "R", "]"}]], "*", 
   RowBox[{"mfit", "[", 
    RowBox[{"R", ",", "k"}], "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"FR4", "[", 
         RowBox[{"R2", ",", "k2"}], "]"}], ",", "R2"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"R2", "\[Rule]", "R"}], ",", 
        RowBox[{"k2", "\[Rule]", "k"}]}], "}"}]}], ")"}], "*", 
    RowBox[{"(", 
     FractionBox["R", 
      RowBox[{"FR4", "[", 
       RowBox[{"R", ",", "k"}], "]"}]], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.01", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0.1", ",", "1"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "k"}], "}"}]}], ",", 
   RowBox[{"ContourLabels", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Framed", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "]"}]}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<RedBlueTones\>\""}], ",", 
   RowBox[{"ContourStyle", "\[Rule]", "Black"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxsfQVUVc0XrwrYiokNBoKNYoG1UWxF/TAAu8UWWwwsVOzCwhYVFQsbWyzE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   "], {{{}, 
     {RGBColor[0.450385, 0.157961, 0.217975], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlmlQl1UUxl8R8P7f9/6FAhVBMss1W8eZVndBBUypb36pyQ/VJ6nUmkRL
R9tGKwkwkUWLylRAc63UpsxyQU1tUTRt3yYsCLXSafmded4Pd57nfe65527n
nvMOmFF298yUIAiO0LrT8nwQrIK0hkHwrQuCnNQg+AZcSluBvgRcTXsN/opp
TvY14DFaJvZHwZJIY+sTQZCCz2VMcnMyCPrF/m2egL4n4eXYX+3l8xjzevQK
7B9B749+Cv0KcAw+PT4r6D9IXxLeCh5w0veDdzDHR/AWbPfyHcH3gW/S1uJn
LbiMthJeATbjdyo2P+HzcngN+mh8jI3k/yX0BdgtRF8I3kLfdPTp9D/LdzX6
c+CDjA3RR6EPjPdie+qKtMfBSfWZzf12HgmtbTTaFFpf+Cz0Jtqd8B/pP4e+
gLFDGfuyrQ+9EK0Fm2nwn9HWw6fAf4DX0nrDi7Cpg/eBF8NXwLPgE+FTaXnw
RYyrRO8JH2drdJrrCfA79GL0adj8x/d89LlgKXb56JVec9saquBV8Az4+Ejn
aOe51GtNtrZ5tif6cuHltnZ4P/gS+PfYlMBne+3Z9r4Yno1Nezox2TMIDjmt
8zB4G2exB94cKSYsNvLgv9HK4WfBmU531AlO4jsbXoPvjkh7WU2MTcVPKf5X
oQ+Cv4/NOvo/Y8xl8E/BF53i4QVwFDYfo2/A5mGn+LQ4/cRp70fADqc4LwPP
00akBcEFcCPrbIFvALslxN9D76K14L8FbECrT9P35053/QV43OnuToBfOd3p
1+B9TvaZ+OtOm8VeUsHTTjFwBnQJnWECTGfuE/jOYf2pnOmv6FnwZ7CrQn8a
3EJrg28Ft9FOwreDm5zGbgYnM6YX/lfi8/E4NixGhnA+H6Cvj7Qf20cSm53w
0/Bd4Lu0L+E7wLed7u4dcBhjdzO2ibHznN6L5YZHne70MXBCpNxSbTHrtc6+
aN297uIS+vVec+WjD/aaqx+8R0L7TQcv4quQc8uAh157v535CyLd+3L0Geil
8F/gJ53ip83W7rT3UxYjXvlwZFJ2Zn8P2pB4Xpu/j9cZ9gbrGPMqvBYc4MUL
GNvO2LsY+4C9Eb4Pw7ezlhL4Ifg2+FHitRH7q7CZhN6KvgX9AHoDei76kVA+
zbedu51/s+Vmp7EN4ENxfFqcmi/TJ+KvkHYAn5vxOQG+H74JfgafTdjchO04
9H3ob6EP43sN+mS0a73y6nAw8sqHu0KNsbFTsGly4uutbjiNbQTH0LcXnxvx
uZ8x9XanXvuxfY2nf43lbvgb4Ieh3qPl6d2hzt/uYWeoe7T7bAwVP5Z3d8Ar
4Qkvv+Z/rOVSJ//LwTps5sLbsb+Y0PlYvapysq8024Te8gh7Q6HWc43l+FA5
0/J0Ed/F2JzD9m/GFMD/Asd58Q70eq933uAVfxaHl7DpjPl4L7/mv5h1LnZa
/yLwXyf//zjtx/RbsUmJ37K96Rvi+Ld3cDzUOdtdZXnVuz1oRYw5yJlvZc3n
I9W110PlNctvmV73YffSy+u+7d5z4KnxW7M35+O7tjvvEecWyzHZ8Vw2Z0b8
Tu29zvfK/1YHnvKqQVaLnveqBVYThsex1BYq7i3+r/Naq615qFfcW/wP8qrB
lufTvGLXYvhKr7u0Ox2Y1FuyN3WjV0xbbOfb+7Z3wnl2Ay/E52DnUe1V46zW
dcb1wurGSFoCvZb+dV41y2qX1QyrHb+DXXEeLmPetV411GrpHKf1zAbneNV6
q/ln45pVHypHWK7IjfTvYv8wSa86Z/XOeeVHy5N/gvd6rcfWZTnXcu8f4P8E
oUd+
         "]], PolygonBox[CompressedData["
1:eJwtllfMFVUUhUcE3HNnhiaIIEZNQDDR6IOxS+9N1CdfRFEBG6iAUgXEjihV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         "]], 
        PolygonBox[{{2544, 1348, 2297, 2295, 3709}, {2548, 1354, 2302, 2300, 
         3710}, {3122, 2292, 2238, 1454, 3248}, {3247, 1454, 2305, 2246, 
         3707}, {3439, 1651, 2307, 2275, 2898}, {3587, 1772, 2312, 2223, 
         3706}, {3708, 2290, 2294, 1331, 2462}, {2463, 1616, 2306, 2290, 
         3708}, {3710, 2300, 2308, 1651, 2547}, {2898, 2275, 2296, 1348, 
         3137}, {3705, 2155, 2301, 1354, 3145}, {3123, 1331, 2293, 2292, 
         3122}, {2835, 1771, 2311, 2309, 3711}, {3711, 2309, 2313, 1772, 
         2836}, {3709, 2295, 2299, 1349, 2545}}]}]}, 
     {RGBColor[0.6305469910117483, 0.3064243820364262, 0.3214819002779316], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mXnc11MWx389/b5PPd/v/T5ZSkYZGbSoSIxZGGurJbKUCVln7Pu+REK2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         "]], PolygonBox[CompressedData["
1:eJwll3eYVdUVxe+beW/w3nsuiKCg9ChFbGB6goU6jMAAmtgD0ZhgjIZYosFg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         "]]}]}, 
     {RGBColor[0.7765578977687124, 0.5443861419536685, 0.46471019810863146`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXe4VcUVxc97nHt595Rng6cmIQhGo0JEBSQogiWWL4mgWECwgSV2oyZB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         "]], PolygonBox[CompressedData["
1:eJwtmHeUVdUVxu/MvPfknncfalCJRpYUo3SQGg0Ek4ialWAg9GKjmCCCBhJB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         "]]}]}, 
     {RGBColor[0.8628918139162652, 0.7593042255055426, 0.6172622355983363], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgm0VtV1x7/vPd73vXsvV3EExeoiqLFtqkZFqSgKGJDBagRRE5YCYsTZ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         "]], 
        PolygonBox[CompressedData["
1:eJwll3uQ1lMYx3/v277v2+/3vmcTJcmtKIOU6LKV9qJIq+zaam1KtatIKGnp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         "]]}]}, 
     {RGBColor[0.8323474409522211, 0.8482971222198411, 0.7572105406222887], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mgm0VfV1xu997/oO51zOMzXLosshIQMoAoIg+MABQalRUEGjFSEORMWH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         "]], 
        PolygonBox[CompressedData["
1:eJwlmHl0ldUVxb+X93iP7yY3Vlqr1YJaxVKqKZMCURSDQQWKJYJUgYJCgJBA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         "]]}]}, 
     {RGBColor[0.6750700944874546, 0.8055222765447541, 0.8240551897135242], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXmQVdURxt9yZ4Z7570nQsUosi+yRQwmCiKTils0wWiJUIqRQVFBBYXR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         "]], PolygonBox[CompressedData["
1:eJwllmlsVVUUhS/vPl+9591HVBIFUQaZxEoQFZnEyKBgIBpLG6lSlAItU0tb
bVUgGIVEjMIPIFFBEQVnDGKZQUDmoeAUoomJRqNB0ASjgqAR/Jbrx0n2Omuf
fe45Z++1b+fKmSW1mSiKVjCyjMYkimbEUfQ+4OV8FG0Ed8PhdcaDhSjaDO6B
vYoxDvx9iKJm/KfhPw3/TfDd4d5gPAT/I/xG+Dr4Wvh2rYlXFEV94WfC1eHz
RC6Kitk7Ardn/VtwBy6Jok7Yp5jbzvo5rG9ifWkaRWVwTay5CH8N4238DzPX
Gftaxjvgo+DrsDsy3gN/Ce6KXSDG58RbT7yV2GOIVwrXSLwL8FfyfR34vnLW
1LD3pfgcw38N/suwlzBWYRcxNxR+FmvqsZuZew1uFPhO8ExwDbgD+F1ifcYe
XbCnMyrhl8MvhL+K/Tqx3z2tomgY3J/E3A3/Avwz8HXMVcfeU3u3xb8L/qPw
Hw53P2MEfCN8PfwF1h8EvwJeBB4Bfzt4KngqeBL3XZ3zHemu7kocS2+it3kA
fC/+s/FvxH81Yyt2V+YqiF0FX4G9hLln4eaCG2P7yHcCeCz4efDT4JhxBLwa
vBR7O3xv9r6VMb3gN9BbNGhPuJeC7SLmBsGdAG8BN8kn7zfQW9RoDv/58OOx
/2HcAncavBN7Pj5z8s5h5fLlzI2CG8eaMdjzmJut9wyOlQUPAJ8H7wMvBS8A
LwJPAbcC98v7DDqL5uqJ9Rz8ROwLjL5554ByoT24FG4DPl0560pGOef9Bjw8
6xxsnfcb6a0UYwZcCT5lvM9a8mUN+BHw5JxrQrVxgHy9IeO5CXBVjCk555hy
bSB7/os9iJhfgGvga+HPEW8H+HDq2ijG51DqO9PdKScXBNeAaqEfPrfBj2V9
Rc419xHcutTfJq1oA25h9M06Z8+wvh7/LhnXdAN2H+b+APfH51N8X9Wbw53A
v1ved6q7leYsDr5D3aVyfiH4EGtuzvpNfwMXMbYSrydzu+DKiFeecw2vBV8P
fzLjb9K37WYUZ61BPwVrhrRjIP79OctecK+sc+zn4G/St6lm6sA9wCdj13QD
uFg5FrtGmsC9wL/Hzqkng+9cd68avAj+VvrAfmfZ7y/2q8K/Cj7L3N2JNVPa
ORj/keCvGUOy1pwE7jj4jqxrKJt3DauWdQc5nZXzf5VzTMU+yh69Ms6Jarje
zJ2JXZNzg99Ab6Ec/xt8BP8bM9aEyfgPTaxF0kBpoe5Ydy2N/wH/y/LWRmmQ
tKg2uJalYdIy5ZRyq4p4E4lXWbAtjZZW14LXxf7mU9g9ifdrbA17jFh9wOdi
a8w88CfEW51xz9mF3ZG57zLOCeVGO/BxcG/wfvAHiXNXNaRaUs9R7xlCvNGJ
NUnapBzpwdoPE+eCcki5dDB1L1GNqdb2p+5FPcH7sDen7oWq6U3YLam1XXeo
uzyb+q1Vc6q9bal7oXroVuxjqXuR3khvtSN1L1XP/Di1JkmbdMYOwRosLdYZ
2wb3QPXC+/SmfPtTzJXHvjPdnTRSWjkSXJK4J6g3tLD+imBNlDaW6o4T9yD1
ImnGgGDNk/ZJU6sTa7y0XjV8U3BPUm/SnpXwbYJjq4ZUSxtSa500YD32+dTa
cxq96J74jfRW6um/BN+p7nYS9/Uw9/V48NlUU6ot9QD1AvWY5dL6gn3fZM3V
iTVb2q0e/CL8sODerJpR7YwO1n7VlGorw/pBsTVoRcE9Wr16D/FSfOOCa1M+
8p0VfFeqIdVSWbC2S8Ol5dPwWZZxT9uW+B9G/zKDOfNAztac2JaGSku3SKMy
zukK8Pjg3iqN+F8rgrVAmiPt2Zv6rFqzB7sx+G2lQdKiR4NzWzWkWtqZ+N9K
NaZaKwSfTRooLfwP7lM9tA==
         "]]}]}, 
     {RGBColor[0.43717370119563564`, 0.6728437097672976, 0.7944652587962707], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmNtz1VcVx38JPYdz6DlWrIVeFEJK2xcriI6jVHp5EaTYAULIjaYkIdCX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         "]], 
        PolygonBox[CompressedData["
1:eJwlkkkuhFEUhW8qfsmfPEPtQKqKiQ0IFmABmOiq1Yy0MzZgA2aImOurVaWo
QiqIkFiR77iDk5xzu3eblyrszG0nzGwC9IBSMCtHZhVQhmf6zA6xd9FZ+EBs
NovO9ZotoevE1CO3yVcHBXxtbM/4aug8uoV+RA+hc+YxK+QvYDujgTS4x3eH
PoGPgkvFEnNE/Af5efggtnnzmsvoPXAAz4AyvgrIwmvEV4Pb/n2Rz/YkRN6D
etkl/zzhNfbhV7G/fQomiX0ADeKboBF8Js3WAW35iS+S+4p+Qa9R44LaP+h1
+Aa4Rv+iN+FfwX2yjZH7hn6LfMcj6GbwtzSjZr0FyYTvaArffPDeZLvBV4p9
d5phBt938Lea5I9rH8FvOY3uR3+ivyLvMR17z+pdPbwGj1GsdrhIv8PoLfMZ
V9HV2G+vnWg3uqluq5224N3gf0U3S+ovkHNs/mYR3gm+O9VUbd1It9IfqsHf
g99aOSn8fxuVXZ4=
         "]]}]}}, {{}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwNyNkyAgAYQOHfZYarxk6EZzBNjxHGkq0Ud5aei7G02yVZwiPhuzhz5px0
8Th3NBARa0gmIq6GIs44Nxxxzkv6l5f5glf9S87oP17ha173q5zVMRhxois4
Rc2v+jXUMaI3/Do3dBMtjOpNv8FtfYNbjOm83+Q7fY8HjOstv8WP+gnPmNDb
fps7+gVdTOodfxevuoc5bwp7XgFv3jvS3jSK3j4+vE/MezMoeWX0vS8seCkc
eIf49n6w6M3iHx7zMRE=
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0+trzXEcwPEvE8a2NIW5bJbLtuQyS8zlgTHkjNqaJpkYtrY5ZzubzWWa
XMo82B6Ycr88wD9BSFJKKaWUIoswD3jgkim8vg8+vb/v9+f8Tqff73cKG9pq
UqNCCEMmNzOEluwQ7mIz3sNWvGpSE0KYmhPCOu32xBAqcApP6m+dJ2nT+Hrn
O86VmMfb7P9khTBiHmgp3zVsPptGn9ugZTiPNtfNNTNPb3fddNdvjL+Fj+Wb
+Th8qA3hPv4OW+w3aTN4mhfxDpzJE3qSZ/EEz8ZH2gfcz99jyr5Km8U7eQk/
iPm8Wk/zXF7FJ+Nj7RM28o/YYV+jFfAuvoB342xep3fFe8O38Dx8on3BJj6M
3fbbtUJ+iC/kR3AO36n38Hy+lRfgU+0bNvOveMy+XpvLj/LFvBeL+R79BC/i
1bwYn2k/sJV/x5P2DVoJP85L+an4O3ijfoYv4bW8FJ9rI5jkv7HPvklbxE/z
Mt6HS3mr3s/LeR1fiS+0f9jG/+KA/QGtjJ/ly3g/Luft+mB83/iO+P7hS22M
luYZeD6etRV8IF7Hz+Hq+Dz0SzzB63kVvtIytU4+Hi/H56Wt4YP25fwCro33
U7/Ba/luvg1fazlaV3yf8Kbp0Sr4RftV/ApW8l79Vnw+fC/fhW+0X/4PP03S
+36fH473ks93/g+X9WyL
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV01toz2Ecx/HfhGEHKYci5LARM9vMobkw5WZuLLLCaprJHNqWrZg2M4cN
2zAMKecLhxtnF0oOQ0phpZSS86EwMTJnr+fivc/z/jzf/9P+z+/3H1ZYOrsk
JoqiHv4k9YyizvgoWpUYRVesVyRE0Vf+DU94fq8oKrS3QB6Li6Jq3Qy+n2fx
PTKbV+oP8jhU8Hj5WDfHfgGfLQ/oVuum8RY+hTfLqbxCv493x0oeKx/pZtrP
5zlyr65cl8V38Em8MSQv1e/kMSjjXeRD3XT783i2bNaV6CbyBp7J62U6X6Zv
5L95Cf8j23RTZB6fLBvsL9Wl8TqewdfLFL5YX8e/8xW8U97TjZdzeKrcZL9I
N5bX8rRwn3IUX6hfx7/wZbxD3tUly1yeJGvsF4SOV/HUcJ9yeHg++jX8Iy/m
7fKObrfn2YJdGKyrNDNfP4gPxAWcR4r+rDyH/hiAPHMV+r/W//AHMc6OcCvc
F29CQ5h3drnZufp+vC/O4DTG6E/KU0hEb+SaK9N3Wv/Ad/zCT7Ta2yy3oB59
nF1qdpY+gcfjBI5jtP6IPIruiMXM8B6Hu7TuwGd8C+81rtvbKDdhA+Kcvdxs
jr4b74rDOIRk/UV5CUMwNHzGXLH+g/VHvMcntAcPz1DWogbdnL3E7PbwzvFM
3MYtjNS3ypvIwARsM7dY/9r6DV7hHd6GO7JXLdeiKvyfzi4y26RP52m4Eb4f
RuivymsYh1RsNbdI/8L6qc8+l8/kS/nFXpvf+wPcx+XwHcPzlv8BbF+PCw==

       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0slLVXEYxvGftXHOKahFg0qbCqTSzBwjqGjS1EqJzKHBZmjSsiJIIV2k
RVlWm5zNEmrTsGokCIIgCIL+goRaGQRZfc7i4fsM7z3Hizez8XjlsZgQwhQ9
iKP4EDYkh9DJ9yeEcAXXy2P6b3wtNsg1eN9+XrdW7pPH+CM4W17D37OXYYZ8
WP+Vr8A6uRzv2lt0JfINeZQ/hOlyKd9rL8E0+aD+S/S34C55Hd60n9AVyN3y
CN+MqXIx32MvwhT5gP5z9C6siXbsth/V5cpd8jC/H2fJhXyXfTUmy/v0n/g8
3C7nYqe9WZcjd8hD/F5Mkgv4dvsqTJSb9B/5pVgpL8HL9ibdYvmSPMg3YoKc
z1+0r8R4uUH/gc/GcjkLL9jrdIvkNnmAr8c4OY9vtedirLxH/56/lhTCdbpK
PdRNLe5qbXP5OXTGfb9czj9JDOEcttFZmuk5je5X2GPkQHfpDmXpH+EEpVE6
Vbsb1VdhqpxCD2mcFkT/f2yN3kkzot+Wbrnbf977l/r0tylTP4TDFE8JtNXd
iH4LxsmxNEgDNF9/Ck/TSYrx7HrdMrfTnvuHbul7aaH+Ob6IvgNlU4e7MX07
ZkY39Iye0m6ffWd7SwX8Yzc79TtoUjcPi/WT+kL8jkWYgW/srylfnpCr3VbR
tC4HN+t/6TfiFG7CVHxlf0l58ri8zW0F/dYtxTL9z+j3jT+wNPqO+B/VPXNG

       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ElsTVEYB/BrUbTGBZXQBYkErSmEDYmFeUFSQal5WphaLEwLLQtzTAvT
wjwl5rlmFtqiWjrPpVXUPCQiWPidxb+/7zv3vO/13Xfu6zY3fUJasyiKBvmz
ITaK7raJolNxUbSwdRSd5iKm8hTbtYqiRvmh/imT1G+kQeolxb7p1idzAY9x
Ho9yPvubf8f8Q/rZ+sOcw2SeZJwZr+Wb+rtMVL+SOqmV8fZNsz6OB1nD/azm
AfYzv8r8Sv1efRX3cQxPMMaMGvmi/iqz1NVSJZUy0r5U6yO4h6XcxRLuZl/z
K80v0u/QF3Mnh/E4IzMq5JP6s8xUl0uZlMpQ+6ZaH8KtLOBm5nML+5hfYX6e
fqP+OTdxMI/xL0vM+aD+KDPUxVIkhTLQ9SnWB3ADc5nJHK5nb/PLzX+sX6fP
ZkZ4Xx7lL7405726SaarX0iB5Eui6ynWe3EtH3E1H3INk8wvM/++fqX+AVex
O4+E75TPzXmrfifT1HnyTJ5KN9cnW+/KFbzNZbzF5Uw0v9T8m/o0fRbTmcDD
/MQn4UyqG8O5VedKjmRLF9cnWe/MpbzBxbzOJeFzmV9s/lV9Ea+F+814/mMT
X9tXLw0yJZxP1kmtdAzfq30dWMgrfMHL4b6yp/n5vBjuAy+xgO35i29ZFc5z
ONuSEs4lK6Q8PH/hXNjXlnm8wKc8z2fsYX4uz+pzeC7cD8bxGxvC5wnnWsrC
cxrOD4ukUGLDubGvJVu0jaJOrscwns253vymcP7CGZEEezOtZakz+C58t3Im
/HaE597aOI6Xf9aTOdac7dYnqLfxr/U/MkY/Wo5YGx6eQfkdnkmO8ppN1kep
NzLJ+yaGcyb35Iz/t46vpFpqpUaSvf4/vq7GaA==
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV00lQj3Ecx/GHiEJUtuzRIvs29rRaKqnJyYUZB5x0wIFkGZwwYyl7MYOD
dvtQMYMLLrjgYuzLTAhZhhm8nsO79+/z/X76zdO/55+4srRkbacgCCL9aIsK
gtU9g+BMdBB09AiC0b2CIA11zj/xA99x1n6NXrrzKj4tf3NO0U1FrfNXfEE7
Ttmv1Pvg/uV8Qm4zT9JNRo3zZ3zCR1TZr9Cb63ycn8mTebFuIa6aT5InYgKG
yg383v0V/ER/DOfrFuCK/Xh5HMbiqX0lF5sf5MdyGi/SzcPl8G+XU5GCIXI9
v3P/Hn6oP5IX6C7EJftkOQmj8Mh+LxeZ7+YHciLn6s7HRfMR8nAMw2C5jt+6
fyff0x/E2bo5uGA/NHyOsIv79rt4ifkOvisncKZuFs6bD5QHoD8GybX8xv2b
+bZ+HM/TzUCTfT+5L+Jxx76cC83L+JYcG/4/dNPRaN5H7o0YJMg1/Nr967lF
P5pn685Bg30vuSd6oNV+Q/j/NF/HzXIUz9SdhXrz7nI3RGKgfI5fub+If3Nn
nq47A8vsu8pdEIE/9sXcCQXh+yTf5BOczy95ER/jG+E7xnkc6C/ko3IrH+EF
/IJz+RC38GGez/+Qg0q5mSs4m59zJh/g6+E7xln8FxnYL1/jfTwv/OzROcbz
I955K/flCN6EOOftHMtLw++i39sm/+KNnOe5O5y3OH/jUp9JiV6Webtcbv4l
fLbwu4cqVGNa+A7pngzfC51qnmo2BU1oRJn5f79TgZM=
       "]]}, {}, {}, {}}, {
     InsetBox[
      FrameBox[
       RowBox[{"-", "3.5`"}],
       StripOnInput->False], {1.3545770391032583`, 0.10540271558720117`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "3"}],
       StripOnInput->False], {1.4022368218250523`, 0.9999183860544995},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "2.5`"}],
       StripOnInput->False], {1.5202499686948592`, 0.11607142857142859`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "2"}],
       StripOnInput->False], {1.6577905732011302`, 0.9985246827365872},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "1.5`"}],
       StripOnInput->False], {1.9334987944167865`, 0.11545085588348562`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "1"}],
       StripOnInput->False], {2.7017058061473533`, 0.9958734901084254},
      Background->GrayLevel[1]]}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["k", TraditionalForm]},
  PlotRange->{{1.01, 5}, {0.1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.559987990545576*^9}]
}, Open  ]],

Cell[TextData[{
 "This plot shows that the sensitivity is negative and increases with higher ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ". This implies that as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " increases the change in threshold decreases, and does so at a slower rate \
for larger ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 ". This is reflected in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "Log"}], 
    RowBox[{"(", 
     SubscriptBox["R", "0"]}]}], TraditionalForm]]],
 ") function in the threshold approximation. Note however that for small ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", 
    RowBox[{"0", " "}]], TraditionalForm]]],
 "close to one, the sensitivity becomes larger and negative, indicating a \
large increase in the number of infected indivduals needed for the outbreak \
to establish.\n\n",
 StyleBox["Sensitivity for ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox["k", TraditionalForm]],
  FontWeight->"Bold"],
 ".",
 StyleBox[" Similarly, we can calculate the sensitivity of ",
  FontWeight->"Plain"],
 StyleBox["f",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" to ",
  FontWeight->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["k",
    FontWeight->"Plain"], TraditionalForm]]],
 StyleBox[":",
  FontWeight->"Plain"]
}], "Text",
 CellChangeTimes->{{3.559988006365836*^9, 3.559988007140913*^9}, 
   3.560249230324613*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"FR4", "[", 
         RowBox[{"R2", ",", "k2"}], "]"}], ",", "k2"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"R2", "\[Rule]", "R"}], ",", 
        RowBox[{"k2", "\[Rule]", "k"}]}], "}"}]}], ")"}], "*", 
    RowBox[{"(", 
     FractionBox["k", 
      RowBox[{"FR4", "[", 
       RowBox[{"R", ",", "k"}], "]"}]], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.01", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0.01", ",", "1"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["R", "0"], ",", "k"}], "}"}]}], ",", 
   RowBox[{"ContourLabels", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Framed", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "]"}]}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<RedBlueTones\>\""}], ",", 
   RowBox[{"ContourStyle", "\[Rule]", "Black"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxlnQVUVU3Xx+luxMRWBAvsxD0qCiYmiomBhdjYgaKoIBioj4KBWFhIqYiK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   "], {{{}, 
     {RGBColor[
      0.47886493757765447`, 0.17798144235328237`, 0.23261829318792046`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVUlPlEEQ7Z6xe0ZU4KoHFRUTl8Sb7Kvb3V/AvqgwgBpjjDHGizHGRKII
CIh49mKCKOJPwWUYPGgygCSQgIDvpZ7xUFP1VVd3V71X1VPSkrncm3DOjUOS
kHbvXBaavlL8FEMWYc9BX9L3Or6XIEWQX5AcpBBycJdzz7C+gjPW8J2HwHS/
ZS8ofkl78lpjzG5nRhoqQP5AcJxLQbYh0dnajnz7uI74vc4kCXsP9FVv8Ywp
4JHezuZawpuP968qf9b6U/WyhuDt7CE4nkM68X0Dlw/CHoAehR6BdMO/6Wyd
uA3D9wLShe8p6NeQHm910MdatpztY31jWH8JueKt7muq/Qx+muAvj4Y1Mc+p
jh7Vwvq4j5hMYH08YXWvqjZiPAnfq4SduyNciMk0kn0Df683/NdUP2vYEA79
3rAlDn3esCXGA97wIU4Zb3gS15Fo/TEKPQ85gcO+QN+OhlVJ2u7zwv9mNGwP
pS3fRfVDt/AKwnVDeXUJa2K4nLI+W0n9r424fcWZJxH8LRpOTljdisbLYd21
rvvuRMP/CPxl0TAn9lWwW2BXQz9VL3MmavDdiu9a6CLoz0nDI4rXoPw2lfNi
sLgf0HUIaoNdD70AOY2AHPQFSCf8F6EfROPlOHK4G43To7DvRePxGOz70fqq
FPZ32KdwTha6AtIMfyV0A6QddiP0OUgH7PPQ28ijmPgFm8O8ep+1rfybeW88
FYgLckc+iB0xLAvGJf3lwfgjj2eD8UWbnDGXIc0OuePeTfUsMSdeHepN8tSi
ueFdrZotxrRpPtjv7Kle9Rx5zqgvyRt5Yh3tmgP2RKfmjz3H2V1QvQfSFt8f
rW6+V1nlM6mciDvxrwx2BjFnnjybfuZDPshLVbA9tHkvc5hQHuSJe6uDvaXz
ej/JMbmuCXb/oHJg7aOqn31JrCoQ8y7a3sZgmIwJF9bEveSV2PBM1svap1R/
k7AhL8R5WFizd/o0583iihzR/1Freb0NWb21fXoHHmP2ZhFTH2wG5pL2LrCv
PyXt/dhQbxG6JymLaQi2xr08j7Gzip+Bfi9eOZ/Fevf4/hXJfivO9qctxw/K
c1m9fT3aXM5pNnN6swr1/5DRe8Vc+/W+PUrZOXXBMN3Sfw17bEb5UJhbQhgw
nuexJ6fVl8zx350PUxZfGwyTfr2bfwELvt0r
         "]], PolygonBox[CompressedData["

1:eJwlkjdPl1EUxi/vy724wQoDiYOhSNlE+ItIdfcTIFI2CUoTRAEHQBEjoUgR
BMJIMxEbfBSagKuwUoTfkzM8yXP6uec+N+uaHz2NnHMJkAwKgnNJSc4t4XwD
zwbn+CexO+Cl3mLfYucGUpzLwndGfBxfG/w+eAK/xJcLv+MtNgHasQtBGnwH
fA3mU+wxKIavgoj5m/QfpP8y9WPEMlnuBDv9hnOnxD/iy4AXedvtE+ikdh/k
UhuTswZ/R81P7NvgAPsv+ankPgRH8Gf4RiOboVkV2A3wK/bPg5+m2GzNXMGu
Ao06GHY+/C6ojewGuoV6qvcWmMLuAtOR3aQUXuHt7bfAP/ifYLsl029ducFq
dSPdqh8swptAdbCZmr2A3QdvCXYL7VAE/8C+27G98Zj+u/hyYrupbqsZmvUL
3zC578FveB44JFZMzQy1s+Al9gbw5G8RHyH3KFiufIqVkf8jthvr1vfw1VF7
wZo58JJgfysNSUv6E/2Nat6SXxPsbdKctPfA227aSbuVe5utN+lt0py0pzft
SG/etPIdDGm+t9voZrqddtAuU9gv9F/euP5EfyPNSDvaORFMs9KubtAd7Aa6
RT0o03uo/wyfA6/0d+C/M18P/Ln07UxTrfAE+fPwL6A32I7aVRrdC+ZTTJqq
DNZTvaXBct0j2GzN0CxpUtpUz9fwa7TFdxs=
         "]]}]}, 
     {RGBColor[0.5538475048813645, 0.23069167607875507`, 0.271171457639822], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVklzVlUQfXl5r78PBKpUCARRYUMGSLCoUsI8KDKoMYCwEacsLFFKSwn5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         "]], 
        PolygonBox[CompressedData["
1:eJwllNlvTlEUxc/3fb3n1piYtUr7GRpTtSp01lbnorRFJN48iCkEFRGqihpK
BPVCwpNZvBieFf8CImKmpqe2KKmhfiv7YSdr7XXOPvvu4cbXbm3YEnXOrcYS
sKrAuZs47secOxU6V+ud2wBPjDg3F3wYuxI1Xw14HjY4YneOg3O5P5o4+wgW
T3SuAn4V7Rp2FL0duwHehC0FO/ROcApWBm7EtxmcgdQAHsCXBe/njSfgAmwc
WivxpxI/Dz4G3gKfnGg5Kle9ecRbDsplOXw3vIjzSZxvw5eOdgjfJbT1WBU4
B30UejN6Gvo9fMOIlwb/HtqberuR8y1oP/DFEyxH5VqMTeD+M3g72hTO70dv
gDdzPh99rDOftCRsDfgx+i30bdgIZ75ktELOj4cfgE+D13mrnWqu2peiT0R/
ge9kaDkr92XwXegXsKaI1fgiOBV9L3odfCe82tu3h5zJAi8kXjLxnqpfxCuB
p8Cfw0/Ay+GXozYDmgXd0V352sBLsI3gQfiywR+xDGZpCPyOt2/Qt6zgTCu8
H5tJ/FzO/AZ/xTJjVnPVfgCbhV6Az/F+T2i1WofeDT6Pvgo+HDsHLvTWa/Ww
ALzIW69U81JwxNssTYc78F1sKPwh8TuIVwlfGbWaV4C7+d50eCb2D/zOWy3U
47eqF1YftZkvAn/w1gvV7D34MzYnZm/orRJvs6CZLQa/8lZrzeRL8Btvs6Me
vAaXe6uVZr5M+XjLPZuYPZo/bAZ8PrwPfJZveBSzGn7xthPaDeW4R7WF9yXY
jOWoP4HVTjPUBf7mLbZi9oKj4uip8B70HfCOqNVEtVGP1evr8GPedly7rhlY
rF5gs53tdD24MrCz+gfoX5DrbRaVk3LTP0D/Au2kdnO7t17rzSZvOSgXzXQv
+Azf+yBmNf7kbcY0a53w06HtuHZdPT2oeeDOJGczcxteG9hua4e1y9WB3VVM
xc73tksjuZPn7Z+of6Nmukv1CW029Y0RcE1gs6QeqBd/vc22ZvgP+Je3Xmnm
f4IXBBZbO6nd/A/8bJqv
         "]]}]}, 
     {RGBColor[0.6235453266568034, 0.2965907124871015, 0.3154335348725995], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlllsV1UQxu+9//89l7WlLL6ZtGV7w5ZWEEQTI7IJRjEGxGgQsEQTQVEU
RKyQlkXCUopGRZZH1Ec10ZcSEwsPvpZXRIz7EtnEiAa/n/OZPpzM3Dlz5syZ
+WbmtqzZuHxDkWXZZa2a1mZ9vKQ1W/yBepat01qp7w/KLDuSZ9mEKsv2S7ZW
a4XkD6Use1b0QdH3pdMvnfHSuaY1XTaWSPai9jfZ5kXRVp2dJX6N91bq7Drx
L4t/TPxu2ZikNVc6e0Rv0bpTfJd0XpHOE9I5KBtPaT2q78X6btH+LtGFWs3i
e0Tv12rFhuhQPXzg3kPybYroQtk7LH6q+EXin9P+WQVhn+6r6UyHvuuiG4vY
m8Ed2puoNUf880Xs3SY+k167+Fz0kmxNF1+IX6Y1WdtviB6SD11aq4p4F3Hj
bd+Irq9HbDg3IB8aJO8l3lp38B7imkcMF9jOFPMLtXZqb1WK3K3V/WeKiCdn
ObfZ8edN06R/I4/9zdY5J9lkre2SX9X510VPiZ4v4g7u+ln22+TbL6LXtWaL
/1M0VwzvEl+I/q3vueL/Ec30PU/8zRQ+YqdD4neqiPPbVdwJHsAK/BT7gD9D
3gN/4HBcHvkm7015vAGe+KK33na688AnmBgsAmO8Hbwib9T+6jLy90gKO1Nt
E4y8YJysSME/Kd3rVegsE79ccormYdEdefgGztr1pjO1kL0l/UHxS6kb8dO0
v1j8u1XUCLUCvicZ2yywMM84xvf50lkt/lXwIb45j7NznUf8Ju/Hq6hNahQM
zde9t0tndBV0rOQnxb8pnQ/Ft+Shz53EG9wS83FVvLtBOr0p4tWWIv7EHp8+
S3H+RBW+tthOqe+7dW+tijyDG3K9XXRbET5DeQu1M0p690h/RBU1vcXyx2V/
KzmWD2eL2EP+aYr3H6uiJrYYt8clPy3+WAo/mh0f9rdah5httw+NVcRnbBW+
nLV9eg5YJR9Je52SjSnD54n5cK72+L30A/rEDOdtr3M3uox31+3nLveKZxx3
4oe93bYJFqk1egi19UUt8AuGwA9xpxdsdP/pd58gr/SRLtc+753gu4g9ucCP
MgXFL/TRpV6eNp6IK/jAXoN83u18t4teKCJHxOJmGbVFXycuyEZW0Vt63aPA
/qDx31eP8+jxpluLeNcmY416hPaY553dxljjiIhJXkZNYo/6+jVFjf3mGG5z
7ugJTdbZ6b7wf8+FLigDIwNFxJL+N9U9EL+4izz8mKJOqVewj6zZOeIs/Pcp
5gVz4xKxlT+/p5gx3H9fGT0J202Ow+F6nBlhzI+pok7IUVUFFsFkk+jVKubB
J547DcYGPeaA+wz5xW6ne+Y590liiT/k5DXjBsyccj8nrkU5jIs+3fWVbH3k
uTHoPnlU8i9l570qZtFp+4EP5IJcXdaZTu1dSdFTu/PhOJ12rM4ZM2AHjMyq
BUa7PAvIFTV6xnX6Rwqda+6vnxdRV/StFtfXgPNCTG5Ib470/0rh34Bn8bcp
5hVzfmQZsitlYGeH89Lj/4R7y6i7br+L3B30TGl3LSwR7Zetr8V/nCKHF1yD
zL09/l8ZVUZPOCmdfSnqrcN11GcMUL9H6oGzIeeOOkCGfeTk/6J5cHHR8whf
8TkrI/a9/icg/vs975i99Bbqg9nGjDuRwn6/a5K5vcv/FuCM+35KMT9b3V+6
XRvEmvkAtvBzb4p6m5lCr99v4Sx2yDeYAqPkoM1zZFFyL6yFbzNtZ2kKrNGf
+z2Xmt1jW/0PwNs3GAv0Wv5ZxrvngPPpxmeHY/5AijwRzx8cf/wkX8iOOA7U
ZV99uF+ed79Ch/3/6rwe74Gndw05X5f9j8e/HvWDznemh20TnB/yv9O/kzEq
wg==
         "]], PolygonBox[CompressedData["
1:eJwllNlLUFEQxs+9es/VilJb3gJN0+qlRDOKCgLL3FosMi1bbA/K9r2IyCyk
DbPdpYL6D+qtCFIfeq4eI6J9V1Pb+33Mw8D3zXfPzNwzMyejtq5ia+icq8ES
sfFJzp0FVOE85Z0bBz8DXwpvgJdGzo0GP0pwrjl2bgL6OfRqfI3oqfgK0QqI
lQJehm8vWid2E5yI5YGPBc49I9ZG7DD8MWeu8f0G+CH4QWwl396G30fLgXeD
V+A7AO7CbnmrQbVMwj7AP2O54FTi3wN/9KalwO+Cc6j3NPVWcr4efpnzXejb
lI/4MXwmPJ/6PTj0lvsI5++g98Dz0dPgX8BD+GYWfDLfDwYP4JsCH47eC27H
GgPLcSU2n7QCeJ+3mlRbB/wiegr1FVFfHvFC8s1HH4W+hRoWgt9jL8HZ6O/A
Q2PLrTsfBo44cyKwGvrRF3g7exJfjPYa/hyexZlX4D7OZJIvB/4EfQm+Hei7
sFr4cvi+0O58PbwKvju0nq6NrEfqlXqoXuoOdZd12GK0kPgzqGUk+f/C/2DT
4CPgP7z5pE3H5/j2LfwFZ8dC34Db8GWgN2Pt4ATiHwfnamjRv2qeEswnTT1R
b+T7Bv7u7a7r8SVGZsLqYTfa3Mhy6U7Ox3ZHuivVHMAD+NHAZl6z/89brQ34
vOLF1ivNTBTbP+nfpsJ/gZNjmyXNyCBwD2cmOovZC/7p7Vv1TL3TTGu2tQOr
1N/IdmknvBK+OjKsHqlX5aqf/mVjA8R/Cs9KtJ6qt4v4RguuGdIszUHPdLbj
2vV53nZXvnJvO6PdUcz+2HqoXm5XPZxtgT8IbSe1m4G3XiincpdFNsud2KXY
7kh3pZ7/9rbz2n3NuGZdNat2vQkJ2g34hcB6vplv27zl1p0lRxZTsbXjn9Ba
4OmBnWkFz+abMc7eLL1dSfCHod1Bhbc3SG/RfqwG7NDTnf1TK3xdZJpmXrO/
Br4ntJnX7KeRoymwnJvQiiLbJb2BegsL4RnO3hi9NTc40xFajGpwSWS7ph3u
JVaZt7dWNZdqHr29TaqpCHw9trdROa+CiyPbfe1IE7zE29usnMXC3nZXOZX7
PzLwo+k=
         "]]}]}, 
     {RGBColor[0.6850408508478432, 0.3829597003449814, 0.36855624716559376`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VklsVmUUfe9///c+UANlbOlABReWUhUILpGx0ErVQIzQOqAVBFFBowvc
qFBkMAWVhJ8OdFYcAXWhie7UBaML1BBNlA0yqhuNQyKJ53iOi5d73333u9+9
505vWvvmlZsKSZL8gyfDUzYKfJokZ0OSnMeH/cUkWQD5HsgWQaESdGxMkkbw
Y0C/hM7z0PkC9GqeJLOgux/yX8DPBn8AfMAzH/pF0CbQq9C9E9+WB+mnQXb3
4lmC9+ui7hoN2pnq7JRU/jSDnw+dSTjTCnobdE5nskubvfDlIJ7l4JtAT+Jp
Bn8sEz+U6jt9oA5l31unDTpXIG9L9J16fL9gHBjPdNy3Eno3gRaCsCJm9J2Y
VIFuDPJnAnROgC7LZJ82rzh2YkbsyqE/PRV+d0Dekum+heDvzfV9Dex1Qf8i
5HMg3wV6HM/iRPIDRZ15Gc8xPIsgvwx6qaB7V2XiiddW0I5UOvSdPG2WYOOn
gmKkv5d99qLjp/x4JqyI5ZQoX2tAJ0blpQJ0GD6/Dpv3g47g2Qf+IdBVeF4F
PyYII/KNsDkE+WvgV4Nuge1XUuFAbIjJPPA9RflD3D4HrStIjzXBuiQOM6Li
vCUqpk7HeGtUXudE5bDkPDIPrBXmuruoO2j/Leh9B/23QQdhYyaeZZAfhd/f
Qv4m5NWpfF4K+TXQBjxNrqUm19h46K+GbBTiKsOZpTg7DrTKuBG/uQX52eE7
ptrO4kz1xJ7YXlCcjHENbNWCXx/kL/1mXmtSYU4bn0GnHvx7UfjOcE8xpt3Q
7cP7QCod+t+fSoe6bc4Fc/JpLvk7UXZnWp890eu+4Hu9z9LvBvswOihPA7Ax
0TjUu0bYw5wnL4BWpOpl9sIWz5APg3yqjfJ3Z0H+M2/MH8+35or5UeiW3D+s
GfpRbT9Zt13uC2JErFj/fGe/LHQNdDvvzAHl7AXSLvOsux7jnMOnBYghRt1R
43gfyJW7dfDn+qj83RDVL+yVWuegylg9HtRj46Piq/T3G/G+AvJpUVgwLtb/
ZGPHPvszKrZPctUU+4h26+DjzUXVYymqlz+Gzn25MHkEdz7o3hx2bvt8L23R
5q+5zpWMM2Pa55pkXTe7trNc2PwVNUPmeqYwpy96ju0oqHZZt+tzzabNQX1b
59xv98xin07xO/nhKDtPBNVjjXPKWKuN4V7HTf9pa0lRtfR3FA73eH9Rzh3T
6XlB+7cXhBex2phrnj4TNEsq3WuMjTHeFZT7Ju8InqF91nqz+531zXsafdfv
QTH+FpTfXcaBM3uH+R7Xx0HQJ6H3EuTtuewOuq6I6VbvgrX4tg38U9DtKEjO
WN53DwxFybZZn3U35NzRL/pHnLgfOnx2bRC27CfOKcbBfp2AZwTyQ7l6gX7Q
5kzPWM5a1s5u92Z7UF5Ya5fsD/3i3uL+6oL+Y0H1xF552HuB+4F47zQmY4N3
O/TP4Z4fM2FR4dpiXT0dhOEG2rF97skNQX3GGUksqU9bZ72ji7nmxwXPH84b
zp1y4827OOO428/53o+Mwx9BWIxYxh79IdMcPRLFH466n7gTc+6KrzP18NEo
+3fj7BvgvwF/JGiXnvQ+PWRMPwg6d8Znuz1rW123rD/mlXFwjzCWd6NmJmdn
eZSsLKj/2c8/m7IfWJ+0Tx9aEs2zPe6NFY6JOPC/jXuyJQiTQe85/tvN8r8b
Z3////PfM5I1xNlFfJmvPJffMVdsjHFqVD2ed44aouKb5PlQ4Xne7f/LwVzx
MK5K3u+dzt3OO1mTvJczo+SztLPF+eXMm+qe2uT+WQebzwbNQe665xwP9yfz
ctz/bP/9D2byrzqqD8YF/ct9lekfcjCKH4jKGXM3zztzwLPrjOuBmM+O+u+Y
HHTPCd/VD/kp8H1R/VHr/mVvM67DQd9P+1+Xu+mUedbENev3uhbZE/8C/mhb
8Q==
         "]], PolygonBox[CompressedData["
1:eJwllElsj1EUxd////V9TweqhKItykJVRSsspUVqiCkk0qohWh3U0JrW5jnm
RWNuaWsoLUsSNmKhgg0SFlhJSbExhVj4ndzFSe6559433Hvfy69pXtaUdM6t
Aimgyzv3PHLuGbgcnFsfO3eQgF7Qid2K7wVaP/w+fCvxh7EPgUZ4Fnwm6+yF
18KXwCewcAH4S24CXoxeDs8c4Nxmb7F7wDriA5iOfSXh3BtvOcqVL0bbiG8X
9k5QDX8IihK2xx9if6G3wxeyx0/sG2AEvID4H97W1Nrzic9i/wfkT4K/5053
yB8FyshdCM/BvkX8Amd3boN/97bWI5CKXYivEr0CfRL2XfABexkYhz0FrECv
ghdje/abRu4/9kySvw0cgb9Fv45+KVjtP+O7R+wI+PzIzpSNvRzfUXKzwVpy
pwZbuwq9BPtGsLUuoV/DnhzsbDpDEfb4YGdTzVS7fPjSyGqgWqgn6o1qptp1
or/WXeB98NHB1p4ItsO/kPMxaT3tx76I3kv8GPQLwe6gu8zF10j8GHyX0QrB
DnhesFprZnKD9US9UU2HoFeDXGJPggrWGuTNnkPOYOLrdCb4abAafSi+eZHN
sGa5Dt8+9n8COrAH4jtB7Gz0dGIz4MfhZfAYng4/lrAeqVdDgp39KbiJdivY
2VvBbewGb3c9o34QXwN2k1vK+TPRukFLwmb2arAaqpbyfcK+GayWqklXsDel
t6U7bED/Bu+Dl7DeV+x2Yl5G1pM73t6M3o7u2ASP0EeyVim6D/YG9BZewTvg
KcE03VF3TYXPiqwGqsUAvYGE+dKwF3t7G5ppzXY3eBfZzIwNVgPVQr4e7GHB
7q6ZHR7sz9DfoT9iQ2w9UC8OgAbss8Fm+TH8HHaPt7PqjrrrIFAeWc/UO/VA
vdCMnUcbCHISFpOpWfJWK81ki84W21vVm9HbaYttrxnEpHn7Q/SXqGeb4PXw
/Un787Z4+9P0t+mN6q2GYLOiGqvWGcFmSTVT7bKCzabOpLNVkn8qYTNcQ/4i
vVlnPf2NvjK22c0DtWhrYpslzXS9+utN0xpVaCmx/R1aI8Ju9lZLnVln/w/u
H6Vo
         "]]}]}, 
     {RGBColor[0.7402789786613376, 0.4716799350593547, 0.4220637237186709], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFV1lvlVUU/e797rnH6IPBBMEJrUCBKpS2IBFap0cNbSmCGmoiLYUWFZwH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         "]], 
        PolygonBox[CompressedData["
1:eJwllMdPVVEQxu/zee+xLOwgdqSj0gRUENtSQxEjatBEESI20Njb32HdaBBU
RARB9GEXbLDQlXVhYkwUo8ZoDIgx/r7M4sv7vpk598ybMzOxFbWlNUM8z9sI
hoIe53l/wp63FSyF//Y9L4WA9+hWeDy2upDnpYN96MugkHPTiPkEXwUGie3A
H4E/Ij4f3g4ewyPgC/4ykATvDjyvIGRnetH30JnoPvRN9ErdT2Kp4C+6xDef
vqFvHURvgm8E89HDOT9Pfwi8xjcAInxvG6Z++HlnuR7H1ow+DCo5uxnk45sH
NkgTnwvfiT+R2FOgkm/H+ObTnQvwZ4H18Gz8afCH4Bf6Gvo+fCJYgY5Hj4e3
Kp7zHxQDjwU/yGc1thnwRvAO33dsnYHlrNy/Y7uDb5Ly9Sznheg48JPYMmwz
ndVItVINVIup6CJiE7g/Bj4HrEPPRafAk529RZbyJb7Dt7u+gdv4dqOT8Z1R
DfHXopPgp8EW9BF0Vdj+8wPiE0FDyN7wAL4EdD08A+xHfwZpIeuhPt/u1N16
40FiJ6inQpbjbHSTs9qoJlfgVYHdrTep8a0n1Zs9/N96fBHwFV6MbQ++Mb69
nWowRd8Hy+EnsI3CNzKwXqngZwR8O7Y4fC+IOad+dFaLHGx34Vd86x3NRB26
C+Sh20A3/Cx4HraZ0GxcBa/QL0E9vk5n3+rl/C39P9/u0hmd1RvprQrRk+HZ
znJTT+bo/Z35ThIzmrPp6PKw1Uy1U4+p1/Qfo5z1pHpTMRnO3lxvvxY9y1mP
qddK0Hs5n+rM16h+9a2mqm05OYxDXwgsd/VwNLrd2S7QG193NoOaxQpwyLcc
latmIBpfh7NeUI/ccHaH7srlm8P49gVntVLPNcCj8DeFbMYy0W3gY9h6SL20
BF2tWUB3cb5UMx+2HaZdJpt8sj1zdofu+odtLLEt4C2+N+AS/mXOdp92knaT
doJ2g3pcvV7gbLb15kfRi5y9vXbcMXSRb7OomW7WrnHWi+oB9YIL7O41xATw
Yt+4ZniA2OnO3kI5KbeLznJTT6u3KwLrXfXoDvx5zmqtnaDdoB2rXduP7Sn8
iTOuGi2GtzjbPaphG/HVgc22ZnoX+j/BBMBC
         "]]}]}, 
     {RGBColor[0.7862803993928642, 0.5638709069910093, 0.47613916089811154`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV1lzVkUQvd/97v0GtdyeLPWBpVApwvLAFkQRJSlDcGERxAcJ+qCWBAjI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         "]], 
        PolygonBox[CompressedData["
1:eJwlldmPj1ccxs/v9/7e94ja4gYpOsQWigvLGHSzLyFM0fSmxQXR2oOxTTHU
ft3/oLEGM2Ob0JlBrRlaate5kDTWXjSamjBBP4/n4kme53y/53vO+13O223u
ktLF+RDCAlAAvWIIM5MQnoLjaQifoOfB/wUn0Z1AZS6Eb9FDsXVEH0EPI0jL
LIQZ6G7wk6ydgjeDBvh2Yr+GX422vWX/b/Ae4Ev4Q1AtX2JMwj6Iy+RahNAT
+wxsj8Ex7HnWBmMbwRlt8W1kbQj6d/R+9Kf4z8f3JajB9jk6B1/F+Z/Bb4DR
xK8Df8Cf41PE3n/wqUOfAy/gJdjPwk9gPwzvh08tuj7aV2u/wL8GGxPfWXfv
g27Gdzbn9YYfBR+hf8Z+lFivUsc6CE7DW7GnBJ4HD9DnwMWcYzay9x6YgL4A
7sMfgIk5+/wJr0v9LSvwv4n+EF2Tcw3e1wJs5i6TyVF7cteE7ovtKuggO+dP
gF8D+zLnTLn7D5wn3liwEL6IGF2wDUdXqd5gDXoPew7B/8bndPQZOkt3PoN9
ImtLsS0HP6K3gbE533GqagvWYSsHO7C9QX/M/jmcdw99Kjq2aqRaFUf3XrF6
JLpH1atP1J/o6an3qgbN6Gmpa/EKXYM+Bh7p+1RP7l6F/itxTpQb9Zh6TT7H
Vf/o2E3Y6/AvxV4W3FNXomuoWiqHymVldK0Vs1r9xNq7vHuyHN+7rGUF5+AO
vF3mXlYPq5dXp86tZqwE+6/RtXiDz9nMENdMrk89k5pN9eyZ6G/St2mmVmKr
z/ztmumy1DOmWVNPPoNvBN+jvwOj2T8OLIIvAZtTr8mmHtgkX+LtZO9usCF1
TpQbzegq9PXoWtdy/1r0FrAscQ+oFyrQixOfobPegYEFz4Bm4Qfsu/I+Q2d9
Fd376vldyjVrN/J+U7rDD2Se/Z+oSXfss1K/HXoj9Fa0yTxbm7C3hl8EY9g7
APtbvXWpue6gu1wATYlrptpdi36rdCfdrR7Egmt4K/pN09umtdualcy5Wcha
Z2z3Qf+Ce1q9rRnSLCkH49FrU781mqmR6L2ZZ1MzpdmaFn33Mvynw6dEz7q+
Qd9SxP4K7OtZm4ltcnTu9cZtxdZV+Q6uwSRs21P7auY0e7qj7qoeGKO3OPos
xSzV2xPdC4qhWKPQSeIZ+AI+K3p29cborbkU/dYqh5fhg8E3if8R+ldoZjW7
Whui89TzwTEb0B9k/pcoZ8rd/xp64RQ=
         "]]}]}, 
     {RGBColor[0.8241581772825048, 0.6490528233921256, 0.5319653453014015], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFV1lvlVUUvcN3vnMLLRBBfVCMYDQxagQeNFEIgwgyF7QocUajFhkejANT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         "]], PolygonBox[CompressedData["
1:eJwllMlvllUUxu/3fe99b6mlRVrcGIIMBhw2uJAEMAhB0DKIhVLAiAIiYSoL
Q2RQELAqlJap1BXBhQtShQXDqqKIVCwEaEGwyCAoKP8DYPw9eRZP8px7zrn3
nnHo4jV1jcUQwjKQgU0phI5SCMfho2MI05A/RC6gPIk8EuxE18rZB+h+RM7Q
lcAV5CfzEMZzYS8Yhq6XsyK6SYUQmpB/Rd8P33LQDQ9lvIP+U+gN9PXRPKH/
D99KbMZy10vY3JQOvMpdnWBy8h26qwz978iNyCfwb8FnDXwgeAWeg9vRMSgW
BduD/Vzk/YgDFCN/WcpZC3wX2I1uEfJ2eDNoRb4DrvP2LPxrsH8O+SD++9Gv
wnZfNG8DK5Frcr8tm2r4Rc4m4P8Y/SX4ArAFvg204LsMuUf3gz3IX4Kp8DOg
Ht057qjAdhPYgW4AclZ0DFXwxdg0B/95Cfxycm0i8i+5Ia6afo7/Z9G1OQlq
sZ2RnPvN3DEdfh77SsnKAbZd4DDvvaH65s6RcqU/nxWP7g3lULl8Hvlr7prJ
H6rJ1wbOvkF3jLP18CHofy64xv257xTyaeQXka+hfyY69vX41CF/m7u3FHMH
fCv6iei/B1NVT9BVcM62R9dYtVYP/qC3QAX8CfUTuuugX+acKrc3knWKWbH/
izyHu/rAA/hp/Msz+/yB/H5yb2gmNBsZMY7J3HPqvXmcvZz5TLq7ybXtBX/B
L2LzVsE2JfTzsR8HHw9SmSE+gfsGYfsPPtXIdfjch19I7qUNvN8ZXTPVTjP5
G/zt5N7awdmz6Gcn53IK/m/C3wNNJffMu/DVoL3kmql2mjnNnmZUs/oR+qPB
NVwH/zi5loeQP4GPwr626B2gXXBbPctbVfjfgc8DbcE1uAX/M1m3VTnEd3Xu
2T2i+UX3VO7YNXOavaejY12L/Uz0e6NzcR6sSJ45zZ5iaEO3Kveu0MxtRn4Y
3VvqYfXyO8m5UQ4Wwjcmx6IdeCD6T/qbZlSzOj95VygGxfJd7ln4CnkEto3J
vVIP2pGHR/9tGDYN8IbkWVIPqZeWI+8puQfUC68l97J23JZoH/kqh2fgg7GZ
XPSOe4T8RXQutFO1WzVjmjX17Dl03aAmc8/cS665ar9Ob6oXk7lmULPYl7xL
NYNXk3eMdo1m6if468m7QjO3Tfs8upcVw9/JO1G7UT3ygvKXu5b6g/5yOXdu
1OM5tv8DwvvBfA==
         "]]}]}, 
     {RGBColor[0.8506257197060231, 0.7243900216593757, 0.5902505789827792], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1V1lsVVUUvfe9e+59KBDaAraAUxQngokGDfihGMIXoAFEoFgFx6jIpMZZ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         "]], PolygonBox[CompressedData["
1:eJwtlVlslVUUhf972/+ciwxB6UBTBgmiGCmaCCTwgBDDk6AJEsBCsUDjFGnr
gKAyOGJCpEIF2lrmoJHECAoapkcipEgLGGRMSwtYAjIE8Q0Tv5XFw8rd6+zh
DP/e6w6ZVzO1OpskyUKQD55Ok+QgvzMgxbkkGRaSZDIBv7L2H74nQVcmSSaw
VoyvE34RPo34IuJHw9uILYf3h1cTU0fsTrAKuzomSWMeufiPEjsLfoz8yWAV
/Aa8BN8M+N/YC0EHdjnYkHoP7XWAPUbCU/hY+CZ4O7yK+DZinwd18A3s+Sx7
/wVvxj4GHmL/1WAN/pupfRXgBvaX+E9ht1BzBLW/Zu1F+J/gTWp/Bn4mdw/Y
hu8c8Y9hDwfng99Eb5MDT+AfBJ+E3Qt0wWvJbyZ2I2iC/wMfzF7/Un8dsZXw
L/BNgc/Gfgdshm8FzcQXcqapxH/PfUfAC8gZT+1xrHXoLsQX5vsOl7GXgx/I
/RFswr8i+uz6RvpWv6d+a9VU7TbqFen7gOPYo/C3Ersb/jm5C8DpjN9kLb6v
wAsZv/kr+E6QU0JsA1iHrwQ+MeseUa+chJfmuQfWw3/TN6L+SfYvY/9l1Lis
u4ON+K5F95564jp2UfDb/sRaYfAb6a1WUG8OdgU5v6hfwdpgyK4As/GNhlcR
vxu+JnhP7a07HMb/HjVmYX9LvcXYZ4i5nbjmWeyO6F7tQ85F7AHk12Dvwz+H
/CPgQXhf0IW/M9pWz6n36sGerL/5HXyl5O/NusbAnGdOs1fJHieodSG4t3QG
nWUMqM13z6n3NEOapSJwlXpD4Y3E1uN/Q3dJfVftqb0/jH7bHfiXalbw78L3
HBgaPAOaBa3VBc+sZrcM3MP3cHAvqycGYy+KfitpgrThNGt3E59xEHepiP42
mvFh+B9gbXy+e6I/sXOjZ3UlMfOx50Xbraw9Snx96ruoJ9Wb6nH1umZesy+N
kdbMJ/4PfD3gPbLeo2fOM6xZno6/Af9T4BL2d9R7n726o99OPaveLcf/DHwC
6E1uLWu3Mu6Z7fhO6cwZx/TKuaZqN5FfE52jXM28Zv/x1NqhGe0HXxAcK02s
wW5U/+dZE6QNH0SfTT2oXizDv4P33MLau9E9rF6WppWS/1LqWdBMBfZeEv1t
dUfd9XV4gfSGmNeiNUPaoT3fgn+TurY0RlqjN9fbS4Nehr8drVU6g85yM7o3
r4Fb0ZokbZJGt2IPDO6Vbvhx+KfRsXqzLak1Tlqnnl8ffCadTTNzKboH1Yv6
z3kkeKY0W/tBQzBkHwCN2FtTa5M0Wdr8arS2S1OkLdIwaZk08Qq+T6K18OD9
/zpplLRKmtYiPQvuJX3z1dgfRf/XSEM/xs7l/F+kHlOvzUz936M3zoO3R2uD
ZvAQvv8B0xjt+Q==
         "]]}]}, 
     {RGBColor[0.8639078993609766, 0.7848926913288319, 0.6475459257353361], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVklMlWcU/d7wDw5dKsNjLOjKsmnpzgU0cefGFYpCwl5L2+fa1qrLYpu2
DpimGrdGcIOauECEhzg0DSiTopgIWp+awlr0nJ5j6OLmu//97r3fnc59r7Hn
6z2HsiGEEigHOpgPoQ3UgI960C3wdThH8uLvBt2NmK+C8Sj4paBzzHyl5RU4
b+N7FjQDmgDN+Zt+yd8B1cch7IJuQyy98SC7WujchJ+a3Hoc85B3ZfUW31nM
hDAM/nqQHvmPtvy+Bv53+B2C7m8423G+yMiOvofz63Y37Ye+S86FtZkGPQQ1
wfYR7IbAF3mfV6zfJJLviBBnGkIz/E3jrdeQ9YAeB8XO2jH+9+BXQOWMYmJs
q4nsusGXodMKX29wfwLyFvAbId+a6r7LOp9BvgCdb6HTB1knaAHykzj3g54E
xcTYtsD2HfgWyLfhzc/Bv4T8aKI+7mbPXNtK+2+G3nPoNOEccw0euD8zrgvr
wBpdDaoLeeqynqwxe7HkGtPuSlbxMbZV14Ezx1z7HD/7053RvHCGtoKmwL9G
zM3g3+A8B7oAn4cTzRpzoO4N58Jv+v4X9MjztGif9MG8mC9rytouwt/xRD37
Anx/LF/ncJ4CvWRtIhH5Gtidtpz3lalyaHWv+NZ1576c1xweNl903quegXbz
rENFqr6wP8uesaLvVpzLWl5xPvYsrTlPzhpjYA03wc9OyDakiuWFcy+5T+wX
a8y3iMFBxPxpTjO06ByqkNd98Huh0+961xpT48Yb6zqAszGnnUAMUYe51xu3
9D/v3cH4uxi7cfTQ88K42Ocxz9i0ZePeS/R/D/xl76Y73iV1xhTvGxxDk+f2
L8Q8A34734317pDfYy3fu25r5tmLj9+sLWu8Zjn3X739E0vE1F3478gIg1dd
jyX3uphIToyWvBuJrblYGP4S52ReM8H68py07Qb3Lk1Vy53eS5+kqsE++KzO
Kh/mcjESpnpjxd3jGZhwj1kr4p41p82FSDrHEmGl2dgvxNp5+yPdUec8+BXw
TyH/JVZOe53vT7Fsict+z8l33oUdrjXf5N4k/7d3Dmecb/CtX2PdddgncdDu
mpfhq8BZTxR/dV7+XiXi/8H5FlTD/WHdJudJWa1/p9i3GvOMj3Gexfs/x9qT
rbHwxTljfXsTxXMaOptTzdYD6PwZadZ/TBTjV//Db5ttz3gm6IN2B733SW3G
L2tw2TPMOW1xL+ti+WCfC1n1mJjgO/x9LGfWZ4W1Il4HvUtrYXMI8kKq+6J1
St7R496lVe51pfcl9+qUsUfclX1H2clY/vuMnWrbEgsj/m/AuIgTxrbseeYM
zxp3xB9nf9S/17PexRPuPWfgQKT9dCmneZ3zPevDHg4Yd889v4zhh0T63yfa
Ve3eucQW3/3vdywWbjamyrXgelabHw3r32PegVdcz2eResGe/BEpriOJ7Cps
O+nfaO7+eeOa+CZOiJdO3H8A2jlZBg==
         "]], PolygonBox[CompressedData["
1:eJwtkstLlGEYxd/5Zt73+9Bwnc5MJk5tAhehuWpj0K5Nq8pK8A+wC7Xuhi61
CERLuljbqNxIQes2WehoEFlEUWjpBLUO+h2OiwPnPJf3cp6nZ/Tc8bEshDAI
KmAzD+FTKYQuxC/4cAzhC/HecgjvUwgXiX0mfwLMkmsSq5ObB3PoFvkavd3o
VXK1gjPpHyNWh0+Qb9E7Cuap7yA2RG6Jmq/oFVCv+Izf1O7jjD4e+J36BnwO
vEJ3ghq8E7TBX9K/G36G/h/w1/Qf4OzbxM6S3897PsBb5BvoY4qht7mjWvGf
9fe/YDHzn//AV6lfQD8HN5N71Ks33IVPJeeGQT98JtqbdXCB/i5iQ5nf2Efu
DjhZsoeXyL+LO38jP0ntADitu8Dj6DN19hR4hN4CvZnfvEX/evLfRoh9hD+M
9nYbjOc7HmX2pArvj84dJdaNPojeKPmNeusNep6VPQPNYm9y7RH0N/Qauqfs
mgfRM9asn4L76GrhWcvD6eQe9WrGmvUVzh/hvifUX4O3FZ7dYfLt8Mu5d+kF
sSV6f+beRe3AP3RRuFY7p91TjWqbqim8o9pVeXgrOaacPH9L7Zvo2chDeXko
2bsGPXsK74x2Rzuj3ZHn8l4724Rfzf12eSbvTkXvrjzZVdgDebFJfhl+PTfX
n++hzyfPVjul3foPIBZ0Nw==
         "]]}]}}, {{}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwVz7cyRVEYhuGlkEOHIzNCg1NwuBClVLgAmVZWypmRL0cYjkyDSjpmqM14
TvHO+3/f/tfae1f19LX1poQQRrGRFsI6ulNDKM0IoQwlWNOt4jc9hB8smTvs
3PAiWnAs9/MVL/A8YjiS44i4p4VnnT/kaT7gGY5xhd1KvJrz7L5wuZxrbjfn
8LW8b55y5pK/OYEr/Z58gUJ7zTyp3+UxnsA4muRiu1EusPfMRXIEWXI2MpGB
uG7H8xHnTjmqO+NtDOm2eJgbeZA3k//PGzzADZzvzAl/JtF94Q0feMefvtZ7
alCNc3mOvziBOvN28jtQihJ06le4i+vdv2y+xx2e8IgHtKLc81v+B1zoP3U=

       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwVzkkyg1EUhuGrSGJMMDJQCqUrbMWE6EUvkn+mZwWJvhnZjdKWdgFJ9BZh
4Mngrfd83z2n6rako8FcVQghg4FYCLuJEC54i3ewjX55gzexinWsoU/fFA+h
m5O1IZS5UW5AQk7JcX6Vz8w5N/f8yz940Z/Kd6i318VZ/Qln+JhXuLPybjeJ
kjlmt8h1co152FzNj/KS/UV84Eb/zm948HYoL5ivuNf+NR9gTrfP89zBs7zH
0zyDNNrlSZ7CGCYwjjb9KBd4hPNc4jKKuJSH0Ipl+Yif/OUZX/I3PnGrz+t6
/OvcHOmycoQcCvjTN1du+R/inDfQ
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0ccuRGEYgOF/JMpi1K06YuE+9M4wg60lwh3oZXAnuAPRo/feZm6EBM9Z
vHn+7zsn/8lkEmPTyalYCGFcDfkhbBeEUK8T5x9967UwhAO+8F1vuvDOuVbt
e82VHNKObsx3utWMecJ7s5xkFZvt59jEebawmm1cYCsX2c4adnKJHVzmA/d4
z112cYWn7n90ftK++Znd6tGZZ79M2f8xbv5yDkUhZFliLlatc7/nA+rToJKq
s08xE/1OrjHNBCvccch1Xbrjw/5TR+ZhbvAq+p5zVsfmHEc0qmvPYu5I2+ex
1FymnHmTW9F/4lzORv4DWCQ5cw==
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwVzUkyQ2EYheHfAEUWoJmlSsRc3yasgNiBqkxjpGc9GCIiiUgE0W+AHWAB
KFR5/sFb7znnfvfe5MpqrtAWQsij2h7CMp47Q2h1hLDA83hCzv7IN/YsZ3CP
B9zhFtee7bmbkyvcive4su/qs3KZm/E27tjRp3mbZ7ifp3iLJ3iTJ7mPx3gc
wxjFCHrt3b6fwKv8Z3vhLv1XXpJ/uKkPcRpVLNorfGnfkAflEpf5DA37up6S
T7kUjbp9TR+QT/gdbyjqRT6KO47xqffgwDv7qNnO8WFrxH/jIv5Pr/MXf6OG
pPtD/AOJ2jyu
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0EdSAmEQgNF2IbBTFMwJXSnmg2iVNwBzAtOFVMCEgi4N9/AGegGtwpVv
Fl+96f5npmqmUK5uVLoioqT+7ohGKuKFv/pRLR3xxGu2WOcXv9XUpfmRVzxk
yfNHLLOHefsB5TSkQfXaj3BUwxrXmLL2W5475iYr3GZNu6qad3jCPdZ1oFPz
Ps944z23aqhtnuA5X53fub7Xs3mSF3yzf3DdTL4z+RZNqaB3Zy2uua/Nac3o
w77Ddfs/psxpfZqzmYg+Zsw5zjkvalYLmlfefonLWtSqVpL/ZP8P1HMsRA==

       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0Ek2Q1EUQNEbyU9JEozAeNCx1EIiag1Go66CjqKvGIlBKDqxVjTt1zjr
3HPf/6/xJrqHMwe5iGihmkX0ihFnpYhTtPWs7vAc36Bi7uMXD2iUI3I8iSP/
fPrmCy841lP2J/ytf/CKgZ62/+O8LuBDN901xJmuccF5lr5BCUUM21e4inJq
1DBiX+dGmjGKJur2C+5b53nu8iLfYhkbeok3eYXvsIot3eJtXuP79A7Y0W3e
5Qv3X+Icj3qM9/jN+ZX5Gk96nPf5Pb2huYdn/Q9eYifd
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwVzzdSglEUBtD7o4RtWBkqwxJQCWasbVyAbMIIDaitlroAdSm6AzA0igJm
8VCc+e5378ybeWPb1cpOEhFb5NIRlUzEJmtssE7WPslGpPjTQw5kxv5H/vLJ
N1+k7d/lB1369Bi1f5VvPNPhhRH7kAl35r73b+WAnrksu/LG/YlHTvWS/Ym8
1h+451gv2jflld6mRUMv2E/lIur6HKusUGPRbdLtyDzLMkscsuA24XZgnqFM
iX3m3cbd9szTFCmwS374L87NZ1wM/0+HlH4p/wGFiDTi
       "]]}, 
     {GrayLevel[0], LineBox[CompressedData["
1:eJwV0DdSA0EQBdAhwFwBEhBe2Axh5AUcgCMQEELhvQ9ACBNDToi9D96kiAtQ
vAledf/5tTu1m5iem5qtCSHM8FMbQpHHuhAGueKST2fffHFRH0LBPDcfYscH
Z3Le+al5L7/zRkXOOT8x7+RXXijLWefH5q38zBNHcsZ5Z0MIh/IAk0xwQFrX
odu39zNOiT3GdO26XXsfRQrsMKpr023be8mTY4sRXatu095DlgwbDOsSunV7
Mt4f72GNlK5Ft2rvjnfEd7HCkK5Zt2zviu+J/1ROmfM02Ru5sf/65irXnlmQ
l1ikKv/xD9goMM8=
       "]]}, {}, {}, {}}, {InsetBox[
      FrameBox[
       RowBox[{"-", "0.95`"}],
       StripOnInput->False], {4.99490026596121, 0.07944893817082639},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.9`"}],
       StripOnInput->False], {1.0801191596245683`, 0.16910714285714284`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.85`"}],
       StripOnInput->False], {3.058808842259622, 0.23549392326742485`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.8`"}],
       StripOnInput->False], {2.070202099486516, 0.30841480663951143`},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.75`"}],
       StripOnInput->False], {4.033232917833112, 0.4772683179585912},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.7`"}],
       StripOnInput->False], {4.715000000000002, 0.6379916721228202},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.65`"}],
       StripOnInput->False], {1.0236499413928613`, 0.8762500000000001},
      Background->GrayLevel[1]], InsetBox[
      FrameBox[
       RowBox[{"-", "0.6`"}],
       StripOnInput->False], {2.635734734687508, 0.8585714285714287},
      Background->GrayLevel[1]]}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
     SubscriptBox["R", "0"], TraditionalForm], 
    FormBox["k", TraditionalForm]},
  PlotRange->{{1.01, 5}, {0.01, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5599880089328117`*^9}]
}, Open  ]],

Cell[TextData[{
 "The sensitivity is negative and increases towards zero for larger ",
 StyleBox["k",
  FontSlant->"Italic"],
 " values, due to the 1/",
 StyleBox["k",
  FontSlant->"Italic"],
 " behaviour of the outbreak threshold. Thus whilst sensitivity increases for \
smaller ",
 StyleBox["k",
  FontSlant->"Italic"],
 ", it does not cause as rapid an increase in the threshold level as changing \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]]],
 " by a similar proportion."
}], "Text",
 CellChangeTimes->{3.560249254187471*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bibliography for Supplementary Material", "Section",
 CellChangeTimes->{{3.561368465280438*^9, 3.561368473774373*^9}}],

Cell[CellGroupData[{

Cell["\<\
Anderson RM, May RM (1991) Infectious Diseases of Humans. Dynamics and \
Control. Oxford: Oxford University Press.\
\>", "Item",
 CellChangeTimes->{{3.561368774263144*^9, 3.561368776064858*^9}}],

Cell["\<\
Grimmett GR, Stirzaker DR (2001) Probability and Random Processes. Oxford: \
Oxford University Press, third edition.\
\>", "Item",
 CellChangeTimes->{{3.561368792819408*^9, 3.561368794208005*^9}, {
  3.561369161675893*^9, 3.5613691618182*^9}}],

Cell["\<\
Hubbarde JE, Wild G, Wahl LM (2007) Fixation probabilities when generation \
times are variable: The burst\[Dash]death model. Genetics 176: \
1703\[Dash]1712.\
\>", "Item",
 CellChangeTimes->{{3.561368799240485*^9, 3.561368819574099*^9}, {
  3.561369159553158*^9, 3.561369159690304*^9}}],

Cell["\<\
May RM, Gupta S, McLean AR (2001) Infectious disease dynamics: What \
characterizes a successful invader? Philos Trans R Soc Lond B Biol Sci 356: \
899\[Dash]910.\
\>", "Item",
 CellChangeTimes->{{3.561368819858018*^9, 3.561368821270452*^9}}],

Cell["\<\
Allen L (2008) An introduction to stochastic epidemic models. In: Brauer F, \
van den Driessche P, Wu J, editors, Mathematical Epidemiology, \
Berlin/Heidelberg: Springer, volume 1945 of Lecture Notes in Mathematics, \
chapter 3. pp. 81\[Dash]130.\
\>", "Item",
 CellChangeTimes->{{3.5613688268259*^9, 3.5613688310437937`*^9}, {
  3.5613688671952972`*^9, 3.561368867197867*^9}, {3.561369171189712*^9, 
  3.5613691721619043`*^9}}],

Cell["\<\
Kaplan NL, Hudson RR, Langley CH (1989) The \
\[OpenCurlyDoubleQuote]hitchhiking effect\[CloseCurlyDoubleQuote] revisited. \
Genetics 123: 887\[Dash]899.\
\>", "Item",
 CellChangeTimes->{{3.5613688674005423`*^9, 3.561368871542111*^9}, {
  3.5613691511316566`*^9, 3.5613691512500134`*^9}}],

Cell["\<\
Barton NH (2000) Genetic hitchhiking. Philos Trans R Soc Lond B Biol Sci 355: \
1553\[Dash]1562.\
\>", "Item",
 CellChangeTimes->{{3.561368871800214*^9, 3.5613688774532833`*^9}}],

Cell["\<\
Desai MM, Fisher DS (2007) Beneficial mutation-selection balance and the \
effect of linkage on positive selection. Genetics 176: 1759\[Dash]1798.\
\>", "Item",
 CellChangeTimes->{
  3.5613688776635227`*^9, {3.561368982544753*^9, 3.5613689825469646`*^9}}],

Cell["\<\
Lloyd-Smith JO, Schreiber SJ, Kopp PE, Getz WM (2005) Superspreading and the \
effect of individual variation on disease emergence. Nature 438: 355\[Dash] \
359.\
\>", "Item",
 CellChangeTimes->{
  3.5613689827720222`*^9, {3.561369070348899*^9, 3.561369070350815*^9}}],

Cell["\<\
R Development Core Team (2008). R: A Language and Environment for Statistical \
Computing. R Foundation for Statistical Computing, Vienna, Austria.\
\>", "Item",
 CellChangeTimes->{{3.5613690706218843`*^9, 3.5613691309901857`*^9}}],

Cell["\<\
Caswell H (2001) Matrix Population Methods. Sinauer Associates, 2nd edition.\
\>", "Item",
 CellChangeTimes->{{3.56136913127448*^9, 3.5613691459782124`*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1334, 871},
WindowMargins->{{Automatic, 136}, {48, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 312, 5, 114, "Title",
 Evaluatable->False],
Cell[894, 29, 736, 24, 129, "Subtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1655, 57, 242, 4, 100, "Section"],
Cell[1900, 63, 903, 18, 107, "Text"],
Cell[2806, 83, 269, 8, 68, "Input"],
Cell[3078, 93, 3109, 90, 271, "Text"],
Cell[CellGroupData[{
Cell[6212, 187, 350, 10, 49, "Input"],
Cell[6565, 199, 520, 10, 32, "Message"],
Cell[7088, 211, 357, 11, 67, "Output"]
}, Open  ]],
Cell[7460, 225, 1617, 46, 135, "Text"],
Cell[CellGroupData[{
Cell[9102, 275, 426, 11, 49, "Input"],
Cell[9531, 288, 184, 5, 42, "Output"]
}, Open  ]],
Cell[9730, 296, 4942, 137, 406, "Text"],
Cell[CellGroupData[{
Cell[14697, 437, 383, 9, 40, "Input"],
Cell[15083, 448, 148, 3, 40, "Output"]
}, Open  ]],
Cell[15246, 454, 922, 25, 84, "Text"],
Cell[CellGroupData[{
Cell[16193, 483, 120, 1, 51, "Subsection"],
Cell[16316, 486, 1617, 56, 152, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17970, 547, 116, 1, 51, "Subsection"],
Cell[18089, 550, 291, 5, 62, "Text"],
Cell[18383, 557, 274, 7, 68, "Input"],
Cell[18660, 566, 953, 36, 66, "Text"],
Cell[CellGroupData[{
Cell[19638, 606, 386, 12, 42, "Input"],
Cell[20027, 620, 518, 10, 32, "Message"],
Cell[20548, 632, 331, 10, 85, "Output"]
}, Open  ]],
Cell[20894, 645, 602, 18, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21533, 668, 103, 1, 51, "Subsection"],
Cell[21639, 671, 2448, 79, 186, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24136, 756, 341, 6, 53, "Section"],
Cell[24480, 764, 2731, 63, 405, "Text"],
Cell[CellGroupData[{
Cell[27236, 831, 513, 15, 70, "Input"],
Cell[27752, 848, 481, 14, 66, "Output"]
}, Open  ]],
Cell[28248, 865, 234, 4, 39, "Text"],
Cell[CellGroupData[{
Cell[28507, 873, 623, 15, 70, "Input"],
Cell[29133, 890, 462, 13, 81, "Output"]
}, Open  ]],
Cell[29610, 906, 103, 1, 39, "Text"],
Cell[29716, 909, 405, 12, 67, "Input"],
Cell[30124, 923, 908, 24, 62, "Text"],
Cell[31035, 949, 209, 5, 42, "Input"],
Cell[CellGroupData[{
Cell[31269, 958, 903, 23, 65, "Input"],
Cell[32175, 983, 4150, 78, 345, "Output"]
}, Open  ]],
Cell[36340, 1064, 2608, 60, 197, "Text"],
Cell[CellGroupData[{
Cell[38973, 1128, 804, 22, 65, "Input"],
Cell[39780, 1152, 4693, 85, 345, "Output"]
}, Open  ]],
Cell[44488, 1240, 301, 8, 39, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[44826, 1253, 325, 6, 86, "Section"],
Cell[CellGroupData[{
Cell[45176, 1263, 111, 1, 51, "Subsection"],
Cell[45290, 1266, 240, 7, 39, "Text"],
Cell[45533, 1275, 335, 11, 66, "Input"],
Cell[45871, 1288, 193, 6, 62, "Text"],
Cell[CellGroupData[{
Cell[46089, 1298, 567, 16, 66, "Input"],
Cell[46659, 1316, 489, 10, 32, "Message"],
Cell[47151, 1328, 481, 16, 64, "Output"]
}, Open  ]],
Cell[47647, 1347, 285, 6, 39, "Text"],
Cell[47935, 1355, 1002, 30, 67, "Input"],
Cell[48940, 1387, 1108, 28, 84, "Text"],
Cell[CellGroupData[{
Cell[50073, 1419, 1733, 41, 88, "Input"],
Cell[51809, 1462, 22462, 400, 363, "Output"]
}, Open  ]],
Cell[74286, 1865, 778, 20, 84, "Text"],
Cell[CellGroupData[{
Cell[75089, 1889, 252, 7, 49, "Input"],
Cell[75344, 1898, 539, 10, 32, "Message"],
Cell[75886, 1910, 280, 8, 66, "Output"]
}, Open  ]],
Cell[76181, 1921, 284, 8, 39, "Text"],
Cell[CellGroupData[{
Cell[76490, 1933, 358, 11, 70, "Input"],
Cell[76851, 1946, 171, 5, 67, "Output"]
}, Open  ]],
Cell[77037, 1954, 680, 17, 62, "Text"],
Cell[77720, 1973, 216, 7, 70, "Input"],
Cell[CellGroupData[{
Cell[77961, 1984, 1530, 42, 111, "Input"],
Cell[79494, 2028, 8958, 164, 558, "Output"]
}, Open  ]],
Cell[88467, 2195, 572, 16, 62, "Text"],
Cell[CellGroupData[{
Cell[89064, 2215, 1299, 36, 87, "Input"],
Cell[90366, 2253, 255, 6, 40, "Output"]
}, Open  ]],
Cell[90636, 2262, 528, 12, 75, "Text"],
Cell[91167, 2276, 74110, 1251, 780, "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],
Cell[165280, 3529, 1344, 38, 84, "Text"],
Cell[166627, 3569, 63012, 1062, 780, "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],
Cell[229642, 4633, 72563, 1237, 780, "Output",
 CellGroupingRules->{FrontEnd`Private`GroupTogetherGrouping, 999.}],
Cell[302208, 5872, 299, 6, 39, "Text"],
Cell[302510, 5880, 310, 10, 69, "Input"],
Cell[302823, 5892, 523, 14, 62, "Text"],
Cell[CellGroupData[{
Cell[303371, 5910, 1350, 37, 87, "Input"],
Cell[304724, 5949, 307, 7, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305068, 5961, 1374, 37, 87, "Input"],
Cell[306445, 6000, 253, 6, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306735, 6011, 1398, 37, 87, "Input"],
Cell[308136, 6050, 252, 6, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308425, 6061, 1397, 37, 87, "Input"],
Cell[309825, 6100, 271, 6, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[310133, 6111, 1398, 37, 87, "Input"],
Cell[311534, 6150, 253, 6, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311824, 6161, 1401, 37, 87, "Input"],
Cell[313228, 6200, 272, 6, 40, "Output"]
}, Open  ]],
Cell[313515, 6209, 168, 3, 39, "Text"],
Cell[CellGroupData[{
Cell[313708, 6216, 3325, 83, 294, "Input"],
Cell[317036, 6301, 2956, 75, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320029, 6381, 493, 14, 69, "Input"],
Cell[320525, 6397, 338, 11, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320900, 6413, 283, 8, 40, "Input"],
Cell[321186, 6423, 483, 11, 40, "Output"]
}, Open  ]],
Cell[321684, 6437, 292, 7, 39, "Text"],
Cell[321979, 6446, 494, 16, 69, "Input"],
Cell[322476, 6464, 426, 7, 62, "Text"],
Cell[322905, 6473, 1320, 39, 87, "Input"],
Cell[CellGroupData[{
Cell[324250, 6516, 673, 18, 71, "Input"],
Cell[324926, 6536, 5235, 92, 360, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[330198, 6633, 627, 18, 71, "Input"],
Cell[330828, 6653, 5256, 93, 371, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336121, 6751, 627, 18, 71, "Input"],
Cell[336751, 6771, 5252, 92, 366, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[342052, 6869, 108, 1, 51, "Subsection"],
Cell[CellGroupData[{
Cell[342185, 6874, 3150, 105, 216, "Subsubsection"],
Cell[345338, 6981, 240, 8, 71, "Input"],
Cell[CellGroupData[{
Cell[345603, 6993, 1314, 38, 134, "Input"],
Cell[346920, 7033, 96174, 1617, 558, "Output"]
}, Open  ]],
Cell[443109, 8653, 1503, 50, 129, "Text"],
Cell[CellGroupData[{
Cell[444637, 8707, 1315, 38, 135, "Input"],
Cell[445955, 8747, 56038, 970, 558, "Output"]
}, Open  ]],
Cell[502008, 9720, 560, 18, 62, "Text"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[502629, 9745, 124, 1, 53, "Section"],
Cell[CellGroupData[{
Cell[502778, 9750, 204, 4, 30, "Item"],
Cell[502985, 9756, 253, 5, 30, "Item"],
Cell[503241, 9763, 297, 6, 30, "Item"],
Cell[503541, 9771, 252, 5, 50, "Item"],
Cell[503796, 9778, 439, 8, 50, "Item"],
Cell[504238, 9788, 298, 6, 30, "Item"],
Cell[504539, 9796, 188, 4, 30, "Item"],
Cell[504730, 9802, 265, 5, 30, "Item"],
Cell[504998, 9809, 278, 6, 30, "Item"],
Cell[505279, 9817, 241, 4, 30, "Item"],
Cell[505523, 9823, 167, 3, 30, "Item"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
